/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  /** @constructor */
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  /** @constructor */
  Instance: function(module, info) {
    // TODO: use the module somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(sb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(){throw new Error("abort")}function q(m){h[2]=m}function r(){return h[2]}function qb(rb){var s=rb.a;var t=s.a;var u=t.buffer;t.grow=ob;var v=new Int8Array(u);var w=new Int16Array(u);var x=new Int32Array(u);var y=new Uint8Array(u);var z=new Uint16Array(u);var A=new Uint32Array(u);var B=new Float32Array(u);var C=new Float64Array(u);var D=Math.imul;var E=Math.fround;var F=Math.abs;var G=Math.clz32;var H=Math.min;var I=Math.max;var J=Math.floor;var K=Math.ceil;var L=Math.trunc;var M=Math.sqrt;var N=s.b;var O=s.c;var P=s.d;var Q=s.e;var R=s.f;var S=s.g;var T=s.h;var U=s.i;var V=s.j;var W=s.k;var X=s.l;var Y=s.m;var Z=s.n;var _=s.o;var $=s.p;var aa=s.q;var ba=s.r;var ca=s.s;var da=s.t;var ea=s.u;var fa=s.v;var ga=s.w;var ha=s.x;var ia=s.y;var ja=s.z;var ka=s.A;var la=s.B;var ma=s.C;var na=s.D;var oa=s.E;var pa=s.F;var qa=s.G;var ra=s.H;var sa=s.I;var ta=s.J;var ua=s.K;var va=s.L;var wa=s.M;var xa=s.N;var ya=s.O;var za=s.P;var Aa=s.Q;var Ba=s.R;var Ca=s.S;var Da=s.T;var Ea=s.U;var Fa=s.V;var Ga=s.W;var Ha=s.X;var Ia=s.Y;var Ja=s.Z;var Ka=s._;var La=s.$;var Ma=s.aa;var Na=s.ba;var Oa=s.ca;var Pa=s.da;var Qa=s.ea;var Ra=s.fa;var Sa=s.ga;var Ta=s.ha;var Ua=s.ia;var Va=s.ja;var Wa=s.ka;var Xa=s.la;var Ya=s.ma;var Za=s.na;var _a=s.oa;var $a=s.pa;var ab=s.qa;var bb=s.ra;var cb=s.sa;var db=535552;var eb=0;var fb=0;var gb=0;var hb=0;
// EMSCRIPTEN_START_FUNCS
function PJ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0,P=0,R=E(0),T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=E(0),za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=E(0),Ta=0;ca=db-32|0;db=ca;da=ca+28|0;x[da>>2]=49708;x[da>>2]=49608;e=OJ(ca+20|0);g=OJ(ca+12|0);ea=b;ka=c;la=x[e>>2];Aa=y[e+4|0];ma=x[g>>2];Ba=y[g+4|0];b=0;M=db-96|0;db=M;d=a;na=a+24604|0;a=na;a:{if(!x[a+16>>2]){break a}c=x[a+20>>2];if(c>>>0>4|!(1<<c&22)){break a}a=x[a+28>>2];if(a>>>0>4){break a}b=23>>>a&1}if(!b){a=M+80|0;iN(a,9031,12860,220,45);b=db-48|0;db=b;c=Tb(b+24|0,17331);x[23549]=0;S(5,b+12|0,1,17004);e=x[23549];x[23549]=0;b:{c:{d:{e:{if((e|0)!=1){x[23549]=0;S(2,b+36|0,c|0,b+12|0);e=x[23549];x[23549]=0;if((e|0)==1){break e}x[23549]=0;S(820,a|0,1,b+36|0);a=x[23549];x[23549]=0;if((a|0)!=1){break b}a=N()|0;tb(b+36|0);break d}a=N()|0;break c}a=N()|0}tb(b+12|0)}tb(c);Q(a|0);p()}tb(b+36|0);tb(b+12|0);tb(c);db=b+48|0}oa=d+8204|0;pa=d+397452|0;qa=d+397448|0;_=d+393352|0;H=d+397456|0;W=d+12|0;Ca=d+1074376|0;while(1){f:{g:{a=x[d+480208>>2];if(!(!ea|a&512)){h:{if(x[d+1074380>>2]){break h}b=a|512;i:{if(a&256){break i}m=db-48|0;db=m;C=db-32|0;db=C;l=d+1074312|0;c=d+1074992|0;h=d+1298264|0;o=d+1074424|0;j=d+484360|0;i=d+1074448|0;s=d+1074376|0;a=x[d+1074392>>2];n=d+480210|0;j:{k:{l:while(1){m:{a=a+1|0;x[d+1074392>>2]=a;if(al(s)>>>0>a>>>0){break m}AO(C+30|0,x[d+480180>>2],z[d+480188>>1],s,(x[d+480208>>2]&524288)>>>19|0);n:{o:{p:{q:{r:{if(y[d+480208|0]&32){g=x[d+484348>>2];f=x[d+484344>>2];a=z[d+1074446>>1];break r}a=65535;b=x[d+484360>>2];q=y[d+484376|0];e=Wb(b,q);g=x[e>>2];f=Ic(g,x[e+4>>2]);e=z[d+1074448>>1];if(f>>>0>e>>>0){a=z[_b(g,e)>>1]}w[d+1074446>>1]=a;s:{t:{f=x[d+484344>>2];g=x[d+484348>>2];k=a&65535;if(qf(f,g)>>>0<=k>>>0){break t}k=Yb(f,k);if(Kb(x[k>>2],x[k+4>>2])){break t}k=0;break s}k=1}while(1){u:{v:{if(!k){a=65534;w[d+1074446>>1]=65534;break v}w:{x:{y:{k=a&65535;if(qf(f,g)>>>0<=k>>>0){z:{A:{if((k|0)==65535){g=Wb(b,q);break A}g=Wb(b,q);if(Ic(x[g>>2],x[g+4>>2])>>>0>(e&65535)>>>0){break z}}k=x[g>>2];a=z[g+28>>1];if(a){f=Ic(k,x[g+4>>2]);break x}b=e&65535;f=Ic(k,x[g+4>>2]);if(!b|f>>>0<b>>>0){break y}while(1){a=b;e=e-1|0;r=e&65535;if(!r){break y}b=a-1|0;if(z[_b(k,r)>>1]!=65535){continue}break}break x}e=e+1|0;w[i>>1]=e;break w}w[d+1074450>>1]=e;break r}a=0}w[d+1074448>>1]=a;x[d+480208>>2]=x[d+480208>>2]&-524289;while(1){b=a&65535;if(b>>>0>=f>>>0){break q}if(z[_b(k,b)>>1]==65534){a=a+1|0;w[i>>1]=a;continue}break}if(!Dq(g,b)){break q}e=z[d+1074448>>1];b=x[d+484360>>2];q=y[d+484376|0];g=Wb(b,q)}a=65535;f=Ic(x[g>>2],x[g+4>>2]);g=e&65535;if(f>>>0>g>>>0){a=z[_b(x[Wb(b,q)>>2],g)>>1]}w[d+1074446>>1]=a;f=x[d+484344>>2];g=x[d+484348>>2];k=a&65535;if(qf(f,g)>>>0<=k>>>0){break v}k=Yb(f,k);if(!Kb(x[k>>2],x[k+4>>2])){break u}}k=1;continue}k=0;continue}}b=a&65535;if(!se(f,g,b)){break k}a=x[o>>2];if(a>>>0>=A[Yb(f,b)+12>>2]){x[o>>2]=0;a=0}if(x[d+480208>>2]&32?x[d+480272>>2]!=-1:0){break n}if(!kt(h,z[i>>1],a,Qp(C+20|0,c),y[C+30|0])){break n}a=x[d+480272>>2];if(a){if((a|0)>0){x[d+480272>>2]=a-1}go(h,1);kt(h,z[i>>1],x[o>>2],Qp(C+20|0,c),y[C+30|0]);break n}if(!(y[n|0]&64)){break q}if(RO(h,i,o)){break o}x[d+1074424>>2]=0;x[d+1074428>>2]=0;x[d+1074448>>2]=0;b=bj(x[d+484360>>2],x[d+484364>>2])-1|0;a=y[d+484376|0];if((b|0)>(a|0)){break p}oj(j,0)}go(h,1);break k}oj(j,a+1&255);go(h,1)}a=0;while(1){if((a|0)==256){XM(d);x[d+1074416>>2]=x[d+480196>>2];x[d+1074420>>2]=x[d+480204>>2];x[d+1074456>>2]=x[d+480200>>2];a=z[d+1074448>>1];w[d+1074450>>1]=a;b=x[d+1074424>>2];x[d+1074428>>2]=b;e=Wb(x[d+484360>>2],y[d+484376|0]);g=x[e>>2];if(Ic(g,x[e+4>>2])>>>0>a>>>0){Qa=d,Ra=z[_b(g,a)>>1],w[Qa+1074446>>1]=Ra}kt(h,a,b,Qp(C+20|0,c),y[C+30|0]);if(!se(x[d+484344>>2],x[d+484348>>2],z[d+1074446>>1])){break k}}else{ko((D(a,872)+d|0)+1074992|0,d,a&65535,134217728);a=a+1|0;continue}break}}zO(d,s,(x[d+480208>>2]&32)>>>5|0);a=Yb(x[d+484344>>2],z[d+1074446>>1]);e=$c(x[a>>2],x[x[a+48>>2]+12>>2],x[d+1074424>>2],0);g=c+D(z[d+480188>>1],872)|0;a=c;while(1){if((a|0)==(g|0)){B:{C:{a=x[d+484344>>2];b=z[d+1074446>>1];if(Gm(a,x[d+484348>>2],b)){a=Yb(a,b);e=x[a+16>>2];b=x[a+20>>2];if(vO(e,b)){break C}}x[d+1074408>>2]=x[d+480216>>2];b=x[d+480220>>2];break B}x[d+1074408>>2]=e}x[d+1074412>>2]=b;if(!y[C+30|0]){break m}a=x[d+1074416>>2];x[d+1074392>>2]=a;continue l}Fb(C+20|0,l,82);D:{if(!Ib(x[x[C+20>>2]>>2],x[C+24>>2])|y[a+805|0]!=1){break D}b=y[e+3|0];if((b|0)!=2&(b|0)!=3){break D}Qa=a,Ra=Rg(d,y[a+800|0],w[a+772>>1],x[a+704>>2]),x[Qa+700>>2]=Ra}Fb(C+20|0,l,91);E:{if(!Ib(x[x[C+20>>2]>>2],x[C+24>>2])){break E}if(Tc(y[e|0])){break E}b=y[a+788|0];if(!Tc(b)|y[a+791|0]!=19){break E}f=y[a+793|0];if((f&240)!=208|A[d+1074416>>2]>(f&15)>>>0){break E}Qa=a,Ra=Rg(d,b,w[a+772>>1],0),x[Qa+700>>2]=Ra}Fb(C+20|0,l,92);F:{if(!Ib(x[x[C+20>>2]>>2],x[C+24>>2])){break F}Fb(C+12|0,l,5);if(Ib(x[x[C+12>>2]>>2],x[C+16>>2])|x[d+1074416>>2]!=1|y[a+791|0]!=17){break F}v[C+20|0]=1;Qa=d,Ra=D(y[af(C+20|0,a+793|0)|0],1e4),x[Qa+1074420>>2]=Ra}b=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);v[a+788|0]=b;v[a+789|0]=b>>>8;v[a+790|0]=b>>>16;v[a+791|0]=b>>>24;b=y[e+4|0]|y[e+5|0]<<8;v[a+792|0]=b;v[a+793|0]=b>>>8;b=x[a+676>>2];x[a+20>>2]=x[a+672>>2];x[a+24>>2]=b;x[a+88>>2]=x[a+88>>2]&-393217;Fb(C+20|0,l,21);if(!Ib(x[x[C+20>>2]>>2],x[C+24>>2])){v[a+831|0]=0}x[a+860>>2]=0;v[a+805|0]=0;e=e+6|0;a=a+872|0;continue}}break}e=x[d+1074416>>2];if(!e){x[d+1074416>>2]=1;e=1}b=x[d+480208>>2];c=x[d+1074392>>2];G:{H:{if(c){a=b&-4097;x[d+480208>>2]=a;g=x[d+480180>>2];if(g&1048580|!(b&2097152)&(g|0)==1){break G}if(al(s)>>>0<=c>>>0){break G}if(!((c>>>0)%(x[d+1074400>>2]+e>>>0)|0)){break H}break G}a=b&-528385}x[d+480208>>2]=a|4096}q=0;j=db-16|0;db=j;w[d+1074444>>1]=65535;a=d+1074436|0;x[a>>2]=-1;x[a+4>>2]=-1;T=d+1075809|0;r=d+1074312|0;O=d+1074376|0;J=d+480209|0;V=d+480210|0;while(1){if(z[d+480188>>1]<=q>>>0){I:{if(!(y[d+480209|0]&16)){break I}if(!nO(d,O,Wb(x[d+484360>>2],y[d+484376|0]),1)){break I}x[d+480208>>2]=x[d+480208>>2]|524288}db=j+16|0}else{n=D(q,872)+d|0;l=n+1075785|0;b=y[l|0];i=n+1075784|0;k=y[i|0];K=n+1075781|0;c=y[K|0];a=x[d+1074392>>2];g=x[d+1074400>>2];f=x[d+1074416>>2];I=n+1075782|0;h=y[I|0];o=n+1075783|0;t=y[o|0];e=az(h,t);G=n+1075843|0;v[G|0]=x[d+480208>>2]>>>12&1|y[G|0]&254;f=(a>>>0)%(g+f>>>0)|0;U=n+1075780|0;a=y[U|0];J:{K:{L:{if((a|0)==252){s=Qj(h,k);L=Qj(t,b);a=252;if((c-1&255)>>>0>249){break L}g=x[(D(c,160)+d|0)+906140>>2];if(!g){break L}ib[x[x[g>>2]+44>>2]](g,s,E(E(L>>>0)/E(999)));a=y[U|0]}if((a&255)==251){break K}}if(B[n+1075852>>2]==E(0)|t){break J}}s=x[d+480208>>2]&4096;M:{if(!s){g=y[n+1075862|0];break M}g=y[K|0];v[n+1075862|0]=g}if((g-1&255)>>>0>249){break J}L=(D(g&255,160)+d|0)+906140|0;g=x[L>>2];if(!g){break J}N:{if(!s){a=z[n+1075860>>1];break N}a=Ty(y[I|0],y[i|0]);w[n+1075860>>1]=a;R=E(E(Ty(y[o|0],y[l|0])>>>0)/E(999));B[n+1075856>>2]=R;Qa=n+1075852|0,Sa=E(E(R-E(ib[x[x[g>>2]+48>>2]](g,a)))/E(al(O)>>>0)),B[Qa>>2]=Sa;g=x[L>>2]}i=a;a=(x[d+1074392>>2]+1|0)==(al(O)|0);ib[x[x[g>>2]+(a?44:104)>>2]](g,i,B[(a?n+1075856|0:n+1075852|0)>>2]);a=y[U|0]}i=n+1074992|0;if(bO(a&255)){b=db-16|0;db=b;w[b+12>>1]=0;x[b+8>>2]=0;a=Wh(b+8|0);c=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[i+788|0]=c;v[i+789|0]=c>>>8;v[i+790|0]=c>>>16;v[i+791|0]=c>>>24;a=y[a+4|0]|y[a+5|0]<<8;v[i+792|0]=a;v[i+793|0]=a>>>8;db=b+16|0;t=0;k=0;h=0;c=0;e=0;b=0}O:{if(!(y[J|0]&16)){IN(d,i);break O}if(!c){break O}x[n+1075752>>2]=0}P:{Q:{if((t|0)==33){Fb(j+8|0,r,30);a=b>>>4|0;Ky(d,q&65535,a+(b&15)|0,Ib(x[x[j+8>>2]>>2],x[j+12>>2]));break Q}a=0;if((t-19&255)>>>0>1){break Q}R:{if(!(!(x[d+480180>>2]&16777250)|b)){b=y[n+1075825|0];break R}v[n+1075825|0]=b}g=b&240;if((g|0)==208){g=b&15;if(!g){g=x[d+480180>>2];if(g&16777248){a=1;break Q}if((g|0)!=2){break Q}break P}if(g>>>0>=x[d+1074400>>2]+x[d+1074416>>2]>>>0){Fb(j+8|0,r,14);a=g;if(!Ib(x[x[j+8>>2]>>2],x[j+12>>2])){break Q}if(!c){break P}v[n+1075795|0]=c;break P}a=g;break Q}if(!(x[d+480208>>2]&4096)|(g|0)!=224){break Q}g=x[d+480180>>2];if(x[d+1074396>>2]?g&16777250:0){break Q}l=b&15;if(!(g&2?l:1)){break Q}x[d+1074396>>2]=l+1}P=b&15;g=x[d+480180>>2]==16&(t|0)==19&(b&240)==208;L=g?0:a;S:{if(!L|y[U|0]!=255|y[I|0]!=2){break S}Fb(j+8|0,r,74);if(!Ib(x[x[j+8>>2]>>2],x[j+12>>2])){break S}v[I|0]=0}l=P|144;a=x[d+1074392>>2];Fb(j+8|0,r,72);T:{if(Ib(x[x[j+8>>2]>>2],x[j+12>>2])){s=0;if(L>>>0>=A[d+1074416>>2]){break T}}Fb(j+8|0,r,88);s=(f|0)==(L|0)|(a|0)==(L|0);if(!(!L|!Ib(x[x[j+8>>2]>>2],x[j+12>>2]))){break T}s=(a|0)==(L|0)}b=g?l:b;a=j+8|0;Fb(a,r,44);g=y[G|0];Qa=G,Ra=(Ib(x[x[j+8>>2]>>2],x[j+12>>2])?g&252|(f|0)==(L|0):g)&253,v[Qa|0]=Ra;Fb(a,r,66);g=(!L|Ib(x[x[j+8>>2]>>2],x[j+12>>2])^1)&e;U:{V:{W:{if(!(x[d+1074392>>2]|(!(y[V|0]&32)|!c))){x[n+1075652>>2]=0;if(s){e=y[U|0];break W}if(!si(x[i+8>>2],x[i+12>>2])){break U}v[n+1075795|0]=c;if(z[d+480190>>1]<c>>>0){break U}a=D(c,104)+d|0;x[n+1075680>>2]=z[a+484410>>1];w[n+1075764>>1]=v[a+484417|0];break U}if(!s){break U}e=y[U|0];if(!c){break V}}v[n+1075795|0]=c}X:{Y:{a=e&255;if(!Tc(a)){break Y}Fb(j+8|0,r,67);if(!Ib(x[x[j+8>>2]>>2],x[j+12>>2])){break Y}f=w[n+1075762>>1];Z:{if(!c|g){break Z}l=_y(d,a,c);if(!l){break Z}f=v[_j(d,l)+36|0]}e=(a+f|0)-132>>>0>=4294967176?e:0;break X}if(!(x[d+480180>>2]&25165856)){break X}f=z[d+480192>>1];if(!f){break X}if(a){a=Tc(a)}else{a=1}if(!a){break X}a=c;_:{if(!a){a=y[n+1075796|0];if(!a){break _}}if(x[((a<<2)+d|0)+900380>>2]?a>>>0<=f>>>0:0){break X}e=0}c=0}if(!((t|0)!=25|b)){Fb(j+8|0,r,55);a=Ib(x[x[j+8>>2]>>2],x[j+12>>2]);c=a?0:c;e=a?0:e}Fb(j+8|0,r,65);f=(c|0)!=0;a=e&255;o=!a;X=Ib(x[x[j+8>>2]>>2],x[j+12>>2]);u=1;$:{if(x[d+480180>>2]&16777248){break $}Fb(j+8|0,r,107);if(Ib(x[x[j+8>>2]>>2],x[j+12>>2])){break $}Fb(j,r,85);u=0;if(!Ib(x[x[j>>2]>>2],x[j+4>>2])){break $}if(si(x[i+8>>2],x[i+12>>2])){break $}u=1;l=x[n+1075096>>2];if(!l){break $}u=Sd(x[l>>2],x[l+20>>2])^1}o=f&o;l=f&X;aa:{ba:{ca:{da:{ea:{fa:{if(!(x[d+480180>>2]&1048580)){break fa}ga:{if((a|0)!=255){break ga}if(!(!((h|0)==1|c)&(t|0)!=13)){Fb(j+8|0,r,55);if(Ib(x[x[j+8>>2]>>2],x[j+12>>2])){break ga}}f=x[n+1075648>>2];if(v[f+60|0]&1?f:0){break ga}x[n+1075680>>2]=0;a=n+1075080|0;x[a>>2]=x[a>>2]|2097152;ha:{if(!(x[d+480208>>2]&4096)){break ha}Fb(j+8|0,r,86);if(!Ib(x[x[j+8>>2]>>2],x[j+12>>2])){break ha}x[a>>2]=x[a>>2]|4096}c=0;e=0;a=0;f=0;o=1;if(l){break ba}break aa}Fb(j+8|0,r,59);if(!Ib(x[x[j+8>>2]>>2],x[j+12>>2])|x[d+480208>>2]&4096){break fa}ia:{if(!a){e=y[n+1075789|0]-y[n+1075762|0]|0;break ia}if(a>>>0>250){u=0;l=1;e=0;break ia}ja:{if(c){break ja}Fb(j+8|0,r,98);if(!Ib(x[x[j+8>>2]>>2],x[j+12>>2])){break ja}c=0;break ia}u=1;l=1}f=e;g=0;break ea}f=0;if(!o){break da}}Fb(j+8|0,r,65);if(!Ib(x[x[j+8>>2]>>2],x[j+12>>2])){break ca}e=f;f=1}a=e;o=1;if(l){break ba}break aa}e=f;f=1;o=l}ka:{la:{if(!z[d+480192>>1]){if(z[d+480190>>1]<c>>>0){break ka}a=(D(c,104)+d|0)+484380|0;break la}a=x[n+1075096>>2];if(!a){break ka}}ma:{if(w[a+34>>1]<0){break ma}if(x[d+480180>>2]==2){if(!Sd(x[a>>2],x[a+20>>2])){break ma}}x[n+1075680>>2]=z[a+30>>1]}if(!o){break ka}Yp(i,z[a+28>>1],d)}a=e}Fb(j+8|0,r,71);if(!(!Ib(x[x[j+8>>2]>>2],x[j+12>>2])|!c)){v[n+1075831|0]=32}na:{if(!z[d+480192>>1]){break na}Fb(j+8|0,r,100);if(!Ib(x[x[j+8>>2]>>2],x[j+12>>2])|!c){break na}if(Tc(a&255)){break na}e=x[d+480208>>2];oa:{if(g){if(e&8){break oa}break na}if(!(e&4)){break na}}hm(i);x[n+1075688>>2]=65536;e=n+1075080|0;x[e>>2]=x[e>>2]|2097152}if(f){Fb(j+8|0,r,11);pa:{qa:{ra:{if(!(Ib(x[x[j+8>>2]>>2],x[j+12>>2])|x[d+480180>>2]==268435456)){e=z[d+480192>>1];break ra}Fb(j+8|0,r,87);f=0;if(Ib(x[x[j+8>>2]>>2],x[j+12>>2])){f=si(x[i+8>>2],x[i+12>>2])^1}e=z[d+480192>>1];sa:{if(e){if(c>>>0>e>>>0){break qa}if(x[n+1075648>>2]!=x[((c<<2)+d|0)+900380>>2]|f){break sa}break qa}if((f^-1)&x[n+1075096>>2]==((D(c,104)+d|0)+484380|0)){break pa}}a=y[n+1075789|0]}if(!(e&65535)){break pa}}if(!(x[d+480180>>2]&1048588)){break pa}hm(i);v[n+1075810|0]=0;x[n+1075748>>2]=0;x[n+1075688>>2]=65536;e=n+1075080|0;x[e>>2]=x[e>>2]&-2101249|2097152;Fb(j+8|0,r,86);if(!Ib(x[x[j+8>>2]>>2],x[j+12>>2])){break pa}x[e>>2]=x[e>>2]&-2049}c=u?c:0}l=a&255;ta:{if(l>>>0<251){break ta}Fb(j+8|0,r,50);ua:{if(!Ib(x[x[j+8>>2]>>2],x[j+12>>2])|!c){break ua}e=_y(d,y[n+1075791|0],c);if(!e){break ua}e=D(e,104)+d|0;if(w[e+484414>>1]<0){break ua}x[n+1075680>>2]=z[e+484410>>1]}Fb(j+8|0,r,100);if(Qa=Ib(x[x[j+8>>2]>>2],x[j+12>>2]),Ra=0,Ta=x[d+480208>>2]&4,Ta?Qa:Ra){break ta}c=0}e=Tc(l);if(e){v[n+1075794|0]=a;v[n+1075791|0]=a;if(!g){KN(d,q&65535,c,l,0)}iQ(i)}va:{wa:{xa:{ya:{za:{if(c){f=n+1075096|0;o=x[f>>2];Pp(d,i,c,g,1,1);a=x[f>>2];Aa:{if(!a|!(y[a+35|0]&2)){break Aa}u=x[d+1298300>>2];if(!ud(u)){break Aa}tz(u,q&65535,a+68|0)}Ba:{Ca:{if(x[d+480180>>2]==1){if(!g){break Ca}Fb(j+8|0,r,85);if(!Ib(x[x[j+8>>2]>>2],x[j+12>>2])){break Ca}break Ba}Fb(j+8|0,r,50);if((e|Ib(x[x[j+8>>2]>>2],x[j+12>>2])^1)!=1){break Ba}}v[n+1075795|0]=0}Fb(j+8|0,r,42);if(Ib(x[x[j+8>>2]>>2],x[j+12>>2])){if(!e|(o|0)==x[f>>2]){break ya}break za}if(x[d+480180>>2]&16777248){a=0;if(e&(o|0)!=x[f>>2]){break xa}}Fb(j+8|0,r,107);Da:{if(!Ib(x[x[j+8>>2]>>2],x[j+12>>2])|(!(e^1|g)|(o|0)==x[f>>2])){break Da}a=n+1075068|0;if(A[a>>2]>=A[i+4>>2]){break Da}x[a>>2]=0;break ya}Fb(j+8|0,r,85);if(!Ib(x[x[j+8>>2]>>2],x[j+12>>2])){break ya}if(!si(x[i+8>>2],x[i+12>>2])){break za}break ya}if(!l){a=g;break va}f=0;o=n+1075795|0;a=y[o|0];if(!(!a|e^1)){Pp(d,i,a,g,!(x[n+1075096>>2]?1:x[n+1075648>>2]),!(x[d+480180>>2]&1048580));v[o|0]=0;f=1}a=g;break wa}x[i>>2]=0;x[i+4>>2]=0}a=g}f=0;if(!l){break va}}e=x[n+1075096>>2];Ea:{if(!e|!(y[e+35|0]&2)){break Ea}g=x[d+1298300>>2];if(!ud(g)){break Ea}if(!f){if(LN(g,q&65535)){break Ea}}tz(g,q&65535,e+68|0)}e=q&65535;ht(d,i,l,a,!(x[d+480180>>2]&1048580),0,e);sO(x[d+480180>>2],z[d+480188>>1],O,e);if(!(!(x[d+480180>>2]&1048580)|(!a|!c))){c=n+1075080|0;x[c>>2]=x[c>>2]|2097152;hm(i);v[n+1075810|0]=0;x[n+1075748>>2]=0}if(!(x[n+1075080>>2]&512)){break va}if(!ud(x[d+1298300>>2])){break va}if(l>>>0<=253){if((l|0)!=253){break va}Fb(j+8|0,r,99);if(Ib(x[x[j+8>>2]>>2],x[j+12>>2])){break va}}Fb(j+8|0,r,110);if(Ib(x[x[j+8>>2]>>2],x[j+12>>2])){uz(x[d+1298300>>2],e,0,1,0)}Rj(x[d+1298300>>2],e)}Fa:{Ga:{switch(h-1|0){case 0:k=k>>>0>=64?64:k;x[n+1075680>>2]=k<<2;c=n+1075080|0;x[c>>2]=x[c>>2]|2097152;break Fa;case 1:break Ga;default:break Fa}}im(d,i,k,6)}if(z[d+480192>>1]){HN(d,q&65535)}g=a}Fb(j+8|0,r,77);if(Qa=Ib(x[x[j+8>>2]>>2],x[j+12>>2]),Ra=0,Ta=x[((q<<5)+d|0)+480280>>2]&1024,Ta?Qa:Ra){break P}a=x[d+1074392>>2];Fb(j+8|0,r,75);e=a>>>0>=L>>>0;Ha:{Ia:{Ja:{Ka:{if(!L|!Ib(x[x[j+8>>2]>>2],x[j+12>>2])){break Ka}c=x[d+1074392>>2];if(!c){break Ja}e=1;if((c|0)!=(L|0)){break Ka}e=!y[K|0]&(h|0)!=11}a=h;if(!e|a>>>0<3){break Ja}if((a|0)==11){a=j+8|0;Yy(a,d,y[U+3|0],y[U+4|0],L);a=y[Ue(a)|0];Zn(d,i,z[j+8>>1]);if(a){break Ia}h=11;break Ja}Fb(j+8|0,r,62);La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{if(!(!Ib(x[x[j+8>>2]>>2],x[j+12>>2])|k)){k=0;h=0;Sa:{switch(a-8|0){case 0:break Ra;case 1:break Sa;default:break Ja}}if(y[J|0]&16){break Ja}x[n+1075684>>2]=0;break Ja}Fb(j+8|0,r,41);Ta:{if(Ib(x[x[j+8>>2]>>2],x[j+12>>2])){break Ta}if(k){v[n+1075826|0]=k;break Ta}k=y[n+1075826|0]}Ua:{switch(a-3|0){case 0:case 1:Va:{Wa:{if(k){break Wa}Fb(j+8|0,r,41);if(!Ib(x[x[j+8>>2]>>2],x[j+12>>2])){break Wa}k=y[n+1075826|0];if(k){break Va}k=0;break Ja}v[n+1075826|0]=k}eo(d,i,((a|0)==3?k<<4:k)&255);break Ja;case 2:if((L|0)!=x[d+1074392>>2]){Fb(j+8|0,r,41);h=5;if(Ib(x[x[j+8>>2]>>2],x[j+12>>2])){break Ja}}Fb(j+8|0,r,41);co(d,i,k,Ib(x[x[j+8>>2]>>2],x[j+12>>2]));h=5;break Ja;case 3:if((L|0)!=x[d+1074392>>2]){Fb(j+8|0,r,41);h=6;if(Ib(x[x[j+8>>2]>>2],x[j+12>>2])){break Ja}}Fb(j+8|0,r,41);bo(d,i,k,Ib(x[x[j+8>>2]>>2],x[j+12>>2]));h=6;break Ja;case 11:break La;case 12:break Ma;case 10:break Na;case 9:break Oa;case 7:break Pa;case 6:break Qa;case 5:break Ra;case 4:break Ua;default:break Ja}}Fb(j+8|0,r,53);if(Ib(x[x[j+8>>2]>>2],x[j+12>>2])){v[n+1075815|0]=k&15;h=7;break Ja}$k(i,k<<4);h=7;break Ja}$k(i,k);h=8;break Ja}Fb(j+8|0,r,62);Jy(d,i,k,Ib(x[x[j+8>>2]>>2],x[j+12>>2])^1);h=9;break Ja}Fb(j+8|0,r,62);Jy(d,i,k<<4&240,Ib(x[x[j+8>>2]>>2],x[j+12>>2])^1);h=10;break Ja}h=12;Fb(j+8|0,r,12);GN(d,q&65535,k<<2&252,Ib(x[x[j+8>>2]>>2],x[j+12>>2]));break Ja}Fb(j+8|0,r,12);FN(d,q&65535,k<<2&252,Ib(x[x[j+8>>2]>>2],x[j+12>>2]));h=13;break Ja}h=15;if(!s){break Ja}a=x[n+1075096>>2];if(!a|k>>>0>9){break Ja}Xa:{if(!k){c=x[n+1075656>>2];break Xa}c=x[xb(a+68|0,k-1|0)>>2];x[n+1075656>>2]=c}fo(d,i,c);break Ja}h=14;if(k>>>0>1){break Ja}v[G|0]=y[G|0]&247|!k<<3}c=b;Ya:{Za:{_a:{$a:{switch(t-1|0){case 12:if(!(y[d+480209|0]&16)){break Ia}a=D(q,872)+d|0;x[a+1075680>>2]=b>>>0>=64?256:b<<2;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break Ia;case 1:if(!b){c=0;if(v[d+480180|0]&1){break Ha}}GN(d,q&65535,b,0);break Ia;case 2:if(!b){c=0;if(v[d+480180|0]&1){break Ha}}FN(d,q&65535,b,0);break Ia;case 10:if(!b){c=0;if(x[d+480180>>2]==1){break Ha}}eo(d,i,b);break Ia;case 3:Zn(d,i,b);break Ia;case 5:if(!(!b&x[d+480180>>2]==1)){eo(d,i,b)}Zn(d,i,0);break Ia;case 4:$k(i,b);break Ia;case 6:if(!(!b&x[d+480180>>2]==1)){eo(d,i,b)}$k(i,0);break Ia;case 15:if(!(y[d+480209|0]&16)){break Ia}break Ya;case 16:Fb(j+8|0,r,5);if(Ib(x[x[j+8>>2]>>2],x[j+12>>2])){if(!(y[d+480209|0]&16)){break Ia}if(b){break Ya}break Ia}c=ao(d,z[d+1074446>>1],x[d+1074424>>2],q&65535,0);ab:{if(!(x[d+480180>>2]&16777250)){break ab}if(c){v[(D(q,872)+d|0)+1075827|0]=c;break ab}c=y[(D(q,872)+d|0)+1075827|0]}x[j+8>>2]=D(c,1e4);tc(j+8|0,D(x[x[d+8>>2]+24>>2],1e4));a=db-16|0;db=a;e=x[j+8>>2];x[a+12>>2]=e;b=x[d+8>>2];bb:{if(e>>>0>=(x[d+480180>>2]&16393?1e4:32e4)>>>0){e=x[d+480208>>2];Fb(a+4|0,d+1074312|0,92);if((Ib(x[x[a+4>>2]>>2],x[a+8>>2])|0)==((e&4096)>>>12|0)){break bb}x[a+4>>2]=D(x[b+24>>2],1e4);Qa=d+1074420|0,Ra=x[Cb(a+12|0,a+4|0)>>2],x[Qa>>2]=Ra;break bb}if(y[d+480209|0]&16){break bb}g=d+1074420|0;e=(e>>>0)/1e4|0;f=D(e&15,1e4);x[g>>2]=x[g>>2]+((e&240)==16?f:0-f|0);e=x[b+20>>2];b=x[b+24>>2];Fb(a+4|0,d+1074312|0,8);To(g,D(e,1e4),Ib(x[x[a+4>>2]>>2],x[a+8>>2])?255e4:D(b,1e4))}db=a+16|0;break Ha;case 9:if(!s|x[d+480180>>2]==4&g){break Ia}rO(d,i,q&65535,x[d+1074424>>2],z[d+1074446>>1]);break Ia;case 43:if(!s){break Ia}c=yka(x[(D(q,872)+d|0)+1075068>>2],0,b,0);a=hb;f=a>>>8|0;fo(d,i,Qc((a&255)<<24|c>>>8,f));break Ia;case 0:if(x[d+1074392>>2]){break Ia}a=D(q,872)+d|0;cb:{if(y[a+1075789|0]?x[a+1075692>>2]:0){break cb}a=x[a+1075648>>2];if(a){if(ej(y[a+31|0])){break cb}}Fb(j+8|0,r,13);if(Ib(x[x[j+8>>2]>>2],x[j+12>>2])){break cb}if(x[d+480180>>2]&16777248){break Ia}}if(!b){c=0;if(y[d+480180|0]&5){break Ha}v[(D(q,872)+d|0)+1075797|0]=1;break Ha}a=D(q,872)+d|0;v[a+1075798|0]=b;v[a+1075797|0]=1;break Ia;case 14:if(x[d+480180>>2]&1048580){b=b&240?b:y[(D(q,872)+d|0)+1075799|0]&240|b;if(!(b&15)){b=y[(D(q,872)+d|0)+1075799|0]&15|b}b=b|256}c=b;Fb(j+8|0,r,23);if(Ib(x[x[j+8>>2]>>2],x[j+12>>2])){b=d;e=q&65535;if(c){v[(D(q,872)+d|0)+1075799|0]=c;a=c}else{a=y[(D(q,872)+d|0)+1075799|0]}Iy(b,e,a&255,(h|0)==15?k+1|0:0);break Ha}db:{if(c){v[(D(q,872)+d|0)+1075799|0]=c;break db}c=y[(D(q,872)+d|0)+1075799|0]}Iy(d,q&65535,c,(h|0)==15?k+1|0:0);break Ha;case 17:if(!(y[d+480209|0]&16)){break Ia}Fb(j+8|0,r,22);eb:{fb:{if(Ib(x[x[j+8>>2]>>2],x[j+12>>2])){if(!b){b=0;break fb}if(y[d+480208|0]&4){break fb}a=b&240?b-16|0:b;b=a-((a&15)!=0)|0;v[(D(q,872)+d|0)+1075832|0]=b;break fb}Fb(j+8|0,r,71);if(!Ib(x[x[j+8>>2]>>2],x[j+12>>2])){break eb}}a=(D(q,872)+d|0)+1075831|0;v[a|0]=y[a|0]|128}a=D(q,872)+d|0;v[a+1075797|0]=18;if(!b){c=0;break Ha}v[a+1075832|0]=b;break Ia;case 22:if(!(y[d+480209|0]&16)){break Ia}a=x[d+480180>>2];c=b<<!(a&59593760);if(c>>>0<=128){x[d+1074456>>2]=c<<1;break Ha}if(a&16777250){break Ha}x[d+1074456>>2]=256;break Ha;case 23:Fb(j+8|0,r,9);if(Ib(x[x[j+8>>2]>>2],x[j+12>>2])){EN(d,b,(D(q,872)+d|0)+1075809|0);break Ia}EN(d,b,T);break Ia;case 8:if(!(y[d+480209|0]&16)){break Ia}im(d,i,b,8);break Ia;case 28:Jy(d,i,b,1);break Ia;case 7:iO(i,b);break Ia;case 25:jO(d,i,b);break Ia;case 18:f=d+1074376|0;c=q&65535;g=D(c,872);e=(f+g|0)+616|0;a=b&15;gb:{hb:{switch(b>>>4|0){case 0:c=(b&1)<<14;e=z[d+480188>>1];a=0;while(1){if((a|0)==(e|0)){break gb}g=(D(a,872)+d|0)+1075080|0;x[g>>2]=(c|x[g>>2]&-16385)^16384;a=a+1|0;continue};case 1:if(a){Hy(d,e,a);break gb}if(!(x[d+480180>>2]&1048580)){break gb}Hy(d,e,0);break gb;case 2:if(a){Gy(d,e,a);break gb}if(!(x[d+480180>>2]&1048580)){break gb}Gy(d,e,0);break gb;case 3:c=(d+g|0)+1075080|0;x[c>>2]=x[c>>2]&-1048577|((a|0)!=0)<<20;break gb;case 4:v[(d+g|0)+1075814|0]=b&7;break gb;case 5:if(!(y[d+480209|0]&16)){break gb}g=x[d+480180>>2];if(g&69206025){e=D(c,872)+d|0;a=a<<28>>24;w[e+1075764>>1]=a;g=e+1075692|0;if(!x[g>>2]){break gb}if(!Tc(y[e+1075780|0])){break gb}c=D(c,872)+d|0;Qa=g,Ra=Rg(d,y[c+1075789|0],a,x[c+1075696>>2]),x[Qa>>2]=Ra;break gb}e=Tc(y[(D(c,872)+d|0)+1075780|0]);if((g|0)==16){if(!e){break gb}e=D(c,872)+d|0;g=x[e+1075096>>2];if(!g){break gb}v[g+37|0]=a;w[e+1075764>>1]=a;e=e+1075692|0;if(!x[e>>2]){break gb}c=D(c,872)+d|0;Qa=e,Ra=Rg(d,y[c+1075789|0],a,x[c+1075696>>2]),x[Qa>>2]=Ra;break gb}if(!e){break gb}a=D(c,872)+d|0;c=(b<<4^-128)<<24>>24;w[a+1075764>>1]=c;e=a+1075692|0;if(!x[e>>2]){break gb}Qa=e,Ra=Rg(d,y[a+1075789|0],c,x[a+1075696>>2]),x[Qa>>2]=Ra;break gb;case 6:if(!(y[d+480209|0]&16)){break gb}Wy(d,f,c,a);break gb;case 7:v[(d+g|0)+1075817|0]=b&7;break gb;case 8:if(!(y[d+480209|0]&16)){break gb}im(d,e,a,4);break gb;case 9:Iy(d,c,a,0);break gb;case 10:if(a){co(d,e,a,0);break gb}if(!(x[d+480180>>2]&1048580)){break gb}co(d,e,0,0);break gb;case 11:if(a){bo(d,e,a,0);break gb}if(!(x[d+480180>>2]&1048580)){break gb}bo(d,e,0,0);break gb;case 12:Ky(d,c,a,0);break gb;case 15:break hb;default:break gb}}if(x[d+480180>>2]==1){v[(D(c,872)+d|0)+1075838|0]=a;if(!(y[d+480209|0]&16)){break gb}IN(d,e);break gb}v[(D(c,872)+d|0)+1075836|0]=a}break Ia;case 19:DN(d,q&65535,b);break Ia;case 24:Fb(j+8|0,r,55);if(Ib(x[x[j+8>>2]>>2],x[j+12>>2])){if(x[d+1074392>>2]!=(b|0)){break Ia}a=x[(D(q,872)+d|0)+1075648>>2];if(v[a+60|0]&1?a:0){break Za}if(!(!(y[K|0]|y[I|0])|b)){a=(D(q,872)+d|0)+1075080|0;x[a>>2]=x[a>>2]|4096;break Za}a=D(q,872)+d|0;x[a+1075680>>2]=0;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break Za}if(y[d+480209|0]&16){break Za}break Ia;case 27:a=(b&240)-16>>>4|0;if(a>>>0>9){break Ia}if(!(1<<a&880)){if(!a){break _a}if((a|0)!=1){break Ia}CN(d,i,b&15);break Ia}Fb(j+8|0,r,58);if(Ib(x[x[j+8>>2]>>2],x[j+12>>2])){break Ia}DN(d,q&65535,b);break Ia;case 34:case 35:g=(t|0)==36;if(!(g|x[d+480208>>2]&4096)){break Ia}c=q&65535;e=O+D(c,872)|0;f=e+616|0;a=oO(d,z[d+1074446>>1],x[d+1074424>>2],c);ib:{if(!g){break ib}g=al(O)-x[O+16>>2]|0;if((g|0)<2){break ib}h=a;a=w[(O+D(c,872)|0)+1390>>1];a=Sc(((h-a|0)/(g|0)|0)+a|0)}w[e+1390>>1]=a;e=at(d,x[e+704>>2],x[f+656>>2]);if(e){ib[x[x[e>>2]+80>>2]](e,(a<<16>>16)+32768>>>2|0,c)}break Ia;case 20:if(!(y[d+480209|0]&16)|b>>>0>64){break Ia}a=D(q,872)+d|0;x[a+1075740>>2]=b;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break Ia;case 21:f=x[d+480180>>2];g=x[d+480208>>2];a=b;jb:{if(a){v[i+816|0]=a;break jb}a=y[i+816|0]}c=a&15;e=a&255;kb:{lb:{if(!((c|0)!=15|e>>>0<16)){if(!(g&4096)){break kb}a=e>>>4|0;break lb}g=g&4096;h=e&240;if(!(!c|(h|0)!=240)){if(!g){break kb}a=0-c|0;break lb}if(g){break kb}if(c){a=0-c|0;if(!h|!(f&25690144)){break lb}break kb}if((a&255)>>>0<16){break kb}a=e>>>4|0}Qa=i,Ra=Ub(a+x[i+748>>2]|0,0,64),x[Qa+748>>2]=Ra}break Ia;case 26:hO(i,b);break Ia;case 29:if(!(y[d+480209|0]&16)){break Ia}a=D(q,872)+d|0;x[a+1075716>>2]=b;Fb(j+8|0,r,60);if(Qa=0,Ra=Ib(x[x[j+8>>2]>>2],x[j+12>>2]),Ta=y[a+1075722|0]&4,Ta?Qa:Ra){break Ia}a=D(q,872)+d|0;x[a+1075732>>2]=b;x[a+1075724>>2]=b;break Ia;case 11:mO(d,O,q&65535);break Ia;case 13:a=lO(d,O,q&65535,b);if((a|0)==-1){break Ia}x[d+1074436>>2]=a;if(!(y[d+480208|0]&32)){break Ia}w[d+1074444>>1]=z[d+1074448>>1];break Ia;case 37:case 38:case 39:case 40:c=(t|0)==38|(t|0)==40;e=(t&254)==40;mb:{nb:{ob:{if(y[d+480209|0]&16){a=y[i+848|0];g=b&240;if(g){a=g|a&15;v[i+848|0]=a}g=b&15;if(g){a=g|a&-16;v[i+848|0]=a}v[i+849|0]=(a&240)>>>4;if(x[d+480180>>2]!=32768){break mb}break ob}if(x[d+480180>>2]==32768){break ob}a=y[i+849|0]-1|0;v[i+849|0]=a;if(a&255){break mb}a=y[i+848|0];break nb}a=y[i+848|0];if((a&240)==16){break nb}if(!(y[d+480209|0]&16)){break mb}}v[i+849|0]=(a&240)>>>4;a=a&15;a=c?a:0-a|0;c=x[i+656>>2];pb:{if(gj(c)){x[i+852>>2]=x[i+852>>2]+D(a,x[x[c+44>>2]+36>>2]);break pb}Qa=i,Ra=Rg(d,$s(d,x[i+700>>2],w[i+772>>1],x[i+704>>2])+a|0,w[i+772>>1],x[i+704>>2]),x[Qa+700>>2]=Ra}if(!e){break mb}x[i>>2]=0;x[i+4>>2]=0}break Ia;case 41:qO(i,b);break Ia;case 42:if(x[d+1074392>>2]|P>>>0>1|b>>>0>47){break Ia}a=(b&240)==16;g=a?z[d+480188>>1]-1|0:q;c=a?0:q;a=((P|0)==1)<<26;while(1){e=c&65535;if(e>>>0>(g&65535)>>>0){break Ia}f=((e<<5)+d|0)+480280|0;x[f>>2]=a|x[f>>2]&-67108865;e=(D(e,872)+d|0)+1075080|0;x[e>>2]=a|x[e>>2]&-67108865;c=c+1|0;continue};case 44:break $a;default:break Ha}}pO(i,b);break Ia}BN(d,i,b&15);break Ia}$n(d,i);break Ia}xO(d,O,b)}c=b}Fb(j+8|0,r,78);if(!(!Ib(x[x[j+8>>2]>>2],x[j+12>>2])|!c)){eO(i,c&255)}a=y[K|0];if(!a){break P}v[n+1075796|0]=a}q=q+1|0;continue}break}a=1;break j}a=0}db=C+32|0;K=a&x[d+1074420>>2]!=0;qb:{if(!K){break qb}a=uO(d,d+1074376|0);x[d+1074380>>2]=a;x[d+1074404>>2]=a;b=Vd(z[d+480188>>1],1,31);rb:{if(vd(y[d+1074366|0])){a=x[d+24628>>2];if((a|0)>=129){a=((D(a-128|0,b+4|0)|0)/16|0)+128|0}l=((D(x[d+480228>>2],a)<<1&-128)>>>0)/y[(b>>>1|0)+32208|0]|0;break rb}l=x[d+480228>>2]}w[d+480212>>1]=0;s=d+1074312|0;O=d+480210|0;U=d+480209|0;u=0;while(1){if((u|0)==256){a=x[d+24608>>2];b=z[d+480212>>1];if(a>>>0>b>>>0){break qb}k=db-16|0;db=k;x[k+12>>2]=d;e=d+1074478|0;c=e+(a<<1)|0;if((c|0)!=(e|0)){a=e+(b<<1)|0;h=k+12|0;sb:{b=c-e|0;if((b|0)<3){break sb}g=b>>1;b=g-2>>>1|0;while(1){if((b|0)<0){break sb}HM(e,x[h>>2],g,e+(b<<1)|0);b=b-1|0;continue}}g=c-e>>1;b=c;while(1){if((a|0)!=(b|0)){if(_k(x[h>>2],z[b>>1],z[e>>1])){GM(b,e);HM(e,x[h>>2],g,e)}b=b+2|0;continue}break}b=c-e>>1;while(1){if((b|0)>1){l=z[e>>1];a=e;o=x[h>>2];f=0;g=b;s=b-2>>>1|0;while(1){b=f<<1;f=b|1;i=b+2|0;b=i+a|0;if((g|0)>(i|0)){r=i;i=_k(o,z[b>>1],z[b+2>>1]);f=i?r:f;b=i?b+2|0:b}w[a>>1]=z[b>>1];a=b;if((f|0)<=(s|0)){continue}break}b=c-2|0;tb:{if((b|0)==(a|0)){w[a>>1]=l;break tb}w[a>>1]=z[b>>1];w[b>>1]=l;l=x[h>>2];a=a+2|0;b=a-e>>1;ub:{if((b|0)<2){break ub}f=b-2|0;b=e+(f&-2)|0;a=a-2|0;if(!_k(l,z[b>>1],z[a>>1])){break ub}f=f>>>1|0;i=z[a>>1];while(1){vb:{o=a;a=b;w[o>>1]=z[a>>1];if(!f){break vb}b=f-1|0;f=b>>>1|0;b=e+(b&-2)|0;if(_k(l,z[b>>1],i)){continue}}break}w[a>>1]=i}}b=g-1|0;c=c-2|0;continue}break}}db=k+16|0}else{i=D(u,872)+d|0;o=i+1075080|0;wb:{if(!(x[o>>2]&4096)|(x[i+1075016>>2]|(x[i+1075012>>2]|x[i+1075688>>2]))){break wb}Fb(m+16|0,s,64);if(Ib(x[x[m+16>>2]>>2],x[m+20>>2])){break wb}x[i+1075068>>2]=0;a=i+1075084|0;x[a>>2]=0;x[a+4>>2]=0}c=z[d+480188>>1];a=x[o>>2];xb:{if(x[i+1075068>>2]|c>>>0>u>>>0?a&1024:1){if(c>>>0>u>>>0){MM(d,u&65535)}w[i+1075834>>1]=0;break xb}b=0;q=i+1075712|0;x[q>>2]=0;r=i+1075672|0;x[r>>2]=0;j=i+1075e3|0;e=j;x[e>>2]=0;x[e+4>>2]=0;x[i+1075092>>2]=0;x[m+44>>2]=1065353216;w[m+42>>1]=0;L=i+1075648|0;C=x[L>>2];x[m+36>>2]=0;e=0;n=i+1075692|0;e=x[n>>2]?x[i+1075068>>2]!=0:e;g=i+1074992|0;yb:{zb:{Ab:{if(c>>>0<=u>>>0){break Ab}if(y[((u<<5)+d|0)+480288|0]){break zb}if(!C){break Ab}b=y[C+34|0]!=0}if((b|e)!=1){break yb}}x[m+8>>2]=x[i+1075680>>2];x[m+32>>2]=x[i+1075744>>2];Fb(m+16|0,s,28);a=m+8|0;b=Ib(x[x[m+16>>2]>>2],x[m+20>>2])?m+32|0:a;c=d+1074312|0;Bb:{if(Ob(c,28)){x[b>>2]=x[b>>2]+w[g+776>>1];ke(b,0,64);break Bb}f=Ob(c,1);c=w[g+776>>1];if(f){x[b>>2]=c+x[b>>2];ke(b,0,256);break Bb}x[g+688>>2]=c+x[g+688>>2];ke(g+688|0,0,256);x[b>>2]=x[g+688>>2];w[g+776>>1]=0}Cb:{Db:{b=d+1074312|0;if(!Ob(b,28)){if(!Ob(b,1)){break Db}}x[g+684>>2]=x[g+692>>2]+w[g+778>>1];ke(g+684|0,0,256);break Cb}x[g+692>>2]=x[g+692>>2]+w[g+778>>1];ke(g+692|0,0,256);w[g+778>>1]=0;x[g+684>>2]=x[g+692>>2]}Eb:{if(!(y[g+90|0]&4)|(x[d+480208>>2]&2101248)==2101248){break Eb}Fb:{if(x[a>>2]<=0){if(!Ob(d+1074312|0,21)){break Fb}}c=5;if(!(y[d+480180|0]&5)){c=Ob(d+1074312|0,21)?5:6}b=sy(d,y[g+825|0],y[g+820|0]);Gb:{if((y[g+825|0]&3)!=1){break Gb}if(!Ob(d+1074312|0,89)){break Gb}b=y[g+819|0];h=y[g+820|0];f=h<<2&124;b=(!(y[g+90|0]&2)|y[d+480209|0]&16?b:y[g+823|0]+b|0)&32?f^127:f;b=h&32?0-b|0:b}if(x[d+480180>>2]!=131072){b=x[a>>2]+((D(y[g+827|0],b)|0)/(1<<c)|0)|0}else{c=64-b|0;b=x[a>>2];b=((D(y[g+827|0],D(c,b))|0)/-8192|0)+b|0}x[a>>2]=b}b=x[d+480208>>2];if(!(x[d+480180>>2]&16777248)|b&4?b&4096:0){break Eb}b=Ob(d+1074312|0,21);c=y[g+826|0];f=y[g+820|0];v[g+820|0]=(b?c<<2:f)+(b?f:c)}h=u&65535;k=db-16|0;db=k;b=d+1074312|0;Fb(k+8|0,b,71);Hb:{if(Ib(x[x[k+8>>2]>>2],x[k+12>>2])){b=(D(h,872)+d|0)+1075831|0;c=v[b|0];if((c|0)>=0){break Hb}if(!(y[d+480209|0]&16|y[(D(h,872)+d|0)+1075797|0]!=18)){Ib:{Jb:{if((c&-33)!=-64){c=c&223;if((c|0)!=128){break Jb}c=y[(D(h,872)+d|0)+1075832|0]>>>4|-64;break Ib}c=y[(D(h,872)+d|0)+1075832|0]&15|-128;break Ib}c=c-1|0}v[b|0]=c;b=(D(h,872)+d|0)+1075080|0;x[b>>2]=x[b>>2]|2097152}if((c&224)!=128){break Hb}x[a>>2]=0;break Hb}if(y[(D(h,872)+d|0)+1075797|0]!=18){break Hb}Fb(k+8|0,b,22);Kb:{if(Ib(x[x[k+8>>2]>>2],x[k+12>>2])){t=D(h,872)+d|0;b=t+1075831|0;f=y[b|0];c=f<<24>>24;if(!((c|0)>=0|!x[t+1075068>>2])){Lb:{Mb:{if((f|0)!=192){if((f|0)!=128){break Mb}c=y[(D(h,872)+d|0)+1075832|0]>>>4|-64;break Lb}c=y[(D(h,872)+d|0)+1075832|0]&15|-128;break Lb}c=c-1|0}v[b|0]=c}if((c&192)!=128){break Kb}x[a>>2]=0;break Kb}b=y[(D(h,872)+d|0)+1075832|0];c=b>>>4|0;t=c+(b&15)|0;G=x[d+480180>>2];if(!(y[d+480208|0]&4?0:G&16777248)){t=t+2|0;c=c+1|0}b=(D(h,872)+d|0)+1075831|0;f=y[b|0];if(!(G&4)){J=c;c=(f&255)>>>0<t>>>0?f:0;if(J>>>0<=(c&255)>>>0){x[a>>2]=0}v[b|0]=c+1;break Kb}Nb:{if(y[d+480209|0]&16){b=f&255;f=b-1|0;f=b>>>0>=f>>>0?f:0;break Nb}v[b|0]=f+1}if(((f&255)>>>0)%(t>>>0)>>>0<c>>>0){break Kb}x[a>>2]=0}b=(D(h,872)+d|0)+1075080|0;x[b>>2]=x[b>>2]|2097152}b=D(h,872)+d|0;Ob:{if(y[b+1075797|0]!=18){break Ob}c=x[b+1075648>>2];if(!c){break Ob}b=y[c+34|0];if(!b|y[c+15|0]&2){break Ob}f=D(h,872)+d|0;if(x[f+1075080>>2]&134218752){break Ob}f=f+1075791|0;t=y[f|0];if(!Tc(t)){break Ob}b=x[(D(b,160)+d|0)+906140>>2];if(!b){break Ob}t=ib[x[x[b>>2]+100>>2]](b,t,h)|0;G=x[a>>2];if(!(!t|G)){ib[x[x[b>>2]+92>>2]](b,c,y[f|0]+255|0,0,h);break Ob}if(t|!G){break Ob}ib[x[x[b>>2]+92>>2]](b,c,y[f|0],z[(D(h,872)+d|0)+1075680>>1],h)}db=k+16|0;ke(a,0,256);x[m+8>>2]=x[m+8>>2]<<6;Pb:{if(C){Fb(m+16|0,s,31);if(Ib(x[x[m+16>>2]>>2],x[m+20>>2])){et(d,g)}b=m+8|0;Qb:{if(!qy(d,g,0)){break Qb}c=x[g+656>>2];f=d+1074312|0;k=Ob(f,31);a=x[g+724>>2];if(a?0:k){break Qb}t=a-Ob(f,31)|0;a=Xp(c+48|0,t,256,64);G=y[c+65|0];Rb:{if((G|0)==255){break Rb}k=w[g+728>>1];if((k|0)==-1){break Rb}G=xb(x[c+48>>2],G);I=y[G+2|0];c=I<<2;a=(t|0)==z[G>>1]?c:a;if(Ob(f,94)){a=k+(a-c<<1)|0;break Rb}if(!I){a=0;break Rb}a=(D(a,k)|0)/(c|0)|0}Qa=b,Ra=(D(Ub(a,0,512),x[b>>2])|0)/256|0,x[Qa>>2]=Ra}ZN(g,b);Sb:{if(!qy(d,g,1)){break Sb}a=x[g+656>>2];b=d+1074312|0;f=Ob(b,31);c=x[g+732>>2];if(c?0:f){break Sb}b=Xp(a+68|0,c-Ob(b,31)|0,64,64)-32|0;a=x[g+684>>2];Qa=g,Ra=Ub(((D(b,(a|0)>127?256-a|0:a)|0)/32|0)+a|0,0,256),x[Qa+684>>2]=Ra}Fb(m+16|0,s,115);if(Ib(x[x[m+16>>2]>>2],x[m+20>>2])){break Pb}b=y[i+1075789|0];if(!b){break Pb}a=x[L>>2];if(!a|!y[a+26|0]){break Pb}$N(i+1075676|0,b,y[a+26|0],y[a+27|0]);break Pb}if(!(y[o+1|0]&16)){break Pb}x[i+1075688>>2]=0;x[m+8>>2]=0}Tb:{if(y[i+1075843|0]&8){f=0;x[m+8>>2]=0;break Tb}f=x[m+8>>2];if(!f){f=0;break Tb}if(y[o+3|0]&8){x[r>>2]=0;break Tb}if(vd(y[d+1074365|0])){a=D(x[m+32>>2],x[i+1075740>>2]);b=a;c=a>>31;a=f<<8;Qa=r,Ra=Cc(zka(yka(b,c,a,a>>31),hb,1048576,0),hb),x[Qa>>2]=Ra;break Tb}a=D(x[m+32>>2],x[i+1075740>>2]);b=a;c=a>>31;a=D(x[d+1074456>>2],f);Qa=r,Ra=Cc(zka(yka(b,c,a,a>>31),hb,1048576,0),hb),x[Qa>>2]=Ra}x[q>>2]=f;Ub:{Vb:{f=x[n>>2];if(!(x[d+480180>>2]==2|(f|0)>=x[d+480260>>2])){if(!Zi(d)){break Vb}f=x[n>>2]}if((f|0)<x[d+480264>>2]){break Ub}Fb(m+16|0,s,113);if(!Ib(x[x[m+16>>2]>>2],x[m+20>>2])){break Ub}if(Zi(d)){break Ub}x[n>>2]=x[d+480264>>2];break Ub}x[n>>2]=x[d+480260>>2]}Fb(m+16|0,s,73);a=x[n>>2];x[m+36>>2]=a;Wb:{if((x[o>>2]&1572864)!=1572864){break Wb}b=x[d+480208>>2];if(b&2097152){if(!az(y[i+1075782|0],y[i+1075783|0])|b&4096){break Wb}}b=i+1075704|0;Xb:{if((a|0)==x[b>>2]){f=x[i+1075708>>2];break Xb}x[b>>2]=a;c=a;a=i+1075764|0;b=i+1075696|0;f=Rg(d,$s(d,c,w[a>>1],x[b>>2]),w[a>>1],x[b>>2]);x[i+1075708>>2]=f}x[m+36>>2]=f}k=db-16|0;db=k;I=D(h,872)+d|0;P=I+1075648|0;b=x[P>>2];Yb:{if(!b){break Yb}a=y[b+34|0];if(!a|y[b+15|0]&2|(!x[(D(a,160)+d|0)+906140>>2]|x[(D(h,872)+d|0)+1075080>>2]&134218752)){break Yb}c=D(h,872)+d|0;J=c+1075783|0;G=y[J|0];a=0;f=y[c+1075791|0];if(Tc(f)){a=y[Db(b+108|0,f-1|0)|0]}t=c+1075780|0;Zb:{_b:{if((G|0)==1){f=0;$b:{ac:{switch((A[d+1074392>>2]%3|0)-1|0){case 0:f=y[(D(h,872)+d|0)+1075798|0]>>>4|0;break $b;case 1:break ac;default:break $b}}f=y[(D(h,872)+d|0)+1075798|0]&15}b=D(h,872)+d|0;v[b+1075793|0]=a;if(y[b+1075792|0]==(a+f|0)){break Zb}b=a;if(!(y[d+480209|0]&16)){break _b}b=a;if(!Tc(y[t|0])){break _b}break Zb}f=0;if(y[t|0]){break Zb}b=D(h,872)+d|0;if(!y[b+1075792|0]){break Zb}b=y[b+1075793|0]}fm(d,h,(b&255)+f|0,z[(D(h,872)+d|0)+1075680>>1])}b=(D(h,872)+d|0)+1075792|0;c=y[b|0];bc:{if(!c){if(!(y[d+480209|0]&16)|(G|0)!=1){break bc}if(Tc(y[t|0])){break bc}c=a;if(!Tc(a)){break bc}}fm(d,h,(c&255)+255|0,0)}v[b|0]=y[J|0]==1?y[(D(h,872)+d|0)+1075793|0]+f|0:0}cc:{if(y[I+1075797|0]!=1){break cc}if(gj(x[P>>2])){f=0;dc:{ec:{fc:{switch(A[d+1074392>>2]%3|0){case 1:f=y[(D(h,872)+d|0)+1075798|0]>>>4|0;break ec;case 0:break ec;case 2:break fc;default:break dc}}f=y[(D(h,872)+d|0)+1075798|0]&15}w[m+42>>1]=f}a=(D(h,872)+d|0)+1075843|0;v[a|0]=y[a|0]|96;break cc}if(!(!(y[d+480209|0]&16)|x[d+480180>>2]!=1048576)){a=D(h,872)+d|0;b=Rg(d,y[a+1075789|0],w[a+1075764>>1],x[a+1075696>>2]);x[m+36>>2]=b;x[a+1075692>>2]=b}b=d+1074312|0;Fb(k+8|0,b,13);if(Ib(x[x[k+8>>2]>>2],x[k+12>>2])){f=y[(D(h,872)+d|0)+1075798|0];if(!f){break cc}b=65536;gc:{switch(((A[d+1074392>>2]%(x[d+1074400>>2]+x[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:f=f<<4;case 0:b=x[((f&240)<<2)+37360>>2];break;default:break gc}}f=Zi(d);a=x[m+36>>2];c=a>>31;if(f){a=yka(a,c,b,b>>31);f=hb;a=a+32768|0;f=a>>>0<32768?f+1|0:f;a=zka(a,f,65536,0);b=hb}else{f=(b|0)/2|0;t=f>>31;h=c<<16|a>>>16;c=a<<16;a=c+f|0;f=h+t|0;a=zka(a,a>>>0<c>>>0?f+1|0:f,b,b>>31);b=hb}Qa=m,Ra=Cc(a,b),x[Qa+36>>2]=Ra;break cc}Fb(k+8|0,b,51);if(Ib(x[x[k+8>>2]>>2],x[k+12>>2])){if(y[d+480209|0]&16){break cc}hc:{ic:{a=x[d+1074416>>2];b=a-(A[d+1074392>>2]%(a>>>0)|0)|0;if((b|0)>16){break ic}if((b|0)==16){break cc}a=0;jc:{switch((b|0)%3|0){case 0:break cc;case 2:break ic;case 1:break jc;default:break hc}}a=y[(D(h,872)+d|0)+1075798|0]>>>4|0;break hc}a=y[(D(h,872)+d|0)+1075798|0]&15}c=a;a=D(h,872)+d|0;b=a+1075764|0;a=a+1075696|0;c=c+$s(d,x[m+36>>2],w[b>>1],x[a>>2])|0;b=Rg(d,c,w[b>>1],x[a>>2]);x[m+36>>2]=b;if(c>>>0<109){break cc}x[k+8>>2]=b;Qa=k,Ra=Rg(d,109,0,x[a>>2]),x[Qa+4>>2]=Ra;Qa=m,Ra=x[Yc(k+8|0,k+4|0)>>2],x[Qa+36>>2]=Ra;break cc}f=x[d+1074392>>2];c=x[d+480180>>2];kc:{if((c|0)!=1){a=y[(D(h,872)+d|0)+1075789|0];break kc}a=D(h,872)+d|0;a=$s(d,x[m+36>>2],w[a+1075764>>1],x[a+1075696>>2]);c=x[d+480180>>2]}lc:{mc:{switch((((c&67633152?f+2|0:f)>>>0)%3|0)-1|0){case 0:a=(y[(D(h,872)+d|0)+1075798|0]>>>4|0)+a|0;break lc;case 1:break mc;default:break lc}}a=(y[(D(h,872)+d|0)+1075798|0]&15)+a|0}if(!(c&67633408|y[(D(h,872)+d|0)+1075789|0]!=(a&255))){Fb(k+8|0,b,82);if(!Ib(x[x[k+8>>2]>>2],x[k+12>>2])){break cc}}if(y[d+480210|0]&32){c=a&255;if((c|0)==85){x[m+36>>2]=2147483647;break cc}a=c>>>0>85?a-37|0:a}c=D(h,872)+d|0;f=Rg(d,a&255,w[c+1075764>>1],x[c+1075696>>2]);x[m+36>>2]=f;if(x[d+480180>>2]&71860480){x[c+1075692>>2]=f;break cc}Fb(k+8|0,b,82);if(!Ib(x[x[k+8>>2]>>2],x[k+12>>2])){break cc}v[(D(h,872)+d|0)+1075792|0]=a}db=k+16|0;if(!(!(y[O|0]&33)|x[m+36>>2]==2147483647)){nc:{if(x[d+480180>>2]==2){f=452;a=3424;break nc}a=D(z[i+1075764>>1]>>>4&15,24);b=z[a+33094>>1]>>>1|0;f=b>>>0<=452?452:b;a=z[a+33072>>1]<<1}ke(m+36|0,f,a);ke(n,f,a)}fO(d,g);a=x[o>>2]}oc:{if(!(a&256)|y[U|0]&64){break oc}Fb(m+16|0,s,37);if(!Ib(x[x[m+16>>2]>>2],x[m+20>>2])){break oc}x[i+1075676>>2]=128}a=tO(d,g);pc:{if((a|0)<0|!(y[o+1|0]&2)){break pc}b=x[d+1298300>>2];if(!ud(b)){break pc}Vp(b,u&65535,a&255,1)}k=u&65535;MM(d,k);qc:{if(!e){break qc}a=_N(d,g,m+36|0);if((a|0)<0|!(y[o+1|0]&2)){break qc}b=x[d+1298300>>2];if(!ud(b)){break qc}Vp(b,k,a>>>2&255,1)}rc:{if(y[i+1075782|0]!=8){break rc}sc:{tc:{a=y[i+1075783|0];switch(a-5|0){case 1:break rc;case 0:case 2:break sc;default:break tc}}if((a|0)!=26){break rc}}a=x[d+480180>>2];if((a|0)==4){if(y[U|0]&16){break rc}a=i+1075811|0;v[a|0]=y[a|0]+y[i+1075815|0];break rc}if(!(a&16777248)){break rc}$k(g,y[i+1075784|0]);LM(d,k,m+36|0,m+44|0)}LM(d,k,m+36|0,m+44|0);uc:{if(!e){break uc}x[m+32>>2]=0;e=m+36|0;n=db-16|0;db=n;c=x[g+104>>2];vc:{if(!c|!y[c+40|0]){break vc}t=gj(x[g+656>>2]);f=Zi(d);b=f?38384:37360;h=f?37360:38384;if(!(t|!Ob(d+1074312|0,21)|x[d+480180>>2]==1048576)){G=y[c+41|0];if(!G){break vc}a=y[g+818|0];x[n+12>>2]=x[g+756>>2]+y[c+39|0];Zh(n+12|0,y[c+40|0]<<8);t=x[n+12>>2];v[g+818|0]=a+G;x[g+756>>2]=t;t=(t|0)/256|0;wc:{xc:{switch(y[c+38|0]-1|0){case 3:c=JM(_n(d))+-64|0;break wc;case 2:c=64-(a+1>>>1|0)|0;break wc;case 1:c=(a+1>>>1|0)+-64|0;break wc;case 0:c=(a^-1)>>>1&64;break wc;default:break xc}}c=v[a+33664|0]}Zh(e,8388607);a=x[e>>2]<<8;x[e>>2]=a;I=D(c,t);t=(I|0)/64|0;c=t>>31;t=(c^t)-c|0;c=t&3;t=t>>>2|0;G=a>>31;yc:{zc:{if((I|0)<=-64){b=x[(t<<2)+b>>2];b=Cc(zka(yka(b,b>>31,a,G),hb,65536,0),hb)-a|0;if(!c){break yc}f=f?37296:37232;break zc}b=x[h+(t<<2)>>2];b=Cc(zka(yka(b,b>>31,a,G),hb,65536,0),hb)-a|0;if(!c){break yc}f=f?37232:37296}c=x[(c<<2)+f>>2];b=(Cc(zka(yka(a,G,c,c>>31),hb,65536,0),hb)+b|0)-a|0}x[e>>2]=(b+a|0)/256;x[m+32>>2]=b&255;break vc}f=x[d+480180>>2]&16777248;a=y[c+39|0];Ac:{if(!(f|a)){x[g+756>>2]=y[c+40|0]<<8;break Ac}Bc:{if(f){x[g+756>>2]=x[g+756>>2]+(a<<1);f=y[c+40|0];break Bc}f=y[c+40|0];if(y[g+89|0]&8){break Bc}x[g+756>>2]=x[g+756>>2]+(((f<<8&65280)>>>0)/(a>>>0)|0)}Zh(g+756|0,f<<8)}a=y[g+818|0]+y[c+41|0]|0;v[g+818|0]=a;a=a<<24>>24;Cc:{Dc:{switch(y[c+38|0]-1|0){case 3:v[g+818|0]=a+1;f=v[(a&63)+33600|0];break Cc;case 2:f=(64-(a>>>1|0)&127)+-64|0;break Cc;case 1:f=((a>>>1|0)- -64&127)+-64|0;break Cc;case 0:f=(a|0)>=0?-64:64;break Cc;default:break Dc}}f=0-v[(a&255)+33664|0]|0;if(x[d+480180>>2]!=1048576){break Cc}f=(64-v[(a+-64&255)+33664|0]|0)/2<<16>>16}a=f;G=D(a,x[g+756>>2]);f=(G|0)/256|0;if(t){B[m+44>>2]=B[m+44>>2]+E(E(E(E(y[c+40|0])*E(.05000000074505806))*E(a|0))*E(.000244140625));v[g+851|0]=y[g+851|0]|64;break vc}if(x[d+480180>>2]!=4){Ec:{if((G|0)<=-256){f=0-f|0;c=f>>>8|0;a=(c<<2)+b|0;break Ec}b=h;c=f>>>8|0;a=b+(c<<2)|0}h=x[e>>2];a=x[a>>2];a=((D(x[((c<<2)+b|0)+4>>2]-a|0,f>>>2&63)|0)/64|0)+a|0;a=Cc(zka(yka(h,h>>31,a,a>>31),hb,256,0),hb);x[e>>2]=a;x[m+32>>2]=a&255;x[e>>2]=x[e>>2]/256;break vc}x[e>>2]=x[e>>2]+((G|0)/16384|0)}db=n+16|0;e=x[m+36>>2];if((e|0)<=x[d+480260>>2]){Fb(m+16|0,s,81);if(Ib(x[x[m+16>>2]>>2],x[m+20>>2])){x[i+1075068>>2]=0}e=x[d+480260>>2];x[m+36>>2]=e}Fc:{if(!gj(x[g+656>>2])){break Fc}a=i+1075843|0;b=y[a|0];if(!(x[d+1074392>>2]|!(b&32)?b&64:1)){break Fc}hQ(g,B[m+44>>2],w[m+42>>1],d);b=a;a=y[a|0];v[b|0]=(a&64?-65:-33)&a}a=m+16|0;Zy(a,d,g,e,x[m+32>>2]);e=wb(a);a=yka(x[m+16>>2],x[m+20>>2],x[d+480240>>2],0);f=hb;b=zka(a,f,65536,0);c=hb;h=b;a=a+65535|0;b=!(a>>>0<65535?f+1|0:f)&a>>>0<131071;a=b?1:h;x[m+16>>2]=a;b=b?0:c;x[m+20>>2]=b;x[j>>2]=a;x[j+4>>2]=b;if((x[o>>2]&134219264)!=512){break uc}if(!ud(x[d+1298300>>2])){break uc}Fb(m+8|0,s,99);a=x[o>>2];c=a&4096;Gc:{Hc:{if(Qa=Ib(x[x[m+8>>2]>>2],x[m+12>>2]),Ra=1,Ta=c,Ta?Qa:Ra){b=x[d+480180>>2];break Hc}b=x[d+480180>>2];if((b|0)!=2){break Gc}}f=(b|0)==2;b=a&2048;Ic:{if(b?f:0){break Ic}a=x[d+480240>>2];f=yka(x[e>>2],0,261625,0);e=hb;f=f+66904|0;e=f>>>0<66904?e+1|0:e;a=yka(a,0,Qc(Bka(f,e,133808,0),hb),0);f=hb;a=a+32768|0;f=a>>>0<32768?f+1|0:f;e=Qc((f&65535)<<16|a>>>16,f>>>16|0);a=1;Jc:{if(b){break Jc}a=0;if(!c){break Jc}a=!x[i+1075688>>2]}Fb(m+8|0,s,110);if(Qa=Ib(x[x[m+8>>2]>>2],x[m+12>>2]),Ra=0,Ta=a,Ta?Qa:Ra){break Ic}b=x[d+1298300>>2];Fb(m+8|0,s,95);uz(b,k,e,a,Ib(x[x[m+8>>2]>>2],x[m+12>>2]))}a=x[d+1298300>>2];b=yka(D(x[i+1075744>>2],D(x[i+1075740>>2],x[q>>2])),0,63,0);h=hb;b=b+33554432|0;h=b>>>0<33554432?h+1|0:h;Vp(a,k,Qc((h&67108863)<<6|b>>>26,h>>>26|0)&255,0);a=i+1075676|0;f=a;b=x[a>>2];e=0;a=x[d+1298300>>2];c=gl(a,k);Kc:{if((c|0)==255){break Kc}h=x[a>>2];if(Sj(h)){break Kc}e=Db($d(a+318|0,c),10);J=x[a+4>>2];c=qt(c)|192;a=y[e|0]&-49;a=(b|0)<171?a|16:a;a=(b|0)>84?a|32:a;Tg(h,J,k,c,a&255);e=(a>>>5&1)+(a<<27>>31)|0}x[f>>2]=(e<<7)+128}Lc:{a=x[L>>2];if(!a|(y[a+60|0]&7)!=1){break Lc}b=x[a+48>>2];a=x[a+52>>2];if(qc(b,a)){break Lc}b=x[KM(g,0)>>2];a=Gf(a);if(b>>>0<z[a>>1]|y[a+2|0]){break Lc}aj(x[d+1298300>>2],k,1);Fb(m+8|0,s,109);a=x[o>>2];Qa=o,Ra=(Ib(x[x[m+8>>2]>>2],x[m+12>>2])?a:a&-4609)|4096,x[Qa>>2]=Ra;x[i+1075688>>2]=0;break uc}Fb(m+8|0,s,99);if(!Ib(x[x[m+8>>2]>>2],x[m+12>>2])|!(y[o+1|0]&16)|x[i+1075688>>2]){break uc}aj(x[d+1298300>>2],k,1);x[o>>2]=x[o>>2]&-513}Mc:{if(!C){break Mc}Fb(m+16|0,s,31);if(Ib(x[x[m+16>>2]>>2],x[m+20>>2])){break Mc}et(d,g)}b=x[o>>2];a=b&-65537;k=x[r>>2];C=i+1075016|0;t=i+1075012|0;f=k|(x[C>>2]|x[t>>2])?(a|b<<7&65536)^65536:a;x[o>>2]=f;r=i+1075664|0;a=r;x[a>>2]=0;x[a+4>>2]=0;h=i+1075834|0;a=y[h|0];b=a-4|0;a=a>>>0>=b>>>0?b:0;v[h|0]=a;n=i+1075835|0;b=y[n|0];c=b-4|0;b=b>>>0>=c>>>0?c:0;v[n|0]=b;Nc:{Oc:{Pc:{Qc:{Rc:{Sc:{Tc:{Uc:{Vc:{c=x[i+1075096>>2];Wc:{if(!c){break Wc}e=x[c+20>>2];if(!Sd(x[c>>2],e)|!x[i+1075068>>2]){break Wc}if(si(x[g+8>>2],x[g+12>>2])){break Vc}}x[i+1075008>>2]=0;break Uc}x[i+1075008>>2]=e;if(e){break Tc}}if(!Pj(x[g+656>>2])){break Sc}e=0;if(f&6144){break Sc}}q=x[i+1075676>>2];c=(D(k,256-q|0)|0)/16384|0;c=c>>>0>=127?127:c;if(a<<24>>24<0){v[h|0]=c;J=c}else{J=a}a=c>>>1|0;if((J&255)>>>0<a>>>0){v[h|0]=a}a=(D(k,q)|0)/16384|0;a=a>>>0>=127?127:a;if(b<<24>>24<0){v[n|0]=a;b=a}a=a>>>1|0;if(a>>>0>(b&255)>>>0){break Rc}break Qc}if((a&255)>>>0>=129){v[h|0]=0}e=0;a=0;if((b&255)>>>0<129){break Pc}}v[n|0]=a}if(!e){break Pc}e=128;h=x[d+24624>>2];if(h>>>0>=2){e=Ub(x[i+1075676>>2],0,256)}x[m+16>>2]=e;a=D(k,l)>>>(vd(y[d+1074366|0])?7:8)|0;Xc:{Yc:{Zc:{switch(y[d+1074364|0]){case 0:if(!(y[d+24616|0]&16)){break Yc}case 1:if((e|0)<=127){b=a>>>1|0;c=(D(a,e)|0)/256|0;break Xc}b=(D(a,256-e|0)|0)/256|0;c=a>>>1|0;break Xc;case 3:break Zc;default:break Yc}}Zh(m+16|0,255);c=x[m+16>>2];if((c|0)<=0){b=65536}else{b=z[(0-c<<1)+39920>>1]}b=D(b,a)>>>16|0;c=D(a,z[(c<<1)+39408>>1])>>>16|0;break Xc}b=(D(a,256-e|0)|0)/256|0;c=(D(a,e)|0)/256|0}a=x[L>>2];_c:{if(a){e=y[a+14|0];if(Mo(e)){break _c}}e=y[d+480268|0];if(Mo(e)){break _c}a=y[d+24648|0];e=y[O|0]&128?x[d+24668>>2]?-1:a:a}k=i+1075668|0;n=i+1075786|0;v[n|0]=e;a=x[j>>2];C=x[j+4>>2];if(!(f&131072|((a|0)!=0|(C|0)!=1)|(x[i+1075748>>2]|(e&255)==255))){v[n|0]=0}e=b;b=1<<x[d+1074360>>2];x[r>>2]=(e|0)/(b|0);b=(c|0)/(b|0)|0;x[k>>2]=(f&256)>>>8|0?(h|0)==2?0-b|0:b:b;if(f&128){x[j>>2]=0-a;x[j+4>>2]=0-(((a|0)!=0)+C|0)}q=0;h=db-16|0;db=h;x[g+28>>2]=0;x[g+32>>2]=0;Zh(g+672|0,524287);Zh(g+676|0,524287);b=x[g+676>>2];a=x[g+672>>2];$c:{ad:{c=x[g+88>>2];if(!(c&65536)){break ad}e=x[g+20>>2];f=x[g+24>>2];if((e|0)==(a|0)&(f|0)==(b|0)){break ad}c=x[d+24620>>2];f=(a|0)<=(e|0)&(b|0)<=(f|0);bd:{if(!f){b=ut(c,x[d+24636>>2]);break bd}b=ut(c,x[d+24640>>2])}if(!(!Ob(d+1074312|0,4)|!(y[d+480180|0]&4))){a=x[d+24620>>2];a=yka(a,a>>31,5,0);e=hb;a=a+500|0;e=a>>>0<500?e+1|0:e;b=Cc(zka(a,e,1e3,0),hb)}a=b;c=x[g+656>>2];cd:{if(f|!c){break cd}c=z[c+12>>1];if(!c){break cd}q=1;a=(D(c,x[d+24620>>2])>>>0)/1e5|0}f=a>>>0<=1?1:a;e=x[g+672>>2];j=x[g+20>>2];n=e-j<<12;r=g;c=x[g+676>>2];a=x[g+24>>2];k=c-a<<12;if(!(y[g+90|0]&32|(!(c|e)|(!(a|j)|q)))){x[h+12>>2]=x[d+1074380>>2];ke(h+12|0,b,2048);f=x[h+12>>2]}k=(k|0)/(f|0)|0;x[r+32>>2]=k;j=(n|0)/(f|0)|0;x[g+28>>2]=j;b=c+((D(f,k)|0)/-4096|0)|0;x[g+24>>2]=b;a=e+((D(f,j)|0)/-4096|0)|0;x[g+20>>2]=a;if(j|k){x[g+100>>2]=f;c=x[g+88>>2];break $c}x[g+24>>2]=c;x[g+20>>2]=e;b=c;a=e;c=x[g+88>>2]&-65537;break $c}x[g+24>>2]=b;x[g+20>>2]=a;c=c&-65537}x[g+88>>2]=c&-2097153;x[g+40>>2]=b<<12;x[g+36>>2]=a<<12;db=h+16|0;f=x[o>>2];if(!(f&512)){break Oc}break Nc}x[t>>2]=0;x[C>>2]=0;x[i+1075068>>2]=0;if(x[i+1075088>>2]){break Oc}if(!x[i+1075084>>2]){break Nc}}a=z[d+480212>>1];w[d+480212>>1]=a+1;w[((a<<1)+d|0)+1074478>>1]=u}x[i+1075660>>2]=f;a=i+1075843|0;v[a|0]=y[a|0]&253}u=u+1|0;continue}break}}db=m+48|0;if(K){a=x[d+480208>>2];break h}if(vd(y[d+1298420|0])){b=x[d+480208>>2]|512;break i}i=0;dd:{a=x[d+24620>>2]/10|0;c=Cc(a,a>>31);if(!c){break dd}b=c>>>0>=1048576?1048576:c;x[d+1074380>>2]=b;g=z[d+480212>>1];e=d+1074376|0;while(1){if((g|0)==(i|0)){break dd}a=e+D(z[(e+(i<<1)|0)+102>>1],872)|0;f=a+1288|0;x[f>>2]=0;x[f+4>>2]=0;x[a+716>>2]=b;f=x[a+640>>2]<<12;x[a+656>>2]=f;h=x[a+636>>2]<<12;x[a+652>>2]=h;x[a+704>>2]=x[a+704>>2]|65536;x[a+644>>2]=(0-h|0)/(b|0);x[a+648>>2]=(0-f|0)/(b|0);i=i+1|0;continue}}a=x[d+480208>>2];b=a|256;if(c){break i}b=a|512}a=b;x[d+480208>>2]=a}if(!(a&512)){break g}Qa=d+1074392|0,Ra=al(Ca),x[Qa>>2]=Ra}db=M+96|0;break f}x[M+80>>2]=512;a=x[d+1074380>>2];x[M+88>>2]=ea;x[M+84>>2]=a;m=LB(M+80|0);if(x[d+24632>>2]){f=0;a=db-48|0;db=a;b=m<<2;while(1){if((f|0)==4){ed:{f=0;while(1){if((f|0)==4){break ed}x[(a+32|0)+(f<<2)>>2]=((f<<11)+d|0)+16396;f=f+1|0;continue}}}else{x[a+32>>2]=0;c=((f<<11)+d|0)+16396|0;Uz(c,b+c|0,a+32|0);f=f+1|0;continue}break}b=rd(a+20|0,a+32|0,x[d+24632>>2],m);c=x[x[da>>2]+8>>2];x[a+16>>2]=x[b+8>>2];e=x[b+4>>2];x[a+8>>2]=x[b>>2];x[a+12>>2]=e;ib[c|0](da,a+8|0);db=a+48|0}if(vd(Ba)){a=0;while(1){if((a|0)==4){a=rd(M+68|0,M+80|0,x[d+24632>>2],m);b=x[x[ma>>2]+8>>2];x[M+40>>2]=x[a+8>>2];c=x[a+4>>2];x[M+32>>2]=x[a>>2];x[M+36>>2]=c;ib[b|0](ma,M+32|0)}else{x[(M+80|0)+(a<<2)>>2]=((a<<11)+d|0)+16396;a=a+1|0;continue}break}}$=0;fa=0;k=db-48|0;db=k;if(m){C=d+12|0;t=d+24592|0;L=d+24588|0;Tm(C,m,t,L);if(A[d+24624>>2]>=3){Tm(d+8204|0,m,d+24600|0,d+24596|0)}w[k+42>>1]=0;ra=d+1074312|0;Da=d+24648|0;Ea=d+24596|0;Fa=d+24600|0;Ga=d+8204|0;O=d+397452|0;U=d+397448|0;r=d+393352|0;sa=d+397456|0;ia=d+1074376|0;while(1){if(z[d+480212>>1]<=$>>>0){Qa=d,Ra=z[Ve(d+480214|0,k+42|0)>>1],w[Qa+480214>>1]=Ra}else{l=ia+($<<1)|0;u=z[l+102>>1];a=D(u,872);P=a+ia|0;fd:{gd:{if(x[P+632>>2]){break gd}b=a+d|0;if(x[b+1075088>>2]){break gd}if(!x[b+1075084>>2]){break fd}}h=a+d|0;a=y[h+1075786|0]+1&255;if(a>>>0<=5){f=x[(a<<2)+27840>>2]}else{f=0}G=h+1075080|0;g=x[G>>2];hd:{if(!(!(g&16777216)&y[d+24612|0]>>>5)){a=t;b=L;c=g;e=C;if(!(c&8388608)){break hd}}a=U;b=O;if(!y[sa+12|0]){Tm(r,m,a,b)}v[sa+12|0]=1;u=z[l+102>>1];c=x[G>>2];e=r}i=b;b=c>>>8&A[d+24624>>2]>2;J=b?Ea:i;T=b?Fa:a;c=b?Ga:e;ja=Dl(d,ia,u&65535,2,1);ta=(ja-1&255)>>>0>249;id:{if(ta){break id}b=x[(D(ja,160)+d|0)+906140>>2];if(!b){break id}a=x[b+24>>2];if(!a){break id}J=b+36|0;T=b+40|0;if(!(v[b+28|0]&1)){Tm(a,m,T,J);x[b+28>>2]=x[b+28>>2]|1}c=a}l=P+616|0;if(y[h+1075843|0]&8){sD(l,c,m);a=h+1075084|0;x[T>>2]=x[T>>2]+x[a>>2];x[J>>2]=x[J>>2]+x[h+1075088>>2];x[a>>2]=0;x[a+4>>2]=0;break fd}aa=0;a=k+20|0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;b=d+1074312|0;Qa=a,Ra=Ob(b,33),v[Qa+16|0]=Ra;Qa=a,Ra=Ob(b,116)^1,v[Qa+17|0]=Ra;if(x[l+16>>2]){qD(a,l);b=x[l+12>>2];e=b>>31;o=e^x[l+8>>2];b=(b^e)-((e>>>0>o>>>0)+e|0)|0;x[a+12>>2]=b>>>0>8191?2:16384/(b+1>>>0)|0}Ha=g>>>12&8|(g>>>5&2|(f|g&1));Ia=fa&65535;Ja=h+1075795|0;Ka=h+1075778|0;La=h+1075688|0;Ma=h+1075024|0;Na=h+1075020|0;Oa=h+1075668|0;Pa=h+1075664|0;V=h+1075088|0;X=h+1075084|0;ua=h+1075016|0;va=h+1075012|0;ga=h+1075096|0;Y=h+1075076|0;I=h+1075068|0;K=h+1075e3|0;ha=h+1075072|0;Z=h+1075092|0;n=a;a=m;while(1){jd:{b=x[Z>>2];q=b?a>>>0>b>>>0?b:a:a;x[k+12>>2]=q;kd:{ld:{if(!q){break ld}b=x[K+4>>2];i=b;g=x[K>>2];if(!(b|g)){break ld}h=x[I>>2];if(!h){break ld}b=x[n>>2];if(!b){break ld}u=x[G>>2];j=u&2;s=x[ha>>2];x[P+632>>2]=b;b=x[l>>2];f=x[l+4>>2];e=f;md:{nd:{o=s&u<<30>>31;if((e|0)<(o|0)){if((i|0)<0){b=Gg(0,o<<1,b,e);x[l>>2]=b;e=hb;x[l+4>>2]=e;if(!(e>>>0<h+o>>>1>>>0&(e|0)>=(o|0))){b=0;x[l>>2]=b;e=o;x[l+4>>2]=e}od:{if(u&4){u=u&-129;x[G>>2]=u;i=0-(((g|0)!=0)+i|0)|0;g=0-g|0;x[K>>2]=g;x[K+4>>2]=i;break od}x[l>>2]=b;e=h-1|0;x[l+4>>2]=e}if(!j){break ld}if(e>>>0<h>>>0){break md}break ld}if((e|0)>0|(e|0)>=0){break md}e=0;break nd}if(f>>>0<h>>>0){break md}if(!j){break ld}if(u&4){if(!!g&(i|0)>=0|(i|0)>0){i=0-(((g|0)!=0)+i|0)|0;g=0-g|0;x[K>>2]=g;x[K+4>>2]=i}u=u|128;x[G>>2]=u;if(y[k+37|0]){f=y[k+36|0];j=x[Y>>2]-(f+s|0)|0;b=Gg(b,e,0,h);e=hb;if(e>>>0<j>>>0){b=Gg(0,h-f|0,b,e);e=hb;break nd}e=s;b=0;break nd}e=0-b|0;f=(h<<1)-((1-((b|0)!=0)|0)+f|0)|0;b=e;x[l>>2]=b;ba=0;e=ba|f;x[l+4>>2]=e;if(f>>>0<h>>>0&f>>>0>s>>>0){break md}x[k+44>>2]=y[k+36|0]+1;e=ba|h-x[Cb(I,k+44|0)>>2];break nd}if((i|0)<0){e=0-(((g|0)!=0)+i|0)|0;i=e;g=0-g|0;x[K>>2]=g;x[K+4>>2]=e}Qb(l,0,o-h|0);u=x[G>>2]|8192;x[G>>2]=u;b=x[l>>2];e=x[l+4>>2];break md}x[l>>2]=b;x[l+4>>2]=e}pd:{if((e|0)<(o|0)){if((e|i)<0){break ld}x[k+44>>2]=q;h=g;f=i;break pd}f=x[I>>2];if(f>>>0<e>>>0|(!!g&(i|0)>=0|(i|0)>0)&(e|0)==(f|0)){break ld}x[k+44>>2]=q;f=i>>31;j=f^g;h=j-f|0;f=(f^i)-((j>>>0<f>>>0)+f|0)|0}s=h;j=f;tc(k+12|0,x[k+32>>2]);wa=x[k+12>>2];Ff(b,e,bf(g,i,wa-1|0),hb);f=hb;h=x[ha>>2];xa=h>>>0>e>>>0|h+16>>>0<=e>>>0;if(xa){u=u&-8193;x[G>>2]=u}h=f;qd:{rd:{ba=x[k+24>>2];sd:{if(ba){f=x[k+28>>2];if(f>>>0<=e>>>0){td:{if((i|0)<0){g=0;i=f;break td}g=b;i=e;b=0;e=x[Y>>2]}Qa=k,Ra=Uo(Gg(Gg(b,e,g,i),hb,1,0),hb,s,j)+1|0,x[Qa+44>>2]=Ra;x[P+632>>2]=ba;break qd}if(!(xa|!(u&8192))){Qa=k,Ra=Uo(Gg(Gg(0,o+16|0,b,e),hb,1,0),hb,s,j)+1|0,x[Qa+44>>2]=Ra;Qa=P,Ra=ba+D(x[Y>>2]-o|0,rk(z[x[ga>>2]+34>>1]))|0,x[Qa+632>>2]=Ra;break qd}if(!g&(i|0)<=0|(i|0)<0){break sd}if(q>>>0<2|f>>>0>h>>>0){break rd}Qa=k,Ra=Uo(Gg(Gg(0,f,b,e),hb,1,0),hb,s,j)+1|0,x[Qa+44>>2]=Ra;break qd}if((i|0)>0|(i|0)>=0){break rd}}if((h|0)>=(o|0)){break qd}Qa=k,Ra=Uo(Gg(Gg(b,e,0,o),hb,1,0),hb,s,j)+1|0,x[Qa+44>>2]=Ra;break qd}g=x[I>>2];if((g|0)>(h|0)){break qd}Qa=k,Ra=Uo(Gg(Gg(0,g,b,e),hb,1,0),hb,s,j)+1|0,x[Qa+44>>2]=Ra}To(k+44|0,1,wa);g=x[k+44>>2];if((g|0)>0){break kd}}x[P+632>>2]=0;x[I>>2]=0;x[l>>2]=0;x[l+4>>2]=0;x[Z>>2]=0;sD(l,c,a);x[T>>2]=x[T>>2]+x[X>>2];x[J>>2]=x[J>>2]+x[V>>2];x[V>>2]=0;x[X>>2]=0;x[G>>2]=x[G>>2]&-129;break jd}ud:{vd:{if(Ia>>>0<A[d+24608>>2]){b=4;if(x[Z>>2]){break vd}b=0;if(x[ua>>2]|x[va>>2]){break vd}}Qb(l,bf(x[K>>2],x[K+4>>2],g),hb);aa=0;x[V>>2]=0;x[X>>2]=0;c=(g<<3)+c|0;break ud}e=(g<<3)+c|0;f=e-8|0;x[X>>2]=0-x[f>>2];h=e-4|0;x[V>>2]=0-x[h>>2];ib[x[((b|Ha)<<2)+27456>>2]](l,Da,c,g);x[X>>2]=x[X>>2]+x[f>>2];x[V>>2]=x[V>>2]+x[h>>2];aa=1;c=e}b=x[Z>>2];wd:{if(!b){break wd}if(b>>>0<=g>>>0){x[Z>>2]=0;x[va>>2]=x[Pa>>2];x[ua>>2]=x[Oa>>2];x[Na>>2]=0;x[Ma>>2]=0;if(x[La>>2]|!(y[G+1|0]&16)){break wd}x[I>>2]=0;x[P+632>>2]=0;break wd}x[Z>>2]=b-g}o=0;u=0;b=x[l+4>>2];u=b>>>0>=A[Y>>2]?(y[G|0]&2)>>>1|0:u;e=b;b=x[I>>2];o=x[G>>2]&2|(e>>>0<b>>>0|!b)?o:!z[Ka>>1];a=a-g|0;Fb(k+12|0,ra,85);xd:{yd:{zd:{if(!Ib(x[x[k+12>>2]>>2],x[k+16>>2])){break zd}b=y[Ja|0];if(!b){break zd}if(b>>>0<=z[d+480190>>1]){break yd}}q=0;break xd}g=x[ga>>2];b=D(b,104)+d|0;e=b+484380|0;q=(g|0)!=(e|0);if((e|0)==(g|0)|(o|u)!=1){break xd}x[ga>>2]=e;e=x[b+484400>>2];x[P+632>>2]=e;g=z[b+484414>>1];x[G>>2]=g|x[G>>2]&-768;f=g<<30>>31;g=x[b+484388>>2];x[I>>2]=f&g;b=x[b+484384>>2];x[ha>>2]=b;x[Y>>2]=g;x[l+4>>2]=b;qD(n,l);if(!e){break jd}if((a|0)>0){continue}break jd}Ad:{if(!u|q){break Ad}Fb(k+12|0,ra,83);if(!Ib(x[x[k+12>>2]>>2],x[k+16>>2])|x[ha>>2]){break Ad}x[l>>2]=x[l>>2];x[l+4>>2]=0;b=x[x[ga>>2]+8>>2];x[I>>2]=b;x[Y>>2]=b}if((a|0)>0){continue}}break}x[P+632>>2]=x[n>>2];fa=aa+fa|0;w[k+42>>1]=fa;if(ta|!aa){break fd}a=x[(D(ja,160)+d|0)+906140>>2];if(!a){break fd}ib[x[x[a>>2]+148>>2]](a)}$=$+1|0;continue}break}}db=k+48|0;n=x[d+1298300>>2];if(ud(n)){a=W;c=m;b=(D(x[d+480232>>2],x[d+480236>>2])>>>0)/48|0;k=db-16|0;db=k;Bd:{if(!y[n+534|0]){break Bd}e=yka(b,0,6169,0);b=hb;h=b>>>16|0;r=Qc((b&65535)<<16|e>>>16,h);while(1){if(!c){break Bd}f=x[n>>2];h=x[f>>2];b=x[f+4>>2];while(1){if((b|0)>=(h|0)){x[f+8>>2]=x[f+12>>2];h=0;i=0;o=0;b=db-16|0;db=b;while(1){if((o|0)==18){e=(h|0)>=32767?32767:h;w[f+12>>1]=(e|0)<=-32768?-32768:e;e=(i|0)>=32767?32767:i;w[f+14>>1]=(e|0)<=-32768?-32768:e;w[f+3832>>1]=z[f+3832>>1]+1;e=(z[f+3834>>1]+1>>>0)%13440|0;w[f+3834>>1]=e;e=e>>>0<6720?e:13440-e|0;w[f+3836>>1]=e>>>8;if(!y[f+3843|0]){w[f+3836>>1]=e>>>10}e=z[f+3838>>1]+1|0;w[f+3838>>1]=e;if((e&65535)>>>0>=1024){w[f+3838>>1]=0;w[f+3840>>1]=z[f+3840>>1]+1&7}db=b+16|0}else{g=f+D(o,44)|0;Cd:{if(!y[g+56|0]){w[b+12>>1]=0;w[b+14>>1]=0;break Cd}l=x[g+32>>2];e=z[l+3840>>1];if(e&3){l=(z[g+36>>1]>>>7&7)>>>!y[l+3844|0]>>>(e&1)<<z[g+38>>1];e=e&4?0-l|0:l}else{e=0}l=x[g+52>>2];Dd:{if(l){t=z[l+32>>1];C=z[g+48>>1];e=e<<16>>16;l=ag(x[g+16>>2],x[g+40>>2],e,0,w[g+46>>1]);s=x[g+40>>2];j=x[g+20>>2];if(!t){if(!C){l=ag(j,s,e,l,0);l=ag(x[g+24>>2],x[g+40>>2],e,l,0);e=ag(x[g+28>>2],x[g+40>>2],e,l,0);break Dd}s=ag(j,s,e,0,0);s=ag(x[g+24>>2],x[g+40>>2],e,s,0);e=ag(x[g+28>>2],x[g+40>>2],e,s,0)+l|0;break Dd}if(!C){l=ag(j,s,e,l,0);s=ag(x[g+24>>2],x[g+40>>2],e,0,0);e=ag(x[g+28>>2],x[g+40>>2],e,s,0)+l|0;break Dd}s=ag(j,s,e,0,0);e=(ag(x[g+24>>2],x[g+40>>2],e,s,0)+l|0)+ag(x[g+28>>2],x[g+40>>2],e,0,0)|0;break Dd}C=z[g+48>>1];e=e<<16>>16;l=ag(x[g+16>>2],x[g+40>>2],e,0,w[g+46>>1]);s=x[g+40>>2];j=x[g+20>>2];if(!C){e=ag(j,s,e,l,0);break Dd}e=ag(j,s,e,0,0)+l|0}w[b+14>>1]=y[g+57|0]?e:0;w[b+12>>1]=y[g+58|0]?e:0}o=o+1|0;i=w[b+12>>1]+i|0;h=w[b+14>>1]+h|0;continue}break}h=x[f>>2];b=x[f+4>>2]-h|0;x[f+4>>2]=b;continue}break}e=h-b|0;w[k+14>>1]=(D(w[f+12>>1],b)+D(e,w[f+8>>1])|0)/(h|0);w[k+12>>1]=(D(w[f+14>>1],b)+D(e,w[f+10>>1])|0)/(h|0);x[f+4>>2]=b+49716;x[a>>2]=x[a>>2]+D(r,w[k+14>>1]);x[a+4>>2]=x[a+4>>2]+D(r,w[k+12>>1]);a=a+8|0;c=c-1|0;continue}}db=k+16|0}a=y[H+12|0];if(a|x[H+16>>2]){if(!a){Tm(_,m,qa,pa)}a=x[H>>2];b=x[H+80>>2];c=D(a,b)>>>4|0;c=c>>>0>=32767?32767:c;w[H+98>>1]=c;w[H+96>>1]=c;c=x[H+49948>>2];e=D(c,a)>>>4|0;e=e>>>0>=65536?65536:e;g=e+127>>>3|0;w[H+49946>>1]=g;e=e+255>>>4|0;w[H+49944>>1]=e;w[H+49942>>1]=e;w[H+49940>>1]=g;b=(b|0)>(c|0)?b:c;a=36-a>>>1|0;a=16-(a>>>0<=8?8:a)|0;a=16-(D((b|0)>=32768?32768:b,a>>>0<=16?a:0)>>15)|0;f=0;while(1){if((f|0)!=(m|0)){b=f<<3;c=b+W|0;x[c>>2]=x[c>>2]+D(a,x[b+_>>2]>>4);b=b|4;c=b+W|0;x[c>>2]=x[c>>2]+D(a,x[b+_>>2]>>4);f=f+1|0;continue}break}l=H+68|0;i=0;c=w[H+84>>1];b=x[H+40>>2];h=x[H+36>>2];while(1){if((i|0)==(m|0)){x[H+40>>2]=b;x[H+36>>2]=h;g=m}else{a=(i<<3)+_|0;e=x[a>>2]>>12;h=(D(c,e-h|0)>>15)+e|0;x[a>>2]=h;e=a;a=x[a+4>>2]>>12;b=(D(c,a-b|0)>>15)+a|0;x[e+4>>2]=b;i=i+1|0;continue}break}if(g){c=_;a=g;o=x[l>>2]-1|0;i=z[l+22>>1];k=z[l+20>>1];b=w[l+26>>1];e=w[l+24>>1];j=w[l+18>>1];n=w[l+16>>1];u=x[l+4>>2];f=l+32928|0;while(1){if(a){h=bd(x[c>>2]);s=bd(x[c+4>>2]);k=bd((k<<16>>16)-h|0);i=bd((i<<16>>16)-s|0);k=Sc(bd((D(k,n)|0)/65536<<1)+h|0);i=Sc(bd((D(i,j)|0)/65536<<1)+s|0);s=f+(u<<2)|0;r=w[s>>1];h=Sc(((D(r,e)|0)/-65536|0)+k|0);u=u+1&127;C=f+(u<<2)|0;s=w[s+2>>1];t=Sc(((D(s,b)|0)/-65536|0)+i|0);w[C+2>>1]=t;w[C>>1]=h;o=o+1&8191;C=l+(o<<2)|0;Qa=C,Ra=Sc(r+((D(e,h)|0)/65536|0)|0),w[Qa+160>>1]=Ra;Qa=C,Ra=Sc(s+((D(b,t)|0)/65536|0)|0),w[Qa+162>>1]=Ra;c=c+8|0;a=a-1|0;continue}break}w[l+22>>1]=i;w[l+20>>1]=k;x[l+4>>2]=u}h=H+49892|0;L=H+33508|0;c=g;a=_;while(1){if(c){e=x[H+76>>2];f=e&4095;i=L+(f<<2)|0;b=a;f=4096-f|0;r=e-x[H+49892>>2]&4095;e=4096-r|0;e=e>>>0>f>>>0?f:e;e=c>>>0<e>>>0?c:e;f=e>>>0>=64?64:e;u=f;e=0;k=db-32|0;db=k;o=x[l>>2];while(1){if((e|0)==7){Ed:{j=w[l+28>>1]/8<<16>>16;Fd:while(1){if(!u){break Ed}u=u-1|0;e=0;q=0;s=0;while(1)if((e|0)==4){e=4;o=0;C=Sc((s|0)/32768|0);t=Sc((q|0)/32768|0);q=0;while(1)if((e|0)==7){e=Sc(C+((q|0)/32768|0)|0);w[i>>1]=e;x[b>>2]=D(e,j);e=Sc(t+((o|0)/32768|0)|0);w[i+2>>1]=e;x[b+4>>2]=D(e,j);b=b+8|0;i=i+4|0;continue Fd}else{s=k+(e<<2)|0;n=x[s>>2]+1&8191;x[s>>2]=n;J=o;o=l+(n<<2)|0;n=w[o+160>>1];s=l+(e<<4)|0;O=w[o+162>>1];o=(J+D(n,w[s+44>>1])|0)+D(O,w[s+46>>1])|0;q=(D(n,w[s+40>>1])+q|0)+D(O,w[s+42>>1])|0;e=e+1|0;continue}}else{o=k+(e<<2)|0;n=x[o>>2]+1&8191;x[o>>2]=n;n=l+(n<<2)|0;C=w[n+160>>1];o=l+(e<<4)|0;n=w[n+162>>1];q=(D(C,w[o+44>>1])+q|0)+D(n,w[o+46>>1])|0;s=(D(C,w[o+40>>1])+s|0)+D(n,w[o+42>>1])|0;e=e+1|0;continue}}}}else{x[k+(e<<2)>>2]=o+(x[(l+(e<<4)|0)+32>>2]^-1);e=e+1|0;continue}break}db=k+32|0;o=L+(r<<2)|0;e=a;b=f;O=h+2|0;i=x[h+4>>2];k=h+24640|0;s=h+16448|0;while(1){j=i&2047;if(b){P=h+8256|0;U=w[P+((i+1206&2047)<<2)>>1];r=h- -64|0;t=w[r+((i+1750&2047)<<2)>>1];q=w[(O+((i+754&2047)<<2)|0)+8256>>1];u=w[(O+((i+1602&2047)<<2)|0)- -64>>1];n=w[o>>1];C=w[o+2>>1];G=k+((i+502&2047)<<2)|0;K=w[G>>1];I=bd(w[h+32>>1]-K|0);G=w[G+2>>1];J=bd(w[h+34>>1]-G|0);T=w[h+26>>1];V=k+((i+22&2047)<<2)|0;X=w[V>>1];Y=bd(w[h+36>>1]-X|0);Z=w[h+28>>1];V=w[V+2>>1];$=bd(w[h+38>>1]-V|0);aa=w[h+30>>1];K=Sc(bd((D(I,w[h+24>>1])|0)/65536<<1)+K|0);w[h+32>>1]=K;Qa=h,Ra=Sc(bd((D(J,T)|0)/65536<<1)+G|0),w[Qa+34>>1]=Ra;Qa=h,Ra=Sc(bd((D(Y,Z)|0)/65536<<1)+X|0),w[Qa+36>>1]=Ra;G=Sc(bd((D($,aa)|0)/65536<<1)+V|0);w[h+38>>1]=G;K=bd((D(K,w[h+16>>1])|0)/32768|0);I=bd((D(G,w[h+22>>1])|0)/32768|0);G=bd(K+((n|0)/4<<16>>16)|0);K=bd(I+((C|0)/4<<16>>16)|0);n=w[h+8>>1];I=bd(G+((D(n,t)|0)/-65536|0)|0);J=r;r=j<<2;J=J+r|0;C=w[h+10>>1];T=bd(K+((D(C,u)|0)/-65536|0)|0);w[J+2>>1]=T;w[J>>1]=I;t=bd(t+((D(n,I)|0)/65536|0)|0);I=s+r|0;J=bd(u+((D(C,T)|0)/65536|0)|0);w[I+2>>1]=J;w[I>>1]=t;u=bd(t+G|0);G=bd(K+J|0);t=s+((i+682&2047)<<2)|0;K=w[t+2>>1];I=w[t>>1];t=bd((D(K,w[h+42>>1])+D(I,w[h+40>>1])|0)/32768|0);i=s+((i+426&2047)<<2)|0;J=w[i+2>>1];T=w[i>>1];i=bd((D(J,w[h+46>>1])+D(T,w[h+44>>1])|0)/32768|0);I=bd(bd(u+I|0)-t|0);K=bd(bd(G+K|0)-i|0);u=bd(bd(u+T|0)-t|0);G=bd(bd(G+J|0)-i|0);t=bd(t+((D(n,U)|0)/-65536|0)|0);P=r+P|0;J=bd(i+((D(q,C)|0)/-65536|0)|0);w[P+2>>1]=J;w[P>>1]=t;n=(D(n,t)|0)/65536|0;i=bd(n+U|0);r=k+r|0;C=(D(C,J)|0)/65536|0;t=bd(C+q|0);w[r+2>>1]=t;w[r>>1]=i;Qa=e,Ra=(x[e>>2]+D(bd(i+I|0),w[h+48>>1])|0)+D(bd(t+K|0),w[h+50>>1])|0,x[Qa>>2]=Ra;Qa=e,Ra=(x[e+4>>2]+D(bd(bd(n)+u|0),w[h+52>>1])|0)+D(bd(bd(C)+G|0),w[h+54>>1])|0,x[Qa+4>>2]=Ra;e=e+8|0;i=j+1|0;o=o+4|0;b=b-1|0;continue}break}x[h+4>>2]=j;x[H+76>>2]=f+x[H+76>>2]&4095;x[H+68>>2]=f+x[H+68>>2]&8191;c=c-f|0;a=(f<<3)+a|0;continue}break}x[H+68>>2]=x[H+68>>2]&8191;i=_;e=W;b=g;h=0;l=0;o=x[H+56>>2];c=x[H- -64>>2];f=x[H+52>>2];a=x[H+60>>2];while(1){if(b){h=x[i>>2];l=x[i+4>>2];c=c-l|0;c=(((c|0)/1024|0)-c|0)+o|0;x[e+4>>2]=c+x[e+4>>2];a=a-h|0;a=(((a|0)/1024|0)-a|0)+f|0;x[e>>2]=a+x[e>>2];o=c+((c|0)/-512|0)|0;f=a+((a|0)/-512|0)|0;e=e+8|0;i=i+8|0;b=b-1|0;a=h;c=l;continue}break}x[H+64>>2]=l;x[H+60>>2]=h;x[H+56>>2]=o;x[H+52>>2]=f;a=x[H+20>>2];Gd:{if(y[H+12|0]){break Gd}a=x[H+16>>2];if(a>>>0>g>>>0){a=a-g|0;break Gd}QK(H,qa,pa);a=0}v[H+12|0]=0;x[H+16>>2]=a}if(x[d+946300>>2]){Hd:{q=0;e=0;g=m<<2;u=z[d+480214>>1]!=0;ya=B[d+1074336>>2];R=B[d+1074332>>2];while(1)if((q|0)==250){k=d+12|0;l=d+12300|0;i=d+14348|0;pv(k,l,i,m,R);a=d+1074476|0;C=y[a|0];v[a|0]=0;a=i;b=l;while(1){Id:{Jd:{Kd:{if((e|0)!=250){s=(D(e,160)+d|0)+906300|0;g=x[s>>2];if(!g|!x[g+24>>2]){break Id}if(!Yh(g+44|0)){break Id}o=g;Ld:{if(ov(y[s+24|0])){break Ld}c=ib[x[x[g>>2]+144>>2]](g)|0;o=x[s>>2];if(c){break Ld}q=0;if(y[o+28|0]&2){break Ld}while(1){if((e|0)==(q|0)){break Id}c=D(q,160);q=q+1|0;if((Rm(x[(c+d|0)+906328>>2])|0)!=(e|0)){continue}break}}c=x[g+44>>2];j=Ac(c,0);n=Ac(c,1);r=(b|0)==(j|0);b=r?l:b;f=b;a=r?i:a;h=x[s+28>>2];c=a;Md:{if(!h){break Md}h=Rm(h);c=a;if(h>>>0<=e>>>0){break Md}c=a;if(h>>>0>249){break Md}h=x[(D(h,160)+d|0)+906300>>2];c=a;if(!h){break Md}if(!(y[o+28|0]&4)){ib[x[x[h>>2]+148>>2]](h)}c=a;if(!Yh(h+44|0)){break Md}c=x[h+44>>2];f=Ac(c,0);c=Ac(c,1)}if(!ov(y[s+24|0])){break Jd}q=0;Nd:{if(r){break Nd}while(1){if((m|0)==(q|0)){break Nd}h=q<<2;r=h+j|0;t=b+h|0;B[r>>2]=B[t>>2]+B[r>>2];r=h+n|0;h=a+h|0;B[r>>2]=B[h>>2]+B[r>>2];x[t>>2]=0;x[h>>2]=0;q=q+1|0;continue}}a=c;b=f;if(!(u&1)){break Jd}a=x[s>>2];if(a){ib[x[x[a>>2]+148>>2]](a)}h=Rm(x[s+28>>2]);a=e;while(1){b=h;h=b&255;if(h>>>0>249|h>>>0<=(a&255)>>>0){break Kd}r=D(h,160)+d|0;h=Rm(x[r+906328>>2]);a=b;b=x[r+906300>>2];if(!b){continue}ib[x[x[b>>2]+148>>2]](b);continue}}c=0;while(1){if((c|0)!=(m|0)){R=E(B[b>>2]*ya);Od:{if(E(F(R))<E(2147483648)){e=~~R;break Od}e=-2147483648}x[k>>2]=e;R=E(B[a>>2]*ya);Pd:{if(E(F(R))<E(2147483648)){e=~~R;break Pd}e=-2147483648}x[k+4>>2]=e;c=c+1|0;k=k+8|0;a=a+4|0;b=b+4|0;continue}break}break Hd}a=c;b=f}Qd:{Rd:{h=y[s+24|0];if(!((h&2)>>>1|0)){if(!nD(h)|!(y[o+28|0]&4)){break Rd}}q=0;while(1){if((m|0)==(q|0)){break Qd}g=q<<2;h=g+f|0;B[h>>2]=B[g+j>>2]+B[h>>2];h=c+g|0;B[h>>2]=B[g+n>>2]+B[h>>2];q=q+1|0;continue}}if(C){ib[x[x[g>>2]+128>>2]](g)}ib[x[x[g>>2]+60>>2]](g,f,c,m);x[o+32>>2]=m+x[o+32>>2];if(!nD(y[s+24|0])){break Qd}if((ib[x[x[g>>2]+156>>2]](g)|0)<=0){break Qd}q=0;if(A[o+32>>2]<x[d+24620>>2]<<2>>>0){break Qd}Sd:{while(1){if((m|0)==(q|0)){break Sd}g=q<<2;R=B[g+f>>2];Td:{if(R>=E(1.1920928955078125e-7)|R<=E(-1.1920928955078125e-7)){break Td}R=B[c+g>>2];if(R>=E(1.1920928955078125e-7)){break Td}q=q+1|0;if(!(R<=E(-1.1920928955078125e-7))){continue}}break}x[o+32>>2]=0;break Qd}x[o+28>>2]=x[o+28>>2]|4}x[o+28>>2]=x[o+28>>2]&-3}e=e+1|0;continue}}else{f=(D(q,160)+d|0)+906300|0;a=x[f>>2];Ud:{if(!a|!x[a+24>>2]){break Ud}if(!Yh(a+44|0)){break Ud}if(!(ib[x[x[a>>2]+112>>2]](a)|0)){ib[x[x[a>>2]+108>>2]](a,1);ib[x[x[a>>2]+120>>2]](a)}c=x[a+44>>2];b=Ac(c,0);c=Ac(c,1);Vd:{if(v[a+28|0]&1){pv(x[a+24>>2],b,c,m,R);break Vd}h=a+40|0;if(x[h>>2]|x[a+36>>2]){Tm(x[a+24>>2],m,h,a+36|0);pv(x[a+24>>2],b,c,m,R);break Vd}Vb(b,0,g);Vb(c,0,g)}b=a;a=x[a+28>>2];x[b+28>>2]=a&-2;if(ov(y[f+24|0])){break Ud}u=!(a&4)|u}q=q+1|0;continue}}}if(x[d+24624>>2]==1){c=0;while(1){if((c|0)!=(m|0)){a=(c<<3)+W|0;x[(c<<2)+W>>2]=(x[a+4>>2]+x[a>>2]|0)/2;c=c+1|0;continue}break}}if(vd(y[d+1074365|0])){b=0;g=db-16|0;db=g;Wd:{if(!x[d+1074376>>2]){i=d+1074460|0;a=i;x[a>>2]=0;x[a+4>>2]=0;a=x[d+1074456>>2];x[d+1074468>>2]=a;break Wd}a=x[d+1074456>>2];c=x[d+1074468>>2];Xd:{if((a|0)==(c|0)){e=x[d+1074460>>2];break Xd}x[d+1074468>>2]=a;e=x[d+24620>>2];f=d+1074460|0;Yd:{if((a|0)>(c|0)){e=ut(e,x[d+24636>>2]);break Yd}e=ut(e,x[d+24640>>2])}x[f>>2]=e;x[d+1074464>>2]=e;c=a}i=d+1074460|0;if((e|0)<=0){break Wd}c=(c<<12)-x[d+1074472>>2]|0;b=(c|0)/(e|0)|0;if(y[d+1074368|0]!=2){break Wd}x[g+12>>2]=50;f=x[d+1074464>>2];x[g+8>>2]=1e4/(f+1|0);h=x[Re(g+12|0,g+8|0)>>2];while(1){k=b>>31;if((h|0)>=((k^b)-k|0)){break Wd}e=e+f|0;x[i>>2]=e;b=(c|0)/(e|0)|0;continue}}Zd:{_d:{switch(x[d+24624>>2]-1|0){case 0:c=0;h=(m|0)>0?m:0;k=a<<12;e=d+12|0;l=a>>31;while(1){if((c|0)==(h|0)){break Zd}$d:{if(x[i>>2]>0){f=x[d+1074472>>2]+b|0;x[d+1074472>>2]=f;o=x[e>>2];Qa=e,Ra=Cc(zka(yka(o,o>>31,f,f>>31),hb,1048576,0),hb),x[Qa>>2]=Ra;x[d+1074460>>2]=x[d+1074460>>2]-1;break $d}f=x[e>>2];Qa=e,Ra=Cc(zka(yka(f,f>>31,a,l),hb,256,0),hb),x[Qa>>2]=Ra;x[d+1074472>>2]=k}c=c+1|0;e=e+4|0;continue};case 1:c=0;k=(m|0)>0?m:0;l=a<<12;e=d+12|0;f=a>>31;while(1){if((c|0)==(k|0)){break Zd}ae:{if(x[i>>2]>0){h=x[d+1074472>>2]+b|0;x[d+1074472>>2]=h;o=x[e>>2];Qa=e,Ra=Cc(zka(yka(o,o>>31,h,h>>31),hb,1048576,0),hb),x[Qa>>2]=Ra;h=x[d+1074472>>2];o=h;s=h>>31;h=x[e+4>>2];Qa=e,Ra=Cc(zka(yka(o,s,h,h>>31),hb,1048576,0),hb),x[Qa+4>>2]=Ra;x[d+1074460>>2]=x[d+1074460>>2]-1;break ae}h=x[e>>2];Qa=e,Ra=Cc(zka(yka(h,h>>31,a,f),hb,256,0),hb),x[Qa>>2]=Ra;h=x[e+4>>2];Qa=e,Ra=Cc(zka(yka(h,h>>31,a,f),hb,256,0),hb),x[Qa+4>>2]=Ra;x[d+1074472>>2]=l}c=c+1|0;e=e+8|0;continue};case 3:break _d;default:break Zd}}l=0;k=(m|0)>0?m:0;o=a<<12;e=d+8204|0;c=d+12|0;f=a>>31;while(1){if((k|0)==(l|0)){break Zd}be:{if(x[i>>2]>0){h=x[d+1074472>>2]+b|0;x[d+1074472>>2]=h;s=x[c>>2];Qa=c,Ra=Cc(zka(yka(s,s>>31,h,h>>31),hb,1048576,0),hb),x[Qa>>2]=Ra;h=x[d+1074472>>2];s=h;r=h>>31;h=x[c+4>>2];Qa=c,Ra=Cc(zka(yka(s,r,h,h>>31),hb,1048576,0),hb),x[Qa+4>>2]=Ra;h=x[d+1074472>>2];s=h;r=h>>31;h=x[e>>2];Qa=e,Ra=Cc(zka(yka(s,r,h,h>>31),hb,1048576,0),hb),x[Qa>>2]=Ra;h=x[d+1074472>>2];s=h;r=h>>31;h=x[e+4>>2];Qa=e,Ra=Cc(zka(yka(s,r,h,h>>31),hb,1048576,0),hb),x[Qa+4>>2]=Ra;x[d+1074460>>2]=x[d+1074460>>2]-1;break be}h=x[c>>2];Qa=c,Ra=Cc(zka(yka(h,h>>31,a,f),hb,256,0),hb),x[Qa>>2]=Ra;h=x[c+4>>2];Qa=c,Ra=Cc(zka(yka(h,h>>31,a,f),hb,256,0),hb),x[Qa+4>>2]=Ra;h=x[e>>2];Qa=e,Ra=Cc(zka(yka(h,h>>31,a,f),hb,256,0),hb),x[Qa>>2]=Ra;h=x[e+4>>2];Qa=e,Ra=Cc(zka(yka(h,h>>31,a,f),hb,256,0),hb),x[Qa+4>>2]=Ra;x[d+1074472>>2]=o}l=l+1|0;e=e+8|0;c=c+8|0;continue}}db=g+16|0}if(x[na>>2]!=128){b=d+12|0;c=d+8204|0;a=x[d+24604>>2];e=x[d+24624>>2];ce:{if((a|0)==128|e>>>0<2){break ce}FM(b,m,a);if(e>>>0<4){break ce}FM(c,m,a)}}a=x[d+24624>>2];if((a|0)==4){a=m;while(1){a=a-1|0;if((a|0)>=0){b=(a<<4)+W|0;c=a<<3;e=c|4;x[b+12>>2]=x[e+oa>>2];x[b+8>>2]=x[c+oa>>2];x[b+4>>2]=x[e+W>>2];x[b>>2]=x[c+W>>2];continue}break}a=x[d+24624>>2]}b=M+44|0;if(vd(Aa)){a=rd(M+56|0,W,a,m);c=x[x[la>>2]+8>>2];x[M+24>>2]=x[a+8>>2];e=x[a+4>>2];x[M+16>>2]=x[a>>2];x[M+20>>2]=e;ib[c|0](la,M+16|0);a=x[d+24624>>2]}a=rd(b,W,a,m);b=x[x[ka>>2]+8>>2];x[M+8>>2]=x[a+8>>2];c=x[a+4>>2];x[M>>2]=x[a>>2];x[M+4>>2]=c;ib[b|0](ka,M);x[d+1074380>>2]=x[d+1074380>>2]-m;x[d+1074376>>2]=m+x[d+1074376>>2];ea=ea-m|0;za=m+za|0;continue}break}db=ca+32|0;return za}function lg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=E(0),q=E(0),s=0,t=0,u=0,G=0,H=0,I=E(0),J=0,K=0,L=0,M=0,P=0,V=0;k=db-2240|0;db=k;a:{b:{c:{d:{e:{f:{if(rv(x[c>>2])){tc(b,268435456);L=x[c+8>>2];H=k+2220|0;x[H>>2]=0;x[H+4>>2]=0;Nb(H+8|0);x[k+2216>>2]=0;g:{h:{i:{j:{k:{l:{m:{f=y[a+3|0];n:{o:{if((f-4&255)>>>0<=4){x[23549]=0;g=R(188,c|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break m}x[k+2216>>2]=g;break o}if(f>>>0>17){break n}p:{d=1<<f;if(!(d&63503)){if(!(d&198144)){break n}break p}if(y[a|0]){break p}break o}f=0;e=dB(a,x[b>>2]);x[23549]=0;S(189,k+48|0,c|0,e|0);e=x[23549];x[23549]=0;if((e|0)==1){break l}e=k+48|0;d=x[e+4>>2];x[H>>2]=x[e>>2];x[H+4>>2]=d;zm(H+8|0,e+8|0);Jc(e);e=Ee(H);g=x[H>>2];x[k+2216>>2]=g;if(!e){break g}}f=y[a+3|0]}q:{r:{switch(f&255){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:i=!y[a|0];case 9:case 10:case 16:case 17:d=x[b>>2];if(!(d>>>0<262145|i)){f=f&255;x[k+48>>2]=((f|0)==10)<<4;g=g-x[Cb(k+48|0,k+2216|0)>>2]|0;if(f>>>0>15){break k}s:{if(!(1<<f&63503)){if((f|0)==10){break s}break k}if(!(y[a|0]&7)){break k}}d=(g|0)<0?-1:g<<1;break j}f=f&255;if(f>>>0>8){break h}if(1<<f&432){break q}if((f|0)!=6){break h}break;case 4:case 5:case 7:case 8:break q;case 6:break r;default:break i}}f=0;if(g>>>0<10){break g}x[23549]=0;O(174,c|0,4)|0;d=x[23549];x[23549]=0;if((d|0)==1){break m}x[23549]=0;d=R(143,c|0)|0;f=x[23549];x[23549]=0;if((f|0)!=1){x[k+48>>2]=d;x[k+28>>2]=x[k+2216>>2];d=x[Cb(k+48|0,k+28|0)>>2];ng(c,8);d=((d>>>0>50529027?-1:D(d,85))>>>0)/(y[a|0]>>>3>>>0)|0;break j}a=N()|0;break a}d=8/(rq(y[a+1|0])>>>0)|0;f=D(d,g);yka(d,0,g,0);d=hb?-1:f;break j}a=N()|0;break a}a=N()|0;break a}d=0;h=rq(y[a+1|0]);t:{u:{switch(f|0){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:d=y[a|0];break t;case 9:d=16;break t;case 10:d=4;break t;case 16:case 17:break u;default:break t}}d=8}d=D(h,d&255)>>>3|0;f=(d+g|0)-1|0;d=((f>>>0<g>>>0?-1:f)>>>0)/(d>>>0)|0}tc(b,d)}d=x[b>>2]}if(!d){f=0;break g}w[b+34>>1]=z[b+34>>1]&65470|y[a|0]>15|(y[a+1|0]!=1)<<6;if(!zg(b)){f=0;x[b>>2]=0;break g}v:{if(de(a,Xc(k+48|0,8,1,0,10))){x[23549]=0;a=O(190,c|0,k+48|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){f=0;if(!a){break v}a=x[b>>2];g=0;x[23549]=0;x[k+28>>2]=a+1>>>1;a=R(188,c|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break b}tc(k+28|0,a);a=e+16|0;b=x[b+20>>2];e=x[k+28>>2];f=e;while(1)if(f){d=k+48|0;g=y[d|y[a|0]&15]+g|0;v[b|0]=g;g=y[d|y[a|0]>>>4]+(g&255)|0;v[b+1|0]=g;f=f-1|0;a=a+1|0;b=b+2|0;continue}else{f=e+16|0;break v}}a=N()|0;break a}w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{d=y[a+3|0];switch(d-4|0){case 3:break C;case 4:break F;case 5:break G;case 2:break H;case 0:case 1:break I;default:break E}}x[23549]=0;a=ba(191,k+1128|0,c|0,b|0,(d|0)==5|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break f}ub(a);f=x[c+8>>2]-L|0;break v}if(y[a+1|0]!=1){break D}x[23549]=0;O(174,c|0,4)|0;a=x[23549];x[23549]=0;if((a|0)==1){break f}x[23549]=0;a=R(143,c|0)|0;e=x[23549];x[23549]=0;J:{K:{L:{if((e|0)!=1){x[23549]=0;x[k+28>>2]=a;e=R(192,c|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break L}x[23549]=0;S(193,k+48|0,c|0,a|0);a=x[23549];x[23549]=0;if((a|0)==1){break J}tc(k+28|0,x[k+48>>2]);a=x[k+28>>2];Kq(k+1120|0,k+48|0);dc(k+1112|0,x[b+20>>2],pj(x[b>>2],z[b+34>>1]));x[23549]=0;aa(194,x[k+1120>>2],x[k+1124>>2],x[k+1112>>2],x[k+1116>>2],e<<24>>24);b=x[23549];x[23549]=0;if((b|0)!=1){break K}a=N()|0;Jc(k+48|0);break a}a=N()|0;break a}a=N()|0;break a}f=a+9|0;Jc(k+48|0);break v}a=N()|0;break a}if(y[a+1|0]!=1|y[a|0]!=16){break D}d=x[k+2216>>2];a=km(k+1110|0);f=x[b>>2];b=x[b+20>>2];g=z[a>>1];a=db-16|0;db=a;x[a+12>>2]=d>>>1;x[a+8>>2]=f;d=x[Cb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){h=y[e|0]+g|0;g=h+y[e+1|0]|0;w[b>>1]=g<<8|h&255;b=b+2|0;e=e+2|0;f=f-1|0;continue}break}db=a+16|0;f=d<<1;break v}if(y[a+1|0]!=1|y[a|0]>16){break D}e=x[c+8>>2];d=x[c>>2];f=0;x[23549]=0;e=U(142,d|0,e|0,8)|0;d=x[23549];x[23549]=0;if((d|0)==1){break f}if(!e){break v}x[23549]=0;e=R(143,c|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break f}x[k+2216>>2]=e;if(e>>>0<4){break v}x[23549]=0;S(176,k+28|0,c|0,e|0);e=x[23549];x[23549]=0;if((e|0)==1){break c}d=k+28|0;e=nr(k+48|0,d);ub(d);d=x[e>>2];x[23549]=0;d=R(195,d|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break e}f=d+4|0;h=y[a|0];j=(h|0)!=16;g=0;i=0;while(1){if(A[b>>2]<=i>>>0){break x}M:{if(j){break M}x[23549]=0;m=O(150,e|0,8)|0;a=x[23549];x[23549]=0;if((a|0)!=1){break M}a=T(30544)|0;break y}x[23549]=0;t=O(150,e|0,1)|0;a=x[23549];x[23549]=0;if((a|0)==1){break z}x[23549]=0;a=O(150,e|0,1)|0;d=x[23549];x[23549]=0;if((d|0)==1){break z}N:{O:{P:{if(!a){d=8;while(1){x[23549]=0;a=O(150,e|0,1)|0;G=x[23549];x[23549]=0;if((G|0)==1){break N}if(a){break P}d=d+16|0;continue}}x[23549]=0;a=O(150,e|0,3)|0;d=x[23549];x[23549]=0;if((d|0)!=1){break O}break z}x[23549]=0;a=O(150,e|0,4)|0;G=x[23549];x[23549]=0;if((G|0)==1){break z}a=a+d|0}g=(g&255)+(((t?-1:0)^a)&255)|0;Q:{if((h|0)!=16){v[x[b+20>>2]+i|0]=g;break Q}w[x[b+20>>2]+(i<<1)>>1]=m&255|g<<8}i=i+1|0;continue}break}a=T(30544)|0;break y}R:{if((d|0)==16){f=y[a|0];break R}f=y[a|0];if((d|0)!=17){break A}}if((f&255)!=16){break A}g=y[a+1|0];if((g-1&255)>>>0>1){break A}M=k,P=D(x[b>>2],rq(g)),x[M+48>>2]=P;tc(k+48|0,x[k+2216>>2]);a=x[b+20>>2];f=x[k+48>>2];if((d|0)==16){b=f;while(1){if(!b){break v}M=a,P=z[_b(30576,y[e|0])>>1],w[M>>1]=P;a=a+2|0;e=e+1|0;b=b-1|0;continue}}b=f;while(1){if(!b){break v}M=a,P=z[_b(31088,y[e|0])>>1],w[M>>1]=P;a=a+2|0;e=e+1|0;b=b-1|0;continue}}if((d|0)!=7){break B}}if(y[a+1|0]!=1|y[a|0]>16){break B}f=0;if(A[k+2216>>2]<5){break v}a=x[b+20>>2];e=z[b+34>>1];b=x[b>>2];x[23549]=0;f=U(196,c|0,a|0,pj(b,e)|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){break v}break f}f=y[a|0]}g=(f&255)!=8;if(!(g|y[a+1|0]!=1)){S:{switch(d|0){case 0:a=x[b>>2];b=x[b+20>>2];d=db-16|0;db=d;x[d+12>>2]=x[k+2216>>2];x[d+8>>2]=a;a=x[Cb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){v[b|0]=y[e|0];b=b+1|0;e=e+1|0;f=f-1|0;continue}break};db=d+16|0;f=a;break v;case 1:a=x[b>>2];b=x[b+20>>2];d=db-16|0;db=d;x[d+12>>2]=x[k+2216>>2];x[d+8>>2]=a;a=x[Cb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){v[b|0]=y[e|0]^128;b=b+1|0;e=e+1|0;f=f-1|0;continue}break};db=d+16|0;f=a;break v;default:f=0;if((d|0)!=11){break v}break;case 2:break S}}a=x[k+2216>>2];d=dz(k+27|0);f=x[b>>2];b=x[b+20>>2];g=y[d|0];d=db-16|0;db=d;x[d+12>>2]=a;x[d+8>>2]=f;a=x[Cb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){g=y[e|0]+g|0;v[b|0]=g;b=b+1|0;e=e+1|0;f=f-1|0;continue}break}db=d+16|0;f=a;break v}if(!(y[a+1|0]!=3|g)){T:{switch(d|0){case 0:g=db-16|0;db=g;a=x[k+2216>>2];x[g+12>>2]=a;f=x[b>>2];x[g+8>>2]=f;h=g+8|0;d=x[Cb(h,g+12|0)>>2];x[g+8>>2]=f;x[g+4>>2]=a-d;f=x[Cb(h,g+4|0)>>2];i=x[b+20>>2];a=d;h=e;while(1){if(a){v[i|0]=y[h|0];i=i+2|0;h=h+1|0;a=a-1|0;continue}break};i=x[b+20>>2]+1|0;h=x[b>>2]+e|0;a=f;while(1){if(a){v[i|0]=y[h|0];i=i+2|0;h=h+1|0;a=a-1|0;continue}break};db=g+16|0;f=d+f|0;break v;case 1:g=db-16|0;db=g;a=x[k+2216>>2];x[g+12>>2]=a;f=x[b>>2];x[g+8>>2]=f;h=g+8|0;d=x[Cb(h,g+12|0)>>2];x[g+8>>2]=f;x[g+4>>2]=a-d;f=x[Cb(h,g+4|0)>>2];i=x[b+20>>2];a=d;h=e;while(1){if(a){v[i|0]=y[h|0]^128;i=i+2|0;h=h+1|0;a=a-1|0;continue}break};i=x[b+20>>2]+1|0;h=x[b>>2]+e|0;a=f;while(1){if(a){v[i|0]=y[h|0]^128;i=i+2|0;h=h+1|0;a=a-1|0;continue}break};db=g+16|0;f=d+f|0;break v;default:f=0;if((d|0)!=11){break v}break;case 2:break T}}d=x[k+2216>>2];f=y[dz(k+26|0)|0];t=db-16|0;db=t;x[t+12>>2]=d;g=x[b>>2];x[t+8>>2]=g;h=t+8|0;i=x[Cb(h,t+12|0)>>2];x[t+8>>2]=g;x[t+4>>2]=d-i;j=x[Cb(h,t+4|0)>>2];g=b;m=x[b+20>>2];h=f;b=i;d=e;while(1){if(b){h=y[d|0]+h|0;v[m|0]=h;m=m+2|0;d=d+1|0;b=b-1|0;continue}break}m=x[g+20>>2]+1|0;d=x[g>>2]+e|0;b=j;while(1){if(b){f=y[d|0]+f|0;v[m|0]=f;m=m+2|0;d=d+1|0;b=b-1|0;continue}break}db=t+16|0;f=i+j|0;if(y[a+3|0]!=11){break v}a=x[g+20>>2];b=a+(x[g>>2]<<1)|0;while(1){if(a>>>0>=b>>>0){break v}v[a+1|0]=y[a+1|0]+y[a|0];a=a+2|0;continue}}g=f&255;if(!((g|0)!=8|y[a+1|0]!=2)){f=0;U:{switch(d|0){case 0:d=x[b>>2];b=x[b+20>>2];a=db-16|0;db=a;x[a+12>>2]=x[k+2216>>2]>>>1;x[a+8>>2]=d;d=x[Cb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){v[b|0]=y[e|0];v[b+1|0]=y[e+1|0];b=b+2|0;e=e+2|0;f=f-1|0;continue}break};db=a+16|0;f=d<<1;break v;case 1:d=x[b>>2];b=x[b+20>>2];a=db-16|0;db=a;x[a+12>>2]=x[k+2216>>2]>>>1;x[a+8>>2]=d;d=x[Cb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){v[b|0]=y[e|0]^128;v[b+1|0]=y[e+1|0]^128;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};db=a+16|0;f=d<<1;break v;case 2:break U;default:break v}}d=x[k+2216>>2];a=dz(k+25|0);h=x[b>>2];g=x[b+20>>2];a=y[a|0];f=db-16|0;db=f;x[f+12>>2]=d>>>1;x[f+8>>2]=h;b=a;h=x[Cb(f+12|0,f+8|0)>>2];d=h;while(1){if(d){a=y[e|0]+a|0;v[g|0]=a;b=y[e+1|0]+b|0;v[g+1|0]=b;g=g+2|0;e=e+2|0;d=d-1|0;continue}break}db=f+16|0;f=h<<1;break v}if(!(y[a+2|0]|((g|0)!=16|y[a+1|0]!=1))){V:{switch(d|0){case 0:d=x[b>>2];b=x[b+20>>2];a=db-16|0;db=a;x[a+12>>2]=x[k+2216>>2]>>>1;x[a+8>>2]=d;d=x[Cb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){w[b>>1]=y[e|0]|y[e+1|0]<<8;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};db=a+16|0;f=d<<1;break v;case 1:d=x[b>>2];b=x[b+20>>2];a=db-16|0;db=a;x[a+12>>2]=x[k+2216>>2]>>>1;x[a+8>>2]=d;d=x[Cb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){w[b>>1]=(y[e|0]|y[e+1|0]<<8)^32768;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};db=a+16|0;f=d<<1;break v;default:f=0;if((d|0)!=11){break v}break;case 2:break V}}d=x[k+2216>>2];a=km(k+22|0);f=x[b>>2];b=x[b+20>>2];g=z[a>>1];a=db-16|0;db=a;x[a+12>>2]=d>>>1;x[a+8>>2]=f;d=x[Cb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){g=(y[e|0]+g|0)+(y[e+1|0]<<8)|0;w[b>>1]=g;b=b+2|0;e=e+2|0;f=f-1|0;continue}break}db=a+16|0;f=d<<1;break v}g=f&255;if(!((g|0)!=16|y[a+1|0]!=1|y[a+2|0]!=1)){f=0;W:{switch(d|0){case 0:d=x[b>>2];b=x[b+20>>2];a=db-16|0;db=a;x[a+12>>2]=x[k+2216>>2]>>>1;x[a+8>>2]=d;d=x[Cb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){g=y[e|0]|y[e+1|0]<<8;w[b>>1]=g<<8|g>>>8;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};db=a+16|0;f=d<<1;break v;case 1:d=x[b>>2];b=x[b+20>>2];a=db-16|0;db=a;x[a+12>>2]=x[k+2216>>2]>>>1;x[a+8>>2]=d;d=x[Cb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){g=y[e|0]|y[e+1|0]<<8;w[b>>1]=(g<<8|g>>>8)^32768;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};db=a+16|0;f=d<<1;break v;case 2:break W;default:break v}}d=x[k+2216>>2];a=km(k+20|0);f=x[b>>2];b=x[b+20>>2];g=z[a>>1];a=db-16|0;db=a;x[a+12>>2]=d>>>1;x[a+8>>2]=f;d=x[Cb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){g=(y[e+1|0]+g|0)+(y[e|0]<<8)|0;w[b>>1]=g;b=b+2|0;e=e+2|0;f=f-1|0;continue}break}db=a+16|0;f=d<<1;break v}if(!(y[a+2|0]|((g|0)!=16|y[a+1|0]!=3))){X:{switch(d|0){case 0:a=db-16|0;db=a;f=x[k+2216>>2];x[a+12>>2]=f;h=x[b>>2]<<1;x[a+8>>2]=h;g=a+8|0;d=x[Cb(g,a+12|0)>>2];x[a+8>>2]=h;x[a+4>>2]=f-d;i=x[Cb(g,a+4|0)>>2];f=x[b+20>>2];j=d>>>1|0;g=j;d=e;while(1){if(g){w[f>>1]=y[d|0]|y[d+1|0]<<8;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+h|0;d=x[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){w[d>>1]=y[f|0]|y[f+1|0]<<8;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};db=a+16|0;f=b+j<<1;break v;case 1:a=db-16|0;db=a;f=x[k+2216>>2];x[a+12>>2]=f;h=x[b>>2]<<1;x[a+8>>2]=h;g=a+8|0;d=x[Cb(g,a+12|0)>>2];x[a+8>>2]=h;x[a+4>>2]=f-d;i=x[Cb(g,a+4|0)>>2];f=x[b+20>>2];j=d>>>1|0;g=j;d=e;while(1){if(g){w[f>>1]=(y[d|0]|y[d+1|0]<<8)^32768;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+h|0;d=x[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){w[d>>1]=(y[f|0]|y[f+1|0]<<8)^32768;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};db=a+16|0;f=b+j<<1;break v;default:f=0;if((d|0)!=11){break v}break;case 2:break X}}d=x[k+2216>>2];f=z[km(k+18|0)>>1];i=db-16|0;db=i;x[i+12>>2]=d;j=x[b>>2]<<1;x[i+8>>2]=j;g=i+8|0;m=x[Cb(g,i+12|0)>>2];x[i+8>>2]=j;x[i+4>>2]=d-m;t=x[Cb(g,i+4|0)>>2];g=b;h=x[b+20>>2];b=f;G=m>>>1|0;m=G;d=e;while(1){if(m){b=(y[d|0]+b|0)+(y[d+1|0]<<8)|0;w[h>>1]=b;h=h+4|0;d=d+2|0;m=m-1|0;continue}break}d=e+j|0;h=x[g+20>>2]+2|0;b=t>>>1|0;m=b;while(1){if(m){f=(y[d|0]+f|0)+(y[d+1|0]<<8)|0;w[h>>1]=f;h=h+4|0;d=d+2|0;m=m-1|0;continue}break}db=i+16|0;f=b+G<<1;if(y[a+3|0]!=11){break v}a=x[g+20>>2];b=a+(x[g>>2]<<2)|0;while(1){if(a>>>0>=b>>>0){break v}w[a+2>>1]=z[a+2>>1]+z[a>>1];a=a+4|0;continue}}g=f&255;if(!((g|0)!=16|y[a+1|0]!=3|y[a+2|0]!=1)){f=0;Y:{switch(d|0){case 0:a=db-16|0;db=a;f=x[k+2216>>2];x[a+12>>2]=f;h=x[b>>2]<<1;x[a+8>>2]=h;g=a+8|0;d=x[Cb(g,a+12|0)>>2];x[a+8>>2]=h;x[a+4>>2]=f-d;i=x[Cb(g,a+4|0)>>2];f=x[b+20>>2];j=d>>>1|0;g=j;d=e;while(1){if(g){m=y[d|0]|y[d+1|0]<<8;w[f>>1]=m<<8|m>>>8;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+h|0;d=x[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){e=y[f|0]|y[f+1|0]<<8;w[d>>1]=e<<8|e>>>8;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};db=a+16|0;f=b+j<<1;break v;case 1:a=db-16|0;db=a;f=x[k+2216>>2];x[a+12>>2]=f;h=x[b>>2]<<1;x[a+8>>2]=h;g=a+8|0;d=x[Cb(g,a+12|0)>>2];x[a+8>>2]=h;x[a+4>>2]=f-d;i=x[Cb(g,a+4|0)>>2];f=x[b+20>>2];j=d>>>1|0;g=j;d=e;while(1){if(g){m=y[d|0]|y[d+1|0]<<8;w[f>>1]=(m<<8|m>>>8)^32768;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+h|0;d=x[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){e=y[f|0]|y[f+1|0]<<8;w[d>>1]=(e<<8|e>>>8)^32768;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};db=a+16|0;f=b+j<<1;break v;case 2:break Y;default:break v}}d=x[k+2216>>2];a=z[km(k+16|0)>>1];f=db-16|0;db=f;x[f+12>>2]=d;j=x[b>>2]<<1;x[f+8>>2]=j;h=f+8|0;g=x[Cb(h,f+12|0)>>2];x[f+8>>2]=j;x[f+4>>2]=d-g;m=x[Cb(h,f+4|0)>>2];d=b;i=x[d+20>>2];b=a;t=g>>>1|0;h=t;g=e;while(1){if(h){b=(y[g+1|0]+b|0)+(y[g|0]<<8)|0;w[i>>1]=b;i=i+4|0;g=g+2|0;h=h-1|0;continue}break}g=e+j|0;i=x[d+20>>2]+2|0;b=m>>>1|0;h=b;while(1){if(h){a=(y[g+1|0]+a|0)+(y[g|0]<<8)|0;w[i>>1]=a;i=i+4|0;g=g+2|0;h=h-1|0;continue}break}db=f+16|0;f=b+t<<1;break v}if(!(y[a+2|0]|((g|0)!=16|y[a+1|0]!=2))){f=0;Z:{switch(d|0){case 0:d=x[b>>2];b=x[b+20>>2];a=db-16|0;db=a;x[a+12>>2]=x[k+2216>>2]>>>2;x[a+8>>2]=d;d=x[Cb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){w[b>>1]=y[e|0]|y[e+1|0]<<8;w[b+2>>1]=y[e+2|0]|y[e+3|0]<<8;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};db=a+16|0;f=d<<2;break v;case 1:d=x[b>>2];b=x[b+20>>2];a=db-16|0;db=a;x[a+12>>2]=x[k+2216>>2]>>>2;x[a+8>>2]=d;d=x[Cb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){w[b>>1]=(y[e|0]|y[e+1|0]<<8)^32768;w[b+2>>1]=(y[e+2|0]|y[e+3|0]<<8)^32768;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};db=a+16|0;f=d<<2;break v;case 2:break Z;default:break v}}d=x[k+2216>>2];a=km(k+14|0);h=x[b>>2];g=x[b+20>>2];a=z[a>>1];f=db-16|0;db=f;x[f+12>>2]=d>>>2;x[f+8>>2]=h;b=a;h=x[Cb(f+12|0,f+8|0)>>2];d=h;while(1){if(d){a=(y[e|0]+a|0)+(y[e+1|0]<<8)|0;w[g>>1]=a;b=(y[e+2|0]+b|0)+(y[e+3|0]<<8)|0;w[g+2>>1]=b;g=g+4|0;e=e+4|0;d=d-1|0;continue}break}db=f+16|0;f=h<<2;break v}g=f&255;if(!((g|0)!=16|y[a+1|0]!=2|y[a+2|0]!=1)){f=0;_:{switch(d|0){case 0:d=x[b>>2];b=x[b+20>>2];a=db-16|0;db=a;x[a+12>>2]=x[k+2216>>2]>>>2;x[a+8>>2]=d;d=x[Cb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){g=y[e|0]|y[e+1|0]<<8;w[b>>1]=g<<8|g>>>8;g=y[e+2|0]|y[e+3|0]<<8;w[b+2>>1]=g<<8|g>>>8;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};db=a+16|0;f=d<<2;break v;case 1:d=x[b>>2];b=x[b+20>>2];a=db-16|0;db=a;x[a+12>>2]=x[k+2216>>2]>>>2;x[a+8>>2]=d;d=x[Cb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){g=y[e|0]|y[e+1|0]<<8;w[b>>1]=(g<<8|g>>>8)^32768;g=y[e+2|0]|y[e+3|0]<<8;w[b+2>>1]=(g<<8|g>>>8)^32768;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};db=a+16|0;f=d<<2;break v;case 2:break _;default:break v}}d=x[k+2216>>2];a=km(k+12|0);h=x[b>>2];g=x[b+20>>2];a=z[a>>1];f=db-16|0;db=f;x[f+12>>2]=d>>>2;x[f+8>>2]=h;b=a;h=x[Cb(f+12|0,f+8|0)>>2];d=h;while(1){if(d){a=(y[e+1|0]+a|0)+(y[e|0]<<8)|0;w[g>>1]=a;b=(y[e+3|0]+b|0)+(y[e+2|0]<<8)|0;w[g+2>>1]=b;g=g+4|0;e=e+4|0;d=d-1|0;continue}break}db=f+16|0;f=h<<2;break v}if(!(d|y[a+1|0]!=1|(g|0)!=24)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=db-16|0;db=a;x[a+12>>2]=(d>>>0)/3;x[a+8>>2]=b;d=x[Cb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,P=gd(y[e+1|0]<<16|y[e|0]<<8|y[e+2|0]<<24,16),w[M>>1]=P;f=f+2|0;e=e+3|0;b=b-1|0;continue}break}db=a+16|0;f=D(d,3);break v}a=db-16|0;db=a;x[a+12>>2]=(d>>>0)/3;x[a+8>>2]=b;d=x[Cb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,P=gd(y[e+1|0]<<16|y[e+2|0]<<8|y[e|0]<<24,16),w[M>>1]=P;f=f+2|0;e=e+3|0;b=b-1|0;continue}break}db=a+16|0;f=D(d,3);break v}g=f&255;if(!(d|y[a+1|0]!=2|(g|0)!=24)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=db-16|0;db=a;x[a+12>>2]=(d>>>0)/6;x[a+8>>2]=b;d=x[Cb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,P=gd(y[e+1|0]<<16|y[e|0]<<8|y[e+2|0]<<24,16),w[M>>1]=P;M=f,P=gd(y[e+4|0]<<16|y[e+3|0]<<8|y[e+5|0]<<24,16),w[M+2>>1]=P;f=f+4|0;e=e+6|0;b=b-1|0;continue}break}db=a+16|0;f=D(d,6);break v}a=db-16|0;db=a;x[a+12>>2]=(d>>>0)/6;x[a+8>>2]=b;d=x[Cb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,P=gd(y[e+1|0]<<16|y[e+2|0]<<8|y[e|0]<<24,16),w[M>>1]=P;M=f,P=gd(y[e+4|0]<<16|y[e+5|0]<<8|y[e+3|0]<<24,16),w[M+2>>1]=P;f=f+4|0;e=e+6|0;b=b-1|0;continue}break}db=a+16|0;f=D(d,6);break v}if(!(d|y[a+1|0]!=1|(g|0)!=32)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=db-16|0;db=a;x[a+12>>2]=d>>>2;x[a+8>>2]=b;d=x[Cb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,P=gd(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),16),w[M>>1]=P;f=f+2|0;e=e+4|0;b=b-1|0;continue}break}db=a+16|0;f=d<<2;break v}a=db-16|0;db=a;x[a+12>>2]=d>>>2;x[a+8>>2]=b;g=x[Cb(a+12|0,a+8|0)>>2];b=g;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);M=f,P=gd(d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24),16),w[M>>1]=P;f=f+2|0;e=e+4|0;b=b-1|0;continue}break}db=a+16|0;f=g<<2;break v}g=f&255;if(!(d|y[a+1|0]!=2|(g|0)!=32)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=db-16|0;db=a;x[a+12>>2]=d>>>3;x[a+8>>2]=b;d=x[Cb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,P=gd(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),16),w[M>>1]=P;M=f,P=gd(y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24),16),w[M+2>>1]=P;f=f+4|0;e=e+8|0;b=b-1|0;continue}break}db=a+16|0;f=d<<3;break v}a=db-16|0;db=a;x[a+12>>2]=d>>>3;x[a+8>>2]=b;g=x[Cb(a+12|0,a+8|0)>>2];b=g;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);M=f,P=gd(d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24),16),w[M>>1]=P;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);M=f,P=gd(d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24),16),w[M+2>>1]=P;f=f+4|0;e=e+8|0;b=b-1|0;continue}break}db=a+16|0;f=g<<3;break v}if(!(d|y[a+1|0]!=1|(g|0)!=64)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=db-16|0;db=a;x[a+12>>2]=d>>>3;x[a+8>>2]=b;d=x[Cb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,P=Lc(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24),48),w[M>>1]=P;f=f+2|0;e=e+8|0;b=b-1|0;continue}break}db=a+16|0;f=d<<3;break v}a=db-16|0;db=a;x[a+12>>2]=d>>>3;x[a+8>>2]=b;h=x[Cb(a+12|0,a+8|0)>>2];b=h;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=d<<24|(d&65280)<<8;g=d&16711680;j=g>>>8|0;m=d&-16777216;t=m>>>24|0;m=m<<8|g<<24;g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);M=f,P=Lc(m|(((g&255)<<24|d>>>8)&-16777216|((g&16777215)<<8|d>>>24)&16711680|(g>>>8&65280|g>>>24)),i|(j|t),48),w[M>>1]=P;f=f+2|0;e=e+8|0;b=b-1|0;continue}break}db=a+16|0;f=h<<3;break v}g=f&255;if(!(d|y[a+1|0]!=2|(g|0)!=64)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=db-16|0;db=a;x[a+12>>2]=d>>>4;x[a+8>>2]=b;d=x[Cb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){M=f,P=Lc(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24),48),w[M>>1]=P;M=f,P=Lc(y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24),y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24),48),w[M+2>>1]=P;f=f+4|0;e=e+16|0;b=b-1|0;continue}break}db=a+16|0;f=d<<4;break v}a=db-16|0;db=a;x[a+12>>2]=d>>>4;x[a+8>>2]=b;h=x[Cb(a+12|0,a+8|0)>>2];b=h;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=d<<24|(d&65280)<<8;g=d&16711680;j=g>>>8|0;m=d&-16777216;t=m>>>24|0;m=m<<8|g<<24;g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);M=f,P=Lc(m|(((g&255)<<24|d>>>8)&-16777216|((g&16777215)<<8|d>>>24)&16711680|(g>>>8&65280|g>>>24)),i|(j|t),48),w[M>>1]=P;d=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);i=d<<24|(d&65280)<<8;g=d&16711680;j=g>>>8|0;m=d&-16777216;t=m>>>24|0;m=m<<8|g<<24;g=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);M=f,P=Lc(m|(((g&255)<<24|d>>>8)&-16777216|((g&16777215)<<8|d>>>24)&16711680|(g>>>8&65280|g>>>24)),i|(j|t),48),w[M+2>>1]=P;f=f+4|0;e=e+16|0;b=b-1|0;continue}break}db=a+16|0;f=h<<4;break v}if(!(y[a+1|0]!=1|(d|0)!=3|(g|0)!=32)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=db-16|0;db=a;x[a+12>>2]=d>>>2;x[a+8>>2]=b;d=x[Cb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){o=Af((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));o=Rh(E(Fd(gg(o)?o>=E(0)?E(1):E(-1):o,E(-1))*E(32768)));$:{if(E(F(o))<E(2147483648)){g=~~o;break $}g=-2147483648}M=f,P=Sc(g),w[M>>1]=P;f=f+2|0;e=e+4|0;b=b-1|0;continue}break}db=a+16|0;f=d<<2;break v}a=db-16|0;db=a;x[a+12>>2]=d>>>2;x[a+8>>2]=b;g=x[Cb(a+12|0,a+8|0)>>2];b=g;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);o=Af((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));o=Rh(E(Fd(gg(o)?o>=E(0)?E(1):E(-1):o,E(-1))*E(32768)));aa:{if(E(F(o))<E(2147483648)){d=~~o;break aa}d=-2147483648}M=f,P=Sc(d),w[M>>1]=P;f=f+2|0;e=e+4|0;b=b-1|0;continue}break}db=a+16|0;f=g<<2;break v}g=f&255;if(!(y[a+1|0]!=2|(d|0)!=3|(g|0)!=32)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=db-16|0;db=a;x[a+12>>2]=d>>>3;x[a+8>>2]=b;d=x[Cb(a+12|0,a+8|0)>>2];b=d;while(1){if(b){o=Af((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));o=Rh(E(Fd(gg(o)?o>=E(0)?E(1):E(-1):o,E(-1))*E(32768)));ba:{if(E(F(o))<E(2147483648)){g=~~o;break ba}g=-2147483648}M=f,P=Sc(g),w[M>>1]=P;o=Af((l(2,y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24)),r()));o=Rh(E(Fd(gg(o)?o>=E(0)?E(1):E(-1):o,E(-1))*E(32768)));ca:{if(E(F(o))<E(2147483648)){g=~~o;break ca}g=-2147483648}M=f,P=Sc(g),w[M+2>>1]=P;f=f+4|0;e=e+8|0;b=b-1|0;continue}break}db=a+16|0;f=d<<3;break v}a=db-16|0;db=a;x[a+12>>2]=d>>>3;x[a+8>>2]=b;g=x[Cb(a+12|0,a+8|0)>>2];b=g;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);o=Af((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));o=Rh(E(Fd(gg(o)?o>=E(0)?E(1):E(-1):o,E(-1))*E(32768)));da:{if(E(F(o))<E(2147483648)){d=~~o;break da}d=-2147483648}M=f,P=Sc(d),w[M>>1]=P;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);o=Af((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));o=Rh(E(Fd(gg(o)?o>=E(0)?E(1):E(-1):o,E(-1))*E(32768)));ea:{if(E(F(o))<E(2147483648)){d=~~o;break ea}d=-2147483648}M=f,P=Sc(d),w[M+2>>1]=P;f=f+4|0;e=e+8|0;b=b-1|0;continue}break}db=a+16|0;f=g<<3;break v}if(!(y[a+1|0]!=1|(d|0)!=3|(g|0)!=64)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=db-32|0;db=a;x[a+24>>2]=d>>>3;x[a+16>>2]=b;d=x[Cb(a+24|0,a+16|0)>>2];b=d;while(1){if(b){g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24));l(1,g|0);s=fg(+n());M=a,V=df(s)?s>=0?1:-1:s,C[M+24>>3]=V;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;s=je(C[wg(a+24|0,a+16|0,a+8|0)>>3]*32768);fa:{if(F(s)<2147483648){g=~~s;break fa}g=-2147483648}M=f,P=Sc(g),w[M>>1]=P;f=f+2|0;e=e+8|0;b=b-1|0;continue}break}db=a+32|0;f=d<<3;break v}a=db-32|0;db=a;x[a+24>>2]=d>>>3;x[a+16>>2]=b;h=x[Cb(a+24|0,a+16|0)>>2];b=h;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=d<<24|(d&65280)<<8;g=d&16711680;j=g>>>8|0;m=d&-16777216;t=m>>>24|0;m=m<<8|g<<24;g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,m|(((g&255)<<24|d>>>8)&-16777216|((g&16777215)<<8|d>>>24)&16711680|(g>>>8&65280|g>>>24)));l(1,i|(j|t));s=fg(+n());M=a,V=df(s)?s>=0?1:-1:s,C[M+24>>3]=V;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;s=je(C[wg(a+24|0,a+16|0,a+8|0)>>3]*32768);ga:{if(F(s)<2147483648){d=~~s;break ga}d=-2147483648}M=f,P=Sc(d),w[M>>1]=P;f=f+2|0;e=e+8|0;b=b-1|0;continue}break}db=a+32|0;f=h<<3;break v}g=f&255;if(!(y[a+1|0]!=2|(d|0)!=3|(g|0)!=64)){f=x[b+20>>2];b=x[b>>2];d=x[k+2216>>2];if(!y[a+2|0]){a=db-32|0;db=a;x[a+24>>2]=d>>>4;x[a+16>>2]=b;d=x[Cb(a+24|0,a+16|0)>>2];b=d;while(1){if(b){g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24));l(1,g|0);s=fg(+n());M=a,V=df(s)?s>=0?1:-1:s,C[M+24>>3]=V;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;s=je(C[wg(a+24|0,a+16|0,a+8|0)>>3]*32768);ha:{if(F(s)<2147483648){g=~~s;break ha}g=-2147483648}M=f,P=Sc(g),w[M>>1]=P;g=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);l(0,y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24));l(1,g|0);s=fg(+n());M=a,V=df(s)?s>=0?1:-1:s,C[M+24>>3]=V;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;s=je(C[wg(a+24|0,a+16|0,a+8|0)>>3]*32768);ia:{if(F(s)<2147483648){g=~~s;break ia}g=-2147483648}M=f,P=Sc(g),w[M+2>>1]=P;f=f+4|0;e=e+16|0;b=b-1|0;continue}break}db=a+32|0;f=d<<4;break v}a=db-32|0;db=a;x[a+24>>2]=d>>>4;x[a+16>>2]=b;h=x[Cb(a+24|0,a+16|0)>>2];b=h;while(1){if(b){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=d<<24|(d&65280)<<8;g=d&16711680;j=g>>>8|0;m=d&-16777216;t=m>>>24|0;m=m<<8|g<<24;g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,m|(((g&255)<<24|d>>>8)&-16777216|((g&16777215)<<8|d>>>24)&16711680|(g>>>8&65280|g>>>24)));l(1,i|(j|t));s=fg(+n());M=a,V=df(s)?s>=0?1:-1:s,C[M+24>>3]=V;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;s=je(C[wg(a+24|0,a+16|0,a+8|0)>>3]*32768);ja:{if(F(s)<2147483648){d=~~s;break ja}d=-2147483648}M=f,P=Sc(d),w[M>>1]=P;d=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);i=d<<24|(d&65280)<<8;g=d&16711680;j=g>>>8|0;m=d&-16777216;t=m>>>24|0;m=m<<8|g<<24;g=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);l(0,m|(((g&255)<<24|d>>>8)&-16777216|((g&16777215)<<8|d>>>24)&16711680|(g>>>8&65280|g>>>24)));l(1,i|(j|t));s=fg(+n());M=a,V=df(s)?s>=0?1:-1:s,C[M+24>>3]=V;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;s=je(C[wg(a+24|0,a+16|0,a+8|0)>>3]*32768);ka:{if(F(s)<2147483648){d=~~s;break ka}d=-2147483648}M=f,P=Sc(d),w[M+2>>1]=P;f=f+4|0;e=e+16|0;b=b-1|0;continue}break}db=a+32|0;f=h<<4;break v}la:{if((g|0)==24){if((d|0)!=15|(y[a+1|0]-1&255)>>>0>1){break la}x[k+48>>2]=-2147483648;d=x[k+2216>>2];ma:{if(!y[a+2|0]){m=k+48|0;f=0;h=db-16|0;db=h;M=h,P=D(x[b>>2],Jd(z[b+34>>1])),x[M+12>>2]=P;tc(h+12|0,(d>>>0)/3|0);a=e;g=x[h+12>>2];i=g;while(1){if(i){j=y[a+1|0]<<16|y[a|0]<<8|y[a+2|0]<<24;na:{oa:{pa:{if((j|0)>=0){d=j;break pa}d=-2147483648;if((j|0)==-2147483648){break oa}d=0-j|0}if(d>>>0<=f>>>0){break na}}f=d}i=i-1|0;a=a+3|0;continue}else{qa:{if(!f){break qa}t=f-1|0;G=f>>>1|0;i=x[b+20>>2];a=g;while(1){if(!a){break qa}j=y[e+1|0]<<16|y[e|0]<<8|y[e+2|0]<<24;d=j&-2147483648|j>>>1;j=G|j<<31;ra:{if((d|0)>0|(d|0)>=0){d=Bka(j,d,f,0);j=hb;break ra}j=Bka(t-j|0,0-((j>>>0>t>>>0)+d|0)|0,f,0);d=0-j|0;j=0-(hb+((j|0)!=0)|0)|0}M=i,P=gd(Cc(d,j),16),w[M>>1]=P;a=a-1|0;e=e+3|0;i=i+2|0;continue}}}break}if(m){x[m>>2]=f}db=h+16|0;f=D(g,3);break ma}m=k+48|0;f=0;h=db-16|0;db=h;M=h,P=D(x[b>>2],Jd(z[b+34>>1])),x[M+12>>2]=P;tc(h+12|0,(d>>>0)/3|0);a=e;g=x[h+12>>2];i=g;while(1){if(i){j=y[a+1|0]<<16|y[a+2|0]<<8|y[a|0]<<24;sa:{ta:{ua:{if((j|0)>=0){d=j;break ua}d=-2147483648;if((j|0)==-2147483648){break ta}d=0-j|0}if(d>>>0<=f>>>0){break sa}}f=d}i=i-1|0;a=a+3|0;continue}else{va:{if(!f){break va}t=f-1|0;G=f>>>1|0;i=x[b+20>>2];a=g;while(1){if(!a){break va}j=y[e+1|0]<<16|y[e+2|0]<<8|y[e|0]<<24;d=j&-2147483648|j>>>1;j=G|j<<31;wa:{if((d|0)>0|(d|0)>=0){d=Bka(j,d,f,0);j=hb;break wa}j=Bka(t-j|0,0-((j>>>0>t>>>0)+d|0)|0,f,0);d=0-j|0;j=0-(hb+((j|0)!=0)|0)|0}M=i,P=gd(Cc(d,j),16),w[M>>1]=P;a=a-1|0;e=e+3|0;i=i+2|0;continue}}}break}if(m){x[m>>2]=f}db=h+16|0;f=D(g,3)}if(!f){break v}a=x[k+48>>2];if((a|0)==-2147483648){break v}a=yka(z[b+32>>1],0,a,0);e=hb;a=a+1073741824|0;e=a>>>0<1073741824?e+1|0:e;M=b,P=Vd(Qc((e&2147483647)<<1|a>>>31,e>>>31|0),1,64),w[M+32>>1]=P;w[b+34>>1]=z[b+34>>1]|8192;break v}g=f&255;if((g|0)==32){if(!((d|0)!=15|(y[a+1|0]-1&255)>>>0>1)){x[k+48>>2]=-2147483648;d=x[k+2216>>2];xa:{if(!y[a+2|0]){m=k+48|0;a=0;h=db-16|0;db=h;M=h,P=D(x[b>>2],Jd(z[b+34>>1])),x[M+12>>2]=P;tc(h+12|0,d>>>2|0);f=e;i=e;g=x[h+12>>2];e=g;while(1){if(e){j=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);ya:{za:{Aa:{if((j|0)>=0){d=j;break Aa}d=-2147483648;if((j|0)==-2147483648){break za}d=0-j|0}if(d>>>0<=a>>>0){break ya}}a=d}e=e-1|0;i=i+4|0;continue}else{Ba:{if(!a){break Ba}t=a-1|0;G=a>>>1|0;i=x[b+20>>2];e=g;while(1){if(!e){break Ba}j=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);d=j&-2147483648|j>>>1;j=G|j<<31;Ca:{if((d|0)>0|(d|0)>=0){d=Bka(j,d,a,0);j=hb;break Ca}j=Bka(t-j|0,0-((j>>>0>t>>>0)+d|0)|0,a,0);d=0-j|0;j=0-(hb+((j|0)!=0)|0)|0}M=i,P=gd(Cc(d,j),16),w[M>>1]=P;e=e-1|0;f=f+4|0;i=i+2|0;continue}}}break}if(m){x[m>>2]=a}db=h+16|0;f=g<<2;break xa}m=k+48|0;a=0;h=db-16|0;db=h;M=h,P=D(x[b>>2],Jd(z[b+34>>1])),x[M+12>>2]=P;tc(h+12|0,d>>>2|0);f=e;i=e;g=x[h+12>>2];e=g;while(1){if(e){d=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);j=d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24);Da:{Ea:{Fa:{if((j|0)>=0){d=j;break Fa}d=-2147483648;if((j|0)==-2147483648){break Ea}d=0-j|0}if(a>>>0>=d>>>0){break Da}}a=d}e=e-1|0;i=i+4|0;continue}else{Ga:{if(!a){break Ga}t=a-1|0;G=a>>>1|0;i=x[b+20>>2];e=g;while(1){if(!e){break Ga}d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);j=d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24);d=j&-2147483648|j>>>1;j=G|j<<31;Ha:{if((d|0)>0|(d|0)>=0){d=Bka(j,d,a,0);j=hb;break Ha}j=Bka(t-j|0,0-((j>>>0>t>>>0)+d|0)|0,a,0);d=0-j|0;j=0-(hb+((j|0)!=0)|0)|0}M=i,P=gd(Cc(d,j),16),w[M>>1]=P;e=e-1|0;f=f+4|0;i=i+2|0;continue}}}break}if(m){x[m>>2]=a}db=h+16|0;f=g<<2}if(!f){break v}a=x[k+48>>2];if((a|0)==-2147483648){break v}a=yka(z[b+32>>1],0,a,0);e=hb;a=a+1073741824|0;e=a>>>0<1073741824?e+1|0:e;M=b,P=Vd(Qc((e&2147483647)<<1|a>>>31,e>>>31|0),1,64),w[M+32>>1]=P;w[b+34>>1]=z[b+34>>1]|8192;break v}if((d|0)!=14|(y[a+1|0]-1&255)>>>0>1){break la}x[k+48>>2]=1065353216;d=x[k+2216>>2];Ia:{if(!y[a+2|0]){h=k+48|0;f=db-16|0;db=f;M=f,P=D(x[b>>2],Jd(z[b+34>>1])),x[M+12>>2]=P;tc(f+12|0,d>>>2|0);g=e;d=x[f+12>>2];a=d;while(1){if(a){q=Af((l(2,y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24)),r()));q=E(F(gg(q)?q>=E(0)?E(1):E(-1):q));o=o<q?q:o;a=a-1|0;g=g+4|0;continue}else{Ja:{a=o==E(0);if(a){break Ja}I=a?E(1):E(E(1)/o);g=x[b+20>>2];a=d;while(1){if(!a){break Ja}q=Af((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));q=Rh(E(Fd(E(I*(gg(q)?q>=E(0)?E(1):E(-1):q)),E(-1))*E(32768)));Ka:{if(E(F(q))<E(2147483648)){j=~~q;break Ka}j=-2147483648}M=g,P=Sc(j),w[M>>1]=P;a=a-1|0;e=e+4|0;g=g+2|0;continue}}if(h){B[h>>2]=o}db=f+16|0;f=d<<2}break}break Ia}i=k+48|0;f=db-16|0;db=f;M=f,P=D(x[b>>2],Jd(z[b+34>>1])),x[M+12>>2]=P;tc(f+12|0,d>>>2|0);g=e;d=x[f+12>>2];a=d;while(1){if(a){h=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);q=Af((l(2,h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24)),r()));q=E(F(gg(q)?q>=E(0)?E(1):E(-1):q));o=o<q?q:o;a=a-1|0;g=g+4|0;continue}else{La:{a=o==E(0);if(a){break La}I=a?E(1):E(E(1)/o);g=x[b+20>>2];a=d;while(1){if(!a){break La}h=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);q=Af((l(2,h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24)),r()));q=Rh(E(Fd(E(I*(gg(q)?q>=E(0)?E(1):E(-1):q)),E(-1))*E(32768)));Ma:{if(E(F(q))<E(2147483648)){j=~~q;break Ma}j=-2147483648}M=g,P=Sc(j),w[M>>1]=P;a=a-1|0;e=e+4|0;g=g+2|0;continue}}if(i){B[i>>2]=o}db=f+16|0;f=d<<2}break}}if(!f){break v}o=B[k+48>>2];if(o==E(1)){break v}o=Rh(cz(E(o*E(z[b+32>>1])),E(1),E(64)));a=65535;Na:{if(o>=E(65535)){break Na}a=0;if(o<=E(0)){break Na}a=~~o>>>0;if(o<E(4294967296)&o>=E(0)){break Na}a=0}w[b+32>>1]=a;w[b+34>>1]=z[b+34>>1]|8192;break v}if((d|0)!=14|(y[a+1|0]-1&255)>>>0>1|(g|0)!=64){break la}x[k+48>>2]=0;x[k+52>>2]=1072693248;d=x[k+2216>>2];Oa:{if(!y[a+2|0]){h=k+48|0;g=db-32|0;db=g;M=g,P=D(x[b>>2],Jd(z[b+34>>1])),x[M+4>>2]=P;tc(g+4|0,d>>>3|0);d=e;f=x[g+4>>2];a=f;while(1){if(a){i=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);l(0,y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));l(1,i|0);u=fg(+n());u=F(df(u)?u>=0?1:-1:u);s=s<u?u:s;a=a-1|0;d=d+8|0;continue}else{Pa:{a=s==0;if(a){break Pa}J=a?1:1/s;d=x[b+20>>2];a=f;while(1){if(!a){break Pa}i=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24));l(1,i|0);u=fg(+n());M=g,V=J*(df(u)?u>=0?1:-1:u),C[M+24>>3]=V;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;u=je(C[wg(g+24|0,g+16|0,g+8|0)>>3]*32768);Qa:{if(F(u)<2147483648){j=~~u;break Qa}j=-2147483648}M=d,P=Sc(j),w[M>>1]=P;a=a-1|0;e=e+8|0;d=d+2|0;continue}}if(h){C[h>>3]=s}db=g+32|0;f=f<<3}break}break Oa}j=k+48|0;g=db-32|0;db=g;M=g,P=D(x[b>>2],Jd(z[b+34>>1])),x[M+4>>2]=P;tc(g+4|0,d>>>3|0);d=e;f=x[g+4>>2];a=f;while(1){if(a){h=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);m=h<<24|(h&65280)<<8;i=h&16711680;t=i>>>8|0;G=h&-16777216;K=G>>>24|0;G=G<<8|i<<24;i=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);l(0,G|(((i&255)<<24|h>>>8)&-16777216|((i&16777215)<<8|h>>>24)&16711680|(i>>>8&65280|i>>>24)));l(1,m|(t|K));u=fg(+n());u=F(df(u)?u>=0?1:-1:u);s=s<u?u:s;a=a-1|0;d=d+8|0;continue}else{Ra:{a=s==0;if(a){break Ra}J=a?1:1/s;d=x[b+20>>2];a=f;while(1){if(!a){break Ra}h=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);m=h<<24|(h&65280)<<8;i=h&16711680;t=i>>>8|0;G=h&-16777216;K=G>>>24|0;G=G<<8|i<<24;i=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,G|(((i&255)<<24|h>>>8)&-16777216|((i&16777215)<<8|h>>>24)&16711680|(i>>>8&65280|i>>>24)));l(1,m|(t|K));u=fg(+n());M=g,V=J*(df(u)?u>=0?1:-1:u),C[M+24>>3]=V;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;u=je(C[wg(g+24|0,g+16|0,g+8|0)>>3]*32768);Sa:{if(F(u)<2147483648){h=~~u;break Sa}h=-2147483648}M=d,P=Sc(h),w[M>>1]=P;a=a-1|0;e=e+8|0;d=d+2|0;continue}}if(j){C[j>>3]=s}db=g+32|0;f=f<<3}break}}if(!f){break v}s=C[k+48>>3];if(s==1){break v}s=je(bz(s*+z[b+32>>1],1,64));a=65535;Ta:{if(s>=65535){break Ta}a=0;if(s<=0){break Ta}a=~~s>>>0;if(s<4294967296&s>=0){break Ta}a=0}w[b+32>>1]=a;w[b+34>>1]=z[b+34>>1]|8192;break v}Ua:{Va:{Wa:{Xa:{g=(f&255)!=32;Ya:{if(!(g|(y[a+1|0]!=1|(d|0)!=12))){o=E(30517578125e-15);f=x[k+2216>>2];if(!y[a+2|0]){break Ya}break Ua}if(!(y[a+1|0]!=2|(d|0)!=12|g)){o=E(30517578125e-15);f=x[k+2216>>2];if(!y[a+2|0]){break Wa}break Va}g=(f&255)!=32;if(g|(y[a+1|0]!=1|(d|0)!=13)){break Xa}o=E(1.1920928955078125e-7);f=x[k+2216>>2];if(y[a+2|0]){break Ua}}d=x[b>>2];b=x[b+20>>2];a=db-16|0;db=a;x[a+12>>2]=f>>>2;x[a+8>>2]=d;d=x[Cb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){q=Af((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));q=Rh(E(Fd(E((gg(q)?q>=E(0)?E(1):E(-1):q)*o),E(-1))*E(32768)));Za:{if(E(F(q))<E(2147483648)){g=~~q;break Za}g=-2147483648}M=b,P=Sc(g),w[M>>1]=P;b=b+2|0;e=e+4|0;f=f-1|0;continue}break}db=a+16|0;f=d<<2;break v}f=0;if(y[a+1|0]!=2|(d|0)!=13|g){break v}o=E(1.1920928955078125e-7);f=x[k+2216>>2];if(y[a+2|0]){break Va}}d=x[b>>2];b=x[b+20>>2];a=db-16|0;db=a;x[a+12>>2]=f>>>3;x[a+8>>2]=d;d=x[Cb(a+12|0,a+8|0)>>2];f=d;while(1){if(f){q=Af((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));q=Rh(E(Fd(E((gg(q)?q>=E(0)?E(1):E(-1):q)*o),E(-1))*E(32768)));_a:{if(E(F(q))<E(2147483648)){g=~~q;break _a}g=-2147483648}M=b,P=Sc(g),w[M>>1]=P;q=Af((l(2,y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24)),r()));q=Rh(E(Fd(E((gg(q)?q>=E(0)?E(1):E(-1):q)*o),E(-1))*E(32768)));$a:{if(E(F(q))<E(2147483648)){g=~~q;break $a}g=-2147483648}M=b,P=Sc(g),w[M+2>>1]=P;b=b+4|0;e=e+8|0;f=f-1|0;continue}break}db=a+16|0;f=d<<3;break v}d=x[b>>2];b=x[b+20>>2];a=db-16|0;db=a;x[a+12>>2]=f>>>3;x[a+8>>2]=d;g=x[Cb(a+12|0,a+8|0)>>2];f=g;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);q=Af((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));q=Rh(E(Fd(E((gg(q)?q>=E(0)?E(1):E(-1):q)*o),E(-1))*E(32768)));ab:{if(E(F(q))<E(2147483648)){d=~~q;break ab}d=-2147483648}M=b,P=Sc(d),w[M>>1]=P;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);q=Af((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));q=Rh(E(Fd(E((gg(q)?q>=E(0)?E(1):E(-1):q)*o),E(-1))*E(32768)));bb:{if(E(F(q))<E(2147483648)){d=~~q;break bb}d=-2147483648}M=b,P=Sc(d),w[M+2>>1]=P;b=b+4|0;e=e+8|0;f=f-1|0;continue}break}db=a+16|0;f=g<<3;break v}d=x[b>>2];b=x[b+20>>2];a=db-16|0;db=a;x[a+12>>2]=f>>>2;x[a+8>>2]=d;g=x[Cb(a+12|0,a+8|0)>>2];f=g;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);q=Af((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));q=Rh(E(Fd(E((gg(q)?q>=E(0)?E(1):E(-1):q)*o),E(-1))*E(32768)));cb:{if(E(F(q))<E(2147483648)){d=~~q;break cb}d=-2147483648}M=b,P=Sc(d),w[M>>1]=P;b=b+2|0;e=e+4|0;f=f-1|0;continue}break}db=a+16|0;f=g<<2;break v}a=T(30544)|0}if((eb|0)!=($(30544)|0)){break d}Y(a|0)|0;x[23549]=0;X(17);a=x[23549];x[23549]=0;if((a|0)==1){break w}}ub(e);break v}a=N()|0;break d}x[23549]=0;O(141,c|0,f+L|0)|0;a=x[23549];x[23549]=0;if((a|0)==1){break f}}Jc(H)}db=k+2240|0;return f|0}a=N()|0;break a}a=N()|0}ub(e);break a}a=N()|0;break a}a=N()|0}Jc(H);Q(a|0);p()}function Wia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;d=db-576|0;db=d;wc(b);f=db-16|0;db=f;h=d+384|0;Hq(f+8|0,h);j=x[f+12>>2];g=b;lc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(j|0)){Zb(g,x[f+12>>2])}db=f+16|0;b=(b|0)==(j|0);if(!b){sU(h)}a:{b:{c:{if(!b){break c}if(!uU(d+384|0)){break c}if(!Lb(x[g>>2],x[g+8>>2],Qc(tU(d+384|0),hb))){break c}if(!c){e=1;break c}Bd(a,32);v[d+383|0]=0;j=Gb(d+368|0);d:{e:{f:{g:{h:{i:{j:{k:{if((y[d+384|0]|y[d+385|0]<<8|(y[d+386|0]<<16|y[d+387|0]<<24))==778924148){x[23549]=0;P(357,a|0,16777216);b=x[23549];x[23549]=0;if((b|0)==1){break b}b=x[g>>2];x[23549]=0;b=R(146,b|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break b}x[23549]=0;O(141,g|0,b-4|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break b}x[23549]=0;t=R(143,g|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break k}break b}l:{m:{n:{o:{p:{q:{if(((y[d+424|0]|y[d+425|0]<<8)-2185&65535)>>>0>1910){break q}b=x[g>>2];x[23549]=0;b=R(146,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break b}x[23549]=0;O(141,g|0,b-4|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break b}x[23549]=0;t=R(143,g|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break b}if(t>>>0<256){break q}b=x[g>>2];x[23549]=0;b=R(146,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break b}if(b>>>0<=t>>>0){break q}x[23549]=0;b=O(141,g|0,t|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break b}if(!b){break q}x[23549]=0;b=R(358,g|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break b}if(!b){break q}x[23549]=0;P(357,a|0,16777216);b=x[23549];x[23549]=0;if((b|0)==1){break b}b=y[d+424|0]|y[d+425|0]<<8;if(b>>>0>=4096){x[23549]=0;c=O(1,d+144|0,16106)|0;b=x[23549];x[23549]=0;if((b|0)==1){break j}a=x[a+1298464>>2];x[23549]=0;S(359,a|0,1,c|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(c);break d}b=N()|0;tb(c);break a}if(b>>>0<2194){break q}x[23549]=0;e=O(1,d+356|0,15635)|0;b=x[23549];x[23549]=0;if((b|0)==1){break p}b=x[a+1298464>>2];x[23549]=0;S(359,b|0,4,e|0);b=x[23549];x[23549]=0;if((b|0)==1){break o}tb(e)}if(x[a+480180>>2]!=32){break k}b=y[d+424|0]|y[d+425|0]<<8;if((b&61440)!=20480){break l}b=b&4095;e=b<<16;if((y[d+444|0]|y[d+445|0]<<8|(y[d+446|0]<<16|y[d+447|0]<<24))!=1414548815){break n}v[d+383|0]=1;break m}b=N()|0;break a}b=N()|0;tb(e);break a}if(b>>>0<297){break m}e=y[d+444|0]|y[d+445|0]<<8|e}x[a+1074308>>2]=e;break k}e=y[d+426|0]|y[d+427|0]<<8;if(!((e|0)!=2184&(b|0)!=2184)){v[d+383|0]=1;x[a+1074308>>2]=18284544;break k}r:{switch(b-532|0){default:if((b|0)!=768|(e|0)!=768|(y[d+444|0]|y[d+445|0]<<8|(y[d+446|0]<<16|y[d+447|0]<<24))|((y[d+416|0]|y[d+417|0]<<8)!=256|y[d+436|0]!=128)){break k}if(y[d+437|0]){break k}x[a+1074308>>2]=18285088;v[d+383|0]=1;break k;case 3:if(y[d+444|0]|y[d+445|0]<<8|(y[d+446|0]<<16|y[d+447|0]<<24)|(e|0)!=512){break k}s:{if(au(d+448|0,255,64)){x[a+1074308>>2]=18219008;x[23549]=0;b=O(1,d+344|0,14492)|0;e=x[23549];x[23549]=0;if((e|0)!=1){break s}b=N()|0;break a}x[a+1074308>>2]=18284544;x[23549]=0;b=O(1,d+344|0,16457)|0;e=x[23549];x[23549]=0;if((e|0)==1){break i}}zb(j,b);tb(b);v[d+383|0]=1;break k;case 1:case 2:break k;case 0:break r}}if(y[d+444|0]|y[d+445|0]<<8|(y[d+446|0]<<16|y[d+447|0]<<24)|(e|0)!=514){break k}x[a+1074308>>2]=17367040;x[23549]=0;b=O(1,d+344|0,14375)|0;e=x[23549];x[23549]=0;if((e|0)==1){break f}zb(j,b);tb(b);v[d+383|0]=1}b=y[d+428|0]|y[d+429|0]<<8;e=b>>>2|0;x[a+480208>>2]=b<<3&32768|(e&8|(e&4|(x[a+480208>>2]&-32797|b<<1&16)));b=d+248|0;Yq(b,d+388|0);x[23549]=0;P(208,d+144|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break h}b=d+144|0;zb(a+1298308|0,b);tb(b);if(!(!(y[d+430|0]&4)|x[a+1074308>>2]-18285314>>>0>4276681982)){x[a+480216>>2]=y[d+414|0];x[a+480220>>2]=y[d+415|0]}b=y[d+432|0];x[a+480200>>2]=b>>>0>128?256:b<<1;b=y[d+434|0];if(b){x[a+480196>>2]=b}v[d+144|0]=31;v[d+248|0]=y[d+435|0];b=d+144|0;e=d+248|0;I=a,J=D(y[af(b,e)|0],1e4),x[I+480204>>2]=J;v[d+144|0]=y[d+433|0];v[d+248|0]=128;I=a,J=y[Sb(b,e)|0],x[I+480228>>2]=J;e=0;while(1){if((e|0)==64){t:{x[23549]=0;O(141,g|0,192)|0;b=x[23549];x[23549]=0;if((b|0)==1){break b}if(x[a+480180>>2]==16777216&((y[d+424|0]|y[d+425|0]<<8)-2187&65535)>>>0<=2){break t}b=y[a+484376|0];e=x[a+484360>>2];x[23549]=0;aa(332,Wb(e,b)|0,g|0,y[d+416|0]|y[d+417|0]<<8,255,254);b=x[23549];x[23549]=0;if((b|0)==1){break b}break e}}else{h=(d+384|0)+e|0;i=h- -64|0;u:{if(y[i|0]==255){break u}f=(e<<5)+a|0;b=f+480280|0;Te(b);I=f+480286|0,J=Vd(y[h+128|0],0,64),w[I>>1]=J;h=v[i|0];if((h|0)<0){x[b>>2]=x[b>>2]|1024}h=h&127;if(h>>>0<=64){w[f+480284>>1]=h<<2;break u}if((h|0)!=100){break u}x[b>>2]=x[b>>2]|256}e=e+1|0;continue}break}e=0;x[23549]=0;b=R(180,g|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break g}if(b){break d}x[23549]=0;b=R(143,g|0)|0;f=x[23549];x[23549]=0;v:{if((f|0)==1){break v}if(b>>>0>4e3){break d}f=y[a+484376|0];h=x[a+484360>>2];x[23549]=0;b=U(360,Wb(h,f)|0,g|0,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break v}if(!b){break d}break e}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}s=Nb(d+332|0);q=Nb(d+320|0);e=0;n=Nb(d+308|0);x[23549]=0;b=U(361,g|0,s|0,y[d+418|0]|y[d+419|0]<<8)|0;f=x[23549];x[23549]=0;w:{x:{y:{if((f|0)==1){break y}if(!b){break w}x[23549]=0;b=U(361,g|0,q|0,y[d+420|0]|y[d+421|0]<<8)|0;f=x[23549];x[23549]=0;if((f|0)==1){break y}if(!b){break w}x[23549]=0;b=U(361,g|0,n|0,y[d+422|0]|y[d+423|0]<<8)|0;f=x[23549];x[23549]=0;if((f|0)==1){break y}if(!b){break w}x[d+304>>2]=-1;I=d,J=yb(x[s>>2]),x[I+144>>2]=J;f=yb(x[s+4>>2]);b=x[d+304>>2];while(1){e=x[d+144>>2];if(Kb(e,f)){e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);if(!(!e|b>>>0<=e>>>0)){x[d+304>>2]=e;b=e}Ae(d+144|0);continue}else{I=d,J=yb(x[q>>2]),x[I+144>>2]=J;f=yb(x[q+4>>2]);b=x[d+304>>2];while(1){e=x[d+144>>2];if(Kb(e,f)){e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);if(!(!e|b>>>0<=e>>>0)){x[d+304>>2]=e;b=e}Ae(d+144|0);continue}else{I=d,J=yb(x[n>>2]),x[I+144>>2]=J;f=yb(x[n+4>>2]);b=x[d+304>>2];z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{while(1){e=x[d+144>>2];if(Kb(e,f)){e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);if(!(!e|b>>>0<=e>>>0)){x[d+304>>2]=e;b=e}Ae(d+144|0);continue}else{if(v[d+430|0]&1){x[d+144>>2]=y[d+440|0]|y[d+441|0]<<8|(y[d+442|0]<<16|y[d+443|0]<<24);b=x[Cb(d+304|0,d+144|0)>>2];x[d+304>>2]=b}e=0;if((y[d+426|0]|y[d+427|0]<<8)!=532){break H}f=y[d+424|0]|y[d+425|0]<<8;if(y[d+415|0]|(f?(f|0)!=532:0)|(y[d+414|0]|y[d+437|0])){break H}if(y[d+428|0]&192|(y[d+444|0]|y[d+445|0]<<8|(y[d+446|0]<<16|y[d+447|0]<<24))){break H}if(y[d+418|0]|y[d+419|0]<<8){break I}f=y[d+420|0]|y[d+421|0]<<8;if(!f){break I}if((x[g+8>>2]+(oc(x[q>>2],x[q+4>>2])<<2)|0)+2>>>0>b>>>0){break I}}break}while(1){if((e&65535)>>>0<(f&65535)>>>0){x[23549]=0;b=R(143,g|0)|0;f=x[23549];x[23549]=0;J:{if((f|0)!=1){if(!b){break J}ng(g,((e&65535)<<2)+4|0);break I}b=N()|0;break x}e=e+1|0;f=y[d+420|0]|y[d+421|0]<<8;continue}break}x[23549]=0;b=O(1,d+292|0,14636)|0;e=x[23549];x[23549]=0;if((e|0)==1){break G}zb(j,b);tb(b)}e=1;if(y[d+424|0]|y[d+425|0]<<8){break H}x[23549]=0;b=O(1,d+280|0,14996)|0;f=x[23549];x[23549]=0;if((f|0)==1){break F}zb(j,b);tb(b)}b=y[d+430|0]|y[d+431|0]<<8;K:{if(b&2){x[23549]=0;f=R(180,g|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break A}b=x[g+8>>2];h=x[g>>2];x[23549]=0;i=b;b=f<<3;h=U(142,h|0,i|0,b|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break A}if(!(!h|A[d+304>>2]<b+x[g+8>>2]>>>0)){x[23549]=0;P(362,a+1298408|0,f|0);b=x[23549];x[23549]=0;if((b|0)==1){break A}I=d,J=yb(x[a+1298408>>2]),x[I+248>>2]=J;h=yb(x[a+1298412>>2]);L:{M:{while(1){b=x[d+248>>2];if(!Kb(b,h)){if(!(!f&e)){break K}if(!(y[d+430|0]&4)){break L}x[23549]=0;b=O(1,d+268|0,15029)|0;e=x[23549];x[23549]=0;if((e|0)==1){break M}zb(j,b);tb(b);break K}x[23549]=0;P(363,g|0,d+144|0);i=x[23549];x[23549]=0;if((i|0)!=1){Vb(b,0,44);i=y[d+144|0]|y[d+145|0]<<8;if(i|(y[d+146|0]|y[d+147|0]<<8)){x[b+20>>2]=((i&65024)>>>9|0)+80;I=b,J=Ub((y[d+144|0]|y[d+145|0]<<8)>>>5&15,1,12)-1|0,x[I+16>>2]=J;I=b,J=Ub((y[d+144|0]|y[d+145|0]<<8)&31,1,31),x[I+12>>2]=J;I=b,J=Ub((y[d+146|0]|y[d+147|0]<<8)>>>11|0,0,23),x[I+8>>2]=J;I=b,J=Ub((y[d+146|0]|y[d+147|0]<<8)>>>5&63,0,59),x[I+4>>2]=J;I=b,J=Ub((y[d+146|0]|y[d+147|0]<<8)<<1&62,0,59),x[I>>2]=J}x[b+44>>2]=y[d+148|0]|y[d+149|0]<<8|(y[d+150|0]<<16|y[d+151|0]<<24);x[d+248>>2]=x[d+248>>2]+48;continue}break}b=N()|0;break x}b=N()|0;break x}x[23549]=0;b=O(1,d+268|0,14658)|0;e=x[23549];x[23549]=0;if((e|0)!=1){zb(j,b);tb(b);break K}b=N()|0;break x}ng(g,2);break K}if(e^1|b>>>0>1){break K}x[23549]=0;b=R(180,g|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break z}if(!b){x[23549]=0;b=O(1,d+268|0,14636)|0;e=x[23549];x[23549]=0;if((e|0)!=1){zb(j,b);tb(b);break K}b=N()|0;break x}ng(g,2)}N:{if(!(y[d+428|0]&128|y[d+430|0]&8)){break N}x[23549]=0;b=a+901404|0;e=O(364,g|0,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break E}if(!e){break N}gB(b)}if((y[d+424|0]|y[d+425|0]<<8)>>>0<=531){sq(a+901404|0)}x[23549]=0;u=R(160,d+248|0)|0;b=x[23549];x[23549]=0;O:{P:{Q:{if((b|0)!=1){x[23549]=0;b=O(354,g|0,13608)|0;e=x[23549];x[23549]=0;if((e|0)==1){break Q}if(b){x[23549]=0;b=R(143,g|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break P}x[23549]=0;S(176,d+228|0,g|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break P}b=d+228|0;e=hc(d+144|0,b);Zc(u,e);ub(e);ub(b)}w[a+480188>>1]=1;x[23549]=0;b=O(354,g|0,13613)|0;e=x[23549];x[23549]=0;if((e|0)==1){break Q}if(!b){break C}x[23549]=0;b=R(143,g|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){x[23549]=0;S(176,d+228|0,g|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){break O}}b=N()|0;break B}b=N()|0;break x}b=N()|0;break B}b=N()|0;break B}b=d+228|0;f=hc(d+144|0,b);ub(b);b=x[f>>2];x[23549]=0;b=R(146,b|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break D}w[d+228>>1]=(b>>>0)/20;b=z[Uc(26708,d+228|0)>>1];w[a+480188>>1]=b;e=0;while(1){if((b|0)==(e|0)){ub(f);break C}x[23549]=0;S(365,f|0,((e<<5)+a|0)+480289|0,20);h=x[23549];x[23549]=0;if((h|0)!=1){e=e+1|0;continue}break}break D}b=N()|0;break x}b=N()|0;break x}b=N()|0;break x}b=N()|0;ub(f);break B}R:{b=x[d+304>>2];e=x[g+8>>2];S:{if(b>>>0>=e>>>0){e=b-e|0;break S}x[23549]=0;e=R(188,g|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break R}}x[23549]=0;S(176,d+144|0,g|0,e|0);b=x[23549];x[23549]=0;if((b|0)==1){break R}b=d+144|0;B=hc(d+228|0,b);ub(b);x[23549]=0;E=O(366,a|0,B|0)|0;b=x[23549];x[23549]=0;T:{U:{V:{if((b|0)==1){break V}if(!(v[d+430|0]&1)|!(y[d+438|0]|y[d+439|0]<<8)){break U}x[23549]=0;b=O(141,g|0,y[d+440|0]|y[d+441|0]<<8|(y[d+442|0]<<16|y[d+443|0]<<24))|0;e=x[23549];x[23549]=0;if((e|0)==1){break V}if(!b){break U}x[23549]=0;V(321,a+1298332|0,g|0,y[d+438|0]|y[d+439|0]<<8,4);b=x[23549];x[23549]=0;if((b|0)!=1){break U}}b=N()|0;break T}w[a+480192>>1]=0;b=0;if(y[d+428|0]&4){w[d+144>>1]=y[d+418|0]|y[d+419|0]<<8;w[d+84>>1]=255;b=z[Uc(d+144|0,d+84|0)>>1];w[a+480192>>1]=b}e=0;W:{while(1){if((b&65535)>>>0<=e>>>0){x[d+224>>2]=0;e=y[d+420|0]|y[d+421|0]<<8;if(e){b=xb(x[q>>2],e-1|0);x[d+224>>2]=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))+80}w[d+144>>1]=e;w[d+84>>1]=3999;b=z[Uc(d+144|0,d+84|0)>>1];w[a+480190>>1]=b;l=c&2;m=d+164|0;e=0;while(1){X:{Y:{Z:{_:{$:{aa:{ba:{ca:{if((b&65535)>>>0>e>>>0){b=xb(x[q>>2],e);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(!b){break Y}x[23549]=0;b=O(141,g|0,b|0)|0;f=x[23549];x[23549]=0;da:{ea:{fa:{ga:{ha:{if((f|0)==1){break ha}if(!b){break Y}x[23549]=0;b=O(367,g|0,d+144|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break ha}if(!b){break Y}x[23549]=0;b=e+1|0;h=D(b,104)+a|0;f=h+484380|0;i=O(368,d+144|0,f|0)|0;k=x[23549];x[23549]=0;if((k|0)==1){break ga}k=d+132|0;Yq(k,m);x[23549]=0;P(208,d+84|0,k|0);k=x[23549];x[23549]=0;if((k|0)==1){break fa}k=d+84|0;zc(((b<<5)+a|0)+946304|0,k);tb(k);x[23549]=0;i=O(141,g|0,i|0)|0;k=x[23549];x[23549]=0;if((k|0)==1){break ga}if(!i){break Y}h=z[h+484414>>1];if(!(h&512)){break ea}x[23549]=0;b=O(369,g|0,d+84|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break ca}if(!b){break da}x[d+8>>2]=y[d+92|0]|y[d+93|0]<<8|(y[d+94|0]<<16|y[d+95|0]<<24);b=y[d+88|0]|y[d+89|0]<<8|(y[d+90|0]<<16|y[d+91|0]<<24);x[d>>2]=y[d+84|0]|y[d+85|0]<<8|(y[d+86|0]<<16|y[d+87|0]<<24);x[d+4>>2]=b;xl(f,1,d);break da}b=N()|0;break T}b=N()|0;break T}b=N()|0;break T}if(!(h&16384)){o=y[d+424|0]|y[d+425|0]<<8;h=y[d+162|0];k=h&2;b=y[d+190|0];i=Xc(d+84|0,k?16:8,1,0,(b^-1)&1);if(!(!(h&4)|o>>>0<532)){Oo(i,3)}ia:{ja:{if(h&8){h=b&4?5:4;break ja}if(!k){h=10;if((b|0)==255){break ja}}if(b&2){v[i+2|0]=1}if(b&4){Uf(i,2)}if(!(b&8)){break ia}h=9;if(!k){break ia}}Uf(i,h)}if(l){b=0;x[23549]=0;U(205,d+84|0,f|0,g|0)|0;h=x[23549];x[23549]=0;if((h|0)!=1){break _}break X}b=1;h=y[d+87|0];if(h>>>0>17){break Z}h=1<<h;if(!(h&63503)){if(!(h&198144)){break Z}break $}if(y[d+84|0]){break $}break _}x[23549]=0;P(370,g|0,d+72|0);f=x[23549];x[23549]=0;if((f|0)==1){break aa}h=x[d+72>>2];if(!(!l|!h)){f=Gb(d+84|0);x[23549]=0;S(257,g|0,f|0,h|0);h=x[23549];x[23549]=0;ka:{la:{ma:{na:{oa:{pa:{qa:{if((h|0)!=1){x[23549]=0;P(371,d+120|0,16028);h=x[23549];x[23549]=0;if((h|0)==1){break qa}x[d+60>>2]=b;x[23549]=0;S(11,d+108|0,0,f|0);b=x[23549];x[23549]=0;if((b|0)==1){break pa}x[23549]=0;V(372,d+132|0,d+120|0,d+60|0,d+108|0);b=x[23549];x[23549]=0;if((b|0)==1){break oa}b=x[a+1298464>>2];x[23549]=0;S(359,b|0,2,d+132|0);b=x[23549];x[23549]=0;if((b|0)==1){break na}tb(d+132|0);tb(d+108|0);Ab(d+120|0);tb(f);break da}b=N()|0;break ka}b=N()|0;break ka}b=N()|0;break la}b=N()|0;break ma}b=N()|0;tb(d+132|0)}tb(d+108|0)}Ab(d+120|0)}tb(f);break T}x[23549]=0;O(174,g|0,h|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break aa}}b=0;break Z}w[d+144>>1]=1;w[d+84>>1]=b;I=a,J=z[Ve(d+144|0,d+84|0)>>1],w[I+480190>>1]=J;if(!((y[d+424|0]|y[d+425|0]<<8)==516&r)|(y[d+426|0]|y[d+427|0]<<8)!=512|(y[d+430|0]|y[d+431|0]<<8|(y[d+444|0]|y[d+445|0]<<8|(y[d+446|0]<<16|y[d+447|0]<<24)))){break ba}if(((y[d+428|0]|y[d+429|0]<<8)&65527)!=21|y[d+432|0]!=128|(y[d+433|0]!=48|y[d+436|0]!=128)){break ba}if(y[d+437|0]|(y[d+438|0]|y[d+439|0]<<8)){break ba}b=d+512|0;f=d+448|0;e=1;while(1)if((b|0)==(f|0)){f=d+576|0;while(1)if((b|0)==(f|0)){b=20;while(1){if((b|0)==26){ra:{if(!(e&1)){break ba}x[23549]=0;b=O(1,d+132|0,9762)|0;e=x[23549];x[23549]=0;if((e|0)==1){break ra}zb(j,b);tb(b);break ba}}else{e=!y[(b+d|0)+388|0]&e;b=b+1|0;continue}break}b=N()|0;break T}else{e=y[b|0]==64&e;b=b+1|0;continue}}else{e=(y[f|0]&127)==32&e;f=f+1|0;continue}}b=N()|0;break T}x[a+480260>>2]=0;x[a+480264>>2]=2147483647;b=oc(x[n>>2],x[n+4>>2]);w[d+144>>1]=b;r=z[Uc(d+144|0,x[a+8>>2]+10|0)>>1];w[d+106>>1]=r;sa:{ta:{ua:{va:{if((b|0)!=(r|0)){x[23549]=0;W(373,d+84|0);b=x[23549];x[23549]=0;if((b|0)==1){break sa}b=x[n+4>>2];e=x[n>>2];x[23549]=0;I=d,J=oc(e,b),x[I+120>>2]=J;V(374,d+144|0,d+84|0,d+120|0,d+106|0);b=x[23549];x[23549]=0;if((b|0)==1){break ua}b=x[a+1298464>>2];x[23549]=0;S(359,b|0,2,d+144|0);b=x[23549];x[23549]=0;if((b|0)==1){break va}tb(d+144|0);Ab(d+84|0)}if(!(c&1)){w[d+106>>1]=0;r=0}h=0;wa:{xa:{ya:{za:{Aa:{Ba:{while(1){Ca:{if((h|0)==(r|0)){Da:{Ea:{b=x[d+224>>2];if(!b){break Ea}x[23549]=0;O(141,g|0,b|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break Da}if(!o){break Ea}while(1){Fa:{b=x[g+8>>2];c=x[g>>2];x[23549]=0;b=U(142,c|0,b|0,4)|0;c=x[23549];x[23549]=0;if((c|0)==1){break Fa}if(!b){break Ea}x[23549]=0;b=O(354,g|0,13587)|0;c=x[23549];x[23549]=0;if((c|0)==1){break Fa}Ga:{if(!b){x[23549]=0;b=O(354,g|0,13592)|0;c=x[23549];x[23549]=0;if((c|0)==1){break Fa}if(!b){break Ga}}x[23549]=0;b=R(143,g|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){ng(g,8);if(!(b&1616928864)|b&-2139062144){break Ga}break Ea}b=N()|0;break T}x[23549]=0;b=R(180,g|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break Fa}x[23549]=0;O(174,g|0,b|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){continue}}break}b=N()|0;break T}x[23549]=0;b=O(375,a|0,g|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break Da}b=b|y[d+383|0];v[d+383|0]=b;if(!(!(b&255)|E)){iu(a+1074312|0);v[a+1074368|0]=0}x[23549]=0;V(376,a|0,g|0,0,d+383|0);b=x[23549];x[23549]=0;if((b|0)==1){break Da}x[23549]=0;o=a+484344|0;P(211,o|0,r|0);b=x[23549];x[23549]=0;if((b|0)==1){break Da}H=a+480183|0;h=0;Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{while(1){Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{if((h|0)!=(r|0)){b=xb(x[n>>2],h);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(b){x[23549]=0;b=O(141,g|0,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break ab}if(b){break $a}}x[23549]=0;b=U(212,o|0,h&65535,64)|0;c=x[23549];x[23549]=0;if((c|0)==1){break ab}if(b){break bb}w[d+48>>1]=h;x[23549]=0;W(377,d+84|0);b=x[23549];x[23549]=0;if((b|0)==1){break fb}x[23549]=0;S(378,d+144|0,d+84|0,d+48|0);b=x[23549];x[23549]=0;if((b|0)==1){break eb}b=x[a+1298464>>2];x[23549]=0;S(359,b|0,2,d+144|0);b=x[23549];x[23549]=0;if((b|0)==1){break db}tb(d+144|0);Ab(d+84|0)}if(!x[a+1074308>>2]){e=y[d+424|0]|y[d+425|0]<<8;if((e|0)!=2184){break Za}x[a+1074308>>2]=18284544}if(!xd(x[j+4>>2],y[j+11|0])){break _a}x[23549]=0;c=O(1,d+84|0,17202)|0;b=x[23549];x[23549]=0;if((b|0)==1){break Ra}b=x[a+1074308>>2];x[23549]=0;P(126,d+60|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break Ta}x[23549]=0;S(2,d+144|0,c|0,d+60|0);b=x[23549];x[23549]=0;if((b|0)==1){break Ua}e=d+144|0;b=zb(j,e);tb(e);tb(d+60|0);tb(c);if((y[d+444|0]|y[d+445|0]<<8|(y[d+446|0]<<16|y[d+447|0]<<24))==1414548815|((y[d+424|0]|y[d+425|0]<<8)&61440)!=20480){break Ya}x[23549]=0;c=O(1,d+144|0,16469)|0;e=x[23549];x[23549]=0;if((e|0)==1){break Va}x[23549]=0;O(87,b|0,c|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break Wa}tb(c);break Xa}b=N()|0;break T}b=N()|0;break cb}b=N()|0;tb(d+144|0)}Ab(d+84|0);break T}b=x[o>>2];x[23549]=0;P(379,Yb(b,h)|0,u|0);b=x[23549];x[23549]=0;if((b|0)!=1){break Pa}}b=N()|0;break T}x[23549]=0;b=R(180,g|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break Ha}x[23549]=0;F=R(180,g|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break Ia}x[23549]=0;c=O(174,g|0,4)|0;e=x[23549];x[23549]=0;if((e|0)==1){break Ia}if(!c){break Pa}x[23549]=0;c=U(212,o|0,h&65535,F|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break Ia}if(!c){break Pa}x[23549]=0;S(176,d+84|0,g|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break Ja}b=d+84|0;k=hc(d+144|0,b);ub(b);b=x[o>>2];x[23549]=0;P(379,Yb(b,h)|0,u|0);b=x[23549];x[23549]=0;if((b|0)==1){break La}b=z[a+480188>>1];x[23549]=0;m=O(380,d+108|0,b|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break Ma}b=z[a+480188>>1];c=d+84|0;Uh(c);x[23549]=0;l=U(381,d+72|0,b|0,c|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break Oa}I=d,J=yb(x[Yb(x[o>>2],h)>>2]),x[I+60>>2]=J;C=0;while(1){gb:{hb:{ib:{jb:{if(C>>>0>=F>>>0){break jb}b=x[k>>2];x[23549]=0;b=U(142,b|0,x[d+152>>2],1)|0;c=x[23549];x[23549]=0;if((c|0)==1){break Qa}if(!b){break jb}x[23549]=0;b=R(192,k|0)|0;c=x[23549];x[23549]=0;kb:{if((c|0)!=1){b=b<<24>>24;if(b){break kb}GU(d+60|0,z[a+480188>>1]);C=C+1|0;continue}break Qa}lb:{c=b&127;i=c?c-1&65535:0;if(Pc(x[m>>2],x[d+112>>2])>>>0>i>>>0){break lb}x[23549]=0;v[d+84|0]=0;c=i+1|0;S(382,m|0,c|0,d+84|0);e=x[23549];x[23549]=0;if((e|0)==1){break Qa}e=d+84|0;Uh(e);x[23549]=0;S(383,l|0,c|0,e|0);c=x[23549];x[23549]=0;if((c|0)!=1){break lb}break Qa}if((b|0)<0){x[23549]=0;b=R(192,k|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break Qa}I=Db(x[m>>2],i),J=b,v[I|0]=J}b=d+84|0;Uh(b);if(i>>>0<z[a+480188>>1]){b=Ad(x[d+60>>2],i)}f=Db(x[m>>2],i);e=y[f|0];if(e&16){I=b,J=y[Ad(x[l>>2],i)|0],v[I|0]=J;e=y[f|0]}if(e&32){I=b,J=y[Ad(x[l>>2],i)+1|0],v[I+1|0]=J;e=y[f|0]}if(e&64){c=Ad(x[l>>2],i);v[b+2|0]=y[c+2|0];v[b+4|0]=y[c+4|0];e=y[f|0]}if(e<<24>>24<0){c=Ad(x[l>>2],i);v[b+3|0]=y[c+3|0];v[b+5|0]=y[c+5|0];e=y[f|0]}if(e&1){x[23549]=0;c=R(192,k|0)|0;e=x[23549];x[23549]=0;mb:{nb:{if((e|0)!=1){c=c<<24>>24;c=(((c^-1)&128)>>>7|0)+c|0;if(!(v[H|0]&1)){break nb}e=c;break mb}break Qa}e=253;if((c-121&255)>>>0<132){break mb}e=(c&255)!=253?c:0}v[b|0]=e;I=Ad(x[l>>2],i),J=e,v[I|0]=J;f=Db(x[m>>2],i)}if(y[f|0]&2){x[23549]=0;c=R(192,k|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break Qa}v[b+1|0]=c;I=Ad(x[l>>2],i),J=c,v[I+1|0]=J;f=Db(x[m>>2],i)}if(!(y[f|0]&4)){break gb}x[23549]=0;f=R(192,k|0)|0;c=x[23549];x[23549]=0;ob:{pb:{if((c|0)!=1){if(f>>>0>64){break pb}v[b+4|0]=f;e=1;break ob}break Qa}if(f<<24>>24<=-64){e=2;v[b+2|0]=2;f=f^-128;v[b+4|0]=f;break hb}if(f>>>0<=74){e=5;v[b+2|0]=5;f=f-65|0;v[b+4|0]=f;break hb}if(f>>>0<=84){e=6;v[b+2|0]=6;f=f-75|0;v[b+4|0]=f;break hb}if(f>>>0<=94){e=3;v[b+2|0]=3;f=f-85|0;v[b+4|0]=f;break hb}if(f>>>0<=104){e=4;v[b+2|0]=4;f=f-95|0;v[b+4|0]=f;break hb}if(f>>>0<=114){e=13;v[b+2|0]=13;f=f-105|0;v[b+4|0]=f;break hb}if(f>>>0<=124){e=12;v[b+2|0]=12;f=f-115|0;v[b+4|0]=f;break hb}c=f+63|0;if((c&255)>>>0<=9){v[b+4|0]=c;e=11;v[b+2|0]=11;f=c;break hb}c=f+53|0;G=c&255;if(G>>>0<=9){v[b+4|0]=c;e=8;v[b+2|0]=8;if(!G){f=0;break hb}if(x[a+1074308>>2]-1>>>0>18285139){break ib}e=7;v[b+2|0]=7;break ib}f=f+33|0;if((f&255)>>>0>=10){f=y[b+4|0];e=y[b+2|0];break hb}v[b+4|0]=f;e=15}v[b+2|0]=e;break hb}ek(l);bc(m);ub(k);break Pa}f=c}c=Ad(x[l>>2],i);v[c+4|0]=f;v[c+2|0]=e;f=Db(x[m>>2],i)}if(!(y[f|0]&8)){continue}x[23549]=0;P(249,d+36|0,k|0);c=x[23549];x[23549]=0;if((c|0)!=1){v[b+3|0]=y[d+36|0];I=b,J=y[fd(d+36|0)|0],v[I+5|0]=J;eB(b,1);c=Ad(x[l>>2],i);v[c+3|0]=y[b+3|0];v[c+5|0]=y[b+5|0];continue}break}break Qa}e=y[d+424|0]|y[d+425|0]<<8}qb:{rb:{sb:{tb:{ub:{vb:{wb:{xb:{b=e&65535;switch(b>>>12|0){case 13:break rb;case 7:break sb;case 6:break tb;case 4:break ub;case 1:break wb;case 0:break xb;default:break Xa}}if(E){x[23549]=0;b=O(1,d+144|0,8238)|0;c=x[23549];x[23549]=0;if((c|0)!=1){zb(j,b);tb(b);break Xa}b=N()|0;break T}yb:{zb:{Ab:{Bb:{Cb:{Db:{Eb:{Fb:{Gb:{Hb:{Ib:{Jb:{Kb:{Lb:{if((e&65535)==532){b=y[d+426|0]|y[d+427|0]<<8;if((b|0)!=532){if((b|0)!=512){e=532;break Kb}Mb:{if(y[d+430|0]|y[d+431|0]<<8|(y[d+428|0]|y[d+429|0]<<8)!=9|(y[d+415|0]|y[d+414|0])){break Mb}if(y[d+418|0]|y[d+419|0]<<8|((y[d+422|0]|y[d+423|0]<<8)+1|0)!=(y[d+416|0]|y[d+417|0]<<8)|(y[d+432|0]!=128|y[d+433|0]!=100)){break Mb}if(y[d+434|0]!=1|y[d+436|0]!=128|(y[d+437|0]|(y[d+438|0]|y[d+439|0]<<8))){break Mb}if(y[d+440|0]|y[d+441|0]<<8|(y[d+442|0]<<16|y[d+443|0]<<24)|(y[d+444|0]|y[d+445|0]<<8|(y[d+446|0]<<16|y[d+447|0]<<24))){break Mb}x[23549]=0;b=O(1,d+144|0,9743)|0;c=x[23549];x[23549]=0;if((c|0)!=1){zb(j,b);tb(b);break Xa}b=N()|0;break T}e=532;if(y[d+415|0]|y[d+414|0]|(y[d+444|0]|y[d+445|0]<<8|(y[d+446|0]<<16|y[d+447|0]<<24))){break Jb}x[a+1074308>>2]=16777381;x[23549]=0;b=O(1,d+144|0,14573)|0;c=x[23549];x[23549]=0;if((c|0)!=1){zb(j,b);tb(b);v[d+383|0]=1;break Xa}b=N()|0;break T}if((y[d+444|0]|y[d+445|0]<<8|(y[d+446|0]<<16|y[d+447|0]<<24))==1229080643){x[23549]=0;b=O(1,d+144|0,8276)|0;c=x[23549];x[23549]=0;if((c|0)!=1){zb(j,b);tb(b);e=a+1074312|0;b=38;break vb}b=N()|0;break T}e=532;if(y[d+437|0]|(y[d+430|0]|y[d+431|0]<<8)>>>0>1|(y[d+444|0]|y[d+445|0]<<8|(y[d+446|0]<<16|y[d+447|0]<<24)|((y[d+428|0]|y[d+429|0]<<8)&4294)!=4)){break Lb}if(!z[a+480190>>1]){break Lb}x[23549]=0;e=O(54,d+84|0,13317)|0;b=x[23549];x[23549]=0;if((b|0)==1){break Hb}b=db-32|0;db=b;c=db-16|0;db=c;hv(c+8|0,a+484527|0);$T(b+24|0,x[c+8>>2],x[c+12>>2]);db=c+16|0;ze(b+16|0,e);c=x[b+20>>2];x[b+8>>2]=x[b+16>>2];x[b+12>>2]=c;c=Gc(x[b+24>>2],x[b+28>>2],b+8|0);db=b+32|0;tb(e);if(c){break Ib}e=y[d+424|0]|y[d+425|0]<<8}if(e&65535){break Lb}if(xd(x[j+4>>2],y[j+11|0])){break Fb}}b=y[d+426|0]|y[d+427|0]<<8}if((b&65535)>>>0>767){break Xa}}if(!xd(x[j+4>>2],y[j+11|0])){break Xa}if((b&65535)>>>0<533){break Db}x[23549]=0;b=O(1,d+60|0,14606)|0;c=x[23549];x[23549]=0;if((c|0)==1){break Eb}zb(j,b);tb(b);break Cb}x[23549]=0;b=O(1,d+144|0,8302)|0;c=x[23549];x[23549]=0;if((c|0)==1){break Gb}zb(j,b);tb(b);break Xa}b=N()|0;break T}b=N()|0;break T}x[23549]=0;b=O(1,d+144|0,9633)|0;c=x[23549];x[23549]=0;if((c|0)!=1){zb(j,b);tb(b);break Xa}b=N()|0;break T}b=N()|0;break T}if((e&65535)>>>0>=533){x[23549]=0;P(384,d+60|0,3956);b=x[23549];x[23549]=0;Nb:{if((b|0)!=1){x[23549]=0;x[d+48>>2]=(y[d+424|0]|y[d+425|0]<<8)-532;S(385,d+144|0,d+60|0,d+48|0);b=x[23549];x[23549]=0;if((b|0)==1){break Nb}b=d+144|0;zb(j,b);tb(b);Ab(d+60|0);break Cb}b=N()|0;break T}b=N()|0;Ab(d+60|0);break T}x[23549]=0;P(255,d+60|0,4255);b=x[23549];x[23549]=0;if((b|0)==1){break Bb}b=y[d+424|0]|y[d+425|0]<<8;x[d+36>>2]=b>>>8&15;x[23549]=0;x[d+20>>2]=b&255;P(386,d+48|0,d+20|0);b=x[23549];x[23549]=0;if((b|0)==1){break Ab}x[23549]=0;V(372,d+144|0,d+60|0,d+36|0,d+48|0);b=x[23549];x[23549]=0;if((b|0)==1){break zb}b=d+144|0;zb(j,b);tb(b);tb(d+48|0);Ab(d+60|0)}if(!qc(x[a+1298408>>2],x[a+1298412>>2])){break Xa}b=y[d+444|0]|y[d+445|0]<<8|(y[d+446|0]<<16|y[d+447|0]<<24);if(!b){break Xa}b=$C(y[d+424|0]|y[d+425|0]<<8,b);c=Eq(d+144|0);x[c+44>>2]=b;x[23549]=0;P(387,a+1298408|0,c|0);b=x[23549];x[23549]=0;if((b|0)!=1){break Xa}b=N()|0;break T}b=N()|0;break T}b=N()|0;break yb}b=N()|0;tb(d+48|0)}Ab(d+60|0);break T}c=y[d+444|0]|y[d+445|0]<<8|(y[d+446|0]<<16|y[d+447|0]<<24);x[23549]=0;S(388,d+144|0,b|0,y[d+444|0]|y[d+445|0]<<8|(y[d+446|0]<<16|y[d+447|0]<<24));e=x[23549];x[23549]=0;Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{if((e|0)!=1){e=d+144|0;zb(j,e);tb(e);c=(b|0)==8191?c:b-4176|0;if((c|0)>1915){break Tb}b=x[a+480208>>2];if(!(b&16)){break Sb}x[23549]=0;O(254,a+1074312|0,7)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break Rb}break qb}b=N()|0;break T}if(c>>>0>4200){break Pb}b=x[a+480208>>2]}if(!(b&16)){x[23549]=0;O(254,a+1074312|0,7)|0;b=x[23549];x[23549]=0;if((b|0)==1){break qb}}if((c|0)>2385){break Qb}}x[23549]=0;O(254,a+1074312|0,38)|0;b=x[23549];x[23549]=0;if((b|0)==1){break qb}}x[23549]=0;b=O(254,a+1074312|0,102)|0;c=x[23549];x[23549]=0;if((c|0)==1){break qb}x[23549]=0;O(254,b|0,48)|0;b=x[23549];x[23549]=0;if((b|0)==1){break qb}break Ob}if(c>>>0>4383){break Xa}}x[23549]=0;e=U(253,a+1074312|0,116,1)|0;c=x[23549];x[23549]=0;b=115;if((c|0)==1){break qb}}x[23549]=0;O(254,e|0,b|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break qb}break Xa}x[23549]=0;W(389,d+84|0);b=x[23549];x[23549]=0;Ub:{Vb:{Wb:{if((b|0)!=1){b=y[d+424|0]|y[d+425|0]<<8;x[d+48>>2]=b>>>8&15;x[23549]=0;x[d+36>>2]=b&255;P(386,d+60|0,d+36|0);b=x[23549];x[23549]=0;if((b|0)==1){break Wb}x[23549]=0;V(372,d+144|0,d+84|0,d+48|0,d+60|0);b=x[23549];x[23549]=0;if((b|0)==1){break Vb}b=d+144|0;zb(j,b);tb(b);tb(d+60|0);Ab(d+84|0);break Xa}b=N()|0;break T}b=N()|0;break Ub}b=N()|0;tb(d+60|0)}Ab(d+84|0);break T}x[23549]=0;b=O(1,d+144|0,8238)|0;c=x[23549];x[23549]=0;if((c|0)!=1){zb(j,b);tb(b);break Xa}b=N()|0;break T}if(!((b|0)!=32767|(y[d+426|0]|y[d+427|0]<<8)!=533)){x[23549]=0;b=O(1,d+144|0,4983)|0;c=x[23549];x[23549]=0;if((c|0)!=1){zb(j,b);tb(b);break Xa}b=N()|0;break T}x[23549]=0;P(123,d+84|0,4091);b=x[23549];x[23549]=0;Xb:{if((b|0)!=1){b=y[d+424|0]|y[d+425|0]<<8;x[d+60>>2]=b>>>8&15;x[d+48>>2]=b>>>4&15;x[23549]=0;x[d+36>>2]=b&15;aa(124,d+144|0,d+84|0,d+60|0,d+48|0,d+36|0);b=x[23549];x[23549]=0;if((b|0)==1){break Xb}b=d+144|0;zb(j,b);tb(b);Ab(d+84|0);break Xa}b=N()|0;break T}b=N()|0;Ab(d+84|0);break T}x[23549]=0;b=O(1,d+144|0,6064)|0;c=x[23549];x[23549]=0;if((c|0)!=1){zb(j,b);tb(b);break Xa}b=N()|0;break T}b=N()|0;break T}if(!oE(x[a+1074308>>2])){break Xa}x[23549]=0;c=O(1,d+144|0,16705)|0;e=x[23549];x[23549]=0;Yb:{if((e|0)!=1){x[23549]=0;O(87,b|0,c|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break Yb}tb(c);break Xa}b=N()|0;break T}b=N()|0;tb(c);break T}e=x[a+480180>>2];if(!((e|0)!=16777216|(y[d+424|0]|y[d+425|0]<<8)>>>0<2186)){x[23549]=0;b=O(141,g|0,t|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break Da}if(b){x[23549]=0;S(390,a|0,g|0,y[d+424|0]|y[d+425|0]<<8);b=x[23549];x[23549]=0;if((b|0)==1){break Da}}e=x[a+480180>>2]}Zb:{_b:{$b:{ac:{bc:{cc:{if((e|0)==16777216){x[23549]=0;O(1,d+48|0,13570)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break cc}b=N()|0;break T}x[23549]=0;P(255,d+36|0,4255);b=x[23549];x[23549]=0;if((b|0)==1){break bc}b=y[d+426|0]|y[d+427|0]<<8;x[d+32>>2]=b>>>8;x[23549]=0;x[d+16>>2]=b&255;P(386,d+20|0,d+16|0);b=x[23549];x[23549]=0;if((b|0)==1){break ac}x[23549]=0;V(372,d+48|0,d+36|0,d+32|0,d+20|0);b=x[23549];x[23549]=0;if((b|0)==1){break $b}}b=d+48|0;zb(a+1298344|0,b);tb(b);if((e|0)!=16777216){tb(d+20|0);Ab(d+36|0)}b=x[a+480180>>2];x[23549]=0;b=O(1,d+48|0,((b|0)==16777216?10007:6068)|0)|0;c=x[23549];x[23549]=0;e=1;if((c|0)==1){break Zb}zb(a+1298356|0,b);tb(b);zb(a+1298368|0,j);x[a+1298404>>2]=x[a+1074308>>2]?8:5;ub(B);ub(u);break w}b=N()|0;break T}b=N()|0;break _b}b=N()|0;tb(d+20|0)}Ab(d+36|0);break T}b=N()|0;break T}b=N()|0;tb(c);break T}b=N()|0;break T}b=N()|0;tb(d+60|0);break Sa}b=N()|0}tb(c);break T}b=N()|0;break T}b=N()|0;ek(l);break Na}h=h+1|0;continue}break}b=N()|0}bc(m);break Ka}b=N()|0;break Ka}b=N()|0}ub(k);break T}b=N()|0;break T}b=N()|0;break T}b=N()|0;break T}b=N()|0;break T}dc:{b=xb(x[n>>2],h);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);ec:{if(!b){break ec}x[23549]=0;b=O(141,g|0,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break Ba}if(!b){break ec}x[23549]=0;b=R(180,g|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break wa}x[23549]=0;k=R(180,g|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break xa}if((k-1025&65535)>>>0<64512){break ec}x[23549]=0;c=O(174,g|0,4)|0;e=x[23549];x[23549]=0;if((e|0)==1){break xa}if(!c){break ec}x[23549]=0;S(176,d+84|0,g|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break ya}b=d+84|0;f=hc(d+144|0,b);ub(b);b=z[a+480188>>1];l=0;x[23549]=0;i=O(380,d+120|0,b|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break Aa}fc:{while(1){if(k>>>0<=l>>>0){break fc}b=x[f>>2];x[23549]=0;b=U(142,b|0,x[d+152>>2],1)|0;c=x[23549];x[23549]=0;if((c|0)==1){break dc}if(!b){break fc}x[23549]=0;b=R(192,f|0)|0;c=x[23549];x[23549]=0;gc:{if((c|0)!=1){c=b<<24>>24;if(c){break gc}l=l+1|0;continue}break Ca}hc:{b=c&127;m=b?b-1|0:0;b=m&65535;if(Pc(x[i>>2],x[d+124>>2])>>>0>b>>>0){break hc}x[23549]=0;v[d+84|0]=0;S(382,i|0,b+1|0,d+84|0);e=x[23549];x[23549]=0;if((e|0)!=1){break hc}break Ca}ic:{if((c|0)<0){x[23549]=0;c=R(192,f|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break ic}I=Db(x[i>>2],b),J=c,v[I|0]=J}e=Db(x[i>>2],b);c=y[e|0];if(!(!(c&15)|b>>>0<z[a+480188>>1])){w[a+480188>>1]=m+1;c=y[e|0]}if(c&1){x[23549]=0;O(174,f|0,1)|0;c=x[23549];x[23549]=0;if((c|0)==1){break ic}e=Db(x[i>>2],b)}if(y[e|0]&2){x[23549]=0;O(174,f|0,1)|0;c=x[23549];x[23549]=0;if((c|0)==1){break ic}e=Db(x[i>>2],b)}if(y[e|0]&4){x[23549]=0;O(174,f|0,1)|0;c=x[23549];x[23549]=0;if((c|0)==1){break ic}e=Db(x[i>>2],b)}if(!(y[e|0]&8)){continue}x[23549]=0;O(174,f|0,2)|0;b=x[23549];x[23549]=0;if((b|0)!=1){continue}}break}break Ca}x[d+84>>2]=x[g+8>>2];I=d,J=x[Yc(d+224|0,d+84|0)>>2],x[I+224>>2]=J;bc(i);ub(f)}h=h+1|0;continue}}break}b=N()|0;bc(i);break za}b=N()|0;break T}b=N()|0}ub(f);break T}b=N()|0;break T}b=N()|0;break T}b=N()|0;break T}b=N()|0;tb(d+144|0);break ta}b=N()|0}Ab(d+84|0);break T}b=N()|0;break T}b=N()|0;break T}b=0;h=dB(d+84|0,x[f>>2]);x[23549]=0;O(174,g|0,h|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break X}}if(y[d+87|0]!=1){break Z}r=x[f>>2]!=0|r}x[d+84>>2]=x[g+8>>2];I=d,J=x[Yc(d+224|0,d+84|0)>>2],x[I+224>>2]=J;o=(b|0)!=0}e=e+1|0;b=z[a+480190>>1];continue}break}b=N()|0;break T}jc:{b=xb(x[s>>2],e);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);kc:{if(!b){break kc}x[23549]=0;b=O(141,g|0,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break jc}if(!b){break kc}b=x[g+8>>2];f=x[g>>2];x[23549]=0;b=U(142,f|0,b|0,554)|0;f=x[23549];x[23549]=0;if((f|0)==1){break jc}if(!b){break kc}x[23549]=0;b=U(240,a|0,e+1&65535,0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break W}if(!b){break kc}x[23549]=0;V(391,a|0,g|0,b|0,y[d+426|0]|y[d+427|0]<<8);f=x[23549];x[23549]=0;if((f|0)==1){break W}v[b+33|0]=y[d+437|0]}e=e+1|0;b=z[a+480192>>1];continue}break}b=N()|0;break T}b=N()|0}ub(B);break B}b=N()|0}ub(u);break x}b=N()|0;break x}b=N()|0;break x}}}}}b=N()|0}sc(n);sc(q);sc(s);break a}sc(n);sc(q);sc(s)}tb(j)}db=d+576|0;return e|0}b=N()|0}tb(j);Q(b|0);p()}function uha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0;d=db-1696|0;db=d;wc(b);a:{if(!$h(b,d+1688|0)){break a}if(!fT(d+1688|0)){break a}if(!c){g=1;break a}m=y[d+1691|0];v[d+1687|0]=m;x[d+1680>>2]=-1;x[d+1676>>2]=1048576;if(m>>>0>=5){e=pg(b);x[d+1680>>2]=e;if(!Lb(x[b>>2],x[b+8>>2],e)){break a}x[d+272>>2]=134217727;M=d,T=x[Cb(d+272|0,d+1680|0)>>2]<<5,x[M+1676>>2]=T}B=Nb(d+1664|0);x[d+272>>2]=y[d+1692|0]|y[d+1693|0]<<8|(y[d+1694|0]<<16|y[d+1695|0]<<24);e=x[Cb(d+1676|0,d+272|0)>>2];x[23549]=0;P(496,B|0,e|0);e=x[23549];x[23549]=0;b:{c:{d:{e:{f:{if((e|0)!=1){x[23549]=0;e=U(497,b|0,B|0,y[d+1692|0]|y[d+1693|0]<<8|(y[d+1694|0]<<16|y[d+1695|0]<<24))|0;h=x[23549];x[23549]=0;g:{if((h|0)==1){break g}if(!e){break b}if(m>>>0>=5){x[23549]=0;O(141,b|0,x[d+1680>>2]+12|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break g}}x[23549]=0;P(235,a|0,0);e=x[23549];x[23549]=0;if((e|0)==1){break g}Dg(a);ge(d+1632|0,x[B>>2],x[B+4>>2]);e=Xd(d+1624|0);x[23549]=0;h=x[e+4>>2];x[d+80>>2]=x[e>>2];x[d+84>>2]=h;n=Xf(498,d+1644|0,x[d+1632>>2],x[d+1636>>2],d+80|0);e=x[23549];x[23549]=0;h:{i:{j:{if((e|0)!=1){x[23549]=0;S(342,n|0,a+1298308|0,-1);e=x[23549];x[23549]=0;if((e|0)==1){break j}x[23549]=0;S(342,n|0,a+1298332|0,-1);e=x[23549];x[23549]=0;if((e|0)==1){break j}x[23549]=0;e=O(499,n|0,d+1202|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break f}if(!e){break c}e=v[d+1202|0];if((e|0)<=0|(y[d+1211|0]|y[d+1212|0]<<8)>>>0>255|(y[d+1213|0]|y[d+1214|0]<<8)>>>0>3999){break c}w[a+480188>>1]=e&255;$e(Wb(x[a+484360>>2],y[a+484376|0]),y[d+1205|0]|y[d+1206|0]<<8);w[a+480192>>1]=y[d+1211|0]|y[d+1212|0]<<8;w[a+480190>>1]=y[d+1213|0]|y[d+1214|0]<<8;e=y[d+1215|0];x[a+480196>>2]=e?e:6;e=y[d+1216|0];x[a+480204>>2]=D(e?e:125,1e4);h=y[d+1217|0]|y[d+1218|0]<<8|(y[d+1219|0]<<16|y[d+1220|0]<<24);e=32;k:{if(h&256){break k}e=2;if(h&2){break k}e=1;if(h&128){break k}e=h&8?16:4}x[23549]=0;P(357,a|0,e|0);e=x[23549];x[23549]=0;if((e|0)==1){break f}h=x[a+480208>>2];f=h|16777216;x[a+480208>>2]=f;e=y[d+1217|0]|y[d+1218|0]<<8|(y[d+1219|0]<<16|y[d+1220|0]<<24);if(e&1){f=h|16777232;x[a+480208>>2]=f}i=x[a+480180>>2];j=(i|0)==32;h=j&!(e&1024);l=(i|0)==2;g=l&e>>>4;s=e&2097152;l=l&e>>>2;j=j&!(e&2048);if(h|(s|l|(j|g))){f=g?f|65536:f;f=l?f|2:f;f=j?f|4:f;x[a+480208>>2]=s>>>6|(h?f|8:f)}if(e&524288){x[23549]=0;U(253,a+1074312|0,5,1)|0;e=x[23549];x[23549]=0;if((e|0)==1){break f}i=x[a+480180>>2]}if((i|0)==2){break i}if((i|0)!=32){break h}v[d+272|0]=y[d+1221|0];v[d+204|0]=128;M=a,T=y[Sb(d+272|0,d+204|0)|0]<<1,x[M+480200>>2]=T;break h}e=N()|0;break d}e=N()|0;break e}v[d+272|0]=y[d+1221|0];v[d+204|0]=64;M=a,T=y[Sb(d+272|0,d+204|0)|0]<<2,x[M+480200>>2]=T}E=a+480188|0;e=v[d+1223|0];l:{if((e|0)<0){e=e+52|0;break l}G=Ir(+(e|0)*3.1/20);m:{if(G<4294967296&G>=0){e=~~G>>>0;break m}e=0}e=e+51|0}x[a+480228>>2]=e;w[d+272>>1]=64;h=z[Uc(E,d+272|0)>>1];f=0;j=(i|0)!=32;l=(i|0)==4;g=0;while(1)if((g|0)==(h|0)){g=0;j=0;while(1){if((f|0)!=16){j=y[(d+f|0)+1352|0]!=0|j;f=f+1|0;continue}break}while(1){if((g|0)!=128){j=y[((g<<1)+d|0)+1369|0]!=0|j;g=g+1|0;continue}break}n:{if(!(j&1)){break n}e=a+901692|0;g=0;while(1){if((g|0)==16){e=a+902204|0;g=0;while(1){if((g|0)!=128){h=(d+1202|0)+(g<<1)|0;o:{if(y[h+167|0]){x[23549]=0;W(500,d+204|0);f=x[23549];x[23549]=0;p:{q:{r:{s:{t:{if((f|0)!=1){f=y[h+167|0];x[23549]=0;x[d+228>>2]=f-1;P(501,d+1148|0,d+228|0);f=x[23549];x[23549]=0;if((f|0)==1){break t}h=y[h+166|0];x[23549]=0;v[d+176|0]=h;P(502,d+1128|0,d+176|0);h=x[23549];x[23549]=0;if((h|0)==1){break s}x[23549]=0;V(503,d+272|0,d+204|0,d+1148|0,d+1128|0);h=x[23549];x[23549]=0;if((h|0)==1){break r}h=d+272|0;ze(d+1176|0,h);Xe(te(e,g),x[d+1176>>2],x[d+1180>>2]);tb(h);tb(d+1128|0);tb(d+1148|0);Ab(d+204|0);break o}e=N()|0;break e}e=N()|0;break p}e=N()|0;break q}e=N()|0;tb(d+1128|0)}tb(d+1148|0)}Ab(d+204|0);break e}h=mc(d+1168|0,21204);Xe(te(e,g),x[h>>2],x[d+1172>>2])}g=g+1|0;continue}break}i=x[a+480180>>2];break n}h=(d+g|0)+1352|0;u:{if(y[h|0]){x[23549]=0;W(504,d+204|0);f=x[23549];x[23549]=0;v:{w:{x:{if((f|0)!=1){h=y[h|0];x[23549]=0;x[d+1128>>2]=h-1;P(501,d+1148|0,d+1128|0);h=x[23549];x[23549]=0;if((h|0)==1){break x}x[23549]=0;S(277,d+272|0,d+204|0,d+1148|0);h=x[23549];x[23549]=0;if((h|0)==1){break w}h=d+272|0;ze(d+1192|0,h);Xe(te(e,g),x[d+1192>>2],x[d+1196>>2]);tb(h);tb(d+1148|0);Ab(d+204|0);break u}e=N()|0;break e}e=N()|0;break v}e=N()|0;tb(d+1148|0)}Ab(d+204|0);break e}h=mc(d+1184|0,21204);Xe(te(e,g),x[h>>2],x[d+1188>>2])}g=g+1|0;continue}}e=y[a+484376|0];h=x[a+484360>>2];x[23549]=0;h=Wb(h,e);e=i&5;aa(332,h|0,n|0,y[d+1203|0]|y[d+1204|0]<<8,(e?65535:255)|0,(e?65535:254)|0);e=x[23549];x[23549]=0;if((e|0)!=1){x[23549]=0;S(176,d+272|0,n|0,D(y[d+1202|0],y[d+1207|0]|y[d+1208|0]<<8)<<1);e=x[23549];x[23549]=0;if((e|0)!=1){e=d+272|0;H=hc(d+1148|0,e);ub(e);x[23549]=0;S(176,e|0,n|0,(y[d+1207|0]|y[d+1208|0]<<8)<<1);e=x[23549];x[23549]=0;y:{if((e|0)!=1){e=d+272|0;I=hc(d+1128|0,e);ub(e);x[23549]=0;s=O(204,d+1116|0,y[d+1209|0]|y[d+1210|0]<<8)|0;e=x[23549];x[23549]=0;z:{if((e|0)!=1){M=d,T=yb(x[s>>2]),x[M+228>>2]=T;e=yb(x[s+4>>2]);A:{B:{C:{while(1){h=x[d+228>>2];if(!Kb(h,e)){e=x[a+480180>>2];o=c&1;if(!o){break B}x[23549]=0;P(211,a+484344|0,y[d+1207|0]|y[d+1208|0]<<8);h=x[23549];x[23549]=0;if((h|0)!=1){break B}e=N()|0;break A}x[23549]=0;f=R(143,n|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){x[23549]=0;S(176,d+204|0,n|0,f|0);f=x[23549];x[23549]=0;if((f|0)==1){break C}g=h;h=d+204|0;f=hc(d+272|0,h);Zc(g,f);ub(f);ub(h);yg(d+228|0);continue}break}e=N()|0;break A}e=N()|0;break A}C=(e|0)==16?14:(e|0)==32?1:13;J=a+484344|0;l=1;while(1){D:{E:{F:{G:{H:{I:{if((y[d+1207|0]|y[d+1208|0]<<8)>>>0<=q>>>0){switch(x[a+480180>>2]-1|0){case 0:break G;case 3:break I;default:break F}}x[23549]=0;e=R(180,I|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break H}x[d+204>>2]=e;if(!o){break D}x[23549]=0;e=U(212,J|0,q&65535,e|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break H}h=0;if(!e){break D}while(1){g=h&65535;if(g>>>0>=y[d+1202|0]){break D}x[23549]=0;e=R(180,H|0)|0;f=x[23549];x[23549]=0;J:{if((f|0)!=1){f=x[s>>2];if(Ef(f,x[s+4>>2])>>>0<=e>>>0){break J}k=Cg(f,e);wc(k);f=0;e=Yb(x[J>>2],q);g=$c(x[e>>2],x[x[e+48>>2]+12>>2],0,g);K:while(1){if(A[d+204>>2]<=f>>>0){break J}x[23549]=0;e=R(192,k|0)|0;j=x[23549];x[23549]=0;if((j|0)!=1){if(!e){break J}r=e>>>4|0;t=e&15;Uh(d+272|0);j=0;while(1){L:{M:{N:{O:{P:{if(t>>>0>(j&255)>>>0){x[23549]=0;P(505,k|0,d+228|0);e=x[23549];x[23549]=0;if((e|0)==1){break P}Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{e=y[d+228|0];switch(e-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break Q;case 33:break U;case 30:case 31:break V;case 29:break W;case 28:break X;case 26:break Y;case 19:case 20:break Z;case 17:break _;case 15:break $;case 14:break aa;case 10:break ba;case 6:break ca;case 5:break da;case 1:break ea;case 0:break fa;default:break ga}}switch(e-48|0){case 4:break R;case 1:case 2:break S;case 0:break T;default:break Q}}e=y[d+229|0];ha:{if(e>>>0<=119){e=e+C|0;break ha}ia:{switch(e-254|0){case 1:e=255;break ha;case 0:e=254;break ha;default:break ia}}e=253}v[d+272|0]=e;l=jB(e)&l;break L}v[d+273|0]=y[d+229|0]+1;break L}if(y[d+274|0]){i=y[d+229|0];break M}i=y[d+229|0];e=x[a+480180>>2];if((e|0)!=32){break N}e=0;while(1){if((e|0)==10){break M}if(y[e+43968|0]==(i&255)){v[d+276|0]=e;v[d+274|0]=11;break L}else{e=e+1|0;continue}}}e=y[d+229|0];if(!(y[d+274|0]|e>>>0>9|x[a+480180>>2]!=32)){v[d+276|0]=e;v[d+274|0]=8;break L}v[d+277|0]=e;v[d+275|0]=5;break L}e=y[d+229|0];if(y[d+274|0]){break O}i=x[a+480180>>2];u=(i|0)!=32;if(!(u|(e|0)!=255)){v[d+276|0]=64;v[d+274|0]=2;break L}ja:{if(!u){if(!(e&3)){break ja}break O}if(e&15|(i|0)!=4){break O}}v[d+274|0]=2;v[d+276|0]=(e&252)>>>2;break L}e=y[d+229|0];if(!(y[d+274|0]|e>>>0>64|x[a+480180>>2]==1)){v[d+276|0]=e;v[d+274|0]=1;break L}v[d+277|0]=e;v[d+275|0]=13;break L}v[d+275|0]=14;e=y[d+229|0];v[d+277|0]=e;if(x[a+480180>>2]==32){break L}v[d+277|0]=D((e&240)>>>4|0,10)+(e&15);break L}e=y[d+229|0];v[d+277|0]=e;if(e>>>0<=31){v[d+275|0]=16;break L}v[d+275|0]=17;break L}i=y[d+229|0];if(i>>>0>=16){v[d+276|0]=i>>>4;v[d+274|0]=(e|0)==20?3:5;break L}v[d+276|0]=i;v[d+274|0]=(e|0)==20?4:6;break L}e=y[d+229|0];if(e>>>0>=16){v[d+274|0]=10;v[d+276|0]=e>>>4;break L}v[d+276|0]=e;v[d+274|0]=9;break L}v[d+275|0]=28;v[d+277|0]=y[d+229|0]|16;break L}v[d+275|0]=28;v[d+277|0]=y[d+229|0]|32;break L}v[d+276|0]=y[d+229|0];v[d+274|0]=y[e+26880|0];break L}v[d+277|0]=y[d+229|0];e=y[d+275|0];v[d+275|0]=(e|0)==4?6:(e|0)==5?7:11;break L}e=y[d+229|0];v[d+276|0]=(e>>>0)%10;if(e>>>0<=9){v[d+274|0]=5;break L}if(e>>>0<=19){v[d+274|0]=6;break L}if(e>>>0<=29){v[d+274|0]=3;break L}if(e>>>0>39){break L}v[d+274|0]=4;break L}v[d+276|0]=y[d+229|0];v[d+274|0]=y[e+26880|0];break L}e=y[d+229|0]+33|0;if((e&255)>>>0>9){break L}v[d+276|0]=e;v[d+274|0]=15;break L}if(e>>>0>57){break L}v[d+277|0]=y[d+229|0];v[d+275|0]=y[e+26880|0];break L}x[d+228>>2]=f+r;e=x[Cb(d+228|0,d+204|0)>>2];e=e>>>0<f>>>0?f:e;while(1){if((e|0)!=(f|0)){j=y[d+272|0]|y[d+273|0]<<8|(y[d+274|0]<<16|y[d+275|0]<<24);v[g|0]=j;v[g+1|0]=j>>>8;v[g+2|0]=j>>>16;v[g+3|0]=j>>>24;j=y[d+276|0]|y[d+277|0]<<8;v[g+4|0]=j;v[g+5|0]=j>>>8;f=f+1|0;g=D(y[d+1202|0],6)+g|0;continue}break}f=e;continue K}e=N()|0;break A}v[d+277|0]=e;v[d+275|0]=9;break L}if(i&15|(e|0)!=4){break M}v[d+274|0]=11;v[d+276|0]=(i&240)>>>4;break L}v[d+277|0]=i;v[d+275|0]=4}j=j+1|0;continue}}break}e=N()|0;break A}e=N()|0;break A}h=h+1|0;continue}}g=z[a+480192>>1];e=0;break E}e=N()|0;break A}if(!(z[E>>1]==4&l)){break F}x[a+480208>>2]=x[a+480208>>2]|8454144}g=0;e=!((y[d+1217|0]|y[d+1218|0]<<8|(y[d+1219|0]<<16|y[d+1220|0]<<24))&512)}x[23549]=0;C=O(506,d+1104|0,g|0)|0;h=x[23549];x[23549]=0;ka:{la:{ma:{na:{oa:{if((h|0)!=1){i=m>>>0<5;j=1;pa:{while(1){g=j&65535;if(g>>>0>z[a+480192>>1]){break pa}qa:{ra:{sa:{ta:{if(!e){x[23549]=0;f=U(240,a|0,g|0,0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break ta}if(f){break sa}}while(1){x[23549]=0;h=R(192,n|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break la}if(h){continue}break}if(!i){while(1){x[23549]=0;h=R(192,n|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){e=N()|0;break ka}if(h){continue}break}}x[23549]=0;O(174,n|0,826)|0;h=x[23549];x[23549]=0;if((h|0)!=1){break ra}}e=N()|0;break ka}h=Gb(d+204|0);x[23549]=0;S(342,n|0,h|0,-1);l=x[23549];x[23549]=0;if((l|0)==1){break qa}zc(f+492|0,h);if(!i){x[23549]=0;S(342,n|0,h|0,-1);l=x[23549];x[23549]=0;if((l|0)==1){break qa}zc(f+524|0,h)}x[23549]=0;l=O(507,n|0,d+272|0)|0;q=x[23549];x[23549]=0;if((q|0)==1){break ma}if(!l){break oa}l=x[a+480180>>2];x[23549]=0;S(508,d+272|0,f|0,l|0);f=x[23549];x[23549]=0;if((f|0)==1){break ma}if(x[a+480180>>2]==4){f=xb(x[C>>2],g-1|0);g=y[d+1074|0]|y[d+1075|0]<<8|(y[d+1076|0]<<16|y[d+1077|0]<<24);v[f|0]=g;v[f+1|0]=g>>>8;v[f+2|0]=g>>>16;v[f+3|0]=g>>>24}tb(h)}j=j+1|0;continue}break}break ma}if(!e){break na}w[a+480192>>1]=0;break na}e=N()|0;break A}tb(h)}e=z[a+480190>>1];x[23549]=0;q=O(509,d+260|0,e|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){u=y[d+1687|0];L=!(v[d+1217|0]&1)|u>>>0>4;r=c&2;j=1;e=0;while(1){h=e;ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{m=j&65535;if(m>>>0<=z[a+480190>>1]){g=Gb(d+248|0);x[23549]=0;S(342,n|0,g|0,-1);c=x[23549];x[23549]=0;Ha:{Ia:{if((c|0)!=1){zc(((m<<5)+a|0)+946304|0,g);e=u>>>0<5;if(e){break Ia}x[23549]=0;S(342,n|0,g|0,-1);c=x[23549];x[23549]=0;if((c|0)!=1){break Ha}}e=N()|0;break xa}Ze(g)}x[23549]=0;c=O(510,n|0,d+272|0)|0;f=x[23549];x[23549]=0;Ja:{Ka:{if((f|0)==1){break Ka}if(!c){break Ja}f=x[a+480180>>2];x[23549]=0;i=D(m,104)+a|0;c=i+484380|0;V(511,d+272|0,c|0,f|0,L|0);f=x[23549];x[23549]=0;if((f|0)==1){break Ka}Ce(i+484423|0,g);l=0;La:{if(((y[d+292|0]|y[d+293|0]<<8)&61440)!=28672|e){break La}x[23549]=0;l=R(512,n|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){break La}e=N()|0;break xa}if(!r){break va}f=y[d+307|0]|y[d+308|0]<<8|(y[d+309|0]<<16|y[d+310|0]<<24);e=y[d+292|0]|y[d+293|0]<<8;k=e&61440;if(!(f|k)){e=Xc(d+204|0,e&1?16:8,e&1024?3:1,0,0);x[23549]=0;U(205,e|0,c|0,b|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break va}e=N()|0;break xa}if((f|0)<0){e=f+m|0;if((e|0)<=0){break va}eT(c,(D(e,104)+a|0)+484380|0);break va}if((f|0)<=0){break va}if(e&1){o=i+484414|0;w[o>>1]=z[o>>1]|1}if(e&1024){o=i+484414|0;w[o>>1]=z[o>>1]|64}x[23549]=0;S(176,d+204|0,b|0,f|0);f=x[23549];x[23549]=0;Ma:{Na:{Oa:{Pa:{Qa:{Ra:{if((f|0)!=1){o=d+204|0;f=hc(d+228|0,o);ub(o);o=Jd(z[c+34>>1]);K=(k|0)==16384;if(!K&(k|0)!=8192){break Pa}t=x[f>>2];x[23549]=0;t=R(146,t|0)|0;F=x[23549];x[23549]=0;if((F|0)==1){break Ma}F=4/(o>>>0)|0;yka(F,0,t,0);tc(c,hb?-1:D(F,t));if((k|0)==8192){break Ra}if(!K){break Pa}if(!zg(c)){break Oa}e=x[i+484400>>2];c=x[c>>2];if(!(v[d+292|0]&1)){break Qa}x[23549]=0;V(513,f|0,e|0,c|0,o|0);c=x[23549];x[23549]=0;e=h;if((c|0)==1){break za}break Na}e=N()|0;break xa}if(!zg(c)){break Oa}e=x[i+484400>>2];c=x[c>>2];if(v[d+292|0]&1){x[23549]=0;V(514,f|0,e|0,c|0,o|0);c=x[23549];x[23549]=0;e=h;if((c|0)!=1){break Na}break za}x[23549]=0;V(515,f|0,e|0,c|0,o|0);c=x[23549];x[23549]=0;e=h;if((c|0)==1){break za}break Na}x[23549]=0;V(516,f|0,e|0,c|0,o|0);c=x[23549];x[23549]=0;e=h;if((c|0)==1){break za}break Na}if((e&45056)==12288){c=dT(d+204|0,f,y[d+311|0]|y[d+312|0]<<8,l);M=Zc(nl(x[q>>2],m-1|0),c),T=x[c+20>>2],x[M+20>>2]=T;ub(c);break Oa}if((k|0)!=32768){e=1;if((k|0)!=4096){break Na}l=le(d+204|0,f);x[23549]=0;e=O(517,d+198|0,f|0)|0;k=x[23549];x[23549]=0;if((k|0)!=1){Sa:{Ta:{if(!y[d+203|0]){break Ta}o=y[d+311|0]|y[d+312|0]<<8;k=z[d+200>>1]<<1;if(o>>>0<(k&65535)>>>0){break Ta}k=o-k|0;v[d+311|0]=k;v[d+312|0]=k>>>8;e=z[e>>1];x[23549]=0;O(141,f|0,e|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break Sa}x[23549]=0;e=R(188,f|0)|0;k=x[23549];x[23549]=0;if((k|0)==1){break Sa}x[23549]=0;S(176,d+156|0,f|0,e|0);e=x[23549];x[23549]=0;if((e|0)==1){break Sa}e=d+156|0;k=hc(d+176|0,e);Zc(l,k);ub(k);ub(e)}x[23549]=0;m=U(518,a|0,m|0,l|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break Sa}e=1;if(m){e=y[d+311|0]|y[d+312|0]<<8;Ua:{if(!e){break Ua}m=z[c+34>>1];k=pj(x[c>>2],m);if(k>>>0<=e>>>0){break Ua}m=rk(m);i=x[i+484400>>2];uk(i,e+i|0,k-e|0);x[c>>2]=x[c>>2]-((e>>>0)/(m>>>0)|0)}tc(c,y[d+280|0]|y[d+281|0]<<8|(y[d+282|0]<<16|y[d+283|0]<<24));e=h}ub(l);break Na}}e=N()|0;ub(l);break ya}x[23549]=0;e=O(369,f|0,d+204|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break Ga}if(!e){break Oa}x[d+72>>2]=y[d+212|0]|y[d+213|0]<<8|(y[d+214|0]<<16|y[d+215|0]<<24);e=y[d+208|0]|y[d+209|0]<<8|(y[d+210|0]<<16|y[d+211|0]<<24);x[d+64>>2]=y[d+204|0]|y[d+205|0]<<8|(y[d+206|0]<<16|y[d+207|0]<<24);x[d+68>>2]=e;xl(c,1,d- -64|0)}e=h}ub(f);break ua}e=N()|0;break ya}e=N()|0;break xa}tb(g)}Va:{Wa:{Xa:{if(!r){break Xa}l=1;while(1){c=l&65535;if(c>>>0>z[a+480190>>1]){break Xa}b=nl(x[q>>2],c-1|0);e=x[b>>2];x[23549]=0;e=R(164,e|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break Va}Ya:{Za:{if(!e){break Za}e=c+w[b+22>>1]|0;e=((e|0)>0?e:l)&65535;j=z[b+20>>1];g=(e|0)!=(c|0)&(e|0)!=0&e>>>0<=z[a+480190>>1]&(j|0)!=0;_a:{if(g){f=nl(x[q>>2],e-1|0);break _a}e=x[b>>2];x[23549]=0;j=R(146,e|0)|0;e=x[23549];x[23549]=0;f=b;if((e|0)==1){break Wa}}wc(f);$a:{if(g){e=x[f+8>>2];i=x[f>>2];m=z[b+20>>1];x[23549]=0;e=U(142,i|0,e|0,m|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break Wa}if(!e){break Za}x[d+204>>2]=0;x[d+228>>2]=0;x[23549]=0;S(189,d+272|0,f|0,j|0);e=x[23549];x[23549]=0;ab:{if((e|0)!=1){i=DA(Ee(d+272|0),Hh(x[d+272>>2]),d+204|0,d+228|0);x[23549]=0;O(174,f|0,x[d+204>>2])|0;e=x[23549];x[23549]=0;if((e|0)==1){break ab}Jc(d+272|0);break $a}e=N()|0;break wa}e=N()|0;Jc(d+272|0);break wa}i=0;x[d+204>>2]=0;x[d+228>>2]=0}x[23549]=0;P(519,d+272|0,b|0);e=x[23549];x[23549]=0;bb:{cb:{if((e|0)!=1){e=Ee(d+272|0);j=x[d+272>>2];if(!g){i=DA(e,Hh(j),d+204|0,d+228|0);x[23549]=0;f=x[d+204>>2];O(174,b|0,f|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break Ya}j=j-f|0;e=e+f|0}if(i){break cb}h=1;break bb}e=N()|0;break wa}c=D(c,104)+a|0;m=c+484380|0;zg(m);t=c+484400|0;f=0;g=x[d+228>>2];while(1){db:{if(!j|(g|0)!=1?g:0){break db}c=x[m>>2];if(c>>>0<=f>>>0){break db}if(!Sd(c,x[m+20>>2])){break db}x[d+176>>2]=0;x[d+156>>2]=0;g=cT(i,e,Hh(j),d+176|0,d+248|0,d+156|0);x[23549]=0;x[d+204>>2]=g;O(174,b|0,g|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break Aa}Zh(d+156|0,Hh(x[m>>2]-f|0));c=x[d+156>>2];eb:{if((c|0)<=0){break eb}k=x[d+176>>2];u=z[m+34>>1];if((Jd(u)|0)!=(k|0)){break eb}o=D(f,k);r=x[t>>2];if(u&1){k=rd(d+144|0,r+(o<<1)|0,k,c);o=rd(d+132|0,x[d+248>>2],x[d+176>>2],c);x[23549]=0;x[d+56>>2]=x[k+8>>2];r=x[k+4>>2];x[d+48>>2]=x[k>>2];x[d+52>>2]=r;x[d+40>>2]=x[o+8>>2];k=x[o+4>>2];x[d+32>>2]=x[o>>2];x[d+36>>2]=k;P(520,d+48|0,d+32|0);k=x[23549];x[23549]=0;if((k|0)!=1){break eb}break Aa}k=rd(d+120|0,o+r|0,k,c);o=rd(d+108|0,x[d+248>>2],x[d+176>>2],c);x[23549]=0;x[d+24>>2]=x[k+8>>2];r=x[k+4>>2];x[d+16>>2]=x[k>>2];x[d+20>>2]=r;x[d+8>>2]=x[o+8>>2];k=x[o+4>>2];x[d>>2]=x[o>>2];x[d+4>>2]=k;P(521,d+16|0,d|0);k=x[23549];x[23549]=0;if((k|0)==1){break Aa}}j=j-g|0;e=e+g|0;g=bT(i);x[d+228>>2]=g;f=c+f|0;continue}break}aT(i)}Jc(d+272|0)}l=l+1|0;continue}break}break Aa}fb:{if(x[a+480180>>2]!=4){break fb}g=0;while(1){if(z[a+480192>>1]<=g>>>0){break fb}b=xb(x[C>>2],g);c=y[b+3|0];e=y[b+2|0];f=y[b+1|0];b=y[b|0];x[23549]=0;g=g+1|0;ia(522,a|0,g&65535,b|0,f|0,e|0,c|0);b=x[23549];x[23549]=0;if((b|0)!=1){continue}break}e=N()|0;break wa}gb:{hb:{ib:{if(!(y[d+1219|0]&16)){break ib}b=x[n+8>>2];c=x[n>>2];x[23549]=0;b=U(142,c|0,b|0,1)|0;c=x[23549];x[23549]=0;jb:{kb:{lb:{if((c|0)!=1){if(!b){break ib}g=0;x[23549]=0;b=R(192,n|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break lb}if(!(b&1)){break jb}while(1){if(z[E>>1]<=g>>>0){break jb}x[23549]=0;b=R(143,n|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break kb}v[((g<<5)+a|0)+480288|0]=b;g=g+1|0;continue}}e=N()|0;break wa}e=N()|0;break wa}e=N()|0;break wa}while(1){b=x[n+8>>2];c=x[n>>2];x[23549]=0;b=U(142,c|0,b|0,1)|0;c=x[23549];x[23549]=0;if((c|0)==1){break Ba}if(!b){break ib}x[23549]=0;b=R(192,n|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break gb}if(!b){break ib}x[23549]=0;c=R(143,n|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break hb}x[23549]=0;S(176,d+204|0,n|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break hb}e=d+204|0;c=hc(d+272|0,e);ub(e);mb:{if(b>>>0<=250){x[23549]=0;P(392,c|0,(D(b,160)+a|0)+906140|0);b=x[23549];x[23549]=0;if((b|0)==1){break mb}}ub(c);continue}break}e=N()|0;ub(c);break wa}j=a+901404|0;c=Gb(d+176|0);e=0;l=0;while(1){b=x[n+8>>2];f=x[n>>2];x[23549]=0;b=U(142,f|0,b|0,8)|0;f=x[23549];x[23549]=0;nb:{ob:{pb:{qb:{rb:{if((f|0)!=1){if(b){x[23549]=0;f=R(143,n|0)|0;b=x[23549];x[23549]=0;sb:{tb:{ub:{vb:{wb:{xb:{yb:{zb:{if((b|0)!=1){x[23549]=0;b=R(143,n|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break zb}x[23549]=0;S(176,d+272|0,n|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break yb}g=d+272|0;b=hc(d+204|0,g);ub(g);if((f|0)==1229211981){break vb}if((f|0)==1229476432){break wb}if((f|0)==1397900630){break xb}if((f|0)!=1414548815){break nb}x[23549]=0;f=O(354,b|0,13608)|0;g=x[23549];x[23549]=0;if((g|0)==1){break Fa}if(!f){break ob}x[23549]=0;f=R(143,b|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){x[23549]=0;S(176,d+272|0,b|0,f|0);f=x[23549];x[23549]=0;if((f|0)!=1){break ub}}e=N()|0;break Ea}e=N()|0;break Ca}e=N()|0;break Ca}e=N()|0;break Ca}Ab:{Bb:{Cb:{f=x[a+480180>>2];switch(f-2|0){case 1:break nb;case 0:break tb;case 2:break Bb;default:break Cb}}if((f|0)==16){break Ab}if((f|0)!=32){break nb}x[23549]=0;e=R(180,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break Fa}x[23549]=0;l=R(180,b|0)|0;f=x[23549];x[23549]=0;if((f|0)!=1){break nb}break Fa}x[d+272>>2]=32;f=x[b>>2];x[23549]=0;f=R(146,f|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){x[d+228>>2]=f;f=x[Cb(d+272|0,d+228|0)>>2];x[23549]=0;S(523,b|0,c|0,f|0);f=x[23549];x[23549]=0;if((f|0)!=1){break nb}}e=N()|0;break Ea}x[23549]=0;f=R(192,b|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break sb}x[23549]=0;P(524,d+228|0,4152);g=x[23549];x[23549]=0;Db:{if((g|0)!=1){x[d+248>>2]=f>>>4;x[23549]=0;x[d+92>>2]=f&15;V(290,d+272|0,d+228|0,d+248|0,d+92|0);f=x[23549];x[23549]=0;if((f|0)==1){break Db}f=d+272|0;zb(c,f);tb(f);Ab(d+228|0);break nb}e=N()|0;break Ea}e=N()|0;Ab(d+228|0);break Ea}x[23549]=0;f=R(192,b|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break Fa}x[a+480216>>2]=f;x[23549]=0;f=R(192,b|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break Fa}x[a+480220>>2]=f;break nb}x[23549]=0;O(364,b|0,j|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break Fa}gB(j);break nb}g=d+272|0;f=hc(d+228|0,g);ub(g);g=x[f>>2];x[23549]=0;g=R(146,g|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break pb}w[d+272>>1]=g>>>5;M=d,T=qf(x[a+484344>>2],x[a+484348>>2]),w[M+248>>1]=T;i=z[Uc(d+272|0,d+248|0)>>1];g=0;while(1){if((g|0)==(i|0)){ub(f);break ob}x[23549]=0;P(525,f|0,d+272|0);m=x[23549];x[23549]=0;Eb:{if((m|0)==1){break Eb}m=x[J>>2];x[23549]=0;P(526,Yb(m,g)|0,d+272|0);m=x[23549];x[23549]=0;if((m|0)==1){break Eb}g=g+1|0;continue}break}break pb}x[23549]=0;e=R(180,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break Fa}break nb}e=N()|0;break Ea}b=x[a+480180>>2];Fb:{Gb:{Hb:{if((b|0)!=32){break Hb}f=e&65535;if(f>>>0<256){break Hb}if(f>>>0<532){break Gb}}b=(b|0)!=2;Ib:{if(b){break Ib}f=e&65535;if(f>>>0<12544){break Ib}if(f>>>0<12820){break Gb}}if(b){break Fb}b=e&65535;if(b>>>0<4864|b>>>0>4895){break Fb}}sq(j)}g=1;Jb:{if(!(v[d+1219|0]&1)){break Jb}f=x[a+1074308>>2];if(!f){while(1){b=g&65535;if(b>>>0<=z[a+480192>>1]){b=x[((b<<2)+a|0)+900380>>2];if(b){e=x[a+480180>>2];x[23549]=0;P(527,Ci(b,2)|0,e|0);e=x[23549];x[23549]=0;if((e|0)==1){break rb}v[b+19|0]=y[b+19|0]+3>>>2}g=g+1|0;continue}break}f=x[a+1074308>>2]}if(f>>>0<=18350079){x[23549]=0;b=O(254,a+1074312|0,27)|0;e=x[23549];x[23549]=0;if((e|0)==1){break Da}x[23549]=0;O(254,b|0,57)|0;b=x[23549];x[23549]=0;if((b|0)==1){break Da}f=x[a+1074308>>2]}if(f>>>0<=19070975){x[23549]=0;O(254,a+1074312|0,73)|0;b=x[23549];x[23549]=0;if((b|0)==1){break Da}f=x[a+1074308>>2]}if(f>>>0>19267583){break Jb}x[23549]=0;O(254,a+1074312|0,50)|0;b=x[23549];x[23549]=0;if((b|0)==1){break Da}}Kb:{Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{if(xd(x[c+4>>2],y[c+11|0])){x[23549]=0;W(528,d+204|0);b=x[23549];x[23549]=0;Yb:{if((b|0)!=1){x[23549]=0;S(493,d+272|0,d+204|0,d+1687|0);b=x[23549];x[23549]=0;if((b|0)==1){break Yb}break Xb}e=N()|0;break Ca}e=N()|0;Ab(d+204|0);break Ca}x[23549]=0;W(529,d+204|0);b=x[23549];x[23549]=0;if((b|0)==1){break Wb}x[23549]=0;V(530,d+272|0,d+204|0,d+1687|0,c|0);b=x[23549];x[23549]=0;if((b|0)==1){break Vb}}b=d+272|0;zb(c,b);tb(b);b=d+204|0;Ab(b);x[23549]=0;P(492,b|0,3940);b=x[23549];x[23549]=0;if((b|0)==1){break Tb}x[23549]=0;S(493,d+272|0,d+204|0,d+1687|0);b=x[23549];x[23549]=0;if((b|0)==1){break Sb}b=d+272|0;zb(a+1298344|0,b);tb(b);Ab(d+204|0);x[23549]=0;b=O(1,b|0,14654)|0;e=x[23549];x[23549]=0;if((e|0)==1){break Rb}zb(a+1298356|0,b);tb(b);b=x[a+480180>>2];switch(b-1|0){case 2:break qb;case 1:break Nb;case 3:break Ob;case 0:break Pb;default:break Ub}}e=N()|0;break Ca}e=N()|0;Ab(d+204|0);break Ca}if((b|0)==16){break Qb}if((b|0)==32){break Mb}if((b|0)!=16777216){break qb}x[23549]=0;b=O(1,d+204|0,10007)|0;e=x[23549];x[23549]=0;if((e|0)==1){break Lb}zb(a+1298392|0,b);tb(b);x[23549]=0;b=O(1,d+228|0,13570)|0;e=x[23549];x[23549]=0;if((e|0)==1){break Kb}zb(a+1298380|0,b);tb(b);break qb}e=N()|0;break Ca}e=N()|0;Ab(d+204|0);break Ca}e=N()|0;break Ca}x[23549]=0;b=O(1,d+204|0,10012)|0;e=x[23549];x[23549]=0;Zb:{if((e|0)!=1){zb(a+1298392|0,b);tb(b);x[23549]=0;b=O(1,d+228|0,8263)|0;e=x[23549];x[23549]=0;if((e|0)==1){break Zb}zb(a+1298380|0,b);tb(b);break qb}e=N()|0;break Ca}e=N()|0;break Ca}x[23549]=0;b=O(1,d+204|0,12176)|0;e=x[23549];x[23549]=0;_b:{if((e|0)!=1){zb(a+1298392|0,b);tb(b);x[23549]=0;b=O(1,d+228|0,13934)|0;e=x[23549];x[23549]=0;if((e|0)==1){break _b}zb(a+1298380|0,b);tb(b);break qb}e=N()|0;break Ca}e=N()|0;break Ca}x[23549]=0;b=O(1,d+204|0,9985)|0;e=x[23549];x[23549]=0;$b:{if((e|0)!=1){zb(a+1298392|0,b);tb(b);x[23549]=0;b=O(1,d+228|0,14878)|0;e=x[23549];x[23549]=0;if((e|0)==1){break $b}zb(a+1298380|0,b);tb(b);break qb}e=N()|0;break Ca}e=N()|0;break Ca}x[23549]=0;b=O(1,d+204|0,10357)|0;e=x[23549];x[23549]=0;ac:{if((e|0)!=1){zb(a+1298392|0,b);tb(b);x[23549]=0;b=O(1,d+228|0,14689)|0;e=x[23549];x[23549]=0;if((e|0)==1){break ac}zb(a+1298380|0,b);tb(b);break qb}e=N()|0;break Ca}e=N()|0;break Ca}x[23549]=0;b=O(1,d+204|0,6068)|0;e=x[23549];x[23549]=0;bc:{cc:{dc:{ec:{fc:{if((e|0)!=1){zb(a+1298392|0,b);tb(b);if(!(l&65535)){break bc}x[23549]=0;P(255,d+248|0,4255);b=x[23549];x[23549]=0;if((b|0)==1){break fc}x[d+104>>2]=(l&65280)>>>8;x[23549]=0;x[d+88>>2]=l&255;P(386,d+92|0,d+88|0);b=x[23549];x[23549]=0;if((b|0)==1){break ec}x[23549]=0;V(372,d+228|0,d+248|0,d+104|0,d+92|0);b=x[23549];x[23549]=0;if((b|0)==1){break dc}b=d+228|0;zb(a+1298380|0,b);tb(b);tb(d+92|0);Ab(d+248|0);break qb}e=N()|0;break Ca}e=N()|0;break Ca}e=N()|0;break cc}e=N()|0;tb(d+92|0)}Ab(d+248|0);break Ca}x[23549]=0;b=O(1,d+228|0,8455)|0;e=x[23549];x[23549]=0;if((e|0)!=1){zb(a+1298380|0,b);tb(b);break qb}e=N()|0;break Ca}e=N()|0;break Ca}e=N()|0;break Ca}e=N()|0;break Ca}e=N()|0;break Ca}zb(a+1298368|0,c);gc:{if(x[a+1074308>>2]){x[a+1298404>>2]=8;break gc}if(x[a+480180>>2]==1){x[a+1298404>>2]=13;break gc}x[a+1298404>>2]=5}g=1;hc:{ic:{if(h&1){x[23549]=0;b=O(1,d+248|0,16240)|0;e=x[23549];x[23549]=0;if((e|0)==1){break ic}a=x[a+1298464>>2];x[23549]=0;S(359,a|0,2,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break hc}tb(b)}tb(c);$S(q);sc(C);kd(s);ub(I);ub(H);break c}e=N()|0;break Ca}e=N()|0;tb(b);break Ca}e=N()|0;ub(f);break Ea}x[23549]=0;f=O(354,b|0,13613)|0;g=x[23549];x[23549]=0;if((g|0)==1){break Fa}jc:{if(!f){break jc}x[23549]=0;f=R(143,b|0)|0;g=x[23549];x[23549]=0;kc:{if((g|0)!=1){x[23549]=0;S(176,d+228|0,b|0,f|0);f=x[23549];x[23549]=0;if((f|0)!=1){break kc}}e=N()|0;break Ea}g=d+228|0;f=hc(d+272|0,g);ub(g);g=x[f>>2];x[23549]=0;g=R(146,g|0)|0;i=x[23549];x[23549]=0;if((i|0)!=1){w[d+228>>1]=(g>>>0)/20;w[d+248>>1]=z[E>>1];i=z[Uc(d+228|0,d+248|0)>>1];g=0;while(1){if((g|0)==(i|0)){ub(f);break jc}x[23549]=0;S(365,f|0,((g<<5)+a|0)+480289|0,20);m=x[23549];x[23549]=0;if((m|0)!=1){g=g+1|0;continue}break}}e=N()|0;ub(f);break Ea}x[23549]=0;O(375,a|0,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break Fa}x[23549]=0;V(376,a|0,b|0,1,0);f=x[23549];x[23549]=0;if((f|0)==1){break Fa}if((e-2186&65535)>>>0<=117){x[a+480180>>2]=16777216;x[23549]=0;S(390,a|0,b|0,e&65535);f=x[23549];x[23549]=0;if((f|0)==1){break Fa}}if(!x[a+1074308>>2]){break nb}x[23549]=0;f=O(1,d+156|0,17202)|0;g=x[23549];x[23549]=0;lc:{mc:{nc:{if((g|0)!=1){g=x[a+1074308>>2];x[23549]=0;P(126,d+228|0,g|0);g=x[23549];x[23549]=0;if((g|0)==1){break nc}x[23549]=0;S(2,d+272|0,f|0,d+228|0);g=x[23549];x[23549]=0;if((g|0)==1){break mc}g=d+272|0;zb(c,g);tb(g);tb(d+228|0);tb(f);break nb}e=N()|0;break Ea}e=N()|0;break lc}e=N()|0;tb(d+228|0)}tb(f);break Ea}ub(b);continue}}e=N()|0;break wa}e=N()|0;break wa}e=N()|0;break wa}e=N()|0;break wa}e=N()|0;break ya}e=N()|0}ub(b);break Ca}e=N()|0}tb(c);break wa}e=N()|0;break wa}e=N()|0;Jc(d+272|0);break wa}e=N()|0}ub(f)}tb(g)}$S(q);break ka}e=h}tb(g);j=j+1|0;continue}}e=N()|0;break ka}e=N()|0;tb(h);break ka}e=N()|0}sc(C);break A}q=q+1|0;continue}}kd(s);break z}e=N()|0}ub(I);break y}e=N()|0}ub(H);break e}e=N()|0;break e}e=N()|0;break e}else{oc:{pc:{if(!j){v[d+272|0]=y[(d+g|0)+1224|0];v[d+204|0]=64;M=((g<<5)+a|0)+480286|0,T=y[Sb(d+272|0,d+204|0)|0],w[M>>1]=T;break pc}if(l){break oc}}qc:{e=y[(d+g|0)+1288|0];if((e|0)!=255){if((e|0)!=127){break qc}x[((g<<5)+a|0)+480280>>2]=256;break oc}w[((g<<5)+a|0)+480284>>1]=256;break oc}w[((g<<5)+a|0)+480284>>1]=e}g=g+1|0;continue}}e=N()|0;break d}e=N()|0;break d}e=N()|0}ub(n)}bc(B);Q(e|0);p()}ub(n)}bc(B)}db=d+1696|0;return g|0}function Hha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;f=db-912|0;db=f;wc(b);a:{if(!qT(b,f+860|0)){break a}if(!uT(f+860|0)){break a}if(!Lb(x[b>>2],x[b+8>>2],Qc(tT(f+860|0),hb))){break a}if(!c){d=1;break a}Bd(a,8);Dg(a);h=y[f+863|0]-48|0;v[f+859|0]=h;Vc(b,$b(y[f+868|0]|y[f+869|0]<<8|(y[f+870|0]<<16|y[f+871|0]<<24)));e=f+552|0;Wd(e,b,504);I=hc(f+836|0,e);ub(e);x[23549]=0;P(465,b|0,e|0);e=x[23549];x[23549]=0;b:{c:{d:{e:{f:{g:{if((e|0)!=1){if(y[f+835|0]>63){break b}if(Hb(z[f+552>>1])<<16>>16<0){break b}Vb(f+472|0,0,80);h:{d=$b(y[f+892|0]|y[f+893|0]<<8|(y[f+894|0]<<16|y[f+895|0]<<24));if(!d){break h}x[23549]=0;d=O(141,b|0,d|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){if(!d){break h}x[23549]=0;P(466,b|0,f+472|0);d=x[23549];x[23549]=0;if((d|0)!=1){break h}}g=N()|0;break e}x[23549]=0;S(467,f+468|0,b|0,h&255);d=x[23549];x[23549]=0;if((d|0)!=1){M=Ue(f+468|0);d=0;e=z[f+468>>1];if((e-128&65535)>>>0<65409){break b}w[a+480188>>1]=e;F=Nb(f+456|0);d=$b(y[f+884|0]|y[f+885|0]<<8|(y[f+886|0]<<16|y[f+887|0]<<24));i:{if(d){x[23549]=0;O(141,b|0,d|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break g}x[23549]=0;S(468,b|0,F|0,y[f+835|0]);d=x[23549];x[23549]=0;if((d|0)==1){break g}d=y[f+835|0];break i}d=0;if(y[f+835|0]){break c}}e=d&255;w[a+480192>>1]=e;w[a+480190>>1]=e;T=(h&255)>>>0<2|v[f+816|0]>=0;t=!T;B=c&2;l=1;o=1;while(1){j:{k:{l:{m:{n:{o:{d=o&65535;if(d>>>0<=(e&65535)>>>0){x[23549]=0;m=l&65535;e=U(240,a|0,d|0,m|0)|0;h=x[23549];x[23549]=0;p:{if((h|0)!=1){if(e){break p}break d}g=N()|0;break f}k=x[((d<<2)+a|0)+900380>>2];w[f+68>>1]=0;x[f+64>>2]=0;x[23549]=0;q=R(160,f+436|0)|0;e=x[23549];x[23549]=0;q:{if((e|0)!=1){d=xb(x[F>>2],d-1|0);d=$b(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));r:{if(!d){break r}x[23549]=0;d=O(141,b|0,d|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break k}if(!d){break r}x[23549]=0;P(469,b|0,f- -64|0);d=x[23549];x[23549]=0;if((d|0)==1){break k}d=x[f+64>>2];e=z[f+68>>1];x[23549]=0;g=$b(d);d=Hb(e);S(176,f+96|0,b|0,g<<(d>>>5&1&d<<16>>16>0));d=x[23549];x[23549]=0;if((d|0)==1){break k}d=f+96|0;e=hc(f+156|0,d);Zc(q,e);ub(e);ub(d)}e=Hb(z[f+68>>1]);d=e&15;g=e<<16>>16;if((g|0)>=0){break q}du(k,0);Y=1;break o}g=N()|0;break f}if(d>>>0>6){break o}j=y[d+26758|0];if(!d){break m}w[a+480190>>1]=(z[a+480190>>1]+j|0)-1;u=k+108|0;n=k+236|0;s=j-2|0;e=4;s:while(1){h=1;if((e|0)==10){break n}h=D(e,12);d=(s<<3)+e|0;r=y[d+26764|0]+l|0;i=y[d+26812|0];d=0;while(1)if((d|0)==12){e=e+1|0;continue s}else{A=d+h|0;ba=_b(n,A),ca=r,w[ba>>1]=ca;A=Db(u,A);v[A|0]=i+y[A|0];d=d+1|0;continue}}}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{d=$b(x[f+476>>2]);if(!d){break D}if(!Hb(z[f+480>>1])){break D}x[23549]=0;d=O(141,b|0,d|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break C}if(!d){break D}ba=f,ca=Hb(z[f+480>>1]),w[ba+156>>1]=ca;w[f+96>>1]=y[f+835|0];q=z[Uc(f+156|0,f+96|0)>>1];d=f+104|0;l=f+100|0;k=Hb(z[f+482>>1]);o=k>>>0<5;n=k>>>0<19;m=k>>>0<21;s=k>>>0<15;t=k>>>0<6;e=0;while(1){if((e|0)==(q|0)){break D}x[23549]=0;S(470,b|0,f+156|0,k|0);h=x[23549];x[23549]=0;E:{F:{G:{if((h|0)!=1){e=e+1|0;h=x[((e<<2)+a|0)+900380>>2];g=y[f+156|0];if(g){u=vo(f+96|0,0,64);vo(l,g-1&65535,64);j=y[f+157|0];if(j){i=64/(j>>>0)|0}else{i=0}vo(d,i+g|0,0);x[23549]=0;g=h+48|0;S(471,g|0,u|0,3);j=x[23549];x[23549]=0;if((j|0)==1){break G}if(y[f+156|0]==1){j=x[vb(f+432|0,yb(x[g>>2]))>>2];u=yb(x[g>>2]);j=x[g>>2]+(bu(j,u)<<2)|0;Dd(g,_g(j+4|0,x[g+4>>2],j));yb(j)}g=y[f+157|0];x[h>>2]=g?g<<9:32767;v[h+60|0]=y[h+60|0]|1;u=1}H:{if(o){break H}g=y[f+160|0];if(g){ba=Db(h+108|0,24),ca=g+24|0,v[ba|0]=ca;u=1}if(n){break H}x[h+4>>2]=y[f+174|0]+1>>>1;if(m){break H}w[h+28>>1]=y[f+176|0]|y[f+177|0]<<8}h=D(z[_b(h+236|0,61)>>1],104)+a|0;v[h+484417|0]=y[f+159|0]<<4;if(s){break F}g=$b(y[f+166|0]|y[f+167|0]<<8|(y[f+168|0]<<16|y[f+169|0]<<24));x[h+484384>>2]=g;ba=h+484388|0,ca=$b(y[f+170|0]|y[f+171|0]<<8|(y[f+172|0]<<16|y[f+173|0]<<24))+g|0,x[ba>>2]=ca;break E}g=N()|0;break f}g=N()|0;break f}if(t){continue}}g=h+484414|0;i=g;j=z[g>>1]&65529;g=y[f+161|0];w[i>>1]=j|g<<1&2|g>>>1&4;if(!(g&4)){continue}w[h+484412>>1]=0;continue}}I:{d=$b(x[f+492>>2]);if(!d){break I}if(!Hb(z[f+496>>1])){break I}x[23549]=0;d=O(141,b|0,d|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break C}if(!d){break I}ba=f,ca=Hb(z[f+496>>1]),w[ba+156>>1]=ca;w[f+96>>1]=y[f+835|0];g=z[Uc(f+156|0,f+96|0)>>1];j=Hb(z[f+498>>1]);d=0;J:while(1){if((d|0)==(g|0)){break I}x[23549]=0;S(472,b|0,f+156|0,j|0);e=x[23549];x[23549]=0;if((e|0)==1){break t}e=f- -64|0;NU(e,f+156|0);x[23549]=0;P(208,f+96|0,e|0);e=x[23549];x[23549]=0;if((e|0)==1){break u}d=d+1|0;k=((d<<2)+a|0)+900380|0;e=f+96|0;zc(x[k>>2]+492|0,e);tb(e);h=x[k>>2];x[23549]=0;P(473,e|0,h|0);e=x[23549];x[23549]=0;if((e|0)==1){break v}ba=f,ca=kj(x[f+96>>2]),x[ba+64>>2]=ca;q=Bf(f+96|0);while(1){e=x[f+64>>2];if(Kb(e,q)){h=(z[iq(e)>>1]<<5)+a|0;l=h+946328|0;e=x[k>>2];o=x[e+520>>2];x[l>>2]=x[e+516>>2];x[l+4>>2]=o;o=x[e+512>>2];l=h+946320|0;x[l>>2]=x[e+508>>2];x[l+4>>2]=o;o=x[e+504>>2];l=h+946312|0;x[l>>2]=x[e+500>>2];x[l+4>>2]=o;l=x[e+496>>2];h=h+946304|0;x[h>>2]=x[e+492>>2];x[h+4>>2]=l;Vg(f- -64|0);continue}else{KA(f+96|0);continue J}}}}sq(a+901404|0);d=mc(f+424|0,4881);Xe(te(a+901692|0,0),x[d>>2],x[d+4>>2]);wc(b);Z=c&1;o=a+484344|0;n=a+1298332|0;W=a+1298308|0;A=a+484360|0;c=0;q=0;while(1){K:{d=c&255;if(d>>>0>=y[M|0]){break K}x[23549]=0;V(474,b|0,f+860|0,f+472|0,f+552|0);e=x[23549];x[23549]=0;L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{if((e|0)==1){break V}W:{if(!d){d=0;break W}x[23549]=0;e=R(261,A|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break V}d=c;if((e|0)==255){break d}}j=jj(x[A>>2],d&255);l=ig(f+412|0);Dc(j);if(y[f+859|0]>1){break U}d=Hb(z[f+554>>1]);if(d>>>0>256|z[a+480188>>1]>16){break T}e=f+156|0;nT(e,f+552|0);x[23549]=0;S(475,j|0,e|0,d|0);d=x[23549];x[23549]=0;if((d|0)==1){break N}ba=f,ca=yb(x[j>>2]),x[ba+156>>2]=ca;e=yb(x[j+4>>2]);while(1){d=x[f+156>>2];if(Kb(d,e)){w[d>>1]=z[d>>1]+q;Se(f+156|0);continue}else{vh(a,1);e=z[a+480188>>1];d=0;while(1)if((d|0)==(e|0)){d=32;break M}else{v[f+156|0]=y[(d+f|0)+818|0];v[f+96|0]=64;ba=((d<<5)+a|0)+480286|0,ca=y[Sb(f+156|0,f+96|0)|0],w[ba>>1]=ca;d=d+1|0;continue}}}}g=N()|0;break f}nT(f+156|0,f+552|0);d=Hb(z[f+168>>1]);if(!d|d>>>0>64|z[a+480188>>1]>64){break T}s=$b(x[f+176>>2]);d=Hb(z[f+180>>1]);if(d){w[f+96>>1]=d;w[f+64>>1]=800;k=Qc(((z[Uc(f+96|0,f- -64|0)>>1]<<5)+50>>>0)/100|0,0)}else{k=32}d=x[f+164>>2];x[23549]=0;e=O(141,b|0,$b(d)|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break S}d=0;X:{if(!e){break X}while(1){if(z[a+480188>>1]<=d>>>0){break X}x[23549]=0;e=R(192,b|0)|0;h=x[23549];x[23549]=0;if((h|0)!=1){v[f+96|0]=e;v[f+64|0]=64;ba=((d<<5)+a|0)+480286|0,ca=y[Sb(f+96|0,f- -64|0)|0],w[ba>>1]=ca;d=d+1|0;continue}break}g=N()|0;break w}Y:{Z:{d=$b(x[f+172>>2]);if(!d){break Z}x[23549]=0;e=O(141,b|0,d|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break S}d=0;if(!e){break Z}while(1){if(z[a+480188>>1]<=d>>>0){break Y}x[23549]=0;e=R(476,b|0)|0;h=x[23549];x[23549]=0;if((h|0)!=1){ba=((d<<5)+a|0)+480284|0,ca=(Ub(e,-16,16)<<3)+128|0,w[ba>>1]=ca;d=d+1|0;continue}break}g=N()|0;break w}vh(a,1)}m=Nb(f+144|0);d=x[f+160>>2];x[23549]=0;h=O(141,b|0,$b(d)|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break R}e=33;d=0;if(!h){break O}h=z[f+554>>1];g=x[b+8>>2];t=x[b>>2];x[23549]=0;h=U(142,t|0,g|0,Hb(h)<<1)|0;g=x[23549];x[23549]=0;if((g|0)==1){break R}if(!h){break O}h=z[f+554>>1];x[23549]=0;h=U(477,b|0,m|0,Hb(h)|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break R}if(!h){break O}ba=f,ca=yb(x[m>>2]),x[ba+140>>2]=ca;t=yb(x[f+148>>2]);B=x[f+156>>2];r=z[f+170>>1];while(1){d=x[f+140>>2];if(!Kb(d,t)){e=0;d=1;break O}d=Hb(y[d|0]|y[d+1|0]<<8);_:{if(Hb(r)>>>0<d>>>0){break _}x[23549]=0;O(141,b|0,$b(B)+(d<<2)|0)|0;d=x[23549];x[23549]=0;$:{aa:{ba:{ca:{da:{if((d|0)==1){break da}x[23549]=0;d=R(268,b|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break da}x[23549]=0;d=O(141,b|0,d|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break da}if(!d){break _}d=x[b+8>>2];e=x[b>>2];x[23549]=0;d=U(142,e|0,d|0,42)|0;e=x[23549];x[23549]=0;if((e|0)==1){break da}if(!d){break _}x[23549]=0;P(478,b|0,f+96|0);d=x[23549];x[23549]=0;ea:{if((d|0)!=1){if(qc(x[j>>2],x[j+4>>2])){break ea}x[23549]=0;P(479,j|0,65534);d=x[23549];x[23549]=0;if((d|0)!=1){break ea}}g=N()|0;break P}d=Hb(y[f+136|0]|y[f+137|0]<<8);x[f+92>>2]=d;e=x[b+8>>2];h=x[b>>2];x[23549]=0;d=U(142,h|0,e|0,d|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break ca}if(!d){x[23549]=0;d=R(188,b|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break ca}tc(f+92|0,d)}tc(f+92|0,65534);e=x[j+4>>2];h=x[j>>2];d=0;x[23549]=0;g=x[f+92>>2];i=Ic(h,e);P(480,j|0,g+i|0);e=x[23549];x[23549]=0;if((e|0)==1){break aa}while(1){fa:{if((d|0)==(g|0)){if(y[f+96|0]){break fa}break ba}x[23549]=0;e=R(260,b|0)|0;h=x[23549];x[23549]=0;ga:{if((h|0)!=1){e=e<<16>>16;if((e|0)<0){break ga}x[23549]=0;P(479,j|0,e+q&65535);e=x[23549];x[23549]=0;if((e|0)!=1){break ga}}g=N()|0;break P}d=d+1|0;continue}break}Nm(f+84|0,f+96|0);x[23549]=0;S(481,f+44|0,x[f+84>>2],x[f+88>>2]);d=x[23549];x[23549]=0;ha:{ia:{ja:{if((d|0)!=1){x[23549]=0;S(11,f- -64|0,13,f+44|0);d=x[23549];x[23549]=0;if((d|0)==1){break ja}x[23549]=0;P(262,j|0,f- -64|0);d=x[23549];x[23549]=0;if((d|0)==1){break ia}tb(f- -64|0);tb(f+44|0);break ba}g=N()|0;break P}g=N()|0;break ha}g=N()|0;tb(f- -64|0)}tb(f+44|0);break P}g=N()|0;break P}g=N()|0;break P}d=$b(y[f+128|0]|y[f+129|0]<<8|(y[f+130|0]<<16|y[f+131|0]<<24));if(!d){break _}x[23549]=0;d=O(141,b|0,d|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){break $}}g=N()|0;break P}if(!d){break _}while(1){ka:{x[23549]=0;d=O(482,b|0,f+84|0)|0;e=x[23549];x[23549]=0;la:{ma:{na:{oa:{if((e|0)!=1){if(!d){break _}x[23549]=0;S(176,f+44|0,b|0,y[f+87|0]);d=x[23549];x[23549]=0;if((d|0)==1){break oa}d=f+44|0;e=hc(f- -64|0,d);ub(d);h=Hb(z[f+84>>1]);d=xu(h+i|0);w[f+44>>1]=d;if((h|0)==65535){break ka}g=x[j>>2];if(Ic(g,x[j+4>>2])>>>0<=d>>>0){break ka}h=65535;switch(y[f+86|0]-1|0){case 0:break ma;case 1:break na;default:break la}}g=N()|0;break P}g=N()|0;break P}x[23549]=0;d=R(260,e|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break Q}x[23549]=0;h=O(483,l|0,f+44|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break Q}w[h>>1]=d;g=x[j>>2];h=65534;d=z[f+44>>1]}ba=_b(g,d),ca=h,w[ba>>1]=ca}ub(e);continue}break}ub(e)}Se(f+140|0);continue}}JA(l);break d}g=N()|0;break w}g=N()|0;break P}g=N()|0;ub(e)}id(m);break w}id(m);if(!d){break L}d=k>>>(s>>>1&1)|0;break M}g=N()|0;break w}g=Hb(z[f+812>>1]);m=y[f+815|0];X=m&64;e=y[f+816|0];J=e&32;G=(e&31)+1|0;ba=a,ca=kT(g,X>>>6|0,J>>>5|0,G),x[ba+480204>>2]=ca;ba=a,ca=Vd(y[f+817|0],1,32),x[ba+480196>>2]=ca;if(J){x[a+480216>>2]=G;x[a+480220>>2]=G<<2}e=y[f+834|0];if(e){v[f+156|0]=e;v[f+96|0]=64;ba=a,ca=y[Sb(f+156|0,f+96|0)|0]<<2,x[ba+480200>>2]=ca}x[a+480228>>2]=d;x[a+480232>>2]=d;x[a+480208>>2]=x[a+480208>>2]&-3|(m^-1)>>>4&2;pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{d=$b(x[f+516>>2]);if(!d){break za}x[23549]=0;d=O(141,b|0,d|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break ya}if(!d){break za}d=x[f+520>>2];x[23549]=0;S(257,b|0,W|0,$b(d)|0);d=x[23549];x[23549]=0;if((d|0)==1){break ya}if(y[M|0]<2){break za}x[23549]=0;S(11,f+156|0,13,W|0);d=x[23549];x[23549]=0;Aa:{if((d|0)!=1){x[23549]=0;P(262,j|0,f+156|0);d=x[23549];x[23549]=0;if((d|0)==1){break Aa}tb(f+156|0);break za}g=N()|0;break w}g=N()|0;tb(f+156|0);break w}Ba:{if($b(x[f+488>>2])>>>0<2){break Ba}d=x[f+484>>2];x[23549]=0;d=O(141,b|0,$b(d)|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break ya}if(!d){break Ba}d=x[f+488>>2];x[23549]=0;V(321,n|0,b|0,$b(d)-1|0,4);d=x[23549];x[23549]=0;if((d|0)==1){break ya}}d=$b(x[f+528>>2]);if(!d){break pa}x[23549]=0;d=O(141,b|0,d|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break ya}if(!d){break pa}d=x[b+8>>2];e=x[b>>2];x[23549]=0;d=U(142,e|0,d|0,12)|0;e=x[23549];x[23549]=0;if((e|0)==1){break ya}if(!d){break pa}x[23549]=0;O(174,b|0,6)|0;d=x[23549];x[23549]=0;if((d|0)==1){break ya}x[23549]=0;d=R(260,b|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break ya}if((d|0)!=1){break pa}x[23549]=0;d=R(268,b|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break wa}if(!d){break pa}e=x[b+8>>2];h=x[b>>2];x[23549]=0;e=U(142,h|0,e|0,d|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break wa}if(e){break xa}break pa}g=N()|0;break w}e=ad(f+156|0,n);x[23549]=0;V(321,n|0,b|0,d|0,4);d=x[23549];x[23549]=0;if((d|0)==1){break ra}if(!xd(x[f+160>>2],y[f+167|0])){x[23549]=0;d=U(484,f+20|0,2,13)|0;h=x[23549];x[23549]=0;if((h|0)==1){break va}x[23549]=0;S(485,f+96|0,e|0,d|0);h=x[23549];x[23549]=0;if((h|0)==1){break ua}x[23549]=0;S(486,f+32|0,f+96|0,n|0);h=x[23549];x[23549]=0;if((h|0)==1){break ta}h=f+32|0;zb(n,h);tb(h);tb(f+96|0);tb(d)}tb(e);break pa}g=N()|0;break w}g=N()|0;break qa}g=N()|0;break sa}g=N()|0;tb(f+96|0)}tb(d);break qa}g=N()|0}tb(e);break w}Ca:{H=y[f+859|0];if(H>>>0<2){break Ca}g=0;if(!$b(x[f+540>>2])){break Ca}while(1){if(z[a+480188>>1]<=g>>>0){break Ca}d=x[f+540>>2];x[23549]=0;d=O(141,b|0,$b(d)+(g<<2)|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break x}Da:{if(!d){break Da}x[23549]=0;d=R(268,b|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break x}x[23549]=0;e=O(141,b|0,d|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break x}h=0;d=0;if(!e){break Da}while(1){Ea:{e=x[b+8>>2];k=x[b>>2];x[23549]=0;e=U(142,k|0,e|0,8)|0;k=x[23549];x[23549]=0;Fa:{Ga:{Ha:{if((k|0)!=1){if(!e){break Ea}x[23549]=0;P(487,b|0,f+156|0);e=x[23549];x[23549]=0;if((e|0)==1){break Ha}e=$b(x[f+156>>2]);if(!e){break Ea}switch((e&536870911)-1|0){case 1:break Fa;case 0:break Ga;default:continue}}g=N()|0;break w}g=N()|0;break w}h=$b(x[f+160>>2]);continue}d=$b(x[f+160>>2]);continue}break}if(!h|!d){break Da}x[23549]=0;e=O(141,b|0,h|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break y}if(!e){break Da}x[23549]=0;S(365,b|0,((g<<5)+a|0)+480289|0,d|0);d=x[23549];x[23549]=0;if((d|0)==1){break y}}g=g+1|0;continue}}ba=f,ca=Hb(z[f+552>>1]),w[ba+84>>1]=ca;Wf(f+84|0,(q^-1)&65535);x[23549]=0;k=z[f+84>>1];P(211,o|0,q+k&65535);d=x[23549];x[23549]=0;Ia:{if((d|0)==1){break Ia}_=m&16;$=q&65535;h=0;Ja:{Ka:{while(1){if((h|0)==(k|0)){ba=f,ca=kj(x[l>>2]),x[ba+96>>2]=ca;g=Bf(l);while(1){La:{Ma:{Na:{Oa:{Pa:{Qa:{d=x[f+96>>2];if(!xg(d,g)){d=$b(x[f+472>>2]);if(d){break Qa}e=31;break Pa}d=iq(d);h=Ue(d);e=z[d>>1];if(!e){e=0;break Oa}x[23549]=0;m=O(299,j|0,e-1&65535)|0;e=x[23549];x[23549]=0;if((e|0)==1){break La}e=z[d>>1];if(!m){break Oa}x[23549]=0;e=O(352,j|0,e-1&65535)|0;d=x[23549];x[23549]=0;if((d|0)==1){break La}break Na}x[23549]=0;d=O(141,b|0,d|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break Ia}e=d?0:31}q=k+q|0;break L}if(z[h>>1]==((e&65535)+1|0)){break Ma}x[23549]=0;e=O(351,o|0,1)|0;m=x[23549];x[23549]=0;if((m|0)==1){break La}if((e|0)==65535){break Ma}ba=_b(x[j>>2],z[d>>1]),ca=e,w[ba>>1]=ca}d=Yb(x[o>>2],e);me(d,Bm(Fe(Be(f+156|0,12,ru(z[h>>1])),x[d+12>>2]-1|0)));k=(k&65535)>>>0>e>>>0?k:e+1|0}Vg(f+96|0);continue}break}g=N()|0;break w}Ra:{Sa:{if(!Z){break Sa}d=y[f+876|0]|y[f+877|0]<<8|(y[f+878|0]<<16|y[f+879|0]<<24);x[23549]=0;d=O(141,b|0,$b(d)+(h<<2)|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break Ka}if(!d){break Sa}x[23549]=0;d=R(268,b|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break Ka}x[23549]=0;d=O(141,b|0,d|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break Ka}if(!d){break Sa}m=Gb(f+44|0);x[23549]=0;d=v[f+814|0];s=R(160,f|0)|0;e=x[23549];x[23549]=0;Ta:{Ua:{if((e|0)!=1){t=d+48|0;if(H){break Ua}x[23549]=0;P(488,b|0,f+156|0);d=x[23549];x[23549]=0;if((d|0)==1){break Ra}w[f+140>>1]=y[f+156|0];B=y[f+157|0]+1|0;break Ta}g=N()|0;break z}x[23549]=0;P(489,b|0,f+144|0);e=x[23549];x[23549]=0;Va:{Wa:{if((e|0)!=1){e=Hb(z[f+144>>1]);w[f+140>>1]=e;B=Hb(z[f+146>>1])+1|0;g=$b(z[f+148>>1]|z[f+150>>1]<<16);if(!g){break Va}r=x[b+8>>2];x[23549]=0;O(141,b|0,g|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break A}x[23549]=0;P(490,b|0,f+156|0);g=x[23549];x[23549]=0;if((g|0)==1){break A}g=y[f+160|0]|y[f+161|0]<<8|(y[f+162|0]<<16|y[f+163|0]<<24);x[23549]=0;g=O(141,b|0,$b(g)|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break A}if(!g){break Wa}g=y[f+164|0]|y[f+165|0]<<8|(y[f+166|0]<<16|y[f+167|0]<<24);x[23549]=0;S(257,b|0,m|0,$b(g)|0);g=x[23549];x[23549]=0;if((g|0)!=1){break Wa}break A}break A}g=$b(y[f+172|0]|y[f+173|0]<<8|(y[f+174|0]<<16|y[f+175|0]<<24));Xa:{if(!g){break Xa}x[23549]=0;g=O(141,b|0,g|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break A}if(!g){break Xa}x[23549]=0;g=R(268,b|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break A}x[23549]=0;g=O(141,b|0,g|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break A}if(!g){break Xa}x[23549]=0;S(176,f- -64|0,b|0,D(e,B)|0);e=x[23549];x[23549]=0;if((e|0)==1){break A}e=f- -64|0;g=hc(f+96|0,e);Zc(s,g);ub(g);ub(e)}x[23549]=0;O(141,b|0,r|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break A}}t=H>>>0>2?d+24|0:t}x[23549]=0;d=h+$|0;e=U(212,o|0,d&65535,B|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break A}Ya:{if(!e){break Ya}e=x[o>>2];x[23549]=0;K=Yb(e,d);P(270,K|0,m|0);d=x[23549];x[23549]=0;if((d|0)==1){break Ja}Wf(f+140|0,z[a+480188>>1]);r=0;aa=z[f+140>>1];Za:while(1){if((r|0)==(B|0)){break Ya}g=0;d=$c(x[K>>2],x[x[K+48>>2]+12>>2],r,0);while(1){if((g&65535)>>>0>=aa>>>0){r=r+1|0;continue Za}_a:{if(!H){x[23549]=0;P(491,f+156|0,b|0);e=x[23549];x[23549]=0;if((e|0)!=1){e=y[f+156|0];i=f+156|0;C=fd(i);v[d+1|0]=e>>>3&16|y[C|0]>>>4|e>>>1&32;v[d+3|0]=y[C|0]&15;ba=d,ca=y[Ue(i)|0],v[ba+5|0]=ca;e=e&63;e=e?e+t|0:0;break _a}break A}x[23549]=0;P(341,f+156|0,b|0);e=x[23549];x[23549]=0;$a:{ab:{if((e|0)!=1){e=f+156|0;i=fd(e);C=Ue(e);L=Ai(e);x[23549]=0;e=R(192,s|0)|0;E=x[23549];x[23549]=0;if((E|0)==1){break A}v[d+4|0]=e;E=y[f+156|0];e=E&127;if(!e){break ab}e=e+t|0;break $a}break A}e=0;if((E|0)!=128){break $a}v[d|0]=254}v[d+1|0]=y[i|0]&63;v[d+3|0]=y[C|0];v[d+5|0]=y[L|0]}if(e-1>>>0<=119){v[d|0]=e}u=(e|0)>84&T|u;C=(X|0)!=0;L=(J|0)!=0;E=(_|0)!=0;e=db-16|0;db=e;bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{vb:{wb:{xb:{yb:{zb:{Ab:{i=y[d+3|0];switch(i-4|0){case 42:break db;case 37:break eb;case 28:break fb;case 27:break gb;case 26:break hb;case 25:break ib;case 24:break jb;case 23:break kb;case 22:break lb;case 21:break mb;case 20:break nb;case 18:break ob;case 17:break pb;case 16:break qb;case 14:break rb;case 13:break sb;case 12:break tb;case 11:break ub;case 10:break vb;case 9:break wb;case 8:break xb;case 5:break yb;case 4:break zb;case 0:break Ab;default:break cb}}v[d+3|0]=5;i=y[d+5|0];v[e+15|0]=i>>>3;v[e+14|0]=15;C=y[Sb(e+15|0,e+14|0)|0];v[e+13|0]=i<<1&30;v[e+12|0]=15;ba=d,ca=y[Sb(e+13|0,e+12|0)|0]|C<<4,v[ba+5|0]=ca;break bb}v[d+3|0]=0;break bb}if((y[d+5|0]-1&255)>>>0<=19){v[d+3|0]=16;break bb}v[d+3|0]=0;break bb}v[d+3|0]=13;i=y[d+5|0];Bb:{if(!E){if(i>>>0>152){break Bb}v[d+5|0]=D((i&240)>>>4|0,10)+(i&15);break bb}v[d+5|0]=(i&127)+1>>>1;break bb}v[d+3|0]=0;break bb}v[d+3|0]=11;break bb}v[d+3|0]=0;break bb}i=y[d+5|0];if(!i){v[d+3|0]=14;break bb}if(i>>>0<=240){v[d+3|0]=17;if(i>>>0<=2){v[d+5|0]=112;break bb}ba=d,ca=uo(+(kT(i,C,L,G)>>>0)/1e4),v[ba+5|0]=ca;break bb}v[d+3|0]=0;break bb}v[d+3|0]=31;v[d+5|0]=y[d+5|0]|128;break bb}v[d+3|0]=19;v[e+11|0]=15;ba=d,ca=y[Sb(d+5|0,e+11|0)|0]|16,v[ba+5|0]=ca;break bb}v[d+3|0]=19;v[e+10|0]=15;ba=d,ca=y[Sb(d+5|0,e+10|0)|0]|32,v[ba+5|0]=ca;break bb}v[d+3|0]=5;i=y[d+5|0];v[e+9|0]=(i>>>4|0)+1;v[e+8|0]=15;ba=d,ca=i&15|y[Sb(e+9|0,e+8|0)|0]<<4,v[ba+5|0]=ca;break bb}v[d+3|0]=19;v[d+5|0]=y[d+5|0]&15|80;break bb}v[d+3|0]=19;v[e+7|0]=15;ba=d,ca=y[Sb(d+5|0,e+7|0)|0]|96,v[ba+5|0]=ca;break bb}v[d+3|0]=19;v[e+6|0]=15;ba=d,ca=y[Sb(d+5|0,e+6|0)|0]|192,v[ba+5|0]=ca;break bb}v[d+3|0]=10;break bb}v[d+3|0]=19;v[e+5|0]=15;ba=d,ca=y[Sb(d+5|0,e+5|0)|0]|160,v[ba+5|0]=ca;break bb}v[d+3|0]=19;v[e+4|0]=15;ba=d,ca=y[Sb(d+5|0,e+4|0)|0]|176,v[ba+5|0]=ca;break bb}i=y[d+5|0]-1<<24>>24;if((i|0)>=0){v[d+5|0]=i;v[d+3|0]=31;break bb}v[d+3|0]=0;break bb}v[d+3|0]=14;break bb}v[d+3|0]=19;v[e+3|0]=15;ba=d,ca=y[Sb(d+5|0,e+3|0)|0]|224,v[ba+5|0]=ca;break bb}i=y[d+5|0];if(i>>>0>=16){v[d+3|0]=19;v[d+5|0]=i>>>4|208;break bb}if(i){v[d+3|0]=19;v[d+5|0]=i|144;break bb}v[d+3|0]=0;break bb}if(!(y[d+5|0]|y[d+4|0])){if(!Tc(y[d|0])){break bb}v[d+5|0]=159;v[d+3|0]=20;break bb}v[d+3|0]=0;break bb}i=y[d+4|0];if(i){v[d+3|0]=44;ba=d,ca=Km(Qc(((y[d+5|0]<<8&65280)>>>0)/(i>>>0)|0,0)),v[ba+5|0]=ca;break bb}v[d+3|0]=0;break bb}i=y[d+5|0];if((i+16&255)>>>0<=32){v[d+3|0]=9;ba=d,ca=xi(((i^128)<<3)-896|0),v[ba+5|0]=ca;break bb}v[d+3|0]=0;break bb}if(i>>>0<=15){Qf(d);break bb}v[d+3|0]=0}db=e+16|0;d=d+6|0;g=g+1|0;continue}}}ub(s);tb(m)}h=h+1|0;continue}break}break A}g=N()|0;break w}break A}g=N()|0;break w}JA(l);d=0;Cb:{switch(e-31|0){default:if(e){break c}break;case 2:break Cb;case 1:break c;case 0:break K}}c=c+1|0;continue}break}oj(A,0);d=1;if(u&1){break B}while(1){b=d&65535;if(b>>>0>z[a+480192>>1]){w[a+480192>>1]=0;break B}b=((b<<2)+a|0)+900380|0;c=x[b>>2];if(c){Eb(cu(c))}x[b>>2]=0;d=d+1|0;continue}}g=N()|0;break f}Db:{if(!Y){break Db}x[23549]=0;b=O(1,f+156|0,15981)|0;c=x[23549];x[23549]=0;Eb:{if((c|0)!=1){c=x[a+1298464>>2];x[23549]=0;S(359,c|0,2,b|0);c=x[23549];x[23549]=0;if((c|0)==1){break Eb}tb(b);break Db}g=N()|0;break f}g=N()|0;tb(b);break f}e=21204;Fb:{Gb:{switch(y[f+859|0]){case 0:e=z[a+480188>>1]>4?16853:16839;break Fb;case 1:e=16821;break Fb;case 2:e=16803;break Fb;case 3:break Gb;default:break Fb}}e=16776}x[23549]=0;P(492,f- -64|0,16391);b=x[23549];x[23549]=0;Hb:{Ib:{Jb:{if((b|0)!=1){x[23549]=0;S(493,f+96|0,f- -64|0,f+859|0);b=x[23549];x[23549]=0;if((b|0)==1){break Jb}b=f+96|0;zb(a+1298344|0,b);tb(b);Ab(f- -64|0);x[23549]=0;b=O(1,b|0,12496)|0;c=x[23549];x[23549]=0;if((c|0)==1){break Ib}zb(a+1298356|0,b);tb(b);x[23549]=0;P(122,a+1298368|0,e|0);b=x[23549];x[23549]=0;if((b|0)==1){break Hb}x[a+1298404>>2]=13;d=1;break c}g=N()|0;break f}g=N()|0;Ab(f- -64|0);break f}g=N()|0;break f}g=N()|0;break f}g=N()|0;ub(s)}tb(m);break w}g=N()|0;break w}g=N()|0}JA(l);break f}g=N()|0;break f}g=N()|0;break f}g=N()|0;break f}j=1;if((d|0)!=7){break m}d=k+108|0;e=sA(d);while(1){if((d|0)!=(e|0)){ba=d,ca=Am(y[d|0]-24|0),v[ba|0]=ca;d=d+1|0;continue}break}h=0}u=1;break l}h=0;Kb:{if(t|(g|0)<0){break Kb}n=k+108|0;e=7;Lb:while(1){if((e|0)==10){break Kb}s=D(e,12);r=D(e,-12)+72|0;d=0;while(1)if((d|0)==12){e=e+1|0;continue Lb}else{i=Db(n,d+s|0);v[i|0]=r+y[i|0];d=d+1|0;continue}}}}x[23549]=0;P(494,I|0,f+156|0);d=x[23549];x[23549]=0;if((d|0)!=1){Mb:{d=y[f+160|0];if((d-1&255)>>>0<=15){v[k+31|0]=d;u=1}d=y[f+161|0];if(d-1<<24>>24>=0){v[k+30|0]=d}d=0;Nb:{while(1){if((d|0)==(j|0)){if(!B){break j}if((g|0)>=0){break Nb}break j}x[23549]=0;e=D(d+m|0,104)+a|0;P(266,e+484380|0,8);k=x[23549];x[23549]=0;if((k|0)!=1){v[f+96|0]=y[f+162|0];v[f+44|0]=64;ba=e+484410|0,ca=y[Sb(f+96|0,f+44|0)|0]<<2,w[ba>>1]=ca;v[e+484416|0]=y[f+163|0];d=d+1|0;continue}break}break k}k=Xc(f+96|0,8,1,1,0);s=Hb(z[f+158>>1]);g=Hb(z[f+156>>1]);d=x[q>>2];x[23549]=0;e=R(146,d|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){d=Hb(z[f+68>>1]);if(d&16){hd(k,16);e=e>>>1|0}if(d&32){Oo(k,3);e=e>>>1|0}if(d&64){Uf(k,2)}e=h?(e>>>0)/((-1<<j^-1)>>>0)|0:e;h=g+s|0;d=0;while(1){if((d|0)==(j|0)){break j}n=D(d+m|0,104)+a|0;r=n+484380|0;x[r>>2]=e;x[23549]=0;U(205,k|0,r|0,q|0)|0;r=x[23549];x[23549]=0;if((r|0)==1){break Mb}g=g<<1;h=h<<1;if(s>>>0>=2){x[n+484388>>2]=h;x[n+484384>>2]=g;n=n+484414|0;w[n>>1]=z[n>>1]|2}d=d+1|0;e=e<<1;continue}}}}}g=N()|0;ub(q);break f}ub(q);o=o+1|0;l=j+l|0;e=z[a+480192>>1];continue}}g=N()|0;break e}g=N()|0;break e}g=N()|0}sc(F)}ub(I);Q(g|0);p()}d=0}sc(F)}ub(I)}db=f+912|0;return d|0}function ffa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=E(0),F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=E(0),ea=0,ga=0,ha=0,ia=0,ja=0;e=db-608|0;db=e;wc(b);a:{b:{c:{if(!$h(b,e+600|0)){break c}if(!cR(e+600|0)){break c}if((Io(b)|0)>=0){break c}if(!c){d=1;break c}Bd(a,16777216);x[a+480208>>2]=x[a+480208>>2]|1681e4;Xz(e+256|0,32);g=x[e+268>>2];d=a+1074320|0;x[d>>2]=x[e+264>>2];x[d+4>>2]=g;d=x[e+260>>2];x[a+1074312>>2]=x[e+256>>2];x[a+1074316>>2]=d;Of(a+1074312|0,38);q=Nb(e+588|0);r=Nb(e+576|0);t=Nb(e+564|0);l=Nb(e+552|0);ng(b,4);m=a+480190|0;K=c&1;H=a+1298332|0;s=2500;I=!(c&2);d:{e:{f:{while(1){c=x[b+8>>2];d=x[b>>2];x[23549]=0;c=U(142,d|0,c|0,4)|0;d=x[23549];x[23549]=0;g:{h:{i:{j:{k:{l:{m:{if((d|0)!=1){n:{if(c){x[23549]=0;c=R(649,b|0)|0;d=x[23549];x[23549]=0;o:{if((d|0)==1){break o}k=4;d=0;p:{q:{r:{switch(c+21|0){case 20:x[23549]=0;c=R(268,b|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){d=c&65535;if(z[a+480188>>1]|d-1>>>0>126){continue}w[a+480188>>1]=c;ia=a,ja=Ub(512/(d>>>0)|0,16,128),x[ia+480228>>2]=ja;continue}c=N()|0;break a;case 19:x[23549]=0;L=R(268,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break o}if(L>>>0<=1024){continue}break m;case 16:x[23549]=0;c=R(268,b|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){if((c&65535)==4){continue}break m}c=N()|0;break a;case 15:x[23549]=0;c=R(268,b|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){x[e+256>>2]=c;x[e+152>>2]=800;ia=a,ja=Le(+A[Cb(e+256|0,e+152|0)>>2]*1.24*1e4),x[ia+480204>>2]=ja;continue}c=N()|0;break a;case 31:x[23549]=0;c=R(268,b|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break o}Y=1;s=Vd(c,0,1e4);continue;case 32:case 33:x[23549]=0;c=R(268,b|0)|0;d=x[23549];x[23549]=0;s:{t:{if((d|0)!=1){Y=1;if(!c){continue}x[23549]=0;d=O(1,e+540|0,12405)|0;c=x[23549];x[23549]=0;if((c|0)==1){break t}c=x[a+1298464>>2];x[23549]=0;S(359,c|0,2,d|0);c=x[23549];x[23549]=0;if((c|0)==1){break s}tb(d);continue}c=N()|0;break a}c=N()|0;break a}c=N()|0;tb(d);break a;case 14:x[23549]=0;O(174,b|0,4)|0;c=x[23549];x[23549]=0;if((c|0)==1){break o}i=!z[m>>1]|i;continue;case 11:if(!K){break q}if(!qc(x[q>>2],x[q+4>>2])){break q}x[23549]=0;P(650,e+256|0,b|0);c=x[23549];x[23549]=0;if((c|0)!=1){if(x[q>>2]){Dc(q);c=x[q>>2];to(q);Eb(c);ia=wb(q),ja=0,x[ia>>2]=ja;x[q>>2]=0;x[q+4>>2]=0}c=e+256|0;x[q>>2]=x[c>>2];x[q+4>>2]=x[c+4>>2];d=wb(c);ia=wb(q),ja=x[d>>2],x[ia>>2]=ja;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;vi(c);continue}c=N()|0;break a;case 3:case 4:case 10:g=ph(x[l>>2],x[l+4>>2]);d=z[m>>1];if(g>>>0<=d>>>0){continue}if((i|I)&1){break q}if(!Th(d)){break q}d=d+1|0;w[m>>1]=d;u=Nb(e+528|0);x[23549]=0;i=R(160,e+508|0)|0;g=x[23549];x[23549]=0;u:{v:{w:{if((g|0)!=1){if((c|0)==-17){break w}if((c|0)!=-11){break v}x[23549]=0;c=R(268,b|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break u}x[23549]=0;S(176,e+152|0,b|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break u}c=e+152|0;g=hc(e+256|0,c);Zc(i,g);ub(g);break g}c=N()|0;break d}x[23549]=0;P(651,e+256|0,b|0);c=x[23549];x[23549]=0;x:{if((c|0)!=1){c=e+256|0;g=zm(u,c);bc(c);ge(e+480|0,x[g>>2],x[e+532>>2]);c=Xd(e+472|0);x[23549]=0;g=x[c+4>>2];x[e+16>>2]=x[c>>2];x[e+20>>2]=g;c=Xf(312,e+488|0,x[e+480>>2],x[e+484>>2],e+16|0);g=x[23549];x[23549]=0;if((g|0)==1){break x}Zc(i,c);break g}c=N()|0;break e}c=N()|0;break e}x[23549]=0;P(652,e+256|0,b|0);c=x[23549];x[23549]=0;y:{if((c|0)!=1){c=e+256|0;g=zm(u,c);bc(c);ge(e+440|0,x[g>>2],x[e+532>>2]);c=Xd(e+432|0);x[23549]=0;g=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=g;c=Xf(312,e+452|0,x[e+440>>2],x[e+444>>2],e+8|0);g=x[23549];x[23549]=0;if((g|0)==1){break y}Zc(i,c);break g}c=N()|0;break e}c=N()|0;break e}c=N()|0;break e;case 9:c=z[m>>1];if(!Th(c)){continue}w[m>>1]=c+1;continue;case 8:if(!K){break q}if(!qc(x[t>>2],x[t+4>>2])){break q}x[23549]=0;P(653,e+256|0,b|0);c=x[23549];x[23549]=0;if((c|0)!=1){c=e+256|0;bR(t,c);sc(c);continue}c=N()|0;break a;case 7:if(!qc(x[l>>2],x[l+4>>2])){break q}x[23549]=0;P(654,e+256|0,b|0);c=x[23549];x[23549]=0;if((c|0)!=1){if(x[l>>2]){Dc(l);c=x[l>>2];Oz(l);Eb(c);ia=wb(l),ja=0,x[ia>>2]=ja;x[l>>2]=0;x[l+4>>2]=0}c=e+256|0;x[l>>2]=x[c>>2];x[l+4>>2]=x[c+4>>2];d=wb(c);ia=wb(l),ja=x[d>>2],x[ia>>2]=ja;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;Gt(c);continue}c=N()|0;break a;case 6:if(!K){break q}if(!qc(x[r>>2],x[r+4>>2])){break q}x[23549]=0;P(655,e+256|0,b|0);c=x[23549];x[23549]=0;if((c|0)!=1){if(x[r>>2]){Dc(r);c=x[r>>2];zr(r);Eb(c);ia=wb(r),ja=0,x[ia>>2]=ja;x[r>>2]=0;x[r+4>>2]=0}c=e+256|0;x[r>>2]=x[c>>2];x[r+4>>2]=x[c+4>>2];d=wb(c);ia=wb(r),ja=x[d>>2],x[ia>>2]=ja;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;ql(c);continue}c=N()|0;break a;case 17:case 18:break p;case 0:case 1:case 2:break q;case 5:break r;default:break m}}x[23549]=0;P(656,e+256|0,b|0);c=x[23549];x[23549]=0;if((c|0)==1){break n}z:{c=x[e+256>>2];d=x[e+260>>2];if(qc(c,d)){break z}x[23549]=0;V(327,H|0,c|0,Pc(c,d)|0,1);c=x[23549];x[23549]=0;if((c|0)!=1){break z}c=N()|0;bc(e+256|0);break a}bc(e+256|0);continue}x[23549]=0;k=R(268,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break o}}x[23549]=0;O(174,b|0,k|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){continue}}c=N()|0;break a}d=0;if(!z[a+480188>>1]|!L){break m}b=x[l>>2];c=x[l+4>>2];if(qc(b,c)){break m}if(K){if(qc(x[q>>2],x[q+4>>2])){break m}if(qc(x[t>>2],x[t+4>>2])){break m}if(qc(x[r>>2],x[r+4>>2])){break m}}b=ph(b,c);if(b>>>0>=256){x[23549]=0;P(657,l|0,255);b=x[23549];x[23549]=0;if((b|0)==1){break b}b=ph(x[l>>2],x[l+4>>2])}w[a+480192>>1]=b;h=a+480192|0;ia=a,ja=z[Ve(m,h)>>1],w[ia+480190>>1]=ja;if(i&1){x[23549]=0;b=O(1,e+528|0,16070)|0;c=x[23549];x[23549]=0;if((c|0)==1){break h}c=x[a+1298464>>2];x[23549]=0;S(359,c|0,2,b|0);c=x[23549];x[23549]=0;if((c|0)==1){break i}tb(b)}i=0;A:while(1){if((i|0)!=2){d=1;while(1){f=d&65535;if(f>>>0>z[h>>1]){i=i+1|0;continue A}B:{c=qm(x[l>>2],f-1|0);if(!y[c|0]|v[c+128|0]<0){break B}if((Ct(c)|0)==((i|0)!=1|0)){break B}C:{D:{E:{g=0;F:{if(!Ct(c)){break F}if(Hb(y[c+6|0]|y[c+7|0]<<8)){break F}if(Hb(y[c+14|0]|y[c+15|0]<<8)>>>0>20){break F}g=(Hb(y[c+18|0]|y[c+19|0]<<8)|0)==4}G:{H:{if(g){g=y[c+23|0];b=y[c+140|0];x[23549]=0;b=fa(658,c|0,a|0,(b&2)>>>1|0,(D(f,104)+a|0)+484380|0,s&65535)|0;k=x[23549];x[23549]=0;I:{J:{if((k|0)!=1){if(!b){break I}x[23549]=0;b=O(54,e+384|0,10609)|0;k=x[23549];x[23549]=0;if((k|0)==1){break J}zc(((f<<5)+a|0)+946304|0,b);tb(b);k=x[l>>2];b=d;if(ph(k,x[l+4>>2])>>>0<=g>>>0){break G}ia=c,ja=y[c+143|0]+y[qm(k,g)+143|0]|0,v[ia+143|0]=ja;break H}c=N()|0;break a}c=N()|0;break a}b=g+1|0;break G}g=0;K:{if(!Ct(c)){break K}if((Hb(y[c+6|0]|y[c+7|0]<<8)|0)!=1){break K}if((Hb(y[c+14|0]|y[c+15|0]<<8)|0)!=2){break K}g=(Hb(y[c+18|0]|y[c+19|0]<<8)|0)==10}b=d;if(!g){break G}rc(e+256|0,c,128);b=Hb(y[e+276|0]|y[e+277|0]<<8);if(b>>>0>=z[m>>1]){break H}x[23549]=0;g=R(647,e+152|0)|0;k=x[23549];x[23549]=0;if((k|0)==1){break E}k=y[e+292|0]|y[e+293|0]<<8;n=z[a+480190>>1];x[23549]=0;o=D(b,104);b=a+484380|0;k=Hb(k);b=ba(659,e+256|0,(o+b|0)+104|0,(k>>>0<n>>>0?(b+D(k,104)|0)+104|0:g)|0,b+D(f,104)|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break D}if(!b){break H}x[23549]=0;b=O(54,e+140|0,11111)|0;g=x[23549];x[23549]=0;if((g|0)==1){break C}zc(((f<<5)+a|0)+946304|0,b);tb(b);v[c+139|0]=y[c+139|0]+12}b=d}x[23549]=0;b=b&65535;g=U(240,a|0,f|0,b|0)|0;f=x[23549];x[23549]=0;if((f|0)!=1){if(!g|b>>>0>z[m>>1]){break B}x[23549]=0;V(660,c|0,g|0,(D(b,104)+a|0)+484380|0,a|0);b=x[23549];x[23549]=0;if((b|0)!=1){break B}}c=N()|0;break a}c=N()|0;break a}c=N()|0;break a}c=N()|0;break a}d=d+1|0;continue}}break}I=ig(e+128|0);u=ig(e+116|0);b=oc(x[t>>2],x[t+4>>2]);Z=D(z[a+480188>>1],L);_=xu((b>>>0)/(Z>>>0)|0);x[23549]=0;T=a+484344|0;P(211,T|0,_|0);b=x[23549];x[23549]=0;if((b|0)==1){break k}Dc(Wb(x[a+484360>>2],y[a+484376|0]));b=z[a+480188>>1];x[23549]=0;F=O(661,e+104|0,b|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break l}ia=e,ja=yb(x[r>>2]),x[ia+56>>2]=ja;ea=a+902204|0;ga=yb(x[r+4>>2]);while(1){L:{M:{N:{n=x[e+56>>2];if(!Kb(n,ga)){break N}b=Hb(y[n+6|0]|y[n+7|0]<<8);if((b|0)==1){break L}if((b|0)==65535){break N}g=Hb(y[n|0]|y[n+1|0]<<8);b=x[q>>2];f=x[q+4>>2];c=hg(b,f);if(g>>>0>=c>>>0){break L}d=Hb(y[n+2|0]|y[n+3|0]<<8);if(d>>>0>c>>>0|!d|g>>>0>c-d>>>0){break L}c=b+(hg(b,f)<<5)|0;x[e+256>>2]=b;x[e+260>>2]=c-b>>5;b=x[e+256>>2];ec(e+80|0,b+(Hb(y[n|0]|y[n+1|0]<<8)<<5)|0,Hb(y[n+2|0]|y[n+3|0]<<8));O:{G=Wb(x[a+484360>>2],y[a+484376|0]);if(qc(x[G>>2],x[G+4>>2])){break O}x[23549]=0;P(479,G|0,65534);b=x[23549];x[23549]=0;if((b|0)!=1){break O}break M}c=x[e+80>>2];ha=te(c,x[e+84>>2]);while(1){if((c|0)==(ha|0)){break L}b=Hb(Hb(y[n+8|0]|y[n+9|0]<<8)+Hb(y[c+16|0]|y[c+17|0]<<8)&65535);v[c+16|0]=b;v[c+17|0]=b>>>8;g=c;b=Ud(I);while(1){P:{c=0;if(!b){break P}d=b+14|0;if(!yt(g,d)){c=1;if(!yt(d,g)){break P}b=b+4|0}b=x[b>>2];continue}break}Q:{R:{S:{if(c){x[23549]=0;b=O(662,I|0,g|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break M}H=z[b>>1];break S}H=0;if(!K){break S}b=y[g+12|0]|y[g+13|0]<<8;x[23549]=0;H=O(351,T|0,Hb(b)|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break M}if((H|0)==65535){break L}x[23549]=0;b=O(662,I|0,g|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break M}w[b>>1]=H;if(Hb(y[g+8|0]|y[g+9|0]<<8)>>>0>=_>>>0){break R}if(Hb(y[g+10|0]|y[g+11|0]<<8)>>>0>=L>>>0){break R}m=Hb(y[g+14|0]|y[g+15|0]<<8);c=Yj(yb(x[t>>2]),D(Hb(y[g+8|0]|y[g+9|0]<<8),Z));b=z[a+480188>>1];ia=e,ja=Yj(c,D(b,Hb(y[g+10|0]|y[g+11|0]<<8))),x[ia+44>>2]=ja;M=0;x[e+32>>2]=0;o=Wh(e+68|0);T:while(1){U:{d=Hb(y[g+12|0]|y[g+13|0]<<8);c=Yb(x[T>>2],H);if(d>>>0<=M>>>0){break U}k=0;X=$c(x[c>>2],x[x[c+48>>2]+12>>2],M,0);c=0;while(1){if((b&65535)>>>0<=k>>>0){M=M+1|0;continue T}b=yb(x[t+4>>2]);d=x[e+44>>2];h=Kb(d,b)?d:e+32|0;b=yb(x[t+4>>2]);if(Kb(x[e+44>>2],b)){$Q(e+44|0)}d=D(k,6)+X|0;f=y[h+1|0];b=(f>>>0>=85?-1:f+25|0)<<24>>24;s=0;i=x[l>>2];$=ph(i,x[l+4>>2]);J=y[h+3|0];V:{if($>>>0<=J>>>0){break V}s=J+1|0;if(v[qm(i,J)+142|0]&1|(b|0)<0){break V}b=Am(Hb(y[g+16|0]|y[g+17|0]<<8)+b<<24>>24)}W:{if(!y[d|0]|!(J|(y[h|0]|(f|0)!=255)|y[h+2|0])){break W}f=y[d+1|0];if(!f|f>>>0>$>>>0){break W}if(y[qm(i,f-1|0)+132|0]!=2){break W}qo(d)}f=Ft(x[F>>2],k);X:{Y:{if(c&1){c=y[o|0]|y[o+1|0]<<8|(y[o+2|0]<<16|y[o+3|0]<<24);v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;c=y[o+4|0]|y[o+5|0]<<8;v[d+4|0]=c;v[d+5|0]=c>>>8;Z:{if(y[d+3|0]){break Z}i=y[f+21|0];c=y[Ft(x[F>>2],k-1|0)+21|0];if((i|0)==(c|0)){break Z}v[d+3|0]=21;v[f+21|0]=c;v[d+5|0]=c}c=0;i=y[h|0];if(i-24>>>0<2|(i|0)==9|!i&(y[h+2|0]+7&255)>>>0<2){break Y}break X}i=y[h|0]}_:{$:{aa:{ba:{ca:{da:{switch(i|0){case 5:c=y[f+17|0];break ca;case 0:ea:{c=y[h+2|0];if(c>>>0>=201){i=0;fa:{switch(c-242|0){case 11:v[d+4|0]=1;v[d+2|0]=14;v[f+16|0]=0;break $;case 9:if(!y[d|0]){v[d|0]=y[f+17|0]}v[d+4|0]=1;v[d+2|0]=15;break $;case 8:if((m&255)>>>0<2){break $}m=m-1|0;break aa;case 7:if((m&255)==255){m=255;break $}m=m+1|0;break aa;case 6:v[f+17|0]=b;if(y[f+18|0]!=(s&255)){break $}v[d|0]=b;v[d+5|0]=255;v[d+3|0]=4;w[f+32>>1]=0;x[f+8>>2]=0;break $;case 5:v[d+5|0]=242;v[d+3|0]=2;break $;case 4:v[d+5|0]=242;v[d+3|0]=3;break $;case 3:v[d+5|0]=244;v[d+3|0]=2;break $;case 2:v[d+5|0]=244;v[d+3|0]=3;break $;case 1:v[d+5|0]=248;v[d+3|0]=2;break $;case 12:break ea;case 0:break fa;default:break $}}v[d+5|0]=248;v[d+3|0]=3;break $}ga:{if(v[h+1|0]<0){i=0;if(c>>>0<100){break ga}break $}v[f+17|0]=b;v[d|0]=b;v[f+18|0]=s;v[d+1|0]=s;w[f+32>>1]=0;x[f+8>>2]=0;c=y[h+2|0]}b=c&255;if(!b){i=0;break $}ia=f,ja=uo(+(b>>>0)*.64),v[ia+19|0]=ja;j=B[f>>2];x[f>>2]=0;i=j!=E(0);break $}v[d+4|0]=0;v[d+2|0]=14;v[f+16|0]=1;break $;case 1:x[f+4>>2]=0;B[f>>2]=E(y[h+2|0])*E(.0333000011742115);break _;case 2:x[f+4>>2]=0;B[f>>2]=E(y[h+2|0])*E(-.0333000011742115);break _;case 12:v[e+256|0]=15;v[e+100|0]=y[h+3|0]>>>3;b=y[Sb(e+256|0,e+100|0)|0];v[e+256|0]=15;v[e+100|0]=y[h+2|0]>>>3;ia=f,ja=y[Sb(e+256|0,e+100|0)|0]|b<<4,v[ia+24|0]=ja;break _;case 3:x[f+12>>2]=0;b=y[h+2|0];w[f+32>>1]=0;B[f+8>>2]=E(b>>>0)*E(.0333000011742115);break _;case 4:x[f+12>>2]=0;b=y[h+2|0];w[f+32>>1]=0;B[f+8>>2]=E(b>>>0)*E(-.0333000011742115);break _;case 15:if(!y[h+2|0]|(b|0)<0){break _}i=b-y[f+17|0]<<5;c=i>>31;c=(c^i)-c|0;x[e+256>>2]=c;v[f+17|0]=b;x[f+8>>2]=0;v[d|0]=b;v[d+3|0]=4;b=xi((c>>>0)/(y[h+2|0]<<1>>>0)|0);v[d+5|0]=b;v[f+27|0]=b;x[e+100>>2]=D(b,(m&255)-1|0);ia=f,ja=c-x[qd(e+256|0,e+100|0)>>2]|0,w[ia+32>>1]=ja;break _;case 10:case 11:v[d+3|0]=0;v[d+5|0]=0;break _;case 13:v[e+256|0]=15;v[e+100|0]=y[h+3|0]>>>3;b=y[Sb(e+256|0,e+100|0)|0];v[e+256|0]=15;v[e+100|0]=y[h+2|0];ia=f,ja=y[Sb(e+256|0,e+100|0)|0]|b<<4,v[ia+23|0]=ja;break _;case 18:b=y[h+2|0]+y[f+17|0]&255;b=b?b>>>0>=120?120:b:1;v[f+17|0]=b;v[d|0]=b;v[d+5|0]=255;v[d+3|0]=4;break ba;case 23:case 24:case 25:b=Ud(u);while(1){ha:{c=0;if(!b){break ha}i=b+13|0;if(!zt(h,i)){c=1;if(!zt(i,h)){break ha}b=b+4|0}b=x[b>>2];continue}break};if(c){v[d+3|0]=31;x[23549]=0;b=O(663,u|0,h|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break M}v[d+5|0]=y[b|0];break _}b=x[wb(u)>>2];if(b>>>0>127){break _}x[e+96>>2]=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);c=te(ea,b&255);i=x[a+480208>>2];x[23549]=0;x[e+28>>2]=x[e+96>>2];c=U(664,e+28|0,c|0,i|0)|0;i=x[23549];x[23549]=0;ia:{if((i|0)==1){break ia}if(!c){break _}v[d+3|0]=31;x[23549]=0;c=O(663,u|0,h|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break ia}b=b|-128;v[c|0]=b;v[d+5|0]=b;aa=(y[h|0]&254)==24|aa;break _}break M;case 16:if(!y[h+2|0]){break _}v[d+3|0]=15;x[e+256>>2]=15;x[e+100>>2]=y[h+3|0]+1;ia=d,ja=x[qd(e+256|0,e+100|0)>>2],v[ia+5|0]=ja;w[f+30>>1]=D(y[h+2|0],y[h+3|0]+1|0);break _;case 9:v[d+3|0]=16;b=y[h+2|0];m=b?b:4;v[d+5|0]=m;break _;case 19:ja:{ka:{switch(y[h+1|0]){case 0:b=128;break ja;case 4:break ka;default:break _}}b=y[h+3|0]}v[e+95|0]=b;v[e+256|0]=y[h+2|0];v[e+100|0]=100;c=e+256|0;s=e+100|0;i=y[Sb(c,s)|0];x[e+256>>2]=128;x[e+100>>2]=256-(b&255);b=x[qd(c,s)>>2];v[e+256|0]=128;c=y[Sb(c,e+95|0)|0];b=(D(b,i)|0)/128|0;s=b&255;if((s|0)!=y[f+20|0]){v[f+20|0]=b;v[d+3|0]=21;b=Qc(((D(s,y[f+19|0])+50&65535)>>>0)/100|0,0);v[f+21|0]=b;v[d+5|0]=b}if(y[h+1|0]!=4|(z[a+480188>>1]-1|0)<=(k|0)){break _}b=k+1|0;h=Ft(x[F>>2],b);c=D(c,i)>>>7|0;if(y[h+20|0]==(c&255)){break _}v[h+20|0]=c;b=D(b,6)+X|0;v[b+3|0]=21;c=Qc(((D(y[f+20|0],y[f+19|0])+50&65535)>>>0)/100|0,0);v[f+21|0]=c;v[b+5|0]=c;break _;case 17:case 20:v[d+3|0]=0;break _;case 7:b=y[h+2|0];v[f+25|0]=0;v[f+26|0]=0;v[f+22|0]=b;break _;case 8:v[f+22|0]=y[f+22|0]+y[h+2|0];break _;case 14:v[f+25|0]=y[h+3|0];v[f+26|0]=y[h+2|0];break _;case 6:break da;default:break _}}v[f+18|0]=s;v[f+17|0]=b;v[d+1|0]=s;c=b}v[d|0]=c;if((b|0)>=0){v[f+18|0]=s;v[d+1|0]=s}if(y[h|0]==5){v[d+4|0]=1;v[d+2|0]=11}b=y[f+26|0];c=y[f+22|0];if(!(b|(c|y[h+2|0]))){break ba}if(b){ca=(ui(+z[f+28>>1]*.006135923151542565+4.71238898038469)+-1)*+(b>>>0)*.25}else{ca=0}v[d+3|0]=44;ia=d,ja=uo(ca+ +(c+y[h+2|0]|0)),v[ia+5|0]=ja}w[f+32>>1]=0;break _}v[d+5|0]=m;v[d+3|0]=16}b=Qc(((D(y[f+20|0],y[f+19|0])+50&65535)>>>0)/100|0,0);if(!(!i&y[f+21|0]==(b&255))){v[f+21|0]=b;v[d+5|0]=b;v[d+3|0]=21}if(k&1|v[h+1|0]<=0|(z[a+480188>>1]-1|0)<=(k|0)){break _}b=x[l>>2];if(ph(b,x[l+4>>2])>>>0<=J>>>0){break _}if(y[qm(b,J)+132|0]!=1){break _}h=k+1|0;b=D(h,6)+X|0;c=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[b|0]=c;v[b+1|0]=c>>>8;v[b+2|0]=c>>>16;v[b+3|0]=c>>>24;c=y[d+4|0]|y[d+5|0]<<8;v[b+4|0]=c;v[b+5|0]=c>>>8;v[b+1|0]=y[b+1|0]+1;b=Ft(x[F>>2],h);v[b+19|0]=y[f+19|0];B[b>>2]=B[f>>2];B[b+4>>2]=B[f+4>>2];B[b+8>>2]=B[f+8>>2];B[b+12>>2]=B[f+12>>2];w[b+30>>1]=z[f+30>>1]}la:{if(y[d|0]){v[f+16|0]=0;break la}c=0;if(y[f+16|0]){break X}}ma:{if(!z[f+30>>1]){break ma}b=m&255;w[e+256>>1]=b;c=f+30|0;ia=c,ja=z[Ve(c,e+256|0)>>1]-b|0,w[ia>>1]=ja;if(y[d+3|0]){break ma}v[d+3|0]=15;v[d+5|0]=0}j=B[f>>2];na:{if(j==E(0)){break na}b=m&255;j=E(E(j*E(b>>>0))+B[f+4>>2]);B[f+4>>2]=j;if(y[d+3|0]){break na}oa:{pa:{qa:{ra:{if(b>>>0>=2){h=b-1|0;C=E(h|0);if(!(C<=j)){break ra}v[e+256|0]=15;ia=e,ja=Ug(E(j/C)),v[ia+100|0]=ja;b=y[Sb(e+256|0,e+100|0)|0];B[f+4>>2]=j-E(D(b,h)|0);v[d+3|0]=22;c=b<<4;break oa}if(!(j>=E(1))){break qa}break pa}if(j>=E(1)){break pa}if(!(j<=E(1-b|0))){break qa}v[e+256|0]=15;ia=e,ja=Ug(E(E(-j)/C)),v[ia+100|0]=ja;c=y[Sb(e+256|0,e+100|0)|0];B[f+4>>2]=j+E(D(h,c)|0);v[d+3|0]=22;break oa}if(!(j<=E(-1))){break na}v[e+256|0]=14;ia=e,ja=Ug(E(-j)),v[ia+100|0]=ja;b=y[Sb(e+256|0,e+100|0)|0];B[f+4>>2]=j+E(b>>>0);v[d+3|0]=22;c=b|-16;break oa}v[e+256|0]=15;ia=e,ja=Ug(j),v[ia+100|0]=ja;b=y[Sb(e+256|0,e+100|0)|0];B[f+4>>2]=j-E(b>>>0);v[d+3|0]=22;c=b<<4|15}v[d+5|0]=c}j=B[f+8>>2];sa:{if(j==E(0)){break sa}b=m&255;j=E(E(j*E(b>>>0))+B[f+12>>2]);B[f+12>>2]=j;ta:{if(!y[d+3|0]){ua:{va:{if(b>>>0>=2){c=b-1|0;C=E(c|0);if(!(C<=j)){break va}v[e+256|0]=223;ia=e,ja=Ug(E(j/C)),v[ia+100|0]=ja;b=y[Sb(e+256|0,e+100|0)|0];B[f+12>>2]=j-E(D(b,c)|0);v[d+3|0]=2;v[d+5|0]=b;break sa}if(!(j>=E(1))){break ua}break ta}if(j>=E(1)){break ta}if(!(j<=E(1-b|0))){break ua}v[e+256|0]=223;ia=e,ja=Ug(E(E(-j)/C)),v[ia+100|0]=ja;b=y[Sb(e+256|0,e+100|0)|0];B[f+12>>2]=j+E(D(b,c)|0);v[d+3|0]=3;v[d+5|0]=b;break sa}if(!(j<=E(-1))){break sa}v[e+256|0]=14;ia=e,ja=Ug(E(-j)),v[ia+100|0]=ja;b=y[Sb(e+256|0,e+100|0)|0];B[f+12>>2]=j+E(b>>>0);v[d+3|0]=3;v[d+5|0]=b|240;break sa}if(y[d+2|0]|b>>>0<2){break sa}da=E(j*E(.25));c=b-1|0;C=E(c|0);if(da>=C){v[e+256|0]=9;ia=e,ja=Ug(E(j/C))>>>2|0,v[ia+100|0]=ja;b=y[Sb(e+256|0,e+100|0)|0];B[f+12>>2]=j-E(D(b,c)<<2);v[d+2|0]=12;v[d+4|0]=b;break sa}if(!(E(1-b|0)>=da)){break sa}v[e+256|0]=9;ia=e,ja=Ug(E(E(-j)/C))>>>2|0,v[ia+100|0]=ja;b=y[Sb(e+256|0,e+100|0)|0];B[f+12>>2]=j+E(D(b,c)<<2);v[d+2|0]=13;v[d+4|0]=b;break sa}v[e+256|0]=15;ia=e,ja=Ug(j),v[ia+100|0]=ja;b=y[Sb(e+256|0,e+100|0)|0];B[f+12>>2]=j-E(b>>>0);v[d+3|0]=2;v[d+5|0]=b|240}wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{b=y[d+3|0];switch(b|0){case 4:break wa;case 0:break Ca;default:break Ba}}Da:{b=y[f+23|0];if(!b){b=y[f+24|0];if(b){break Da}if(!z[f+32>>1]){break wa}c=f+32|0;break Aa}v[d+3|0]=5;v[d+5|0]=b;if(!z[f+32>>1]){break wa}break za}v[d+3|0]=8;v[d+5|0]=b;if(z[f+32>>1]){break za}break wa}if(!z[f+32>>1]){break wa}c=f+32|0;if(b){break ya}}v[d+3|0]=4;break xa}c=f+32|0}v[d+2|0]=11}w[e+256>>1]=D(y[f+27|0],(m&255)-1|0);ia=f,ja=z[f+32>>1]-z[Uc(c,e+256|0)>>1]|0,w[ia+32>>1]=ja}w[f+28>>1]=z[f+28>>1]+D(y[f+25|0],m&255)&1023;c=0;if(k&1){break X}b=y[f+18|0];if(!b){break X}f=x[l>>2];if(ph(f,x[l+4>>2])>>>0<b>>>0){break X}f=qm(f,b-1|0);if(!(y[f+142|0]&4)){break X}b=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[o|0]=b;v[o+1|0]=b>>>8;v[o+2|0]=b>>>16;v[o+3|0]=b>>>24;b=y[d+4|0]|y[d+5|0]<<8;v[o+4|0]=b;v[o+5|0]=b>>>8;c=1;b=y[e+69|0];if(!b|y[f+132|0]!=1){break X}v[e+69|0]=b+1}k=k+1|0;b=z[a+480188>>1];continue}}break}me(c,wh(Fe(Be(e+256|0,16,Hb(y[g+14|0]|y[g+15|0]<<8)&255),0)))}b=vl(x[G>>2],x[G+4>>2]);ia=e,ja=Hb(y[g+4|0]|y[g+5|0]<<8),w[ia+256>>1]=ja;w[e+68>>1]=1;c=z[Ve(e+256|0,e+68|0)>>1];x[23549]=0;V(665,G|0,b|0,c|0,H&65535);b=x[23549];x[23549]=0;if((b|0)==1){break Q}b=Hb(y[n+8|0]|y[n+9|0]<<8);b=Hb(Hb(y[g+16|0]|y[g+17|0]<<8)-b&65535);v[g+16|0]=b;v[g+17|0]=b>>>8}c=g+32|0;continue}break}break M}c=aa&1;if(c){x[23549]=0;W(273,a+906300|0);b=x[23549];x[23549]=0;if((b|0)==1){break M}b=a+906324|0;x[b>>2]=655376;x[b+4>>2]=0;b=a+906316|0;x[b>>2]=1299020115;x[b+4>>2]=1869112133;x[e+256>>2]=0;d=a+906348|0;b=e+256|0;ZV(a+906332|0,d,b);x[23549]=0;b=O(54,b|0,9454)|0;g=x[23549];x[23549]=0;if((g|0)==1){break M}NB(d,b);tb(b);x[23549]=0;b=O(54,e+80|0,9447)|0;d=x[23549];x[23549]=0;if((d|0)==1){break M}Eu(a+906380|0,b);tb(b);x[23549]=0;b=O(54,e+68|0,9439)|0;d=x[23549];x[23549]=0;if((d|0)==1){break M}NB(a+906508|0,b);tb(b)}b=0;while(1){if(z[a+480188>>1]>b>>>0){uB(a,b&65535);d=(b<<5)+a|0;v[d+480288|0]=c;w[d+480284>>1]=b<<8&256;b=b+1|0;continue}break}x[23549]=0;b=O(1,e+56|0,11955)|0;c=x[23549];x[23549]=0;Ea:{Fa:{Ga:{if((c|0)!=1){zb(a+1298344|0,b);tb(b);x[23549]=0;b=O(1,e+44|0,12173)|0;c=x[23549];x[23549]=0;if((c|0)==1){break M}zb(a+1298356|0,b);tb(b);if(Y){break Ga}x[23549]=0;b=O(1,e+32|0,11955)|0;c=x[23549];x[23549]=0;if((c|0)==1){break M}break Fa}break M}if(ph(x[l>>2],x[l+4>>2])>>>0<=128){x[23549]=0;b=O(1,e+32|0,9196)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break Fa}break M}x[23549]=0;b=O(1,e+32|0,14464)|0;c=x[23549];x[23549]=0;if((c|0)==1){break Ea}}zb(a+1298368|0,b);tb(b);x[a+1298404>>2]=13;_Q(F);QQ(u);PQ(I);d=1;break m}}c=N()|0;_Q(F);break j}jl(e+56|0);continue}}c=N()|0;break a}c=N()|0;break a}Gt(l);sc(t);ql(r);vi(q);break c}c=N()|0;break j}c=N()|0}QQ(u);PQ(I);break a}c=N()|0;tb(b);break a}c=N()|0;break a}ub(c);x[23549]=0;c=d&65535;d=U(666,a|0,c|0,i|0)|0;g=x[23549];x[23549]=0;Ha:{Ia:{Ja:{Ka:{if((g|0)==1){break Ka}if(d){break Ha}x[23549]=0;d=U(667,a|0,c|0,i|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break Ka}if(d){break Ha}x[23549]=0;d=U(668,a|0,c|0,i|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break Ka}if(d){break Ha}x[23549]=0;d=O(669,(D(c,104)+a|0)+484380|0,i|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break Ka}if(d){break Ha}x[23549]=0;d=O(1,e+420|0,15781)|0;g=x[23549];x[23549]=0;if((g|0)==1){break Ja}g=x[a+1298464>>2];x[23549]=0;S(359,g|0,2,d|0);g=x[23549];x[23549]=0;if((g|0)==1){break Ia}tb(d);break Ha}c=N()|0;break e}c=N()|0;break e}c=N()|0;tb(d);break e}La:{Ma:{Na:{F=D(c,104)+a|0;if(y[F+484414|0]&64){d=z[m>>1];if(Th(d)){break Na}}d=x[l>>2];if(ph(d,x[l+4>>2])>>>0<=c>>>0){break Ma}if(y[qm(d,c)+132|0]!=2){break Ma}c=z[m>>1];if(!Th(c)){break Ma}w[m>>1]=c+1;break Ma}c=d+1|0;w[a+480190>>1]=c;G=D(c&65535,104)+a|0;o=G+484380|0;h=F+484380|0;g=x[h>>2];c=x[h+20>>2];Oa:{if(!Sd(g,c)){break Oa}f=z[h+34>>1];if((h|0)==(o|0)|(Jd(f)|0)!=2){break Oa}d=(h|0)==(o|0);if(!(Sd(x[o>>2],x[o+20>>2])?d:1)){break Oa}Sd(x[h>>2],x[h+20>>2]);if(!d){c=Bt(g,Sm(f))}f=x[h+20>>2];if(!(f?c:0)){if(!d){Ez(c)}break Oa}Pa:{Qa:{switch(Sm(z[h+34>>1])-1|0){case 1:g=c;d=f;k=x[h+20>>2];n=x[h>>2];while(1){if(n){w[g>>1]=z[k>>1];w[d>>1]=z[k+2>>1];k=k+4|0;d=d+2|0;g=g+2|0;n=n-1|0;continue}break};break Pa;case 0:break Qa;default:break Pa}}g=c;d=f;k=x[h+20>>2];n=x[h>>2];while(1){if(n){v[g|0]=y[k|0];v[d|0]=y[k+1|0];k=k+2|0;d=d+1|0;g=g+1|0;n=n-1|0;continue}break}}d=ro(o,h);w[d+34>>1]=z[d+34>>1]&65471;x[o+20>>2]=c;g=ro(h,h);w[g+34>>1]=z[g+34>>1]&65471;x[h+20>>2]=f;f=a+1298224|0;c=a+1074992|0;while(1){if((c|0)!=(f|0)){h=x[c+104>>2];if(!((h|0)!=(d|0)&(g|0)!=(h|0))){x[c+88>>2]=x[c+88>>2]&-65}c=c+872|0;continue}break}dj(d,a);dj(g,a)}x[23549]=0;c=O(54,e+408|0,6261)|0;d=x[23549];x[23549]=0;if((d|0)==1){break La}Ce(G+484423|0,c);tb(c);x[23549]=0;c=O(54,e+396|0,6164)|0;d=x[23549];x[23549]=0;if((d|0)==1){break f}Ce(F+484423|0,c);tb(c)}ub(i);bc(u);i=0;continue}break}c=N()|0;break e}c=N()|0}ub(i)}bc(u);break a}db=e+608|0;return d|0}c=N()|0}Gt(l);sc(t);ql(r);vi(q);Q(c|0);p()}function Wt(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,R=0,T=0,X=0,Y=0,Z=0,_=0,$=0,ba=0,ca=0,da=0,ga=0,ha=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,va=0,wa=E(0),xa=0,ya=0,za=0,Aa=E(0);i=db-192|0;db=i;Y=Nb(a);u=i+160|0;v[u+26|0]=0;w[u+24>>1]=0;x[u+16>>2]=0;x[u+20>>2]=-1;x[u+8>>2]=-1;x[u+12>>2]=-1;x[u>>2]=0;x[u+4>>2]=0;ga=x[d+16>>2];a=y[d+6|0];g=x[b+484360>>2];ka=(xa=a,ya=y[b+484376|0],za=bj(g,x[b+484364>>2])>>>0>a>>>0,za?xa:ya);a=ka&255;J=jj(g,a);x[23549]=0;F=O(543,i+128|0,b|0)|0;g=x[23549];x[23549]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((g|0)!=1){k=x[F+4>>2];x[23549]=0;H=U(544,i+92|0,b|0,a|0)|0;a=x[23549];x[23549]=0;if((a|0)==1){break h}qa=b+484360|0;$=c&7;e=x[d>>2];a=z[d+4>>1];while(1){g=a&65535;if(Ic(x[J>>2],x[J+4>>2])>>>0<=g>>>0){break f}x[23549]=0;g=O(299,J|0,g|0)|0;q=x[23549];x[23549]=0;if((q|0)==1){break g}if(g){break f}a=a+1|0;e=0;continue}}a=N()|0;break c}a=N()|0;break d}a=N()|0;break e}x[d>>2]=e;w[d+4>>1]=a;x[k+52>>2]=e;x[k+48>>2]=e;x[u+16>>2]=e;w[k+74>>1]=a;w[k+72>>1]=a;w[u+24>>1]=a;la=Xd(i+84|0);ma=xc(i+80|0);i:{if(($|0)!=7){break i}bl(bl(bl(bl(bl(bl(bl(bl(la,1),2),3),28),38),40),39),41);CO(CO(ma,12),13);if((ga|0)!=2){break i}a=x[J>>2];e=Ic(a,x[J+4>>2]);g=z[d+12>>1];if(e>>>0<=g>>>0){break i}e=x[b+484344>>2];f=x[b+484348>>2];a=z[_b(a,g)>>1];if(!se(e,f,a)){break i}g=Yb(e,a);e=x[d+8>>2];if(A[g+12>>2]<=e>>>0){break i}a=0;m=$c(x[g>>2],x[x[g+48>>2]+12>>2],e,0);g=x[F+8>>2];e=z[b+480188>>1];q=z[b+480192>>1];while(1){if((a|0)==(e|0)){break i}j:{k:{l:{m:{h=y[m|0];switch(h-253|0){case 1:case 2:break k;case 0:break m;default:break l}}if(q){break k}}if(!Tc(h)){break j}if(az(y[m+2|0],y[m+3|0])){break j}}xa=Qe(g,a),ya=-1,x[xa>>2]=ya}m=m+6|0;a=a+1|0;continue}}Z=c&1;if(Z){BO(k+223860|0)}R=k+74|0;K=k+48|0;ra=k+223872|0;T=k+80|0;sa=b+901692|0;ta=b+902204|0;ba=k+44|0;ha=k+223860|0;_=k+20|0;G=b+1074312|0;na=k+616|0;ca=32768;va=($|0)!=7;q=0;n:{o:{p:{q:{r:{s:{t:{u:{v:while(1){oa=C[d+8>>3];o(+oa);g=j(1)|0;a=j(0)|0;n=x[d+16>>2];e=a;while(1){AO(i+16|0,x[b+480180>>2],z[b+480188>>1],k,X&1);l=y[i+16|0];if((n|0)==3&C[F+24>>3]>=oa){break o}a=65535;h=x[J>>2];f=Ic(h,x[J+4>>2]);t=z[k+72>>1];if(f>>>0>t>>>0){a=z[_b(h,t)>>1]}w[k+70>>1]=a;s=x[b+484344>>2];h=x[b+484348>>2];f=a&65535;if(!(se(s,h,f)|(n|0)!=2|(f|0)==65535)&(t|0)==(g&65535)){break o}w:{while(1){r=qf(s,h);t=x[J>>2];while(1){f=a&65535;if(f>>>0<r>>>0){break w}a=z[k+72>>1];x:{y:{if((f|0)!=65535){f=Ic(t,x[J+4>>2]);if(a>>>0<f>>>0){break y}}m=z[J+28>>1];if((a|0)==(m|0)){break w}f=Ic(t,x[J+4>>2]);break x}m=a+1|0}w[k+72>>1]=m;a=65535;I=f;f=m&65535;if(I>>>0>f>>>0){a=z[_b(t,f)>>1]}w[k+74>>1]=m;w[k+70>>1]=a;if(se(s,h,a&65535)){continue}break}a=Qp(i+16|0,na);x[23549]=0;a=fa(545,H|0,m&65535,0,a|0,(l|0)!=0|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break s}if(!a){h=x[b+484348>>2];s=x[b+484344>>2];a=z[k+70>>1];continue}break}if(ga>>>0<=1){a=z[k+72>>1];x[u+8>>2]=0;w[u+20>>1]=a}if(!n){break w}x[23549]=0;a=U(546,H|0,R|0,K|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break r}if(!a){break w}C[u>>3]=C[F+24>>3];x[23549]=0;P(547,Y|0,u|0);a=x[23549];x[23549]=0;if((a|0)==1){break r}x[u+16>>2]=x[K>>2];w[u+24>>1]=z[R>>1];x[23549]=0;W(548,F|0);a=x[23549];x[23549]=0;if((a|0)==1){break r}a=z[k+74>>1];w[k+72>>1]=a;xa=k,ya=z[_b(x[J>>2],a)>>1],w[xa+70>>1]=ya;x[k+52>>2]=x[k+48>>2]}if(z[R>>1]==65535){break n}a=x[b+484344>>2];h=z[k+70>>1];if(!se(a,x[b+484348>>2],h)){a=z[k+72>>1];if((a|0)==z[J+28>>1]){if(!n){break p}x[23549]=0;a=U(546,H|0,R|0,K|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break r}if(!a){break q}C[u>>3]=C[F+24>>3];x[23549]=0;P(547,Y|0,u|0);a=x[23549];x[23549]=0;if((a|0)==1){break r}x[u+16>>2]=x[K>>2];w[u+24>>1]=z[R>>1];x[23549]=0;W(548,F|0);a=x[23549];x[23549]=0;if((a|0)==1){break r}x[k+52>>2]=x[k+48>>2];continue}w[R>>1]=a+1;continue}break}f=x[K>>2];if(f>>>0>=A[Yb(a,h)+12>>2]){x[K>>2]=0;f=0}z:{A:{if((n|0)==2){if(z[k+72>>1]!=(g&65535)){break A}if((e|0)==(f|0)){break o}break A}a=0;if((n|0)==3){break z}}a=0;if(A[H+28>>2]<ca>>>0){break z}x[F+24>>2]=0;x[F+28>>2]=2146435072;x[H+28>>2]=0;ca=ca>>>(ca>>>0>256)|0;f=x[K>>2];a=1}g=z[k+72>>1];e=Qp(i+16|0,na);x[23549]=0;g=fa(545,H|0,g|0,f|0,e|0,(l|0)!=0|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break u}if((a|g)==1){if(ga>>>0<=1){w[u+20>>1]=z[k+72>>1];x[u+8>>2]=x[k+48>>2]}if(!n){break p}x[23549]=0;a=U(546,H|0,R|0,K|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break t}if(!a){break q}C[u>>3]=C[F+24>>3];x[23549]=0;P(547,Y|0,u|0);a=x[23549];x[23549]=0;if((a|0)==1){break t}x[u+16>>2]=x[K>>2];w[u+24>>1]=z[R>>1];x[23549]=0;W(548,F|0);a=x[23549];x[23549]=0;if((a|0)==1){break t}x[k+52>>2]=x[k+48>>2];continue}w[u+22>>1]=z[k+72>>1];x[u+12>>2]=x[k+48>>2];zO(b,k,0);m=x[k+48>>2];g=Yb(x[b+484344>>2],z[k+70>>1]);if(m>>>0>=A[g+12>>2]){x[K>>2]=0;m=0}if(l){continue}a=0;m=$c(x[g>>2],x[x[g+48>>2]+12>>2],m,0);Fb(i+16|0,G,77);l=Ib(x[x[i+16>>2]>>2],x[i+20>>2]);B:{while(1){if(z[b+480188>>1]>a>>>0){C:{if(!(!$y(m)&(!l|!(y[((a<<5)+b|0)+480281|0]&4)))){qo((k+D(a,872)|0)+1404|0);break C}if(Sg(y[m|0])){D:{if(!vd(y[k+223884|0])){break D}g=y[m+1|0];if(g-251>>>0<5|!g){break D}h=y[m+5|0];s=y[m+3|0];t=Qj(y[m+2|0],y[m+4|0]);e=i+16|0;v[e|0]=g-1;x[e+4>>2]=t&65535;x[23549]=0;g=O(549,ra|0,e|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break B}xa=g,Aa=E(E(Qj(s,h)>>>0)/E(999)),B[xa>>2]=Aa}qo((k+D(a,872)|0)+1404|0);break C}g=k+D(a,872)|0;e=g+1408|0;h=y[m+4|0]|y[m+5|0]<<8;v[e|0]=h;v[e+1|0]=h>>>8;e=g+1404|0;h=y[m|0]|y[m+1|0]<<8|(y[m+2|0]<<16|y[m+3|0]<<24);v[e|0]=h;v[e+1|0]=h>>>8;v[e+2|0]=h>>>16;v[e+3|0]=h>>>24;E:{F:{G:{H:{switch(y[m+3|0]-16|0){case 0:e=y[m+5|0];break G;case 3:break E;case 4:break F;case 1:break H;default:break C}}Fb(i+16|0,G,5);if(!Ib(x[x[i+16>>2]>>2],x[i+20>>2])){break C}e=y[m+5|0];if(!e){break C}}xO(b,k,e&255);break C}e=g+1409|0;h=y[e|0];I:{if(!(h|!(x[b+480180>>2]&16777250))){v[e|0]=y[g+1449|0];break I}v[g+1449|0]=h}g=y[m+5|0];e=g&240;if((e|0)!=224){if((e|0)!=96){break C}x[k+24>>2]=x[k+24>>2]+(g&15);break C}if(x[_>>2]){break C}g=g&15;if(g?0:y[b+480180|0]&2){break C}x[_>>2]=g+1;break C}g=y[m+5|0];if((g&240)!=224){break C}x[_>>2]=(g&15)+1}m=m+6|0;a=a+1|0;continue}break}g=al(k);x[i+16>>2]=1;a=x[Yc(_,i+16|0)>>2];w[k+68>>1]=65535;x[k+60>>2]=-1;x[k+64>>2]=-1;M=g-1|0;a=g-a|0;ja=D(a,1e4);m=0;while(1){J:{K:{L:{M:{N:{if(z[b+480188>>1]<=m>>>0){if(x[b+480180>>2]!=4|x[k+40>>2]!=65535){break N}x[k+52>>2]=x[k+48>>2];w[k+74>>1]=z[k+72>>1];continue v}l=k+D(m,872)|0;e=l+1404|0;if($y(e)){break J}s=l+616|0;L=l+1409|0;f=y[L|0];da=l+1407|0;t=y[da|0];if(!Z){break L}n=y[e|0];h=n;r=l+1405|0;I=y[r|0];if(I){v[l+1415|0]=0;v[l+1419|0]=I;xa=Qe(x[F+8>>2],m),ya=255,v[xa+5|0]=ya;h=y[e|0]}if(Tc(h)){v[l+1415|0]=n;iQ(s);h=y[e|0]}O:{if(!(Tc(h)|y[r|0])){break O}I=l+1419|0;h=y[I|0];P:{if(!h){h=0;break P}if(z[b+480192>>1]<h>>>0){break P}r=x[((h<<2)+b|0)+900380>>2];if(!r|!(v[r+15|0]&1)){break P}Yp(s,x[r+8>>2],b);h=y[I|0]}h=_y(b,n,h&255);if(!h){break O}h=D(h,104)+b|0;if(!(y[h+484414|0]&32)){break O}Yp(s,z[h+484408>>1],b)}Q:{R:{S:{h=y[l+1406|0];switch(h-1|0){case 1:break L;case 2:case 3:break R;case 0:break S;default:break Q}}xa=Qe(x[F+8>>2],m),ya=y[l+1408|0],v[xa+5|0]=ya;break L}e=y[l+1408|0];if(!e){break L}v[l+1450|0]=e;break L}if((h|0)==11){break M}break L}x[k+32>>2]=x[b+480216>>2];a=Yb(x[b+484344>>2],z[k+70>>1]);e=x[a+16>>2];if(vO(e,x[a+20>>2])){x[k+32>>2]=e}e=uO(b,k);a=D(e,g);C[F+24>>3]=C[F+24>>3]+ +(a>>>0)/+A[b+24620>>2];x[k>>2]=a+x[k>>2];T:{U:{if(va){break U}m=0;ja=(q|0)!=0&(e|0)!=(q|0);while(1){if(z[b+480188>>1]<=m>>>0){break U}n=Qe(x[F+8>>2],m);V:{if(x[n>>2]==-1){break V}r=k+D(m,872)|0;X=r+1404|0;L=x[r+1316>>2];if(!L){if($y(X)){break V}}s=r+1409|0;h=1;W:{X:{M=r+1407|0;switch(y[M|0]-4|0){case 0:case 2:break W;default:break X}}h=y[r+1406|0]==11}a=y[s|0];if(y[r+1405|0]){x[r+1276>>2]=0}l=r+616|0;f=a&15;t=0;Y:{Z:{_:{if(!Tc(y[X|0])){break _}if(y[n+4|0]!=0&h){Zy(i+16|0,b,l,L,0);t=x[i+20>>2];x[r+624>>2]=x[i+16>>2];x[r+628>>2]=t}v[r+1418|0]=y[r+1415|0];L=r+1308|0;da=x[L>>2];t=y[r+1419|0];if(t){Pp(b,l,t,h,1,1)}t=y[X|0];x[23549]=0;ea(550,b|0,l|0,t|0,h|0,1,0,65535);t=x[23549];x[23549]=0;if((t|0)==1){break Z}a=a>>>4|0;tO(b,l);sO(x[b+480180>>2],z[b+480188>>1],k,m&65535);I=Qe(x[F+8>>2],m);v[I+4|0]=1;n=y[M|0];$:{if(!((y[s|0]&240)!=208|(n-19&255)>>>0>1)){t=f;if(f>>>0<g>>>0){break $}}t=(n|0)==33?a>>>0<g>>>0?a:0:0}pa=x[_>>2];if(!(!(x[b+480180>>2]&16777250)|(!t|pa>>>0<2))){t=D(pa-1|0,x[k+24>>2]+x[k+40>>2]|0)+t|0}if(!h){x[I>>2]=0}aa:{if((n|0)==9){break aa}ba:{if((n|0)!=19){if((n|0)!=20|(a|0)!=8){break ba}break aa}if((a|0)==8){break aa}}if(y[r+1406|0]!=2){break _}}x[L>>2]=da}ca:{if(!Tc(y[X|0])){Fb(i+16|0,G,114);if(!Ib(x[x[i+16>>2]>>2],x[i+20>>2])){break ca}}da:{ea:{fa:{ga:{a=y[M|0];switch(a-42|0){case 1:break da;case 0:break ea;case 2:break fa;default:break ga}}if((a|0)!=10){break da}a=z[k+70>>1];n=x[k+48>>2];x[23549]=0;aa(551,b|0,l|0,m&65535,n|0,a|0);a=x[23549];x[23549]=0;if((a|0)!=1){break ca}break T}n=yka(y[s|0],0,x[r+692>>2],0);a=hb;L=a>>>8|0;fo(b,l,Qc((a&255)<<24|n>>>8,L));break ca}if(!x[r+720>>2]){break da}x[23549]=0;V(552,F|0,m&65535,q|0,-1);a=x[23549];x[23549]=0;if((a|0)==1){break T}qO(l,y[s|0]);t=x[k+40>>2]-1|0;break ca}if(y[r+1406|0]!=15){break ca}n=x[r+720>>2];if(!n){break ca}a=y[r+1408|0];if(a>>>0>9){break ca}ha:{if(!a){n=x[r+1280>>2];break ha}n=x[xb(n+68|0,a-1|0)>>2];x[r+1280>>2]=n}fo(b,l,n)}ia:{ja:{ka:{switch(y[X|0]-253|0){case 0:if(z[b+480192>>1]){break ja}break;case 1:case 2:break ja;default:break ka}}a=y[M|0];if(!((y[s|0]&240)!=192|(a-19&255)>>>0>1)&f>>>0<g>>>0|(a|0)==25){break ja}n=0;if(!((a|0)==33&(f|0)!=0&g>>>0>f+t>>>0)){break ia}}a=y[M|0];n=1}I=r+1304|0;la:{if((a|0)!=13){if(y[r+1406|0]!=1){break la}f=r+1408|0}else{f=s}x[I>>2]=y[f|0]<<2}ma:{if(!(n|!x[r+720>>2])){n=0;na:{oa:{pa:{if(a>>>0>45){break pa}Fb(i+16|0,la,a);if(Ib(x[x[i+16>>2]>>2],x[i+20>>2])){break oa}if(y[M|0]!=19){break pa}n=(y[s|0]-16&255)>>>0<32}a=y[r+1406|0];if(a>>>0<16){break na}if(n){break ma}break Y}n=1;a=y[r+1406|0];if(a>>>0>=16){break ma}}Ll(i+16|0,ma,a);a=Ib(x[x[i+16>>2]>>2],x[i+20>>2]);if(n){break ma}if(!a){break Y}break ma}if(!n){break Y}}kQ(l);xa=Qe(x[F+8>>2],m),ya=0,x[xa>>2]=ya;break V}a=N()|0;break e}if(ja){x[23549]=0;V(552,F|0,m&65535,q|0,-1);a=x[23549];x[23549]=0;if((a|0)==1){break T}}qa:{ra:{sa:{ta:{ua:{a=y[M|0];if(a-6>>>0>=2){va:{switch(a-19|0){case 1:break ta;case 0:break ua;default:break va}}if(a-35>>>0<2){break ra}if((a|0)==45){break sa}if((a|0)!=11){break qa}}if(!y[s|0]&x[b+480180>>2]==1){break qa}a=r+1467|0;f=0;while(1){if((f|0)==(g|0)){break qa}v[a|0]=!f|y[a|0]&254;eo(b,l,y[s|0]);f=f+1|0;continue}}s=y[s|0];a=s&15;if(!(a|x[b+480180>>2]&1048580)){break qa}f=r+1467|0;v[f|0]=y[f|0]|1;s=s&240;if((s|0)!=176){if((s|0)!=160){break qa}co(b,l,a,0);break qa}bo(b,l,a,0);break qa}wa:{xa:{ya:{a=y[s|0];switch(a-158|0){case 1:break xa;case 0:break ya;default:break wa}}x[23549]=0;V(552,F|0,m&65535,q|0,-1);a=x[23549];x[23549]=0;if((a|0)==1){break T}x[r+704>>2]=x[r+704>>2]&-129;break qa}x[23549]=0;V(552,F|0,m&65535,q|0,-1);a=x[23549];x[23549]=0;if((a|0)==1){break T}a=x[r+704>>2];x[r+704>>2]=a|128;if(x[l+4>>2]){break qa}s=x[r+692>>2];if(!s){break qa}if(!(xa=Tc(y[X|0]),ya=1,za=a&2,za?xa:ya)){break qa}x[l>>2]=-1;x[l+4>>2]=s-1;break qa}if((a&240)!=112|a>>>0<115){break qa}gQ(l,a,x[b+480180>>2]);break qa}pO(l,y[s|0]);break qa}x[23549]=0;a=m&65535;V(552,F|0,a|0,q|0,-1);s=x[23549];x[23549]=0;if((s|0)==1){break T}xa=r+1390|0,ya=oO(b,z[k+70>>1],x[k+48>>2],a),w[xa>>1]=ya}f=r+1467|0;a=y[f|0]|1;v[f|0]=a;za:{Aa:{Ba:{Ca:{Da:{n=r+1406|0;switch(y[n|0]-3|0){case 11:break Aa;case 0:case 1:break Ba;case 3:break Ca;case 2:break Da;default:break za}}a=y[r+1408|0];Fb(i+16|0,G,41);co(b,l,a,Ib(x[x[i+16>>2]>>2],x[i+20>>2]));break za}a=y[r+1408|0];Fb(i+16|0,G,41);bo(b,l,a,Ib(x[x[i+16>>2]>>2],x[i+20>>2]));break za}s=y[r+1408|0];Ea:{if(s){break Ea}Fb(i+16|0,G,41);s=0;if(!Ib(x[x[i+16>>2]>>2],x[i+20>>2])){break Ea}s=y[r+1450|0];if(!s){break za}}s=y[n|0]==3?s<<4:s;a=0;while(1){if((a|0)==(g|0)){break za}v[f|0]=!a|y[f|0]&254;eo(b,l,s&255);a=a+1|0;continue}}l=y[r+1408|0];if(l>>>0>1){break za}v[f|0]=a&247|!l<<3}if(y[f|0]&8){break V}if(h){h=Qe(x[F+8>>2],m);a=x[h>>2];x[h>>2]=a+g;x[23549]=0;V(552,F|0,m&65535,e|0,(a+t|0)+1|0);a=x[23549];x[23549]=0;if((a|0)!=1){break V}a=N()|0;break e}a=Qe(x[F+8>>2],m);x[a>>2]=x[a>>2]+(g-t|0)}m=m+1|0;continue}}X=nO(b,k,J,0);q=e;continue v}a=N()|0;break e}h=y[l+1408|0];if(!h){break L}n=i+16|0;Yy(n,b,y[e+3|0],h,0);w[l+1384>>1]=z[i+16>>1];if(y[Ue(n)|0]){break K}}Fa:{Ga:{Ha:{Ia:{Ja:{switch(t-12|0){case 0:mO(b,k,m&65535);break Fa;case 2:e=lO(b,k,m&65535,f);if((e|0)==-1){break Fa}x[k+60>>2]=e;break Fa;case 5:Fb(i+16|0,G,5);if(Ib(x[x[i+16>>2]>>2],x[i+20>>2])){break Fa}e=D(ao(b,z[k+70>>1],x[k+48>>2],m&65535,0),1e4);x[i+52>>2]=e;Ka:{if(!Z|!(x[b+480180>>2]&16777250)){break Ka}if(e>>>0>=1e4){v[l+1451|0]=(e>>>0)/1e4;break Ka}e=D(y[l+1451|0],1e4);x[i+52>>2]=e}h=x[b+8>>2];if(e>>>0>=32e4){x[i+16>>2]=D(x[h+24>>2],1e4);xa=ba,ya=x[Cb(i+52|0,i+16|0)>>2],x[xa>>2]=ya;break Fa}n=x[ba>>2];r=(e>>>0)/1e4|0;I=D(ja,r&15);e=n-I|0;x[ba>>2]=(r&240)==16?n+I|0:e>>>0<=n>>>0?e:0;e=x[h+20>>2];h=x[h+24>>2];Fb(i+16|0,G,8);To(ba,D(e,1e4),Ib(x[x[i+16>>2]>>2],x[i+20>>2])?255e4:D(h,1e4));break Fa;case 8:La:{switch((f&240)-144>>>4|0){case 0:if(f>>>0>145){break Fa}x[l+704>>2]=x[l+704>>2]&-257|((f|0)==145)<<8;break Fa;case 1:v[l+1452|0]=f&15;break Fa;case 2:break Ia;case 6:break La;default:break Fa}}v[l+1460|0]=f&15;break Fa;case 1:case 3:case 4:case 6:break Fa;case 7:break Ja;default:break Ga}}e=f&240;if((e|0)==240){break Ha}if((e|0)!=96){break Fa}}Wy(b,k,m&65535,f&15);break Fa}v[l+1460|0]=f&15;break Fa}if((t|0)!=28|(f&240)!=160){break Fa}Fb(i+16|0,G,58);if(Ib(x[x[i+16>>2]>>2],x[i+20>>2])){break Fa}v[l+1452|0]=f&15}if(!Z){break J}Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{switch(t-2|0){case 0:if(!f){break Ma}Fb(i+16|0,G,90);if(!Ib(x[x[i+16>>2]>>2],x[i+20>>2])){v[l+1428|0]=f}v[l+1427|0]=f;break K;case 1:if(!f){break Ma}Fb(i+16|0,G,90);if(!Ib(x[x[i+16>>2]>>2],x[i+20>>2])){v[l+1427|0]=f}v[l+1428|0]=f;break K;case 2:if(!f){break Ma}w[l+1384>>1]=f;break K;case 8:if(!f){break Ma}x[l+1280>>2]=f<<8;break K;case 4:case 9:if(!f){break Ma}v[l+1425|0]=f;break K;case 11:xa=Qe(x[F+8>>2],m),ya=f,v[xa+5|0]=ya;break K;case 21:e=x[b+480180>>2];f=f<<(!(e&59593760)&f<<24>>24>=0);h=f&255;if(h>>>0<=128){x[T>>2]=h<<1;break K}if(e&16777250){break K}x[T>>2]=256;break K;case 22:Fb(i+16|0,G,9);Va:{if(Ib(x[x[i+16>>2]>>2],x[i+20>>2])){e=l+1433|0;if(f){v[e|0]=f;break Va}f=y[e|0];break Va}if(f){v[k+1433|0]=f;break Va}f=y[k+1433|0]}e=f&15;h=f&255;Wa:{if(!((e|0)!=15|h>>>0<16)){f=(f&240)>>>4<<!(x[b+480180>>2]&59593760);e=x[T>>2]+(f<<1)|0;break Wa}h=h&240;if(!(!e|(h|0)!=240)){f=e<<(x[b+480180>>2]&59593760?1:2);e=x[T>>2]-f|0;break Wa}if(h){f=(f>>>3&30)<<!(x[b+480180>>2]&59593760);e=x[T>>2]+D(a,f)|0;break Wa}f=e<<(x[b+480180>>2]&59593760?1:2);e=x[T>>2]-D(a,f)|0}x[T>>2]=e;ke(T,0,256);break K;case 19:if(f>>>0>64){break K}x[l+1364>>2]=f;break K;case 20:e=l+1432|0;Xa:{if(f){v[e|0]=f;break Xa}f=y[e|0]}n=l+1364|0;e=x[n>>2];h=f&15;t=f&255;Ya:{if(!((h|0)!=15|t>>>0<16)){x[i+16>>2]=e+(t>>>4|0);break Ya}if(!(!h|(t&240)!=240)){x[i+16>>2]=e-h;break Ya}if(h){x[i+16>>2]=e-D(a,h);break Ya}x[i+16>>2]=e+D(a,t>>>4|0)}ke(i+16|0,0,64);x[n>>2]=x[i+16>>2];break K;case 7:im(b,s,f,8);break K;case 29:case 30:break Na;case 25:break Oa;case 6:break Pa;case 24:break Qa;case 3:break Ra;case 5:break Sa;case 18:break Ta;case 17:break Ua;default:break K}}if(f>>>0>15){break Ta}h=(f&1)<<14;t=z[b+480188>>1];e=0;while(1){if((e|0)==(t|0)){break Ta}n=k+D(e,872)|0;x[n+704>>2]=(h|x[n+704>>2]&-16385)^16384;e=e+1|0;continue}}if((f&240)!=128){break K}im(b,s,f&15,4);break K}if(f){v[l+1425|0]=f}f=0}$k(s,f);break K}jO(b,s,f);break K}iO(s,f);break K}hO(s,f);break K}Za:{if(f<<24>>24>=0){e=te(sa,y[l+1460|0]);break Za}e=te(ta,f&127)}h=y[L|0];x[23549]=0;ia(553,b|0,k|0,m&65535,0,e|0,h|0);e=x[23549];x[23549]=0;if((e|0)!=1){break K}a=N()|0;break e}f=0}_a:{$a:{switch(y[l+1406|0]-2|0){case 0:im(b,s,y[l+1408|0],6);break _a;case 5:Fb(i+16|0,G,53);e=y[l+1408|0];if(Ib(x[x[i+16>>2]>>2],x[i+20>>2])){v[l+1439|0]=e&15;break _a}$k(s,e<<4);break _a;case 6:break $a;default:break _a}}$k(s,y[l+1408|0])}ab:{bb:{cb:{db:{eb:{e=y[da|0];switch(e-5|0){case 1:break ab;case 3:break cb;case 0:case 2:break db;default:break eb}}switch(e-26|0){case 1:break bb;case 0:break db;default:break ab}}fb:{if(x[b+480180>>2]&16777248){e=g;if(!(y[b+480208|0]&4)){break fb}}e=a}h=y[l+1439|0];Fb(i+16|0,G,21);l=l+1435|0;t=y[l|0];e=D(e,h);xa=l,ya=(Ib(x[x[i+16>>2]>>2],x[i+20>>2])?e<<2:e)+t|0,v[xa|0]=ya;break ab}gb:{if(x[b+480180>>2]&16777248){e=g;if(!(y[b+480208|0]&4)){break gb}}e=a}h=y[l+1442|0];Fb(i+16|0,G,21);l=l+1436|0;t=y[l|0];e=D(e,h);xa=l,ya=(Ib(x[x[i+16>>2]>>2],x[i+20>>2])?e<<2:e)+t|0,v[xa|0]=ya;break ab}e=l+1437|0;v[e|0]=y[e|0]+D(M,y[l+1445|0]);fO(b,s)}Fb(i+16|0,G,78);if(!Ib(x[x[i+16>>2]>>2],x[i+20>>2])){break J}e=f&255;if(!e){break J}eO(s,e)}m=m+1|0;continue}}break}a=N()|0;break e}a=N()|0;break e}a=N()|0;break e}a=N()|0;break e}a=N()|0;break e}n=1;break n}n=0;break n}n=1;v[u+26|0]=1}hb:{if(($|0)!=7){break hb}a=0;while(1){if(z[b+480188>>1]<=a>>>0){break hb}ib:{if(x[Qe(x[F+8>>2],a)>>2]==-1){break ib}x[23549]=0;V(552,F|0,a&65535,q|0,-1);d=x[23549];x[23549]=0;if((d|0)!=1){break ib}a=N()|0;break e}a=a+1|0;continue}}if(y[u+26|0]){w[u+20>>1]=z[k+72>>1];x[u+8>>2]=x[k+48>>2]}C[u>>3]=C[F+24>>3];x[23549]=0;P(547,Y|0,u|0);a=x[23549];x[23549]=0;jb:{kb:{lb:{mb:{if((a|0)!=1){if(!Z){break a}if(!(n?y[u+26|0]:1)){break lb}e=Qy(i+52|0);if(vd(y[ha+24|0])){UN(e,ha)}Vy(ha);a=rc(b+1074376|0,k,614);q=0;while(1){if((q|0)==256){zm(a+223848|0,k+223848|0);d=a+223860|0;q=y[d+24|0];g=k+223860|0;nb:{if((vd(y[g+24|0])|0)==(q|0)){if(!q){break nb}q=gc(d);dt(d,x[q>>2]);x[d>>2]=x[g>>2];x[d+4>>2]=x[g+4>>2];x[d+8>>2]=x[g+8>>2];ob:{if(!x[wb(d)>>2]){x[d>>2]=q;break ob}x[x[q>>2]+8>>2]=q;q=gc(g);x[g>>2]=q;x[q>>2]=0;xa=wb(g),ya=0,x[xa>>2]=ya}d=d+12|0;q=gc(d);ct(d,x[q>>2]);g=g+12|0;x[d>>2]=x[g>>2];x[d+4>>2]=x[g+4>>2];x[d+8>>2]=x[g+8>>2];pb:{if(!x[wb(d)>>2]){x[d>>2]=q;break pb}x[x[q>>2]+8>>2]=q;d=gc(g);x[g>>2]=d;x[d>>2]=0;xa=wb(g),ya=0,x[xa>>2]=ya}break nb}if(q){Vy(d);break nb}UN(d,g)}}else{d=D(q,872);Mp((d+a|0)+616|0,(d+k|0)+616|0);q=q+1|0;continue}break}Uy(a);x[b+1074400>>2]=0;v[b+1074476|0]=1;a=b+1074392|0;x[a>>2]=-2;x[a+4>>2]=0;x[b+1074428>>2]=x[b+1074424>>2];a=x[b+1298300>>2];if(ud(a)){break mb}break kb}a=N()|0;break e}x[23549]=0;W(554,a|0);a=x[23549];x[23549]=0;if((a|0)!=1){break kb}break jb}if((c|0)==3){break b}x[b+1074416>>2]=x[b+480196>>2];x[b+1074420>>2]=x[b+480204>>2];x[b+1074456>>2]=x[b+480200>>2];break b}q=($|0)==7;a=0;while(1){if(z[b+480188>>1]<=a>>>0){a=mA(i+16|0);xa=i,ya=kj(x[e+12>>2]),x[xa+12>>2]=ya;h=Bf(e+12|0);while(1){d=x[i+12>>2];if(!xg(d,h)){qb:{q=250;d=a;rb:{while(1){if(q>>>0>=32){if(x[a>>2]){a=1;break rb}else{q=q-32|0;a=a+4|0;continue}}break}a=(x[d+28>>2]&67108863)!=0}if(!a){break qb}a=0;while(1){if((a|0)==250){break qb}Fb(i+4|0,d,a);sb:{if(!Ib(x[x[i+4>>2]>>2],x[i+8>>2])){break sb}g=x[(D(a,160)+b|0)+906300>>2];q=x[x[g>>2]+176>>2];x[23549]=0;W(q|0,g|0);g=x[23549];x[23549]=0;if((g|0)!=1){break sb}break jb}a=a+1|0;continue}}xa=i,ya=kj(x[e>>2]),x[xa+4>>2]=ya;a=Bf(e);while(1){d=x[i+4>>2];if(xg(d,a)){d=td(d);xa=(D(y[d|0],160)+b|0)+906444|0,Aa=B[gc(d)>>2],B[xa>>2]=Aa;Vg(i+4|0);continue}else{Op(e);break b}}}g=td(d);l=wb(g);tb:{q=y[g|0];d=x[(D(q,160)+b|0)+906300>>2];if(d){Fb(i+4|0,a,q);if(!Ib(x[x[i+4>>2]>>2],x[i+8>>2])){x[23549]=0;O(555,a|0,q|0)|0;q=x[23549];x[23549]=0;if((q|0)==1){break tb}q=x[x[d>>2]+172>>2];x[23549]=0;P(q|0,d|0,-1);q=x[23549];x[23549]=0;if((q|0)==1){break tb}}wa=B[l>>2];g=x[g+4>>2];q=x[x[d>>2]+44>>2];x[23549]=0;ua(q|0,d|0,g|0,E(wa));d=x[23549];x[23549]=0;if((d|0)==1){break tb}}Vg(i+12|0);continue}break}break jb}d=D(a,872)+b|0;g=y[d+1075791|0];if(g){v[d+1075794|0]=g}g=Qe(x[F+8>>2],a);if(!(y[g+5|0]==255|q)){v[i+16|0]=64;xa=d+1075680|0,ya=y[Sb(g+5|0,i+16|0)|0]<<2,x[xa>>2]=ya}ub:{g=x[d+1075096>>2];vb:{if(!g|!(y[g+35|0]&2)){break vb}h=x[b+1298300>>2];if(!ud(h)){break vb}x[23549]=0;f=h;h=a&65535;S(556,f|0,h|0,g+68|0);g=x[23549];x[23549]=0;if((g|0)==1){break ub}g=x[b+1298300>>2];x[23549]=0;S(557,g|0,h|0,1);g=x[23549];x[23549]=0;if((g|0)==1){break ub}}x[d+1075008>>2]=0;a=a+1|0;continue}break}}a=N()|0;Op(e)}gt(H)}cO(F)}vi(Y);Q(a|0);p()}a=ka&255;if((a|0)==y[b+484376|0]){break a}oj(qa,a)}if(c&9){a=b+1298264|0;if(x[a>>2]){aP(a);b=x[a>>2];tk(a);Eb(b);xa=wb(a),ya=0,x[xa>>2]=ya;x[a>>2]=0;x[a+4>>2]=0}x[a>>2]=x[H>>2];x[a+4>>2]=x[H+4>>2];b=wb(H);xa=wb(a),ya=x[b>>2],x[xa>>2]=ya;x[b>>2]=0;x[H>>2]=0;x[H+4>>2]=0;a=a+12|0;c=gc(a);Sp(a,x[c>>2]);b=H+12|0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];wb:{if(!x[wb(a)>>2]){x[a>>2]=c;break wb}x[x[c>>2]+8>>2]=c;a=gc(b);x[b>>2]=a;x[a>>2]=0;xa=wb(b),ya=0,x[xa>>2]=ya}}gt(H);cO(F);db=i+192|0}function cT(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=0,q=0,r=0,s=E(0),t=E(0),u=0,C=0,F=0,G=E(0),H=0,I=0,J=E(0),K=0,L=E(0),M=0,N=E(0),O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=E(0),W=E(0),X=0,Y=0,Z=0,$=0,aa=E(0),ba=E(0),ca=E(0),da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0;$=db-16|0;db=$;a:{if(x[a+1420>>2]>=0){x[f>>2]=0;e=x[a+1420>>2];d=(e|0)>0?e:0;while(1){if((d|0)!=(g|0)){x[(D(g,20)+a|0)+1436>>2]=0;g=g+1|0;continue}break}b:{c:{d:{if((e|0)>3){break d}g=0;if((c|0)<4){break c}c=c-3|0;d=0;while(1){if((c|0)==(d|0)){break d}e:{f:{j=b+d|0;if(y[j|0]!=79|(y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24))!=(y[93220]|y[93221]<<8|(y[93222]<<16|y[93223]<<24))){break f}q=d+26|0;if((q|0)>=(c|0)){break e}n=d+27|0;i=b+q|0;f=y[i|0];if((n+f|0)>=(c|0)){break e}h=f+27|0;g=0;while(1)if((f|0)==(g|0)){g=0;Q=0;while(1){f=22;if((g|0)!=22){Q=fx(Q,y[(d+g|0)+b|0]);g=g+1|0;continue}break}while(1){if((f|0)!=26){f=f+1|0;Q=fx(Q,0);continue}break}x[a+1420>>2]=e+1;e=D(e,20)+a|0;x[e+1432>>2]=Q;x[e+1428>>2]=h-26;x[e+1424>>2]=y[j+22|0]|y[j+23|0]<<8|(y[j+24|0]<<16|y[j+25|0]<<24);f=y[(q+y[i|0]|0)+b|0]==255?-1:y[j+6|0]|y[j+7|0]<<8|(y[j+8|0]<<16|y[j+9|0]<<24);x[e+1436>>2]=q;x[e+1440>>2]=f;e=x[a+1420>>2];if((e|0)!=4){break f}e=4;break d}else{h=y[(g+n|0)+b|0]+h|0;g=g+1|0;continue}}d=d+1|0;continue}break}c=d}d=0;g:while(1){i=(d|0)>(e|0)?d:e;while(1){if((d|0)==(i|0)){break b}g=0;f=D(d,20)+a|0;m=f+1428|0;j=x[m>>2];q=x[f+1436>>2];n=c-q|0;h=(j|0)<(n|0)?j:n;k=(h|0)>0?h:0;Y=f+1432|0;Q=x[Y>>2];while(1){if((g|0)!=(k|0)){Q=fx(Q,y[(g+q|0)+b|0]);g=g+1|0;continue}break}x[m>>2]=j-h;x[Y>>2]=Q;if((j|0)<=(n|0)){f=f+1424|0;if(x[f>>2]==(Q|0)){x[a+1380>>2]=-1;x[a+992>>2]=0;x[a+1420>>2]=-1;b=x[(D(d,20)+a|0)+1440>>2];x[a+1060>>2]=b;x[a+1064>>2]=(b|0)!=-1;g=h+q|0;break c}e=e-1|0;x[a+1420>>2]=e;e=D(e,20)+a|0;x[f+16>>2]=x[e+1440>>2];g=e+1432|0;j=x[g+4>>2];x[f+8>>2]=x[g>>2];x[f+12>>2]=j;e=e+1424|0;g=x[e+4>>2];x[f>>2]=x[e>>2];x[f+4>>2]=g;e=x[a+1420>>2];continue g}else{d=d+1|0;continue}}}}c=g}break a}x[a+100>>2]=0;x[a+32>>2]=b;x[a+40>>2]=b+c;if(!DI(a)){x[f>>2]=0;c=0;break a}fa=db-16|0;db=fa;ha=$+4|0;x[a+1504>>2]=0;x[a+1508>>2]=0;h:{if(x[a+96>>2]){break h}i:{j:{k:{if(x[a+1380>>2]!=-1){break k}c=Ne(a);if(x[a+96>>2]){break i}if((c|0)!=79){break j}if((Ne(a)|0)!=103){break j}if((Ne(a)|0)!=103){break j}if((Ne(a)|0)!=83){break j}if(!CI(a)){break i}if(!(v[a+1375|0]&1)){break k}v[a+1376|0]=0;x[a+1384>>2]=0;cc(a,32);break i}j=bx(a);break i}cc(a,30)}if(!j){break h}if(nc(a,1)){cc(a,35);break h}l:{m:{if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){c=nc(a,Wl(x[a+408>>2]-1|0));if((c|0)==-1|(c|0)>=x[a+408>>2]){break h}x[fa+12>>2]=c;h=D(c,6)+a|0;if(!y[h+412|0]){g=x[a+112>>2];j=g>>1;break m}g=x[a+116>>2];j=g>>1;c=nc(a,1);k=nc(a,1);if(c|!y[h+412|0]){break m}x[ha>>2]=g-x[a+112>>2]>>2;c=x[a+112>>2]+g>>2;break l}_(6266,13048,3152,10617);p()}x[ha>>2]=0;c=j}x[fa+8>>2]=c;n:{if(!(!y[h+412|0]|k)){c=D(g,3);x[$+8>>2]=c-x[a+112>>2]>>2;g=c+x[a+112>>2]>>2;break n}x[$+8>>2]=j}x[fa+4>>2]=g;g=1}if(g){Y=x[ha>>2];ka=x[$+8>>2];ia=x[fa+4>>2];h=0;O=db-2368|0;db=O;o=x[a+404>>2];oa=D(x[fa+12>>2],6)+a|0;C=y[oa+413|0];T=o+D(C,40)|0;S=x[((y[oa+412|0]<<2)+a|0)+104>>2];da=S>>1;ra=0-da|0;o:{while(1){c=x[a+4>>2];if((c|0)>(h|0)){c=y[(x[T+4>>2]+D(h,3)|0)+2|0];H=(O+1344|0)+(h<<2)|0;x[H>>2]=0;g=y[(c+T|0)+9|0];if(z[((g<<1)+a|0)+132>>1]){j=x[a+260>>2];p:{q:{if(!nc(a,1)){break q}c=2;n=x[((h<<2)+a|0)+996>>2];q=j+D(g,1596)|0;F=x[(y[q+1588|0]<<2)+71756>>2];g=Wl(F)-1|0;ta=n,ua=nc(a,g),w[ta>>1]=ua;ta=n,ua=nc(a,g),w[ta+2>>1]=ua;i=0;while(1){if(y[q|0]>i>>>0){K=y[(i+q|0)+1|0];g=K+q|0;r=y[g+49|0];m=-1<<r;k=y[g+33|0];r:{if(!r){j=0;break r}g=x[a+124>>2]+D(y[g+65|0],2096)|0;if(x[a+1396>>2]<=9){Ok(a)}j=x[a+1392>>2];I=w[(g+((j&1023)<<1)|0)+36>>1];s:{if((I|0)>=0){u=j;I=I&65535;j=y[I+x[g+8>>2]|0];x[a+1392>>2]=u>>>j;j=x[a+1396>>2]-j|0;x[a+1396>>2]=(j|0)>0?j:0;j=(j|0)<0?-1:I;break s}j=Vl(a,g)}if(!y[g+23|0]){break r}j=x[x[g+2088>>2]+(j<<2)>>2]}I=m^-1;g=c+k|0;while(1){if((c|0)!=(g|0)){m=0;k=w[((q+(K<<4)|0)+((j&I)<<1)|0)+82>>1];t:{if((k|0)<0){break t}k=x[a+124>>2]+D(k&65535,2096)|0;if(x[a+1396>>2]<=9){Ok(a)}m=x[a+1392>>2];P=w[(k+((m&1023)<<1)|0)+36>>1];u:{if((P|0)>=0){u=m;P=P&65535;m=y[P+x[k+8>>2]|0];x[a+1392>>2]=u>>>m;m=x[a+1396>>2]-m|0;x[a+1396>>2]=(m|0)>0?m:0;m=(m|0)<0?-1:P;break u}m=Vl(a,k)}if(!y[k+23|0]){break t}m=x[x[k+2088>>2]+(m<<2)>>2]}j=j>>r;w[n+(c<<1)>>1]=m;c=c+1|0;continue}break}i=i+1|0;c=g;continue}break}if(x[a+1396>>2]==-1){break q}w[O+320>>1]=257;c=2;while(1){m=x[q+1592>>2];if((m|0)<=(c|0)){c=0;while(1){if((c|0)>=(m|0)){break p}if(!y[(O+320|0)+c|0]){w[n+(c<<1)>>1]=65535;m=x[q+1592>>2]}c=c+1|0;continue}}else{g=q+338|0;j=c<<1;m=j+q|0;r=y[m+1088|0];k=r<<1;i=z[g+k>>1];H=y[m+1089|0];K=H<<1;I=w[k+n>>1];m=w[K+n>>1]-I|0;k=m>>31;g=(D((k^m)-k|0,z[g+j>>1]-i|0)|0)/(z[g+K>>1]-i|0)|0;m=I+((m|0)<0?0-g|0:g)|0;k=j+n|0;j=z[k>>1];v:{w:{if(j){g=O+320|0;v[g+H|0]=1;v[g+r|0]=1;v[c+g|0]=1;g=j<<16>>16;i=F-m|0;if((g|0)>=((i|0)<(m|0)?i:m)<<1){if((i|0)>(m|0)){break v}m=F+(j^-1)|0;break w}if(g&1){m=m-(g+1>>>1|0)|0;break w}m=(g>>1)+m|0;break w}v[(O+320|0)+c|0]=0}w[k>>1]=m}c=c+1|0;continue}}}x[H>>2]=1}h=h+1|0;continue}else{cc(a,21);c=0;break o}}break}if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){rc(O+320|0,O+1344|0,c<<2);j=z[T>>1];c=0;while(1){if((c|0)==(j|0)){la=o+D(C,40)|0}else{h=x[T+4>>2]+D(c,3)|0;g=y[h+1|0];m=O+1344|0;h=m+(y[h|0]<<2)|0;if(!(x[(g<<2)+m>>2]?x[h>>2]:0)){x[(O+1344|0)+(g<<2)>>2]=0;x[h>>2]=0}c=c+1|0;continue}break}j=0;while(1){x:{if(y[la+8|0]>j>>>0){m=0;c=x[a+4>>2];q=(c|0)>0?c:0;c=0;while(1){if((c|0)==(q|0)){break x}if(y[(x[T+4>>2]+D(c,3)|0)+2|0]==(j|0)){n=m+O|0;h=c<<2;y:{if(x[h+(O+1344|0)>>2]){h=0;g=1;break y}h=x[(a+h|0)+800>>2];g=0}v[n|0]=g;x[(O+256|0)+(m<<2)>>2]=h;m=m+1|0}c=c+1|0;continue}}if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){h=(da|0)>0?da:0;g=z[T>>1];j=a+800|0;z:while(1){if((g|0)<=0){K=da<<2;m=0;c=0;while(1){j=x[a+4>>2];if((j|0)<=(c|0)){while(1){if((j|0)>(m|0)){T=y[oa+412|0];H=S>>1;g=H<<2;la=x[a+92>>2];k=S>>3;P=S>>2;j=x[((m<<2)+a|0)+800>>2];c=H<<2;K=j+c|0;A:{if(x[a+80>>2]){q=Gn(a,g);break A}q=Nd(g)}g=(q+c|0)-8|0;n=x[((T<<2)+a|0)+1068>>2];i=n;c=j;while(1){if((c|0)!=(K|0)){B[g+4>>2]=E(B[c>>2]*B[i>>2])-E(B[i+4>>2]*B[c+8>>2]);B[g>>2]=E(B[c>>2]*B[i+4>>2])+E(B[c+8>>2]*B[i>>2]);c=c+16|0;i=i+8|0;g=g-8|0;continue}break}c=((H<<2)+j|0)-12|0;while(1){if(g>>>0>=q>>>0){B[g+4>>2]=E(B[c>>2]*B[i+4>>2])-E(B[c+8>>2]*B[i>>2]);B[g>>2]=E(E(-B[c+8>>2])*B[i+4>>2])-E(B[i>>2]*B[c>>2]);c=c-16|0;i=i+8|0;g=g-8|0;continue}break}c=P<<2;r=c+j|0;g=c+q|0;i=(n+(H<<2)|0)-32|0;c=q;h=j;while(1){if(i>>>0>=n>>>0){l=B[c>>2];s=B[g>>2];t=B[g+4>>2];G=B[c+4>>2];B[r+4>>2]=t+G;B[r>>2]=B[g>>2]+B[c>>2];t=E(t-G);l=E(s-l);B[h+4>>2]=E(t*B[i+16>>2])-E(B[i+20>>2]*l);B[h>>2]=E(l*B[i+16>>2])+E(t*B[i+20>>2]);l=B[c+8>>2];s=B[g+8>>2];t=B[g+12>>2];G=B[c+12>>2];B[r+12>>2]=t+G;B[r+8>>2]=B[g+8>>2]+B[c+8>>2];t=E(t-G);l=E(s-l);B[h+12>>2]=E(t*B[i>>2])-E(B[i+4>>2]*l);B[h+8>>2]=E(l*B[i>>2])+E(t*B[i+4>>2]);c=c+16|0;g=g+16|0;h=h+16|0;r=r+16|0;i=i-32|0;continue}break}g=Wl(S);c=S>>4;h=H-1|0;i=0-k|0;zI(c,j,h,i,n);zI(c,j,h-P|0,i,n);I=S>>5;c=0-c|0;rp(I,j,h,c,n,16);rp(I,j,h-k|0,c,n,16);rp(I,j,h-(k<<1)|0,c,n,16);rp(I,j,h+D(k,-3)|0,c,n,16);c=g-4>>1;r=(c|0)<=2?2:c;c=2;while(1){B:{C:{D:{if((c|0)==(r|0)){ja=g-7|0;break D}i=0;k=2<<c;k=(k|0)>0?k:0;F=8<<c;C=S>>c+4;o=S>>c+2;Z=0-(o>>1)|0;while(1){if((i|0)==(k|0)){break C}rp(C,j,h-D(i,o)|0,Z,n,F);i=i+1|0;continue}}while(1){E:{if((r|0)<(ja|0)){ma=32<<r;F=2<<r;Z=8<<r;i=S>>r+6;X=S>>r+2;ea=0-(X>>1)|0;g=h;c=n;while(1){if((i|0)<=0){break E}k=F;o=(g<<2)+j|0;C=o+(ea<<2)|0;U=D(Z,12)+c|0;l=B[U>>2];M=(Z<<3)+c|0;s=B[M>>2];u=(Z<<2)+c|0;t=B[u>>2];G=B[U+4>>2];L=B[M+4>>2];V=B[u+4>>2];W=B[c+4>>2];ca=B[c>>2];U=0-X<<2;while(1){if((k|0)>0){M=C-4|0;N=B[M>>2];aa=B[o>>2];ba=B[C>>2];B[o>>2]=aa+ba;u=o-4|0;J=B[u>>2];B[u>>2]=J+B[M>>2];J=E(J-N);N=E(aa-ba);B[M>>2]=E(J*ca)+E(W*N);B[C>>2]=E(N*ca)-E(W*J);M=C-12|0;aa=B[M>>2];u=o-8|0;J=B[u>>2];R=u;u=C-8|0;ba=B[u>>2];B[R>>2]=J+ba;R=o-12|0;N=B[R>>2];B[R>>2]=N+B[M>>2];N=E(N-aa);J=E(J-ba);B[M>>2]=E(N*t)+E(V*J);B[u>>2]=E(J*t)-E(V*N);M=C-20|0;aa=B[M>>2];u=o-16|0;J=B[u>>2];R=u;u=C-16|0;ba=B[u>>2];B[R>>2]=J+ba;R=o-20|0;N=B[R>>2];B[R>>2]=N+B[M>>2];N=E(N-aa);J=E(J-ba);B[M>>2]=E(N*s)+E(L*J);B[u>>2]=E(J*s)-E(L*N);M=C-28|0;aa=B[M>>2];u=o-24|0;J=B[u>>2];R=u;u=C-24|0;ba=B[u>>2];B[R>>2]=J+ba;R=o-28|0;N=B[R>>2];B[R>>2]=N+B[M>>2];N=E(N-aa);J=E(J-ba);B[M>>2]=E(N*l)+E(G*J);B[u>>2]=E(J*l)-E(G*N);k=k-1|0;C=C+U|0;o=o+U|0;continue}break}i=i-1|0;g=g-8|0;c=(ma<<2)+c|0;continue}}c=(h<<2)+j|0;h=c-(I<<6)|0;l=B[n+(S>>3<<2)>>2];ca=E(-l);while(1){if(c>>>0>h>>>0){L=B[c>>2];g=c-32|0;V=B[g>>2];B[c>>2]=L+V;n=c-4|0;s=B[n>>2];k=n;n=c-36|0;W=B[n>>2];B[k>>2]=s+W;i=c-8|0;t=B[i>>2];k=i;i=c-40|0;J=B[i>>2];B[k>>2]=t+J;k=c-12|0;G=B[k>>2];u=k;k=c-44|0;N=B[k>>2];B[u>>2]=G+N;B[g>>2]=L-V;B[n>>2]=s-W;n=c-16|0;s=B[n>>2];u=n;n=c-48|0;aa=B[n>>2];B[u>>2]=s+aa;t=E(t-J);G=E(G-N);B[i>>2]=l*E(t+G);B[k>>2]=l*E(G-t);i=c-28|0;t=B[i>>2];k=c-60|0;G=B[k>>2];F=c-24|0;L=B[F>>2];r=c-56|0;V=B[r>>2];C=c-20|0;W=B[C>>2];u=C;C=c-52|0;J=B[C>>2];B[u>>2]=W+J;B[F>>2]=L+V;B[i>>2]=t+G;B[n>>2]=W-J;B[C>>2]=-E(s-aa);s=E(t-G);t=E(L-V);B[r>>2]=l*E(s-t);B[k>>2]=E(t+s)*ca;yI(c);yI(g);c=c+-64|0;continue}break}k=H-4|0;g=q+(k<<2)|0;i=(q+(P<<2)|0)-16|0;c=x[((T<<2)+a|0)+1100>>2];while(1){if(i>>>0>=q>>>0){h=(z[c>>1]<<2)+j|0;B[g+12>>2]=B[h>>2];B[g+8>>2]=B[h+4>>2];B[i+12>>2]=B[h+8>>2];B[i+8>>2]=B[h+12>>2];h=(z[c+2>>1]<<2)+j|0;B[g+4>>2]=B[h>>2];B[g>>2]=B[h+4>>2];B[i+4>>2]=B[h+8>>2];B[i>>2]=B[h+12>>2];c=c+4|0;g=g-16|0;i=i-16|0;continue}break}c=x[((T<<2)+a|0)+1084>>2];i=q;g=i+(H<<2)|0;h=g;while(1){n=h-16|0;if(n>>>0>i>>>0){l=B[i+4>>2];F=h-4|0;s=B[F>>2];t=E(l-s);G=B[c+4>>2];l=E(l+s);s=B[i>>2];r=h-8|0;L=B[r>>2];V=E(s-L);W=B[c>>2];ca=E(E(G*l)-E(V*W));B[i+4>>2]=t+ca;s=E(s+L);l=E(E(G*V)+E(l*W));B[i>>2]=s+l;B[F>>2]=ca-t;B[r>>2]=s-l;l=B[i+8>>2];s=B[n>>2];t=E(l+s);G=B[c+12>>2];l=E(l-s);s=B[i+12>>2];h=h-12|0;L=B[h>>2];V=E(s+L);W=B[c+8>>2];ca=E(E(G*l)+E(V*W));B[i+8>>2]=t+ca;s=E(s-L);l=E(E(G*V)-E(l*W));B[i+12>>2]=s+l;B[n>>2]=t-ca;B[h>>2]=l-s;i=i+16|0;c=c+16|0;h=n;continue}break}i=x[((T<<2)+a|0)+1076>>2]+(H<<2)|0;c=(k<<2)+j|0;h=((S<<2)+j|0)-16|0;while(1){n=g-32|0;if(n>>>0>=q>>>0){l=B[g-8>>2];s=B[i-4>>2];t=B[i-8>>2];G=B[g-4>>2];L=E(E(l*s)-E(t*G));B[j>>2]=L;B[c+12>>2]=-L;l=E(E(t*E(-l))-E(s*G));B[K>>2]=l;B[h+12>>2]=l;l=B[g-16>>2];s=B[i-12>>2];t=B[i-16>>2];G=B[g-12>>2];L=E(E(l*s)-E(t*G));B[j+4>>2]=L;B[c+8>>2]=-L;l=E(E(t*E(-l))-E(s*G));B[K+4>>2]=l;B[h+8>>2]=l;l=B[g-24>>2];s=B[i-20>>2];t=B[i-24>>2];G=B[g-20>>2];L=E(E(l*s)-E(t*G));B[j+8>>2]=L;B[c+4>>2]=-L;l=E(E(t*E(-l))-E(s*G));B[K+8>>2]=l;B[h+4>>2]=l;l=B[n>>2];s=B[i-28>>2];i=i-32|0;t=B[i>>2];G=B[g-28>>2];L=E(E(l*s)-E(t*G));B[j+12>>2]=L;B[c>>2]=-L;l=E(E(t*E(-l))-E(s*G));B[K+12>>2]=l;B[h>>2]=l;h=h-16|0;c=c-16|0;K=K+16|0;j=j+16|0;g=n;continue}break}if(!x[a+80>>2]){Eb(q)}x[a+92>>2]=la;break B}r=r+1|0;continue}}c=c+1|0;continue}break}m=m+1|0;j=x[a+4>>2];continue}break}}else{g=c<<2;j=g+a|0;n=x[j+800>>2];F:{if(x[g+(O+320|0)>>2]){Vb(n,0,K);break F}H=x[j+996>>2];G:{g=y[(T+y[(x[T+4>>2]+D(c,3)|0)+2|0]|0)+9|0];if(!z[((g<<1)+a|0)+132>>1]){cc(a,21);break G}F=S>>1;r=x[a+260>>2]+D(g,1596)|0;j=D(y[r+1588|0],w[H>>1]);i=1;g=0;while(1){if(x[r+1592>>2]>(i|0)){h=y[(i+r|0)+838|0]<<1;q=w[h+H>>1];if((q|0)>=0){q=D(y[r+1588|0],q&65535);h=z[(h+r|0)+338>>1];if((h|0)!=(g|0)){k=q-j|0;C=h-g|0;o=(k|0)/(C|0)|0;H:{I=(h|0)<(F|0)?h:F;if((I|0)<=(g|0)){break H}u=k;k=k>>31;P=o>>31;P=((u^k)-k|0)-D(C,(P^o)-P|0)|0;Z=k|1;k=n+(g<<2)|0;B[k>>2]=B[((j&255)<<2)+71776>>2]*B[k>>2];I=I-1|0;k=0;while(1){if((g|0)==(I|0)){break H}g=g+1|0;U=n+(g<<2)|0;k=k+P|0;M=(k|0)<(C|0);j=(j+o|0)+(M?0:Z)|0;B[U>>2]=B[((j&255)<<2)+71776>>2]*B[U>>2];k=k-(M?0:C)|0;continue}}g=h}j=q}i=i+1|0;continue}break}if((g|0)>=(F|0)){break G}j=(j<<2)+71776|0;while(1){if((g|0)==(F|0)){break G}h=n+(g<<2)|0;B[h>>2]=B[j>>2]*B[h>>2];g=g+1|0;continue}}}c=c+1|0;continue}break}BI(a);I:{if(y[a+1377|0]){x[a+1060>>2]=ra;v[a+1377|0]=0;x[a+1064>>2]=1;x[a+1412>>2]=S-ia;break I}c=x[a+1412>>2];if(!c){break I}g=ka-Y|0;if((g|0)<=(c|0)){x[a+1412>>2]=c-g;x[ha>>2]=ka;Y=ka;break I}Y=c+Y|0;x[ha>>2]=Y;x[a+1412>>2]=0}c=x[a+1064>>2];J:{K:{L:{M:{if(x[a+1388>>2]==x[a+1404>>2]){N:{if(!c|!(y[a+1375|0]&4)){break N}c=x[a+1408>>2];g=x[a+1060>>2];if(c>>>0>=g+(ia-Y|0)>>>0){break N}g=c-g|0;c=(c>>>0>=g>>>0?g:0)+Y|0;c=(c|0)<(ia|0)?c:ia;x[$+12>>2]=c;x[a+1060>>2]=c+x[a+1060>>2];break K}x[a+1064>>2]=1;c=x[a+1408>>2]+(Y-da|0)|0;break M}if(!c){break L}c=x[a+1060>>2]}x[a+1060>>2]=c+(ka-Y|0)}if(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0){break J}x[$+12>>2]=ia}c=1;break o}_(6266,13048,3451,5575);p()}g=g-1|0;c=x[T+4>>2]+D(g,3)|0;q=x[j+(y[c+1|0]<<2)>>2];n=x[j+(y[c|0]<<2)>>2];c=0;while(1){if((c|0)==(h|0)){continue z}i=c<<2;m=i+q|0;t=B[m>>2];i=i+n|0;l=B[i>>2];O:{if(l>E(0)){if(t>E(0)){s=E(l-t);break O}s=l;l=E(l+t);break O}if(t>E(0)){s=E(l+t);break O}s=l;l=E(l-t)}B[i>>2]=l;B[m>>2]=s;c=c+1|0;continue}}}_(6266,13048,3335,5575);p()}Z=O+256|0;H=db-16|0;db=H;i=x[a+4>>2];r=x[a+396>>2];g=y[(j+la|0)+24|0];F=r+D(g,24)|0;h=x[F+4>>2];ja=z[((g<<1)+a|0)+268>>1];c=da<<((ja|0)==2);n=c>>>0>h>>>0?h:c;h=x[F>>2];I=(n-(c>>>0>h>>>0?h:c)>>>0)/A[F+8>>2]|0;q=I<<2;c=D(i,q+4|0);M=x[x[a+124>>2]+D(y[F+13|0],2096)>>2];R=x[a+92>>2];P:{if(x[a+80>>2]){h=Gn(a,c);i=x[a+4>>2];break P}h=Nd(c)}n=(m|0)>0?m:0;C=da<<2;c=0;o=(i|0)>0?i:0;k=(i<<2)+h|0;while(1){if((c|0)!=(o|0)){x[(c<<2)+h>>2]=k;c=c+1|0;k=k+q|0;continue}break}q=h;c=0;while(1){if((c|0)!=(n|0)){if(!y[c+O|0]){Vb(x[Z+(c<<2)>>2],0,C)}c=c+1|0;continue}break}Q:{if(!((m|0)==1|(ja|0)!=2)){c=0;while(1){R:{if((c|0)!=(n|0)){if(y[c+O|0]){break R}}else{c=n}if((c|0)==(m|0)){break Q}n=r+D(g,24)|0;r=(m|0)!=2;C=(m|0)<3;i=0;while(1){if((i|0)==8){break Q}S:{if(!r){k=0;h=0;while(1){if((h|0)>=(I|0)){break S}c=x[F>>2]+D(x[F+8>>2],h)|0;x[H+12>>2]=c&1;x[H+8>>2]=c>>1;if(!i){g=x[a+124>>2]+D(y[F+13|0],2096)|0;if(x[a+1396>>2]<=9){Ok(a)}c=x[a+1392>>2];o=w[(g+((c&1023)<<1)|0)+36>>1];T:{if((o|0)>=0){u=c;o=o&65535;c=y[o+x[g+8>>2]|0];x[a+1392>>2]=u>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:o;break T}c=Vl(a,g)}c=y[g+23|0]?x[x[g+2088>>2]+(c<<2)>>2]:c;if((c|0)==-1){break Q}x[x[q>>2]+(k<<2)>>2]=x[x[n+16>>2]+(c<<2)>>2]}c=0;while(1){if(!((c|0)>=(M|0)|(h|0)>=(I|0))){g=x[F+8>>2];o=w[(x[n+20>>2]+(y[x[x[q>>2]+(k<<2)>>2]+c|0]<<4)|0)+(i<<1)>>1];U:{if((o|0)>=0){if(!AI(a,x[a+124>>2]+D(o&65535,2096)|0,Z,2,H+12|0,H+8|0,da,g)){break Q}h=h+1|0;break U}h=h+1|0;g=x[F>>2]+D(g,h)|0;x[H+8>>2]=g>>1;x[H+12>>2]=g&1}c=c+1|0;continue}break}k=k+1|0;continue}}if(C){break S}k=0;h=0;while(1){if((h|0)>=(I|0)){break S}g=x[F>>2]+D(x[F+8>>2],h)|0;c=(g|0)/(m|0)|0;x[H+12>>2]=g-D(c,m);x[H+8>>2]=c;if(!i){g=x[a+124>>2]+D(y[F+13|0],2096)|0;if(x[a+1396>>2]<=9){Ok(a)}c=x[a+1392>>2];o=w[(g+((c&1023)<<1)|0)+36>>1];V:{if((o|0)>=0){u=c;o=o&65535;c=y[o+x[g+8>>2]|0];x[a+1392>>2]=u>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:o;break V}c=Vl(a,g)}c=y[g+23|0]?x[x[g+2088>>2]+(c<<2)>>2]:c;if((c|0)==-1){break Q}x[x[q>>2]+(k<<2)>>2]=x[x[n+16>>2]+(c<<2)>>2]}c=0;while(1){if(!((c|0)>=(M|0)|(h|0)>=(I|0))){g=x[F+8>>2];o=w[(x[n+20>>2]+(y[x[x[q>>2]+(k<<2)>>2]+c|0]<<4)|0)+(i<<1)>>1];W:{if((o|0)>=0){if(!AI(a,x[a+124>>2]+D(o&65535,2096)|0,Z,m,H+12|0,H+8|0,da,g)){break Q}h=h+1|0;break W}h=h+1|0;g=x[F>>2]+D(g,h)|0;o=(g|0)/(m|0)|0;x[H+8>>2]=o;x[H+12>>2]=g-D(m,o)}c=c+1|0;continue}break}k=k+1|0;continue}}i=i+1|0;continue}}c=c+1|0;continue}}ma=r+D(g,24)|0;i=0;while(1){if((i|0)==8){break Q}k=0;m=0;while(1){if((k|0)<(I|0)){X:{if(i){break X}c=0;while(1){if((c|0)==(n|0)){break X}if(!y[c+O|0]){h=x[a+124>>2]+D(y[F+13|0],2096)|0;if(x[a+1396>>2]<=9){Ok(a)}g=x[a+1392>>2];r=w[(h+((g&1023)<<1)|0)+36>>1];Y:{if((r|0)>=0){u=g;r=r&65535;g=y[r+x[h+8>>2]|0];x[a+1392>>2]=u>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;g=(g|0)<0?-1:r;break Y}g=Vl(a,h)}g=y[h+23|0]?x[x[h+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}x[x[q+(c<<2)>>2]+(m<<2)>>2]=x[x[ma+16>>2]+(g<<2)>>2]}c=c+1|0;continue}}h=0;while(1){Z:{if((h|0)>=(M|0)){break Z}c=0;if((k|0)>=(I|0)){break Z}while(1){if((c|0)!=(n|0)){_:{if(y[c+O|0]){break _}g=c<<2;r=w[(x[ma+20>>2]+(y[x[x[g+q>>2]+(m<<2)>>2]+h|0]<<4)|0)+(i<<1)>>1];if((r|0)<0){break _}K=x[a+124>>2]+D(r&65535,2096)|0;X=x[g+Z>>2];U=x[F+8>>2];P=x[F>>2]+D(U,k)|0;$:{aa:{if(ja){r=0;while(1){g=1;if((r|0)>=(U|0)){break $}ea=X+(P<<2)|0;g=U-r|0;C=0;l=E(0);ba:{o=xI(a,K);if((o|0)<0){break ba}C=x[K>>2];g=(g|0)>(C|0)?C:g;u=D(o,C);if(y[K+22|0]){o=0;g=(g|0)>0?g:0;C=1;while(1){if((g|0)==(o|0)){break ba}ga=ea+(o<<2)|0;l=E(l+B[x[K+28>>2]+(o+u<<2)>>2]);B[ga>>2]=B[ga>>2]+l;o=o+1|0;l=E(l+B[K+12>>2]);continue}}o=0;g=(g|0)>0?g:0;C=1;while(1){if((g|0)==(o|0)){break ba}ga=ea+(o<<2)|0;B[ga>>2]=B[ga>>2]+E(B[x[K+28>>2]+(o+u<<2)>>2]+E(0));o=o+1|0;continue}}if(!C){break aa}g=x[K>>2];P=g+P|0;r=g+r|0;continue}}r=0;ea=(U|0)/x[K>>2]|0;u=(ea|0)>0?ea:0;ga=X+(P<<2)|0;g=1;while(1){if((r|0)==(u|0)){break $}C=r+P|0;o=r<<2;r=r+1|0;sa=o+ga|0;X=U-C|0;o=0;l=E(0);ca:{na=xI(a,K);if((na|0)<0){break ca}C=0;o=x[K>>2];X=(o|0)<(X|0)?o:X;X=(X|0)>0?X:0;na=D(o,na);o=1;while(1){if((C|0)==(X|0)){break ca}qa=sa+(D(C,ea)<<2)|0;s=E(l+B[x[K+28>>2]+(C+na<<2)>>2]);B[qa>>2]=B[qa>>2]+s;l=y[K+22|0]?s:l;C=C+1|0;continue}}if(o){continue}break}}g=0}if(!g){break Q}}c=c+1|0;continue}break}k=k+1|0;h=h+1|0;continue}break}m=m+1|0;continue}break}i=i+1|0;continue}}if(!x[a+80>>2]){Eb(q)}x[a+92>>2]=R;db=H+16|0;j=j+1|0;continue}}_(6266,13048,3302,5575);p()}db=O+2368|0}else{c=0}db=fa+16|0;if(!c){da:{ea:{fa:{c=x[a+100>>2];switch(c-32|0){case 0:break ea;case 3:break fa;default:break da}}x[a+100>>2]=0;while(1){if((jh(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;c=x[a+32>>2]-b|0;break a}if(x[a+992>>2]){break da}x[a+100>>2]=0;while(1){if((jh(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;c=x[a+32>>2]-b|0;break a}x[a+1420>>2]=0;x[a+992>>2]=0;x[a+1504>>2]=0;x[a+1508>>2]=0;x[a+1412>>2]=0;x[a+1416>>2]=0;v[a+1377|0]=0;x[a+1064>>2]=0;x[a+100>>2]=c;x[f>>2]=0;c=1;break a}h=x[$+12>>2];n=x[$+4>>2];j=x[$+8>>2];ga:{ha:{q=x[a+992>>2];if(q){g=q<<1;ia:{if((g|0)==x[a+112>>2]){c=a+1092|0}else{c=0;if((g|0)!=x[a+116>>2]){break ia}c=a+1096|0}c=x[c>>2]}if(!c){break ha}m=(q|0)>0?q:0;while(1){if(x[a+4>>2]>(Q|0)){i=(Q<<2)+a|0;g=0;while(1){if((g|0)!=(m|0)){k=x[i+800>>2]+(g+n<<2)|0;u=k;l=B[k>>2];k=g<<2;B[u>>2]=E(l*B[k+c>>2])+E(B[k+x[i+928>>2]>>2]*B[c+(q+(g^-1)<<2)>>2]);g=g+1|0;continue}break}Q=Q+1|0;continue}break}Q=x[a+992>>2]}x[a+992>>2]=h-j;q=(h|0)<(j|0);i=(q?j:h)-j|0;while(1){if(x[a+4>>2]>(pa|0)){c=(pa<<2)+a|0;g=0;while(1){if((g|0)!=(i|0)){B[x[c+928>>2]+(g<<2)>>2]=B[x[c+800>>2]+(g+j<<2)>>2];g=g+1|0;continue}break}pa=pa+1|0;continue}break}if(!Q){break ha}c=(q?h:j)-n|0;x[a+1416>>2]=c+x[a+1416>>2];break ga}c=0}g=c;c=0;j=x[a+4>>2];h=(j|0)>0?j:0;while(1){if((c|0)!=(h|0)){q=(c<<2)+a|0;x[q+864>>2]=x[q+800>>2]+(n<<2);c=c+1|0;continue}break}if(d){x[d>>2]=j}x[f>>2]=g;x[e>>2]=a+864;c=x[a+32>>2]-b|0}db=$+16|0;return c}function Cga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0;d=db-1728|0;db=d;wc(b);f=db-16|0;db=f;h=d+1602|0;yS(f+8|0,h);g=x[f+12>>2];m=b;lc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(g|0)){Zb(m,x[f+12>>2])}db=f+16|0;b=(b|0)==(g|0);if(!b){xS(h)}a:{if(!b){break a}if(!zS(d+1602|0)){break a}if(!Lb(x[m>>2],x[m+8>>2],Qc(256,0))){break a}b:{if(!c){break b}Bd(a,1048576);Dg(a);b=db-16|0;db=b;e=Tb(b+4|0,4171);ad(d+1344|0,e);tb(e);db=b+16|0;b=y[d+1610|0]|y[d+1611|0]<<8;x[d+144>>2]=b>>>8;x[23549]=0;x[d+12>>2]=b&255;P(386,d+72|0,d+12|0);b=x[23549];x[23549]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((b|0)!=1){x[23549]=0;V(372,d+256|0,d+1344|0,d+144|0,d+72|0);b=x[23549];x[23549]=0;if((b|0)==1){break m}b=d+256|0;zb(a+1298344|0,b);tb(b);e=d+72|0;tb(e);f=d+1344|0;Ab(f);g=Tb(b,14778);zb(a+1298356|0,g);tb(g);_e(e,2,d+1612|0);Bc(f,e);x[23549]=0;S(11,b|0,8,f|0);b=x[23549];x[23549]=0;if((b|0)==1){break i}b=d+256|0;zb(a+1298368|0,b);tb(b);e=d+1344|0;tb(e);x[a+1298404>>2]=8;pA(e,2,d+1644|0);Bc(b,e);zb(a+1298308|0,b);tb(b);w[a+480188>>1]=y[d+1714|0]|y[d+1715|0]<<8;f=y[d+1718|0];x[a+480204>>2]=125e4;x[a+480208>>2]=32792;G=a,H=Vd(f,1,31),x[G+480196>>2]=H;w[a+480192>>1]=y[d+1724|0]|y[d+1725|0]<<8;w[a+480190>>1]=y[d+1726|0]|y[d+1727|0]<<8;f=Vd(y[d+1719|0],1,32);x[a+480216>>2]=f;x[a+480228>>2]=96;x[a+480232>>2]=48;x[a+480220>>2]=f<<2;_u(m,e);f=a+484376|0;Qq(Wb(x[a+484360>>2],y[f|0]),e,y[d+1708|0]|y[d+1709|0]<<8,65535,65535);$e(Wb(x[a+484360>>2],y[f|0]),y[d+1710|0]|y[d+1711|0]<<8);r=Fg(m);Wd(b,m,r?274:0);u=hc(d+1324|0,b);ub(b);x[23549]=0;b=R(143,m|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break k}x[23549]=0;S(176,d+256|0,m|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break k}b=d+256|0;t=hc(d+1304|0,b);ub(b);s=z[a+480188>>1];if(r){w[a+480188>>1]=s+8}B=c&1;if(!B){break j}x[23549]=0;P(211,a+484344|0,y[d+1712|0]|y[d+1713|0]<<8);b=x[23549];x[23549]=0;if((b|0)!=1){break j}g=N()|0;break e}g=N()|0;break l}g=N()|0;tb(d+72|0)}Ab(d+1344|0);break c}g=N()|0;break d}o=a+484344|0;g=0;while(1){n:{o:{p:{q:{r:{s:{if((y[d+1712|0]|y[d+1713|0]<<8)>>>0<=q>>>0){b=y[d+1716|0]|y[d+1717|0]<<8;if((b-2&65535)>>>0>=4998){break q}if(!(g&1)){break s}h=0;b=Cc(((b>>>1|0)+11025e5>>>0)/(b>>>0)|0,0);break r}x[23549]=0;b=R(180,m|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break f}x[d+144>>2]=b;x[23549]=0;b=R(143,m|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break g}x[23549]=0;S(176,d+72|0,m|0,b+1&-2);b=x[23549];x[23549]=0;if((b|0)==1){break g}b=d+72|0;k=hc(d+256|0,b);ub(b);tc(d+144|0,1024);if(!B){break o}j=x[d+144>>2];if(!j){break o}x[23549]=0;b=U(212,o|0,q&65535,j|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){if(!b){break o}i=0;e=0;if(v[d+1720|0]&1){break p}t:while(1){if((i|0)==(j|0)){break o}e=0;b=Yb(x[o>>2],q);b=sf(x[b>>2],x[x[b+48>>2]+12>>2],i);while(1){if((e|0)==(s|0)){i=i+1|0;continue t}x[23549]=0;P(564,k|0,d+72|0);f=x[23549];x[23549]=0;if((f|0)!=1){g=wS(b+D(e,6)|0,d+72|0)|g;e=e+1|0;continue}break}break}break h}break h}h=2;b=Le(2646e3/+(D(b,D(x[a+480216>>2],x[a+480196>>2]))>>>0)*1e4)}v[a+480224|0]=h;x[a+480204>>2]=b}b=z[a+480188>>1];x[23549]=0;v[d+256|0]=0;q=U(565,d+1292|0,b|0,d+256|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){h=a+1298320|0;k=a+1298332|0;n=0;u:{v:{w:{x:{y:{z:{while(1){b=x[t+8>>2];e=x[t>>2];x[23549]=0;b=U(142,e|0,b|0,8)|0;e=x[23549];x[23549]=0;A:{if((e|0)!=1){if(b){break A}f=x[q>>2];h=0;while(1){e=z[a+480188>>1];if(e>>>0<=h>>>0){x[d+248>>2]=0;x[d+252>>2]=0;x[d+240>>2]=0;x[d+244>>2]=0;x[d+232>>2]=0;x[d+236>>2]=0;x[d+224>>2]=0;x[d+228>>2]=0;B:{C:{if(!r){break C}e=0;x[23549]=0;P(566,u|0,d+256|0);b=x[23549];x[23549]=0;if((b|0)==1){break B}while(1){if((e|0)==8){e=0;x[23549]=0;k=O(204,d+212|0,z[d+256>>1])|0;b=x[23549];x[23549]=0;if((b|0)!=1){D:{E:{F:{G:{while(1){if(z[d+256>>1]<=e>>>0){x[23549]=0;i=U(567,d+200|0,y[d+1712|0]|y[d+1713|0]<<8,26984)|0;b=x[23549];x[23549]=0;if((b|0)==1){break E}f=0;break F}x[23549]=0;b=R(180,m|0)|0;f=x[23549];x[23549]=0;if((f|0)!=1){x[23549]=0;S(176,d+144|0,m|0,b<<5);b=x[23549];x[23549]=0;if((b|0)==1){break G}f=d+144|0;b=hc(d+72|0,f);Zc(Cg(x[k>>2],e),b);ub(b);e=e+1|0;ub(f);continue}break}g=N()|0;break D}g=N()|0;break D}while(1){if((y[d+1708|0]|y[d+1709|0]<<8)>>>0<=f>>>0){id(i);kd(k);break C}H:{g=d+f|0;e=y[g+274|0];if(e>>>0>=z[d+256>>1]){break H}b=z[_b(x[Wb(x[a+484360>>2],y[a+484376|0])>>2],f)>>1];if(b>>>0>=(y[d+1712|0]|y[d+1713|0]<<8)>>>0){break H}I:{h=_b(x[i>>2],b);j=z[h>>1];J:{if((j|0)==65535){w[h>>1]=e;break J}if((e|0)==(j|0)){break J}x[23549]=0;e=O(568,o|0,b|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break I}if((e|0)==65535){break J}G=_b(x[Wb(x[a+484360>>2],y[a+484376|0])>>2],f),H=e,w[G>>1]=H;b=e}if(!se(x[a+484344>>2],x[a+484348>>2],b)){break H}l=Cg(x[k>>2],y[g+274|0]);wc(l);e=x[l>>2];x[23549]=0;e=R(146,e|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break I}r=e>>>5|0;h=0;K:while(1){e=Yb(x[o>>2],b);if(A[e+12>>2]<=h>>>0){break H}g=0;e=$c(x[e>>2],x[x[e+48>>2]+12>>2],h,z[a+480188>>1]-8&65535);while(1){if((g|0)==8){h=h+1|0;continue K}Uh(d+72|0);j=y[d+76|0]|y[d+77|0]<<8;v[e+4|0]=j;v[e+5|0]=j>>>8;j=y[d+72|0]|y[d+73|0]<<8|(y[d+74|0]<<16|y[d+75|0]<<24);v[e|0]=j;v[e+1|0]=j>>>8;v[e+2|0]=j>>>16;v[e+3|0]=j>>>24;L:{if(h>>>0>=r>>>0){break L}x[23549]=0;O(569,l|0,d+72|0)|0;j=x[23549];x[23549]=0;if((j|0)==1){break I}if(v[d+72|0]>=0){break L}v[e|0]=61;v[e+1|0]=y[(d+240|0)+(g<<1)|0];j=y[d+72|0]&31;v[d+144|0]=j;if(j){pf(d+144|0,15);v[e+3|0]=20;v[e+5|0]=y[d+144|0]|208}v[e+2|0]=1;v[e+4|0]=y[d+73|0]+3>>>2}e=e+6|0;g=g+1|0;continue}}}g=N()|0;id(i);break D}f=f+1|0;continue}}g=N()|0}kd(k);break u}g=N()|0;break u}f=e<<1;g=f+(d+240|0)|0;b=z[a+480192>>1]+1&65535;h=z[x[a+8>>2]+58>>1];while(1){M:{N:{k=b&65535;if(k>>>0<=h>>>0){if(x[((k<<2)+a|0)+900380>>2]){break N}}else{b=65535}b=b&65535;break M}b=b+1|0;continue}break}w[g>>1]=b;j=f+(d+224|0)|0;f=z[(d+f|0)+258>>1];w[j>>1]=f;O:{if((b|0)!=65535){x[23549]=0;b=U(240,a|0,b|0,f+1&65535)|0;f=x[23549];x[23549]=0;P:{Q:{if((f|0)!=1){if(!b){break O}x[23549]=0;P(275,d+144|0,4416);f=x[23549];x[23549]=0;if((f|0)==1){break Q}x[23549]=0;x[d+12>>2]=e+1;S(570,d+72|0,d+144|0,d+12|0);f=x[23549];x[23549]=0;if((f|0)==1){break P}f=b+492|0;b=d+72|0;zc(f,b);tb(b);Ab(d+144|0);break O}g=N()|0;break u}g=N()|0;break u}g=N()|0;Ab(d+144|0);break u}w[g>>1]=0}e=e+1|0;continue}}R:{S:{b=y[d+1720|0]|y[d+1721|0]<<8|(y[d+1722|0]<<16|y[d+1723|0]<<24);if(!(b&2)){break S}b=(((b&8?z[a+480188>>1]:s)&65535)+((y[d+1610|0]|y[d+1611|0]<<8)>>>0>591?n:0)|0)+(b>>>4&1)|0;f=0;T:while(1){e=0;if((y[d+1712|0]|y[d+1713|0]<<8)>>>0<=f>>>0){break S}while(1){U:{if((b|0)!=(e|0)){g=x[m+8>>2];h=x[m>>2];x[23549]=0;g=U(142,h|0,g|0,4)|0;h=x[23549];x[23549]=0;if((h|0)==1){break R}if(g){break U}}f=f+1|0;continue T}x[23549]=0;P(571,y[d+1610|0]|y[d+1611|0]<<8,m|0);g=x[23549];x[23549]=0;if((g|0)==1){break R}e=e+1|0;continue}}}x[23549]=0;k=O(204,d+188|0,255)|0;b=x[23549];x[23549]=0;if((b|0)!=1){f=0;while(1){V:{b=f;W:{if((b|0)==255){n=mA(d+72|0);o=mA(d+144|0);g=0;while(1){X:{Y:{Z:{if((g|0)==256){h=0;break Z}x[23549]=0;P(572,m|0,d+256|0);b=x[23549];x[23549]=0;if((b|0)==1){break Y}x[23549]=0;b=R(143,m|0)|0;e=x[23549];x[23549]=0;_:{$:{aa:{if((e|0)!=1){x[23549]=0;S(176,d+12|0,m|0,b|0);e=x[23549];x[23549]=0;if((e|0)==1){break aa}e=d+12|0;i=hc(d+52|0,e);ub(e);if((y[d+1726|0]|y[d+1727|0]<<8)>>>0>g>>>0){e=d+40|0;_e(e,2,d+256|0);x[23549]=0;P(208,d+12|0,e|0);e=x[23549];x[23549]=0;if((e|0)==1){break _}e=d+12|0;zc(((g<<5)+a|0)+946336|0,e);tb(e)}if(!b){break X}if((y[d+1726|0]|y[d+1727|0]<<8)>>>0>g>>>0){break $}break X}g=N()|0;break W}g=N()|0;break W}x[23549]=0;b=D(g+1|0,104)+a|0;e=b+484380|0;P(266,e|0,32);f=x[23549];x[23549]=0;ba:{ca:{da:{if((f|0)!=1){Po(e);x[23549]=0;P(573,i|0,d+12|0);f=x[23549];x[23549]=0;if((f|0)==1){break _}f=x[d+12>>2];x[e>>2]=f;x[b+484404>>2]=x[d+16>>2];if(y[d+20|0]>=2){h=b+484414|0;w[h>>1]=z[h>>1]|1;f=f>>>1|0;x[e>>2]=f}if(y[d+21|0]>=2){h=b+484414|0;w[h>>1]=z[h>>1]|64;x[e>>2]=f>>>1}h=2;switch(y[d+23|0]-1|0){case 0:break ca;case 1:break da;default:break ba}}break _}h=6}e=b+484414|0;w[e>>1]=z[e>>1]|h}x[b+484384>>2]=x[d+24>>2];x[b+484388>>2]=x[d+28>>2];w[b+484410>>1]=z[d+32>>1]>>>7;e=y[d+34|0];ea:{if((e|0)==128){e=b+484414|0;f=z[e>>1]|256;w[e>>1]=f;break ea}w[b+484408>>1]=(e<<24>>24)+128;f=z[b+484414>>1]}h=b+484414|0;w[h>>1]=f|32;v[b+484416|0]=y[d+35|0];e=y[d+22|0];if(e&2){b=d+40|0;Fb(b,o,g);xm(b);e=y[d+22|0]}if(e&5){w[h>>1]=z[h>>1]|16384}if(!(e&8)){break X}b=d+40|0;Fb(b,n,g);xm(b);e=0;while(1){if((e|0)==8){break X}b=e<<1;fa:{if(z[b+(d+224|0)>>1]!=(g|0)){break fa}b=x[((z[b+(d+240|0)>>1]<<2)+a|0)+900380>>2];if(!b){break fa}v[b+14|0]=0}e=e+1|0;continue}}g=N()|0;ub(i);break W}while(1){ga:{ha:{if((y[d+1724|0]|y[d+1725|0]<<8)>>>0<=h>>>0){if(!(c&2)){break ha}g=0;ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{while(1){if(z[a+480190>>1]<=g>>>0){break ha}g=g+1|0;c=D(g,104)+a|0;e=c+484380|0;b=c+484416|0;vq(e,(+(v[b|0]-49|0)+ +v[c+484417|0]*-.0078125)/-12);w[b>>1]=0;b=z[c+484414>>1];if(!(b&16384)){b=Xc(d+256|0,b&1?16:8,b&64?3:1,0,11);x[23549]=0;U(205,b|0,e|0,m|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){continue}g=N()|0;break W}x[23549]=0;e=R(143,m|0)|0;b=x[23549];x[23549]=0;qa:{if((b|0)==1){break qa}x[23549]=0;O(174,m|0,12)|0;b=x[23549];x[23549]=0;if((b|0)==1){break qa}b=Gb(d+256|0);x[23549]=0;S(257,m|0,b|0,e|0);e=x[23549];x[23549]=0;if((e|0)==1){break pa}Ce(c+484423|0,b);x[23549]=0;P(371,d+52|0,16028);c=x[23549];x[23549]=0;if((c|0)==1){break oa}x[d+8>>2]=g;c=x[a+1298404>>2];x[23549]=0;S(11,d+40|0,c|0,b|0);c=x[23549];x[23549]=0;if((c|0)==1){break na}x[23549]=0;V(372,d+12|0,d+52|0,d+8|0,d+40|0);c=x[23549];x[23549]=0;if((c|0)==1){break ma}c=x[a+1298464>>2];x[23549]=0;S(359,c|0,2,d+12|0);c=x[23549];x[23549]=0;if((c|0)==1){break la}tb(d+12|0);tb(d+40|0);Ab(d+52|0);tb(b);continue}break}g=N()|0;break W}g=N()|0;break ia}g=N()|0;break ia}g=N()|0;break ja}g=N()|0;break ka}g=N()|0;tb(d+12|0)}tb(d+40|0)}Ab(d+52|0)}tb(b);break W}b=x[Cg(x[k>>2],h)>>2];x[23549]=0;b=R(146,b|0)|0;e=x[23549];x[23549]=0;ra:{sa:{if((e|0)!=1){if(!b){h=h+1|0;continue}b=Cg(x[k>>2],h);wc(b);x[23549]=0;P(574,b|0,d+256|0);b=x[23549];x[23549]=0;if((b|0)==1){break sa}i=Nb(d+12|0);x[23549]=0;S(575,m|0,i|0,z[d+256>>1]);b=x[23549];x[23549]=0;if((b|0)==1){break ra}h=h+1|0;b=x[((h<<2)+a|0)+900380>>2];if(!b|y[b+34|0]){break ga}x[b+4>>2]=32;e=0;du(b,0);s=b+108|0;l=b+236|0;while(1){if((e|0)==96){break ga}f=y[(d+e|0)+258|0];ta:{if(f>>>0>=z[d+256>>1]){break ta}j=Qe(x[i>>2],f);f=y[j|0];g=f+1|0;r=e+12|0;G=_b(l,r),H=g,w[G>>1]=H;if(f>>>0>=z[a+480190>>1]){break ta}f=D(g,104)+a|0;v[f+484418|0]=y[d+354|0]&3;v[f+484419|0]=y[d+355|0];v[f+484420|0]=y[d+356|0];v[f+484421|0]=y[d+357|0];w[f+484412>>1]=y[j+1|0]<<1;v[f+484417|0]=y[j+2|0];f=g-1|0;Fb(d+52|0,n,f);if(Ib(x[x[d+52>>2]>>2],x[d+56>>2])){v[b+14|0]=0}Fb(d+52|0,o,f);if(!Ib(x[x[d+52>>2]>>2],x[d+56>>2])){break ta}G=Db(s,r),H=61,v[G|0]=H}e=e+1|0;continue}}g=N()|0;break W}g=N()|0;break W}g=N()|0;oe(i);break W}kd(k);bc(q);ub(t);ub(u);break b}oe(i);continue}}g=N()|0;break W}ub(i);g=g+1|0;continue}}x[23549]=0;P(572,m|0,d+144|0);e=x[23549];x[23549]=0;ua:{va:{wa:{xa:{if((e|0)!=1){x[23549]=0;e=R(143,m|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break xa}x[23549]=0;e=(e|0)==32?428:e;i=e?(y[d+1610|0]|y[d+1611|0]<<8)>>>0>513?e+4|0:e:e;S(176,d+72|0,m|0,i|0);e=x[23549];x[23549]=0;if((e|0)==1){break wa}g=d+72|0;e=hc(d+256|0,g);h=le(d+12|0,Zc(Cg(x[k>>2],b),e));ub(e);f=b+1|0;ub(g);if(b>>>0>=(y[d+1724|0]|y[d+1725|0]<<8)>>>0){break V}x[23549]=0;b=f&65535;g=U(240,a|0,b|0,b|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break va}break ua}g=N()|0;break W}g=N()|0;break W}g=N()|0;break W}if(!g){break V}b=d+72|0;_e(b,2,d+144|0);x[23549]=0;P(208,d+256|0,b|0);b=x[23549];x[23549]=0;ya:{if((b|0)!=1){b=d+256|0;zc(g+492|0,b);tb(b);if(!i){break V}x[23549]=0;P(574,h|0,d+256|0);b=x[23549];x[23549]=0;if((b|0)!=1){o=3;i=0;if((y[d+1610|0]|y[d+1611|0]<<8)>>>0<513){n=0;break ya}x[23549]=0;n=R(180,h|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break ua}if((y[d+1610|0]|y[d+1611|0]<<8)>>>0<514){break ya}x[23549]=0;o=R(143,h|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break ya}break ua}break ua}break ua}x[g>>2]=y[d+358|0]|y[d+359|0]<<8;v[g+16|0]=y[((y[d+360|0]|y[d+361|0]<<8)&3)+26986|0];v[g+17|0]=y[(y[d+361|0]&3)+26986|0];v[g+18|0]=y[((y[d+360|0]|y[d+361|0]<<8)>>>12&3)+26990|0];while(1){za:{Aa:{if((i|0)==4){if(!(v[g+60|0]&1|y[g+16|0]==3)){x[g>>2]=32767}Mm(g,127,1);Lm(g,0,1);if(!n){break V}x[23549]=0;P(576,h|0,d+72|0);b=x[23549];x[23549]=0;if((b|0)==1){break ua}if(n&2){Mm(g,tS(x[a+480208>>2],+((y[d+74|0]|y[d+75|0]<<8)>>>0)),1);Lm(g,y[d+76|0],1)}v[g+25|0]=y[d+73|0]==1;if(!(n&4)){break V}v[g+31|0]=y[d+79|0]+1;b=v[d+80|0];v[g+34|0]=b+1;if((b|0)<0){v[g+30|0]=y[d+87|0]+1}if(!y[d+84|0]){break Aa}i=g+108|0;e=0;while(1){if((e|0)==128){break Aa}b=e+1|0;x[d+52>>2]=b+v[d+84|0];sS(d+52|0);n=x[d+52>>2];G=Db(i,e),H=n,v[G|0]=H;e=b;continue}}if(!(o&1)){break za}x[23549]=0;P(577,h|0,d+72|0);b=x[23549];x[23549]=0;Ba:{if((b|0)!=1){b=Ci(g,y[i+26994|0]);Ca:{if((i|0)!=3){e=y[d+72|0];j=y[b+12|0]&-17;break Ca}e=y[d+72|0];j=e<<4&16|y[b+12|0]&-17}v[b+12|0]=e>>>1&2|(e<<1&4|(j&248|e&1));v[d+52|0]=y[d+73|0];v[d+40|0]=16;e=y[Sb(d+52|0,d+40|0)|0];x[23549]=0;P(280,b|0,e|0);e=x[23549];x[23549]=0;if((e|0)==1){break Ba}e=y[d+74|0];v[b+15|0]=e;v[b+16|0]=e;v[b+13|0]=y[d+75|0];v[b+14|0]=y[d+76|0];e=0;j=x[b>>2];s=ne(j,x[b+4>>2]);while(1){if((e|0)==(s|0)){break za}l=xb(j,e);b=(d+72|0)+(e<<2)|0;w[l>>1]=y[b+8|0]|y[b+9|0]<<8;G=l,H=Vd(y[b+10|0]|y[b+11|0]<<8,0,64),v[G+2|0]=H;e=e+1|0;continue}}break ua}break ua}du(g,0);break V}i=i+1|0;o=o>>>1|0;continue}}g=N()|0;ub(h)}kd(k);break u}ub(h);continue}}g=N()|0;break u}g=N()|0;break u}g=N()|0;break u}else{b=v[Db(f,h)|0];Da:{if((b|0)<=(h|0)|(b|0)>=(e|0)){break Da}b=y[((b<<5)+a|0)+480288|0];if(!b){break Da}e=((h<<5)+a|0)+480288|0;g=y[e|0];if(!g){v[e|0]=b;break Da}e=g-1|0;while(1){g=D(e&255,160)+a|0;e=Rm(x[g+906328>>2]);if((e|0)!=255){continue}break}b=b-1&255;x[(g+906300|0)+28>>2]=b>>>0<250?b+128|0:0}h=h+1|0;continue}}}g=N()|0;break u}x[23549]=0;f=R(143,t|0)|0;b=x[23549];x[23549]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{if((b|0)!=1){x[23549]=0;b=R(143,t|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break Ma}x[23549]=0;S(176,d+256|0,t|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break Ma}e=d+256|0;b=hc(d+72|0,e);ub(e);if((f|0)==4674381){break Ia}if((f|0)==5068115){break Ha}if((f|0)==726487106){break La}if((f|0)==844387158){break Ga}e=0;if((f|0)==1280004692){break Ka}if((f|0)==1314144592){break Ja}if((f|0)!=1397445204){break Fa}x[23549]=0;e=R(180,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break w}e=e>>>0<256?48:e>>>8|0;x[a+480228>>2]=e;x[a+480232>>2]=e>>>1;e=0;while(1){if(z[a+480188>>1]<=e>>>0){break Fa}x[23549]=0;f=O(578,b|0,d+256|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break z}if(f){w[((e<<5)+a|0)+480286>>1]=z[d+256>>1]>>>10;G=Db(x[q>>2],e),H=y[d+259|0],v[G|0]=H}e=e+1|0;continue}}g=N()|0;break u}g=N()|0;break u}if(g&1){break Fa}v[a+480224|0]=2;x[23549]=0;C=+ja(579,b|0);e=x[23549];x[23549]=0;if((e|0)==1){break Ea}if(!(C>1e-8)){break Fa}G=a,H=Le(2646e3/(C*+(D(x[a+480216>>2],x[a+480196>>2])>>>0))*1e4),x[G+480204>>2]=H;break Fa}while(1){Na:{if(z[a+480188>>1]<=e>>>0){break Fa}f=x[b>>2];x[23549]=0;f=U(142,f|0,x[d+80>>2],1)|0;i=x[23549];x[23549]=0;if((i|0)==1){break y}if(!f){break Fa}f=Gb(d+256|0);x[23549]=0;S(342,b|0,f|0,-1);i=x[23549];x[23549]=0;if((i|0)!=1){i=d+12|0;Tf(i,3,Mb(f),Oc(x[d+260>>2],y[d+267|0]));x[23549]=0;P(208,d+144|0,i|0);i=x[23549];x[23549]=0;if((i|0)==1){break Na}i=d+144|0;Em(((e<<5)+a|0)+480289|0,i);tb(i);tb(f);e=e+1|0;continue}}break}g=N()|0;tb(f);break v}while(1){if((y[d+1712|0]|y[d+1713|0]<<8)>>>0<=e>>>0){break Fa}f=x[b>>2];x[23549]=0;f=U(142,f|0,x[d+80>>2],1)|0;i=x[23549];x[23549]=0;if((i|0)==1){break x}if(!f){break Fa}if(!Gm(x[a+484344>>2],x[a+484348>>2],e&65535)){break Fa}f=Gb(d+256|0);x[23549]=0;S(342,b|0,f|0,-1);i=x[23549];x[23549]=0;Oa:{if((i|0)==1){break Oa}i=x[o>>2];x[23549]=0;P(270,Yb(i,e)|0,f|0);i=x[23549];x[23549]=0;if((i|0)==1){break Oa}tb(f);e=e+1|0;continue}break}g=N()|0;tb(f);break v}x[23549]=0;O(174,b|0,1)|0;e=x[23549];x[23549]=0;if((e|0)==1){break w}x[23549]=0;e=R(188,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break w}x[23549]=0;V(321,k|0,b|0,e|0,2);e=x[23549];x[23549]=0;if((e|0)!=1){break Fa}break w}x[23549]=0;O(580,b|0,d+12|0)|0;e=x[23549];x[23549]=0;Pa:{if((e|0)!=1){e=Gb(d+256|0);x[23549]=0;S(342,b|0,e|0,-1);f=x[23549];x[23549]=0;if((f|0)==1){break Pa}if(lu(e,12472)){x[23549]=0;S(11,d+144|0,8,e|0);f=x[23549];x[23549]=0;if((f|0)==1){break Pa}f=d+144|0;zb(h,f);tb(f)}tb(e);break Fa}g=N()|0;break v}g=N()|0;tb(e);break v}x[23549]=0;n=R(143,b|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break w}}ub(b);continue}break}g=N()|0;break v}g=N()|0;break v}g=N()|0;break v}g=N()|0;break v}g=N()|0}ub(b)}bc(q);break e}g=N()|0;break e}while(1){b=x[k>>2];x[23549]=0;b=U(142,b|0,x[d+264>>2],1)|0;f=x[23549];x[23549]=0;Qa:{if((f|0)!=1){if(!b){break o}x[23549]=0;h=R(192,k|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break h}n=0;if((h|0)!=255){break Qa}x[23549]=0;n=R(192,k|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){x[23549]=0;h=R(192,k|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break Qa}}break h}break h}if(h&127){b=Yb(x[o>>2],q);f=$c(x[b>>2],x[x[b+48>>2]+12>>2],e,i&65535);Mu(d+72|0);if(h&1){x[23549]=0;b=R(192,k|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break n}v[d+72|0]=b}if(h&2){x[23549]=0;b=R(192,k|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break n}v[d+73|0]=b}if(h&4){x[23549]=0;b=R(192,k|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break n}v[d+74|0]=b}if(h&8){x[23549]=0;b=R(192,k|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break n}v[d+75|0]=b}if(h&16){x[23549]=0;b=R(192,k|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break n}v[d+76|0]=b}if(h&32){x[23549]=0;b=R(192,k|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break n}v[d+77|0]=b}if(h&64){x[23549]=0;b=R(192,k|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break n}v[d+78|0]=b}E=wS(f,d+72|0);x[d+12>>2]=n;x[d+52>>2]=j+(e^-1);F=x[Cb(d+12|0,d+52|0)>>2];h=0;b=f;while(1){if((h|0)!=(F|0)){b=D(z[a+480188>>1],6)+b|0;l=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[b|0]=l;v[b+1|0]=l>>>8;v[b+2|0]=l>>>16;v[b+3|0]=l>>>24;l=y[f+4|0]|y[f+5|0]<<8;v[b+4|0]=l;v[b+5|0]=l>>>8;h=h+1|0;continue}break}g=g|E}e=(e+n|0)+1|0;while(1){if(e>>>0>=j>>>0){i=i+1|0;e=e-j|0;continue}break}if(s>>>0>(i&65535)>>>0){continue}break}}ub(k);q=q+1|0;continue}break}break h}g=N()|0;tb(d+1344|0);break c}g=N()|0;ub(k);break e}g=N()|0;break e}g=N()|0}ub(t)}ub(u)}Q(g|0);p()}e=1}db=d+1728|0;return e|0}function qaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0,P=0,R=0,S=0,T=0,V=0,W=0,X=0,Y=0,Z=0,$=0,aa=0,ba=0;l=db-1168|0;db=l;wc(b);a:{if(!pr(b,l+1144|0)){break a}if(!rM(l+1144|0)){break a}if((y[l+1152|0]|y[l+1153|0]<<8|(y[l+1154|0]<<16|y[l+1155|0]<<24))!=(Ig(x[b>>2])|0)){break a}if((y[l+1160|0]|y[l+1161|0]<<8|(y[l+1162|0]<<16|y[l+1163|0]<<24))!=(rf(b)|0)){break a}if(!c){h=1;break a}d=l+1088|0;Vb(d,0,56);o=-2;b:{if(!d){break b}x[d+44>>2]=0;x[d+48>>2]=0;x[d+52>>2]=0;x[d+20>>2]=0;x[d+24>>2]=0;x[d+8>>2]=0;o=x[d+32>>2];if(!o){x[d+32>>2]=1069;o=1069}if(!x[d+36>>2]){x[d+36>>2]=1070}e=ib[o|0](x[d+40>>2],1,43784)|0;o=-4;if(!e){break b}x[d+28>>2]=e;x[e+43780>>2]=1;x[e+10992>>2]=0;x[e+10996>>2]=0;x[e>>2]=0;x[e+11008>>2]=15;x[e+11e3>>2]=1;x[e+11004>>2]=0;o=0}if(o){break a}h=y[l+1160|0]|y[l+1161|0]<<8|(y[l+1162|0]<<16|y[l+1163|0]<<24);x[l+1084>>2]=h;J=y[l+1164|0]|y[l+1165|0]<<8|(y[l+1166|0]<<16|y[l+1167|0]<<24);S=rU(l+1072|0,J);c:{d:{while(1){if(!(!J|!h|(g|0)==1)){x[l+32>>2]=1024;g=l+32|0;T=x[Cb(g,l+1084|0)>>2];d=ec(l+40|0,l+48|0,T);h=x[d>>2];d=x[d+4>>2];x[23549]=0;hn(151,g,b,h,d);g=x[23549];x[23549]=0;if((g|0)==1){break d}d=l+48|0;g=d;h=T;e=Z^-1;while(1){if(h>>>0<4){while(1){if(h){e=x[(((y[g|0]^e)&255)<<2)+62192>>2]^e>>>8;h=h-1|0;g=g+1|0;continue}break}Z=e^-1}else{e=x[(((y[g|0]^e)&255)<<2)+62192>>2]^e>>>8;e=e>>>8^x[(((e^y[g+1|0])&255)<<2)+62192>>2];e=e>>>8^x[(((e^y[g+2|0])&255)<<2)+62192>>2];e=e>>>8^x[(((e^y[g+3|0])&255)<<2)+62192>>2];h=h-4|0;g=g+4|0;continue}break}x[l+1092>>2]=T;x[l+1088>>2]=d;x[l+1104>>2]=J;x[l+1100>>2]=x[S>>2]+$;E=db-16|0;db=E;g=-2;q=l+1088|0;e:{if(!q){break e}i=x[q+28>>2];if(!i){break e}ba=x[q+4>>2];x[i+11e3>>2]=0;f:{if(x[i+43780>>2]<0){break f}if(x[i+11004>>2]){break e}h=x[i+11008>>2];g=0;x[i+11004>>2]=0;d=x[i+10996>>2];if(!d){V=(h|0)>0?11:10;H=i+11012|0;e=x[q+4>>2];k=x[i+10992>>2];while(1){x[E+12>>2]=e;x[E+8>>2]=32768-k;C=x[q>>2];d=0;e=0;o=0;I=0;K=0;L=0;W=0;X=db-144|0;db=X;g:{h:{M=k+H|0;if(M>>>0>=H>>>0){F=x[E+8>>2]+M|0;s=F-H|0;Y=(H^-1)+F|0;if(!(s&Y)){break h}}x[E+8>>2]=0;x[E+12>>2]=0;n=-3;break g}t=x[E+12>>2];B=t+C|0;O=x[i+60>>2];u=x[i+40>>2];g=x[i+36>>2];r=x[i+32>>2];h=x[i+56>>2];f=x[i+4>>2];n=-1;j=C;m=M;i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{k=x[i>>2];switch(k|0){case 36:break k;case 39:break n;case 10:break o;case 35:break p;case 17:break q;case 21:break r;case 34:break s;case 42:break w;case 41:break x;case 53:break y;case 52:break z;case 51:break A;case 38:break B;case 27:break C;case 26:break D;case 25:break E;case 24:break F;case 23:break G;case 18:break H;case 16:break I;case 14:break J;case 11:break K;case 9:break L;case 7:break M;case 6:break N;case 3:break O;case 37:break P;case 32:break Q;case 5:break R;case 2:break T;case 1:break U;case 0:break V;default:break j}}x[i+28>>2]=1;h=0;x[i+8>>2]=0;x[i+12>>2]=0;x[i+16>>2]=1;u=0;g=0;r=0;f=0;if(V&1){break U}break S}if((t|0)<=0){x[i>>2]=1;break m}x[i+8>>2]=y[C|0];j=C+1|0}if(j>>>0>=B>>>0){x[i>>2]=2;n=1;break i}g=y[j|0];x[i+12>>2]=g;j=j+1|0;k=36;d=x[i+8>>2];e=256<<(d>>>4);if(e>>>0>32768|e>>>0>s>>>0|(((g|d<<8)>>>0)%31|g&32)){break l}g=0;if((d&15)!=8){break l}}d=0;break v}if((t|0)<=0){x[i>>2]=5;break m}L=f+8|0;j=C+1|0;h=y[C|0]<<f|h;d=2;break v}if((t|0)<=0){x[i>>2]=32;break m}f=f+8|0;j=C+1|0;break u}k=37;break k}d=1;break v}d=4;break v}d=3;break v}d=7;break v}d=9;break v}d=10;break v}d=11;break v}d=12;break v}d=13;break v}d=14;break v}d=15;break v}d=16;break v}d=17;break v}d=8;break v}d=5;break v}d=6;break v}d=18;break v}k=2;break t}k=1;break t}W:while(1){X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{switch(d|0){case 0:if(f>>>0>2){break Ca}d=1;continue;case 2:break Ba;case 1:break Da;case 9:break ga;case 10:break ha;case 11:break ia;case 12:break ja;case 13:break ka;case 14:break la;case 15:break ma;case 16:break na;case 17:break oa;case 8:break ua;case 7:break va;case 6:break wa;case 5:break xa;case 4:break za;case 3:break Aa;default:break pa}}while(1){if(j>>>0>=B>>>0){x[i>>2]=3;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;if(f>>>0<3){continue}break}}d=h&7;x[i+20>>2]=d;k=d>>>1|0;x[i+24>>2]=k;f=f-3|0;h=h>>>3|0;if(d>>>0>=2){break ta}L=f;break qa}f=L&-8;h=h>>>(L&7)|0;g=0;d=0;break sa}if(j>>>0<B>>>0){break ya}x[i>>2]=7;n=1;break i}while(1){if(j>>>0>=B>>>0){x[i>>2]=6;n=1;break i}h=y[j|0]<<f|h;d=f>>>0>4294967287;j=j+1|0;f=f+8|0;if(d){continue}break}d=1;break sa}v[(g+i|0)+10528|0]=y[j|0];j=j+1|0;d=2;break sa}while(1){if(j>>>0>=B>>>0){x[i>>2]=51;n=1;break i}h=y[j|0]<<f|h;d=f>>>0>4294967287;j=j+1|0;f=f+8|0;if(d){continue}break}break _}if(m>>>0<F>>>0){v[m|0]=r;g=g-1|0;m=m+1|0;break $}n=2;k=52;break k}if(m>>>0<F>>>0){break ra}n=2;k=9;break k}if(j>>>0<B>>>0){d=F-m|0;e=B-j|0;d=d>>>0<e>>>0?d:e;d=d>>>0<g>>>0?d:g;g=g-d|0;m=rc(m,j,d)+d|0;j=d+j|0;break Z}x[i>>2]=38;n=1;break i}e=0;Ea:{switch(k-1|0){case 0:x[i+44>>2]=288;x[i+48>>2]=32;d=i+3552|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i+3560|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i+3568|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i+3576|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i- -64|0;k=0;while(1){e=144;if((k|0)==144){while(1){k=256;if((e|0)==256){while(1){e=280;if((k|0)==280){while(1){if((e|0)==288){break da}v[d|0]=8;e=e+1|0;d=d+1|0;continue}}else{v[d|0]=7;k=k+1|0;d=d+1|0;continue}}}else{v[d|0]=9;e=e+1|0;d=d+1|0;continue}}}else{v[d|0]=8;k=k+1|0;d=d+1|0;continue}};case 2:break o;default:break Ea}}d=0;break fa}while(1){Fa:{Ga:{Ha:{Ia:{Ja:{switch(d|0){case 0:if(g>>>0>3){break Ia}if(!f){f=0;d=3;continue W}if(f>>>0>7){break Ga}d=4;continue W;case 1:v[(g+i|0)+10528|0]=h;f=f-8|0;h=h>>>8|0;break Fa;default:break Ja}}g=g+1|0;break Ha}g=z[i+10528>>1];if((g|0)==(z[i+10530>>1]^65535)){break $}break n}d=0;continue}d=1;continue}d=2;continue}}d=8;continue}d=2;continue}if(m>>>0>=F>>>0){n=2;k=53;break k}v[m|0]=y[(O-r&Y)+H|0];m=m+1|0;O=O+1|0;d=7;break aa}while(1){if(j>>>0>=B>>>0){x[i>>2]=27;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;if(u>>>0>f>>>0){continue}break}d=6;break aa}if(j>>>0>=B>>>0){x[i>>2]=26;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;d=4;if(f>>>0<15){break aa}d=5;break aa}while(1){if(j>>>0>=B>>>0){x[i>>2]=25;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;if(u>>>0>f>>>0){continue}break}d=3;break aa}if(m>>>0>=F>>>0){n=2;k=24;break k}v[m|0]=g;m=m+1|0;break ba}if(j>>>0>=B>>>0){x[i>>2]=23;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;d=0;if(f>>>0<15){break aa}d=1;break aa}while(1){if(j>>>0>=B>>>0){x[i>>2]=18;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;if(u>>>0>f>>>0){continue}break}W=r-16|0;d=3;break ca}if(j>>>0>=B>>>0){x[i>>2]=16;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;d=1;if(f>>>0<15){break ca}d=2;break ca}while(1){if(j>>>0>=B>>>0){x[i>>2]=14;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;if(f>>>0<3){continue}break}d=1;break ea}d=g+21185|0;while(1){if(j>>>0>=B>>>0){x[i>>2]=11;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;K=v[d|0];if(f>>>0<K>>>0){continue}break}e=g;d=1}while(1){Ka:{La:{Ma:{if(!d){if(e>>>0>2){break Ma}g=e;K=v[e+21185|0];if(K>>>0<=f>>>0){break Ka}d=9;continue W}g=e<<2;x[(g+i|0)+44>>2]=x[g+63728>>2]+((-1<<K^-1)&h);e=e+1|0;f=f-K|0;h=h>>>K|0;break La}g=0;Vb(i+7040|0,0,288);d=0;break ea}d=0;continue}d=1;continue}}while(1){Na:{Oa:{Pa:{if(!d){if(A[i+52>>2]<=g>>>0){break Pa}if(f>>>0>2){break Na}d=10;continue W}v[(y[g+63744|0]+i|0)+7040|0]=h&7;g=g+1|0;f=f-3|0;h=h>>>3|0;break Oa}x[i+52>>2]=19;break da}d=0;continue}d=1;continue}}I=x[i+24>>2];d=0}while(1){Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{switch(d|0){case 0:d=0;if((I|0)<0){break ba}P=Vb(X,0,64);e=D(I,3488)+i|0;Vb(e+352|0,0,3200);aa=e- -64|0;G=x[i+24>>2];e=x[((G<<2)+i|0)+44>>2];while(1){if((d|0)!=(e|0)){k=(y[d+aa|0]<<2)+P|0;x[k>>2]=x[k>>2]+1;d=d+1|0;continue}break};x[P+64>>2]=0;x[P+68>>2]=0;s=0;d=1;k=0;while(1){if((d|0)!=16){t=d<<2;d=d+1|0;t=x[t+P>>2];k=t+k<<1;x[(P- -64|0)+(d<<2)>>2]=k;s=s+t|0;continue}break};R=0;t=-1;if((k|0)!=65536&s>>>0>=2){break p}while(1){if(e>>>0>R>>>0){s=y[R+aa|0];Za:{if(!s){break Za}d=(P- -64|0)+(s<<2)|0;k=x[d>>2];x[d>>2]=k+1;d=0;e=s;while(1){if(e){d=k&1|d<<1;k=k>>>1|0;e=e-1|0;continue}break}if(s>>>0<=10){e=1<<s;k=s<<9|R;s=D(I,3488)+i|0;while(1){if(d>>>0>1023){break Za}w[(s+(d<<1)|0)+352>>1]=k;d=d+e|0;continue}}G=D(I,3488)+i|0;k=G+((d&1023)<<1)|0;e=w[k+352>>1];_a:{if(e){k=t;t=e;break _a}w[k+352>>1]=t;k=t-2|0}d=d>>>9|0;while(1){d=d>>>1|0;e=d&1;if(s>>>0>=12){e=(G+(e+(t^-1)<<1)|0)+2400|0;t=w[e>>1];if(!t){w[e>>1]=k;t=k;k=k-2|0}s=s-1|0;continue}break}w[((D(I,3488)+i|0)+(e+(t^-1)<<1)|0)+2400>>1]=R;t=k}R=R+1|0;G=x[i+24>>2];e=x[((G<<2)+i|0)+44>>2];continue}break};d=0;if((G|0)!=2){break Ra}break Va;case 1:d=w[(((h&1023)<<1)+i|0)+7328>>1];$a:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>f>>>0){break $a}break Ua}if(f>>>0<11){break $a}e=10;while(1){d=w[(((h>>>e&1)+(d^-1)<<1)+i|0)+9376>>1];if((d|0)<0){k=e+2|0;e=e+1|0;if(f>>>0>=k>>>0){continue}}break}if((d|0)>=0){break Ua}}d=11;continue W;case 2:r=w[(((h&1023)<<1)+i|0)+7328>>1];if((r|0)>=0){break Xa}d=10;while(1){e=h>>>d|0;d=d+1|0;r=w[(((e&1)+(r^-1)<<1)+i|0)+9376>>1];if((r|0)<0){continue}break};break Wa;default:break Ya}}d=v[W+17408|0]+((-1<<u^-1)&h)|0;f=f-u|0;h=h>>>u|0;e=g+i|0;Vb(e+10532|0,(r|0)==16?y[e+10531|0]:0,d);d=d+g|0;break Va}d=r>>>9|0;r=r&511}f=f-d|0;h=h>>>d|0;if(r>>>0>15){break Ta}v[(g+i|0)+10532|0]=r;d=g+1|0}e=x[i+48>>2];g=x[i+44>>2];k=e+g|0;if(k>>>0<=d>>>0){break Sa}if(f>>>0<=14){if((B-j|0)<=1){g=d;d=1;continue}h=y[j|0]<<f|y[j+1|0]<<f+8|h;j=j+2|0;f=f+16|0}g=d}d=2;continue}if(!((r|0)!=16|g)){g=0;r=16;break q}W=r-16|0;u=v[r+21165|0];if(u>>>0<=f>>>0){break Qa}d=12;continue W}if((d|0)!=(k|0)){g=d;break r}k=i+10532|0;rc(i- -64|0,k,g);rc(i+3552|0,g+k|0,e);G=x[i+24>>2];g=d}I=G-1|0;x[i+24>>2]=I;d=0;continue}d=3;continue}}o=h;d=2}ab:while(1){bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{switch(d|0){case 0:d=w[(((h&1023)<<1)+i|0)+352>>1];qb:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>f>>>0){break qb}break bb}if(f>>>0<11){break qb}e=10;while(1){d=w[(((h>>>e&1)+(d^-1)<<1)+i|0)+2400>>1];if((d|0)<0){k=e+2|0;e=e+1|0;if(f>>>0>=k>>>0){continue}}break}if((d|0)>=0){break bb}}d=13;continue W;case 1:g=w[(((h&1023)<<1)+i|0)+352>>1];if((g|0)>=0){break ob}d=10;while(1){e=h>>>d|0;d=d+1|0;g=w[(((e&1)+(g^-1)<<1)+i|0)+2400>>1];if((g|0)<0){continue}break};break nb;case 3:break eb;case 4:break fb;case 5:break jb;case 6:break kb;case 2:break pb;default:break lb}}while(1){d=B-j|0;if(!((F-m|0)>1&(d|0)>=4)){if(f>>>0>14){h=o;break bb}if((d|0)<=1){h=o;d=0;continue ab}h=y[j|0]<<f|y[j+1|0]<<f+8|o;f=f+16|0;j=j+2|0;break bb}if(f>>>0>14){k=j}else{o=(y[j|0]|y[j+1|0]<<8)<<f|o;f=f+16|0;k=j+2|0}g=w[(((o&1023)<<1)+i|0)+352>>1];rb:{if((g|0)<0){d=10;while(1){h=o>>>d|0;d=d+1|0;g=w[(((h&1)+(g^-1)<<1)+i|0)+2400>>1];if((g|0)<0){continue}break}break rb}d=g>>>9|0}f=f-d|0;h=o>>>d|0;if(g&256){j=k;break mb}if(!(f>>>0>14)){h=(y[k|0]|y[k+1|0]<<8)<<f|h;k=k+2|0;f=f+16|0}s=f;j=k;e=w[(((h&1023)<<1)+i|0)+352>>1];sb:{if((e|0)<0){d=10;while(1){o=h>>>d|0;d=d+1|0;e=w[(((o&1)+(e^-1)<<1)+i|0)+2400>>1];if((e|0)<0){continue}break}break sb}d=e>>>9|0}v[m|0]=g;f=s-d|0;o=h>>>d|0;if(!(e&256)){v[m+1|0]=e;m=m+2|0;continue}break}m=m+1|0;h=o;g=e;break mb}d=g>>>9|0;g=g&511}f=f-d|0;h=h>>>d|0;if(g>>>0>255){break mb}d=14;continue W}e=g&511;g=256;if((e|0)==256){break Y}d=e-257<<2;g=x[d+63216>>2];u=0;if(e-285>>>0<4294967276){break db}u=x[d+63344>>2];if(u>>>0>f>>>0){d=15;continue W}d=3;continue}if(!g){o=h;g=-1;break hb}g=g-1|0;d=18;continue W}f=f-u|0;o=h>>>u|0;r=((-1<<u^-1)&h)+r|0;break ib}d=w[(((h&1023)<<1)+i|0)+3840>>1];tb:{if((d|0)<0){e=10;while(1){k=h>>>e|0;e=e+1|0;d=w[(((k&1)+(d^-1)<<1)+i|0)+5888>>1];if((d|0)<0){continue}break}break tb}e=d>>>9|0;d=d&511}f=f-e|0;h=h>>>e|0;e=d<<2;r=x[e+63472>>2];u=0;if(d-30>>>0<4294967270){o=h;break ib}u=x[e+63600>>2];if(u>>>0<=f>>>0){break gb}d=17;continue W}O=m-H|0;d=(O-r&Y)+H|0;if((d>>>0<m>>>0?m:d)+g>>>0>F>>>0){h=o;d=7;continue}while(1){if(g>>>0>=3){v[m|0]=y[d|0];v[m+1|0]=y[d+1|0];v[m+2|0]=y[d+2|0];g=g-3|0;d=d+3|0;m=m+3|0;continue}break}if(!g){g=0;break hb}v[m|0]=y[d|0];if((g|0)!=1){v[m+1|0]=y[d+1|0]}m=g+m|0}d=2;continue}d=6;continue}d=w[(((h&1023)<<1)+i|0)+3840>>1];ub:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>f>>>0){break ub}break cb}if(f>>>0<11){break ub}e=10;while(1){d=w[(((h>>>e&1)+(d^-1)<<1)+i|0)+5888>>1];if((d|0)<0){k=e+2|0;e=e+1|0;if(f>>>0>=k>>>0){continue}}break}if((d|0)>=0){break cb}}d=16;continue W}f=f-u|0;g=((-1<<u^-1)&h)+g|0;h=h>>>u|0}if(f>>>0>14){break cb}if((B-j|0)<=1){d=4;continue}h=y[j|0]<<f|y[j+1|0]<<f+8|h;f=f+16|0;j=j+2|0}d=5;continue}d=1;continue}}if(!g|!f){break Z}if(f>>>0>7){break _}d=5;continue}f=f-8|0;r=h&255;h=h>>>8|0;d=6;continue}if(g){break X}g=0}if(v[i+20|0]&1){break u}d=0;continue}d=7;continue}}h=0;d=f>>>3|0;e=j-C|0;e=e>>>0<=j>>>0?e:0;d=d>>>0<e>>>0?d:e;if((f&-8)==d<<3){j=j-d|0;e=0;d=0;f=0;if(!(V&1)){break s}k=0;break t}_(6780,13026,2797,6790);p()}while(1){vb:{wb:{xb:{yb:{zb:{Ab:{switch(k|0){case 0:if(e>>>0>3){g=e;f=d;break s}f=0;if(d){break zb}g=e;k=1;continue;case 1:break Ab;default:break yb}}if(j>>>0<B>>>0){break wb}x[i>>2]=42;n=1;break i}g=e;f=d;if(d>>>0>7){break xb}k=2;continue}while(1){if(j>>>0>=B>>>0){x[i>>2]=41;n=1;break i}h=y[j|0]<<f|h;e=f>>>0>4294967287;j=j+1|0;d=f+8|0;f=d;if(e){continue}break}e=g}k=h&255;h=h>>>8|0;d=d-8|0;break vb}k=y[j|0];j=j+1|0;e=g;d=f}x[i+16>>2]=x[i+16>>2]<<8|k;e=e+1|0;k=0;continue}}n=0;k=34;break k}k=21;break k}k=17;break k}k=35;break k}k=10;break k}k=39;break k}n=1;break i}g=1}x[i>>2]=k}d=f>>>3|0;e=j-C|0;e=e>>>0<=j>>>0?e:0;d=d>>>0<e>>>0?d:e;j=j-d|0;f=f-(d<<3)|0}x[i+4>>2]=f;x[i+60>>2]=O;x[i+40>>2]=u;x[i+36>>2]=g;x[i+32>>2]=r;x[i+56>>2]=(((f&63)>>>0<32?-1<<f:0)^-1)&h;x[E+12>>2]=j-C;h=m-M|0;x[E+8>>2]=h;if((n|0)<0){break g}f=(h>>>0)%5552|0;g=x[i+28>>2];e=g>>>16|0;k=g&65535;while(1){j=0;if(h){d=M;while(1){if((j|7)>>>0<f>>>0){g=y[d|0]+k|0;o=g+y[d+1|0]|0;t=o+y[d+2|0]|0;s=t+y[d+3|0]|0;m=s+y[d+4|0]|0;C=m+y[d+5|0]|0;L=C+y[d+6|0]|0;k=L+y[d+7|0]|0;e=k+(L+(C+(m+(s+(t+(o+(e+g|0)|0)|0)|0)|0)|0)|0)|0;d=d+8|0;j=j+8|0;continue}break}j=f&8184;while(1){if((f|0)!=(j|0)){j=j+1|0;k=y[d|0]+k|0;e=k+e|0;d=d+1|0;continue}break}h=h-f|0;e=(e>>>0)%65521|0;k=(k>>>0)%65521|0;M=f+M|0;f=5552;continue}break}g=e<<16|k;x[i+28>>2]=g;if(n){break g}n=0;if(!(V&1)){break g}n=(g|0)!=x[i+16>>2]?-2:0}db=X+144|0;x[i+43780>>2]=n;g=x[E+12>>2];x[q>>2]=g+x[q>>2];x[q+4>>2]=x[q+4>>2]-g;x[q+8>>2]=g+x[q+8>>2];x[q+48>>2]=x[i+28>>2];g=x[E+8>>2];x[i+10996>>2]=g;d=x[q+16>>2];d=d>>>0>g>>>0?g:d;rc(x[q+12>>2],x[i+10992>>2]+H|0,d);x[q+12>>2]=d+x[q+12>>2];x[q+16>>2]=x[q+16>>2]-d;x[q+20>>2]=d+x[q+20>>2];h=x[i+10996>>2];x[i+10996>>2]=h-d;k=d+x[i+10992>>2]&32767;x[i+10992>>2]=k;if((n|0)<0){break f}if(!((n|0)!=1|ba)){g=-5;break e}if(n){g=0;e=x[q+4>>2];if(!e|!x[q+16>>2]){break e}if((d|0)==(h|0)){continue}break e}break}g=(d|0)==(h|0);break e}h=x[q+16>>2];d=d>>>0<h>>>0?d:h;rc(x[q+12>>2],(x[i+10992>>2]+i|0)+11012|0,d);x[q+12>>2]=d+x[q+12>>2];x[q+16>>2]=x[q+16>>2]-d;x[q+20>>2]=d+x[q+20>>2];h=x[i+10996>>2];x[i+10996>>2]=h-d;x[i+10992>>2]=d+x[i+10992>>2]&32767;if(x[i+43780>>2]){break e}g=(d|0)==(h|0);break e}g=-3}db=E+16|0;h=x[l+1084>>2]-T|0;x[l+1084>>2]=h;d=J+$|0;J=x[l+1104>>2];$=d-J|0;continue}break}b=l+1088|0;Bb:{if(!b){break Bb}d=x[b+28>>2];if(!d){break Bb}ib[x[b+36>>2]](x[b+40>>2],d);x[b+28>>2]=0}h=0;Cb:{Db:{if(!((y[l+1156|0]|y[l+1157|0]<<8|(y[l+1158|0]<<16|y[l+1159|0]<<24))!=(Z|0)|(g|0)!=1|J)){ge(l+24|0,x[S>>2],x[S+4>>2]);b=Xd(l+16|0);x[23549]=0;g=x[b+4>>2];x[l+8>>2]=x[b>>2];x[l+12>>2]=g;b=Xf(498,l+48|0,x[l+24>>2],x[l+28>>2],l+8|0);g=x[23549];x[23549]=0;if((g|0)==1){break Db}x[23549]=0;h=U(848,a|0,b|0,c|0)|0;a=x[23549];x[23549]=0;if((a|0)==1){break Cb}ub(b)}bc(S);break a}a=N()|0;break c}a=N()|0;ub(b);break c}a=N()|0}bc(S);Q(a|0);p()}db=l+1168|0;return h|0}function bha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=E(0),A=0,C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=E(0),M=E(0),O=0,P=0,S=0,V=0,W=0,Z=0,_=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=E(0),ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=E(0);n=db-96|0;db=n;wc(c);a:{while(1){b:{if(!Lb(x[c>>2],x[c+8>>2],4)){break b}h=n+76|0;d=db-16|0;db=d;c:{if(!Lb(x[c>>2],x[c+8>>2],3)){A=0;while(1){if((A|0)!=3){tg(h+A|0);A=A+1|0;continue}break}break c}tv(d+8|0,h);pd(d,c,x[d+8>>2],x[d+12>>2])}db=d+16|0;d:{e:{if(!cd(h,14681,3)){h=n+32|0;d=db-16|0;db=d;f:{if(!Lb(x[c>>2],x[c+8>>2],7)){A=0;while(1){if((A|0)!=7){tg(h+A|0);A=A+1|0;continue}break}break f}Jo(d+8|0,h);pd(d,c,x[d+8>>2],x[d+12>>2])}db=d+16|0;A=0;h=3;while(1){if((h|0)==7){break d}d=v[(n+32|0)+h|0];if((d|0)<0){break e}h=h+1|0;A=d&255|A<<7;continue}}g:{if(cd(n+76|0,13886,3)){break g}if(!LS(c,13388)){break g}Zb(c,pg(c)+16|0);continue}if(!cd(n+76|0,30286,3)){continue}if(!cd(n+76|0,30290,3)){continue}if(!y[n+76|0]){ng(c,2);continue}if(nQ(n+76|0)){break b}}h=0;break a}Zb(c,A);continue}break}wc(c);d=n+76|0;$A(d,c);V=x[n+76>>2];c=Ee(d);O=Nb(n- -64|0);x[23549]=0;aa=R(535,n+60|0)|0;d=x[23549];x[23549]=0;h:{i:{j:{if((d|0)!=1){kz(Vb(x[aa>>2],0,6668));x[n+48>>2]=0;x[n+52>>2]=0;x[n+40>>2]=0;x[n+44>>2]=0;x[n+32>>2]=0;x[n+36>>2]=0;x[23549]=0;ba=R(536,n+20|0)|0;d=x[23549];x[23549]=0;k:{if((d|0)!=1){A=0;while(1){G=x[aa>>2];g=Cc(V,ca);W=x[ba>>2];d=0;m=0;s=db-17152|0;db=s;x[s+17148>>2]=0;l:{m:{n:{if(y[G+6152|0]!=255|(g|0)<5){break n}if(!tp(G+6152|0,c)){break n}h=kx(y[c+1|0],y[c+2|0],x[G+6148>>2])+sp(c)|0;x[s+17148>>2]=h;if((g|0)==(h|0)){h=g;break m}o:{if((g|0)>=(h+4|0)){if(tp(c,c+h|0)){break o}}x[s+17148>>2]=0;break n}if(h){break m}}f=c;C=Vb(G,0,6668)+6148|0;r=s+17148|0;o=g-4|0;I=(o|0)>0?o:0;while(1){p:{q:{r:{s:{if((m|0)==(I|0)){m=g;break s}if(!JI(f)){break q}i=kx(y[f+1|0],y[f+2|0],x[C>>2]);h=i+sp(f)|0;j=4;k=m+4|0;t:{while(1){if(!(j>>>0>2303|i)){if((o|0)<=((j<<1)+m|0)){break t}i=0;l=f+j|0;u:{if(!tp(f,l)){break u}e=j-sp(f)|0;q=sp(l)+e|0;if((g|0)<(q+(j+k|0)|0)){break u}if(!tp(f,l+q|0)){break u}x[C>>2]=e;i=e;h=j}j=j+1|0;continue}break}if(!i|(g|0)<(h+m|0)){break t}k=g-m|0;j=0;e=0;while(1){v:{w:{if((e|0)!=10){l=(e|0)!=0;K=j;j=f+j|0;j=(K+kx(y[j+1|0],y[j+2|0],i)|0)+sp(j)|0;if((k|0)<(j+4|0)){break v}if(tp(f,f+j|0)){break w}l=0}else{l=1}break v}e=e+1|0;continue}break}if(!l){break t}d=h;break s}if((g|0)!=(h|0)|m){break r}m=0;d=g}x[r>>2]=d;d=m;break p}x[C>>2]=0}f=f+1|0;m=m+1|0;continue}break}h=x[s+17148>>2];if((g|0)>=(d+h|0)?h:0){break m}x[n+32>>2]=d;q=0;break l}F=c+d|0;x[G+6152>>2]=y[F|0]|y[F+1|0]<<8|(y[F+2|0]<<16|y[F+3|0]<<24);x[n+36>>2]=d;x[n+32>>2]=d+h;x[n+40>>2]=y[F+3|0]>191?1:2;ra=n,sa=MI(y[F+1|0],y[F+2|0]),x[ra+44>>2]=sa;x[n+48>>2]=4-(y[F+1|0]>>>1&3);ra=n,sa=jx(y[F+1|0],y[F+2|0]),x[ra+52>>2]=sa;if(!W){q=ix(y[F+1|0]);break l}LI(s+17136|0,F+4|0,h-4|0);if(!(v[F+1|0]&1)){ce(s+17136|0,16)}x:{if(x[n+48>>2]==3){q=0;d=s+17136|0;ia=s+3728|0;h=ia;f=0;e=y[F+1|0];g=D((e>>>3&1)+(e>>>4&1)|0,3)+(y[F+2|0]>>>2&3)|0;g=g-((g|0)!=0)|0;m=y[F+3|0]>191?1:2;y:{if(e&8){i=ce(d,9);m=m<<1;f=ce(d,m+7|0);break y}i=ce(d,m|8)>>>m|0}e=D(g,40);C=e+64064|0;o=e+64384|0;r=D(g,23)+63872|0;e=-1;l=0;z:{while(1){g=y[F+3|0];I=ce(d,12);w[h+4>>1]=I;j=ce(d,9);w[h+6>>1]=j;if((j&65535)>>>0>288){break z}j=g>>>0>191?f<<4:f;ra=h,sa=ce(d,8),v[ra+10|0]=sa;g=ce(d,y[F+1|0]&8?4:9);v[h+13|0]=22;v[h+14|0]=0;x[h>>2]=r;w[h+8>>1]=g;A:{if(ce(d,1)){g=ce(d,2);v[h+11|0]=g;if(!(g&255)){break z}g=ce(d,1);w[h+18>>1]=65287;v[h+12|0]=g;if(y[h+11|0]==2){B:{if(!(g&255)){x[h>>2]=C;v[h+18|0]=8;f=0;g=39;break B}x[h>>2]=o;f=y[F+1|0]&8?8:6;g=30}v[h+14|0]=g;v[h+13|0]=f;j=j&3855}g=ce(d,10);ra=h,sa=ce(d,3),v[ra+21|0]=sa;ra=h,sa=ce(d,3),v[ra+22|0]=sa;ra=h,sa=ce(d,3),v[ra+23|0]=sa;f=g<<5;break A}v[h+11|0]=0;v[h+12|0]=0;f=ce(d,15);ra=h,sa=ce(d,4),v[ra+18|0]=sa;g=ce(d,3);v[h+20|0]=255;v[h+19|0]=g}v[h+17|0]=f&31;v[h+15|0]=f>>>10;v[h+16|0]=f>>>5&31;l=(I&65535)+l|0;C:{if(y[F+1|0]&8){g=ce(d,1);break C}g=z[h+8>>1]>499}v[h+24|0]=g;ra=h,sa=ce(d,1),v[ra+25|0]=sa;g=ce(d,1);v[h+27|0]=j>>>12&15;v[h+26|0]=g;h=h+28|0;f=j<<4;m=m-1|0;if(m){continue}break}e=(x[d+4>>2]+l|0)>(x[d+8>>2]+(i<<3)|0)?-1:i}if(!((e|0)<0|x[s+17140>>2]>x[s+17144>>2])){d=s+17136|0;f=x[d+4>>2];j=x[d+8>>2];m=s+900|0;h=x[G+6144>>2];g=h-e|0;h=(e|0)>(h|0)?h:e;g=rc(m+12|0,(((g|0)>0?g:0)+G|0)+6156|0,h);i=x[d>>2]+(x[d+4>>2]/8|0)|0;d=(j-f|0)/8|0;rc(g+h|0,i,d);LI(m,g,d+h|0);D:{h=x[G+6144>>2]>=(e|0);if(!h){break D}ma=G+2304|0;na=s+8608|0;oa=s+3840|0;while(1){if((y[F+1|0]&8?2:1)>>>0<=q>>>0){break D}pa=Vb(oa,0,4608);e=x[n+40>>2];m=D(D(e,q),28)+ia|0;d=0;ja=(e|0)>0?e:0;C=s+900|0;I=C+7548|0;Z=G+6152|0;while(1){if((d|0)!=(ja|0)){f=D(d,28)+m|0;K=z[f+4>>1];S=x[C+4>>2];t=(C+D(d,39)|0)+16156|0;e=I;o=d;g=db-48|0;db=g;d=f;J=y[d+25|0];H=D(!y[d+13|0]+(y[d+14|0]!=0)|0,28)+64704|0;E:{if(y[Z+1|0]&8){i=y[d+27|0];f=y[z[d+8>>1]+64800|0];j=f&3;v[g+47|0]=j;v[g+46|0]=j;f=f>>>2|0;v[g+45|0]=f;v[g+44|0]=f;break E}f=(y[Z+3|0]&16)>>>4&(o|0)!=0;k=f?12:0;f=z[d+8>>1]>>>f|0;while(1){if((f|0)>=0){i=3;j=1;while(1){if((i|0)>=0){l=y[(i+k|0)+64816|0];v[(g+44|0)+i|0]=((f|0)/(j|0)|0)%(l|0);i=i-1|0;j=D(j,l);continue}break}k=k+4|0;f=f-j|0;continue}break}H=k+H|0;i=-16}j=g;da=g+44|0;f=0;while(1){F:{G:{H:{if((f|0)==4){break H}r=y[f+H|0];if(!r){break H}if(i&8){rc(j,t,r);break G}k=y[f+da|0];if(!k){Vb(j,0,r);Vb(t,0,r);break G}ea=(i|0)>=0?-1:-1<<k^-1;l=0;while(1){if((l|0)==(r|0)){break G}P=ce(C,k);v[l+t|0]=(P|0)==(ea|0)?-1:P;v[j+l|0]=P;l=l+1|0;continue}}v[j+2|0]=0;v[j|0]=0;v[j+1|0]=0;break F}i=i<<1;f=f+1|0;j=j+r|0;t=r+t|0;continue}break}I:{j=y[d+14|0];if(j){f=2-J|0;l=y[d+23|0]<<f;r=y[d+22|0]<<f;k=y[d+21|0]<<f;t=y[d+13|0];i=0;while(1){if(i>>>0>=j>>>0){break I}f=g+(i+t|0)|0;v[f|0]=k+y[f|0];v[f+1|0]=r+y[f+1|0];v[f+2|0]=l+y[f+2|0];i=i+3|0;continue}}if(!y[d+24|0]){break I}i=0;while(1){if((i|0)==10){break I}f=g+i|0;v[f+11|0]=y[f+11|0]+y[i+64840|0];i=i+1|0;continue}}f=J+1|0;i=0;u=hx(E(2048),((((y[Z+3|0]&224)==96)<<1)-y[d+10|0]|0)+258|0);while(1){if(y[d+13|0]+(j&255)>>>0>i>>>0){ra=e+(i<<2)|0,ta=hx(u,y[g+i|0]<<f),B[ra>>2]=ta;i=i+1|0;j=y[d+14|0];continue}break}db=g+48|0;l=(C+D(o,2304)|0)+2940|0;i=e;da=K+S|0;u=E(0);f=x[C+4>>2];g=x[C>>2]+((f|0)/8|0)|0;e=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);e=(e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24))<<(f&7);k=f|-8;t=g+4|0;r=d;H=x[d>>2];J=z[d+6>>1];d=0;while(1){J:{K:{if((J|0)>0){g=d+1|0;f=d+r|0;d=y[f+15|0];ea=(w[(d<<1)+69264>>1]<<1)+64880|0;P=y[f+18|0];if(d>>>0>=16){fa=y[d+69328|0];qa=32-fa|0;while(1){ga=y[H|0]>>>1|0;ha=(J|0)<(ga|0)?J:ga;u=B[i>>2];while(1){f=e>>>27|0;d=5;while(1){f=w[ea+(f<<1)>>1];if((f|0)<0){e=e<<d;j=f&7;f=(e>>>32-j|0)-(f>>3)|0;k=d+k|0;d=j;continue}break}d=f>>>8|0;k=d+k|0;e=e<<d;j=0;while(1){if((j|0)!=2){K=f&15;L:{if((K|0)==15){k=k+fa|0;d=e<<fa;while(1){if((k|0)>=0){d=y[t|0]<<k|d;t=t+1|0;k=k-8|0;continue}break}K=(e>>>qa|0)+15|0;e=K;M:{if((e|0)<=128){L=B[(e<<2)+69424>>2];break M}ka=e>>>0<1024;e=ka?e<<3:e;S=e<<1&64;M=E(E((e&63)-S|0)/E(S+(e&-64)|0));L=E((ka?E(16):E(256))*E(E(E(M*E(E(M*E(.2222222238779068))+E(1.3333333730697632)))+E(1))*B[(e+S>>6<<2)+69424>>2]))}L=E(E(u*L)*E(d>>31|1));break L}d=e;L=E(u*B[(((d>>>27&16|K)^16)<<2)+69360>>2])}B[l>>2]=L;f=f>>>4|0;l=l+4|0;j=j+1|0;e=(K|0)!=0;k=e+k|0;e=d<<e;continue}break}while(1){if((k|0)>=0){e=y[t|0]<<k|e;t=t+1|0;k=k-8|0;continue}break}ha=ha-1|0;if(ha){continue}break}i=i+4|0;H=H+1|0;J=J-ga|0;if((J|0)<=0){break K}d=(P|0)>0;P=P-1|0;if(d){continue}break}break K}while(1){S=y[H|0]>>>1|0;K=(J|0)<(S|0)?J:S;u=B[i>>2];while(1){d=e>>>27|0;f=5;while(1){d=w[ea+(d<<1)>>1];if((d|0)<0){e=e<<f;j=d&7;d=(e>>>32-j|0)-(d>>3)|0;k=f+k|0;f=j;continue}break}f=d>>>8|0;k=f+k|0;e=e<<f;f=0;while(1){if((f|0)!=2){j=d&15;B[l>>2]=u*B[(((j|e>>>27&16)^16)<<2)+69360>>2];d=d>>>4|0;l=l+4|0;f=f+1|0;j=(j|0)!=0;k=j+k|0;e=e<<j;continue}break}while(1){if((k|0)>=0){e=y[t|0]<<k|e;t=t+1|0;k=k-8|0;continue}break}K=K-1|0;if(K){continue}break}i=i+4|0;H=H+1|0;J=J-S|0;if((J|0)<=0){break K}d=(P|0)>0;P=P-1|0;if(d){continue}break}break K}f=1-J|0;while(1){N:{g=y[r+26|0]?69248:69216;d=y[g+(e>>>28|0)|0];if(!(d&8)){d=y[g+((e<<4>>>32-(d&3))+(d>>>3)|0)|0]}g=d&7;k=g+k|0;if((da|0)<((k+(t-x[C>>2]<<3)|0)-24|0)){break N}f=f-1|0;if(!f){f=y[H|0];if(f>>>0<2){break N}H=H+1|0;u=B[i>>2];i=i+4|0;f=f>>>1|0}e=e<<g;if(d>>>0>=128){B[l>>2]=(e|0)<0?E(-u):u;k=k+1|0;e=e<<1}if(d&64){B[l+4>>2]=(e|0)<0?E(-u):u;k=k+1|0;e=e<<1}f=f-1|0;if(!f){g=y[H|0];if(g>>>0<2){break N}H=H+1|0;u=B[i>>2];i=i+4|0;f=g>>>1|0}if(d&32){B[l+8>>2]=(e|0)<0?E(-u):u;k=k+1|0;e=e<<1}if(d&16){B[l+12>>2]=(e|0)<0?E(-u):u;k=k+1|0;e=e<<1}while(1){if((k|0)>=0){e=y[t|0]<<k|e;t=t+1|0;k=k-8|0;continue}break}l=l+16|0;continue}break}x[C+4>>2]=da;break J}d=g;continue}break}d=o+1|0;continue}break}d=y[G+6155|0];O:{if(d&16){l=C+16195|0;d=0;g=db-16|0;db=g;j=C+2940|0;i=j+2304|0;I=x[m>>2];k=y[m+14|0];t=y[m+13|0];r=k+t|0;o=g+4|0;x[o+8>>2]=-1;x[o>>2]=-1;x[o+4>>2]=-1;while(1){if((d|0)!=(r|0)){H=d+I|0;f=y[H|0];e=0;P:{while(1){if(e>>>0>=f>>>0){break P}J=e<<2;if(B[J+i>>2]==E(0)){e=e+2|0;if(B[(J|4)+i>>2]==E(0)){continue}}break}x[o+((d>>>0)%3<<2)>>2]=d;f=y[H|0]}d=d+1|0;i=(f<<2)+i|0;continue}break}if(t){d=x[g+4>>2];e=x[g+8>>2];d=(d|0)>(e|0)?d:e;e=x[g+12>>2];d=(d|0)>(e|0)?d:e;x[g+12>>2]=d;x[g+8>>2]=d;x[g+4>>2]=d}e=k?3:1;i=r-e|0;d=0;while(1){if((d|0)!=(e|0)){o=d+i|0;f=o-e|0;if((f|0)<=x[(g+4|0)+(d<<2)>>2]){f=y[Z+1|0]<<28>>31&3}else{f=y[f+l|0]}v[l+o|0]=f;d=d+1|0;continue}break}o=x[m>>2];r=g+4|0;I=w[m+36>>1]&1;i=0;k=y[Z+1|0]&8?7:64;while(1){t=i+o|0;e=y[t|0];if(e){f=y[Z+3|0]&32;Q:{R:{if(x[r+((i>>>0)%3<<2)>>2]>=(i|0)){break R}d=y[i+l|0];if(d>>>0>=k>>>0){break R}L=f?E(1.4142135381698608):E(1);S:{if(y[Z+1|0]&8){d=d<<3;u=B[d+69956>>2];M=B[d+69952>>2];break S}M=hx(E(1),d+1>>>1<<I);d=d&1;u=d?E(1):M;M=d?M:E(1)}M=E(L*M);L=E(L*u);d=0;while(1){if((d|0)!=(e|0)){f=(d<<2)+j|0;u=B[f>>2];B[f+2304>>2]=u*L;B[f>>2]=u*M;d=d+1|0;continue}break}break Q}if(!f){break Q}II(j,e)}i=i+1|0;j=(y[t|0]<<2)+j|0;continue}break}db=g+16|0;break O}if((d&224)!=96){break O}II(C+2940|0,576)}j=C+7708|0;d=0;while(1){if((d|0)!=(ja|0)){e=y[G+6153|0];o=(y[m+12|0]!=0)<<1<<((D((e>>>3&1)+(e>>>4&1)|0,3)+(y[G+6154|0]>>>2&3)|0)==2);l=(C+D(d,2304)|0)+2940|0;i=l;if(y[m+14|0]){f=x[m>>2]+y[m+13|0]|0;t=((C+D(d,2304)|0)+D(o,72)|0)+2940|0;g=t;e=j;while(1){r=y[f|0];if(r){k=r<<1;I=0;while(1){if((r|0)!=(I|0)){B[e>>2]=B[g>>2];B[e+4>>2]=B[(r<<2)+g>>2];B[e+8>>2]=B[(k<<2)+g>>2];g=g+4|0;I=I+1|0;e=e+12|0;continue}break}f=f+3|0;g=(k<<2)+g|0;continue}break}rc(t,j,e-j|0);e=o-1|0}else{e=31}while(1){g=0;if((e|0)>0){while(1){if((g|0)!=8){f=g<<2;r=f+i|0;u=B[r+72>>2];M=B[f+70016>>2];L=B[f+70048>>2];f=(17-g<<2)+i|0;la=B[f>>2];B[r+72>>2]=E(u*M)-E(L*la);B[f>>2]=E(u*L)+E(la*M);g=g+1|0;continue}break}i=i+72|0;e=e-1|0;continue}break}g=l;e=D(d,1152)+G|0;f=y[m+11|0];if(o){HI(g,e,70080,o);g=D(o,72)+g|0;e=D(o,36)+e|0}T:{if((f|0)==2){i=32-o|0;f=db-80|0;db=f;r=f|8;I=f|4;while(1){if((i|0)>0){o=rc(f,g,72);k=x[e+20>>2];x[g+16>>2]=x[e+16>>2];x[g+20>>2]=k;k=x[e+12>>2];x[g+8>>2]=x[e+8>>2];x[g+12>>2]=k;k=x[e+4>>2];x[g>>2]=x[e>>2];x[g+4>>2]=k;K=o;o=e+24|0;gx(K,g+24|0,o);gx(I,g+48|0,o);gx(r,e,o);g=g+72|0;e=e+36|0;i=i-1|0;continue}break}db=f+80|0;break T}HI(g,e,D((f|0)==3,72)+70080|0,32-o|0)}f=0;i=l+72|0;while(1){g=1;if(f>>>0<=31){while(1){if(g>>>0<=17){e=(g<<2)+i|0;B[e>>2]=-B[e>>2];g=g+2|0;continue}break}i=i+144|0;f=f+2|0;continue}break}m=m+28|0;d=d+1|0;continue}break}KI(ma,pa,18,x[n+40>>2],W,na);q=q+1|0;W=D(x[n+40>>2],1152)+W|0;continue}}e=s+900|0;f=x[e+8>>2]>>>3|0;j=x[e+4>>2]+7>>>3|0;d=f-j|0;g=(d|0)>=511?511:d;if((d|0)>0){uk(G+6156|0,(e+(d>>>0>511?f-511|0:j)|0)+12|0,g)}x[G+6144>>2]=g;break x}kz(G);break l}f=s+17136|0;q=0;m=0;i=0;g=s;d=0;U:{V:{W:{h=y[F+3|0];j=h>>>6|0;switch(j-1|0){case 2:break U;case 0:break W;default:break V}}d=(h>>>2&12)+4|0;break U}d=32}h=y[F+1|0];X:{if((h&6)==6){h=32;e=71484;break X}if(!(h&8)){h=30;e=71487;break X}l=y[F+2|0];e=l>>>2&3;h=jx(h,l)>>>((j|0)!=3)|0;h=h?h:192;if(h>>>0<=55){h=(e|0)==2?12:8;e=71508;break X}h=h>>>0<=95?27:(e|0)!=1?30:27;e=71496}v[g+768|0]=h;v[g+769|0]=(d|0)<(h|0)?d:h;h=e;j=71392;while(1){d=y[g+768|0];if(q>>>0>=d>>>0){q=0;while(1){e=d<<1&510;if(e>>>0>q>>>0){e=g+q|0;Y:{if(!y[e+770|0]){h=6;break Y}h=2;if((y[F+1|0]&6)==6){break Y}h=ce(f,2);d=y[g+768|0]}v[e+834|0]=h;q=q+1|0;continue}break}m=g+770|0;j=g+834|0;h=0;i=e;while(1){if((h|0)!=(i|0)){l=y[m|0];e=l?19>>>y[h+j|0]&3|4:0;m=m+1|0;l=D(l,3)-6|0;u=E(0);d=4;while(1){if(d){if(d&e){C=ce(f,6);o=(C|0)/3|0;u=E(B[(l+(D(o,-3)+C|0)<<2)+71520>>2]*E(2097152>>>o|0))}B[g>>2]=u;d=d>>>1|0;g=g+4|0;continue}break}h=h+1|0;continue}break}q=y[s+769|0];d=y[s+768|0];d=d>>>0<q>>>0?q:d;while(1){if((d|0)!=(q|0)){v[((q<<1)+s|0)+771|0]=0;q=q+1|0;continue}break}}else{if((i|0)==(q|0)){j=y[h|0]+71392|0;i=y[h+2|0]+q|0;m=y[h+1|0];h=h+3|0}e=q<<1;d=y[ce(f,m)+j|0];v[(e+g|0)+770|0]=d;l=y[g+769|0];if(l>>>0>q>>>0){d=y[ce(f,m)+j|0];l=y[g+769|0]}v[((e|1)+g|0)+770|0]=l?d:0;q=q+1|0;continue}break}h=0;g=Vb(s+3840|0,0,4608);I=G+2304|0;k=s+8608|0;q=0;Z:{while(1){if((q|0)==3){break Z}F=g+(h<<2)|0;C=s+17136|0;f=0;l=x[n+48>>2]|1;o=(l|0)>0?l:0;e=576;while(1){if((f|0)!=4){m=F+(D(f,l)<<2)|0;j=0;while(1){if(y[s+768|0]<<1>>>0>j>>>0){_:{i=y[(j+s|0)+770|0];if(!i){break _}if(i>>>0<=16){r=(-1<<i-1)+1|0;d=0;while(1){if((d|0)==(o|0)){break _}ra=(d<<2)+m|0,ta=E(ce(C,i)+r|0),B[ra>>2]=ta;d=d+1|0;continue}}d=2<<i-17;i=ce(C,(d-(d>>>3|0)|0)+3|0);t=d>>>1|0;r=d|1;d=0;while(1){if((d|0)==(o|0)){break _}K=i;i=(i>>>0)/(r>>>0)|0;B[(d<<2)+m>>2]=K-(t+D(r,i)|0)|0;d=d+1|0;continue}}j=j+1|0;m=(e<<2)+m|0;e=18-e|0;continue}break}f=f+1|0;continue}break}h=(l<<2)+h|0;if((h|0)==12){d=(q<<2)+s|0;h=g;e=y[s+769|0];f=g+D(e,72)|0;rc(f+2304|0,f,D(y[s+768|0]-e|0,72));m=0;while(1){if(y[s+768|0]>m>>>0){f=0;while(1){if((f|0)!=12){e=(f<<2)+h|0;B[e>>2]=B[d>>2]*B[e>>2];e=e+2304|0;B[e>>2]=B[d+12>>2]*B[e>>2];f=f+1|0;continue}break}d=d+24|0;h=h+72|0;m=m+1|0;continue}break}KI(I,g,12,x[n+40>>2],W,k);Vb(g,0,4608);W=D(x[n+40>>2],768)+W|0;h=0}q=q+1|0;if(x[s+17140>>2]<=x[s+17144>>2]){continue}break}kz(G);q=0;break l}h=1}q=D(ix(y[G+6153|0]),h)}db=s+17152|0;d=x[n+32>>2];if((d|0)<0|!d){break h}h=x[n+44>>2];if((h|0)!=(_|0)?_:0){break h}d=x[n+40>>2];if((d|0)!=(A|0)?A:0){break h}if(d-3>>>0<4294967294|(h|0)<=0){break i}x[n+16>>2]=0;ra=n,sa=Cc(V,ca),x[ra+12>>2]=sa;g=x[sj(n+32|0,n+16|0,n+12|0)>>2];x[n+16>>2]=0;ra=n,sa=Cc(V,ca),x[ra+12>>2]=sa;e=x[sj(n+32|0,n+16|0,n+12|0)>>2];f=e>>31;$:{if(!q){break $}A=x[ba>>2];x[23549]=0;U(537,O|0,A|0,A+(D(d,q)<<1)|0)|0;A=x[23549];x[23549]=0;if((A|0)!=1){break $}c=T(92296)|0;if((eb|0)==($(92296)|0)){Y(c|0)|0;x[23549]=0;X(17);c=x[23549];x[23549]=0;A=d;_=h;if((c|0)!=1){break h}c=N()|0}id(ba);break k}if((Ic(x[O>>2],x[O+4>>2])>>>0)/(d>>>0)>>>0>268435456){break i}c=c+g|0;_=h;A=d;h=ca-(f+(e>>>0>V>>>0)|0)|0;ca=h;V=V-e|0;if(!!V&(h|0)>=0|(h|0)>0){continue}break}break h}c=N()|0}QO(aa);break j}c=N()|0}id(O);Jc(n+76|0);Q(c|0);p()}A=d;_=h}h=0;aa:{if(!_|!A){break aa}c=x[O>>2];d=x[O+4>>2];if(qc(c,d)){break aa}if((Ic(c,d)>>>0)/(A>>>0)>>>0>268435456){break aa}jt(a,b);b=D(b,104)+a|0;a=b+484380|0;ra=a,sa=(Ic(x[O>>2],x[O+4>>2])>>>0)/(A>>>0)|0,x[ra>>2]=sa;d=b+484414|0;c=z[d>>1];w[d>>1]=(A|0)==2?c|65:c&65470|1;zg(a);c=b+484400|0;h=Sd(x[a>>2],x[c>>2]);if(!h){break aa}d=yb(x[O>>2]);h=yb(x[O+4>>2]);b=db-16|0;db=b;YP(b+8|0,d,h,x[c>>2]);db=b+16|0;h=Sd(x[a>>2],x[a+20>>2])}id(ba);QO(aa);id(O);Jc(n+76|0)}db=n+96|0;return h|0}function DA(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=0,G=0,H=0,I=E(0),K=E(0),L=0,M=0,N=0,O=E(0);C=db-1520|0;db=C;e=C+8|0;M=Vb(e,0,1512),N=-1,x[M+1420>>2]=N;v[C+56|0]=1;x[C+48>>2]=a+b;x[C+40>>2]=a;b=0;q=db-1024|0;db=q;v[e+1377|0]=1;a:{if(!is(e)){break a}f=y[e+1375|0];if(!(f&2)){cc(e,34);break a}if(f&4){cc(e,34);break a}if(f&1){cc(e,34);break a}if(x[e+1116>>2]!=1){cc(e,34);break a}f=y[e+1120|0];if((f|0)!=30){b:{if((f|0)!=64){break b}if(!cx(e,q+1018|0,6)|y[q+1018|0]!=102|(y[q+1019|0]!=105|y[q+1020|0]!=115)){break b}if(y[q+1021|0]!=104|y[q+1022|0]!=101|y[q+1023|0]!=97){break b}if((Ne(e)|0)!=100){break b}if(Ne(e)){break b}cc(e,38);break a}cc(e,34);break a}if((Ne(e)|0)!=1){cc(e,34);break a}if(!cx(e,q+1018|0,6)){cc(e,10);break a}if(!ax(q+1018|0)){cc(e,34);break a}if(Ui(e)){cc(e,34);break a}f=Ne(e);x[e+4>>2]=f;if(!f){cc(e,34);break a}if(f>>>0>=17){cc(e,5);break a}f=Ui(e);x[e>>2]=f;if(!f){cc(e,34);break a}Ui(e);Ui(e);Ui(e);g=Ne(e);f=g>>>4|0;x[e+116>>2]=1<<f;h=g&15;x[e+112>>2]=1<<h;if(h-14>>>0<=4294967287){cc(e,20);break a}if(g+32<<24>>24>=0){cc(e,20);break a}c:{if(f>>>0<h>>>0){cc(e,20);break c}if(!(Ne(e)&1)){cc(e,34);break c}if(!is(e)){break a}if(!bx(e)){break a}if(!ex(e)){break a}d:{e:{if((jh(e)|0)==3){while(1){if((b|0)!=6){M=(q+1018|0)+b|0,N=jh(e),v[M|0]=N;b=b+1|0;continue}break}if(!ax(q+1018|0)){cc(e,20);break c}g=$w(e);b=be(e,g+1|0);x[e+20>>2]=b;if(!b){break e}b=0;h=(g|0)>0?g:0;while(1){if((b|0)!=(h|0)){f=jh(e);v[x[e+20>>2]+b|0]=f;b=b+1|0;continue}break}v[g+x[e+20>>2]|0]=0;b=$w(e);x[e+28>>2]=0;x[e+24>>2]=b;if((b|0)<=0){break d}b=be(e,b<<2);x[e+28>>2]=b;if(b){break d}cc(e,3);break c}cc(e,20);break c}cc(e,3);break c}while(1){f:{g:{if(x[e+24>>2]>(m|0)){j=$w(e);b=be(e,j+1|0);g=m<<2;x[g+x[e+28>>2]>>2]=b;if(!x[g+x[e+28>>2]>>2]){break g}b=0;h=(j|0)>0?j:0;while(1){if((b|0)==(h|0)){break f}f=jh(e);v[x[g+x[e+28>>2]>>2]+b|0]=f;b=b+1|0;continue}}if(!(jh(e)&1)){cc(e,20);break c}wI(e,y[e+1376|0]);v[e+1376|0]=0;while(1){b=ex(e);wI(e,b);v[e+1376|0]=0;if(b){continue}break}b=0;if(!bx(e)){break a}if(!DI(e)){if(x[e+100>>2]!=21){break a}x[e+100>>2]=20;break a}h=0;while(1){if((h|0)!=256){i=h<<24;f=0;while(1){if((f|0)!=8){i=i>>31&79764919^i<<1;f=f+1|0;continue}break}x[(h<<2)+463088>>2]=i;h=h+1|0;continue}break}if((jh(e)|0)==5){while(1){if((b|0)!=6){M=(q+1018|0)+b|0,N=jh(e),v[M|0]=N;b=b+1|0;continue}break}if(!ax(q+1018|0)){cc(e,20);break c}b=nc(e,8)+1|0;x[e+120>>2]=b;b=be(e,D(b,2096));x[e+124>>2]=b;if(!b){cc(e,3);break c}Vb(b,0,D(x[e+120>>2],2096));h:{i:{while(1){j:{k:{if(x[e+120>>2]>(k|0)){b=x[e+124>>2];if((nc(e,8)&255)!=66){cc(e,20);break c}if((nc(e,8)&255)!=67){cc(e,20);break c}if((nc(e,8)&255)!=86){cc(e,20);break c}g=b+D(k,2096)|0;M=g,N=nc(e,8)&255|nc(e,8)<<8,x[M>>2]=N;M=g,N=nc(e,8)&255|(nc(e,8)<<8&65280|nc(e,8)<<16),x[M+4>>2]=N;t=g+4|0;b=0;f=nc(e,1);if(!f){b=nc(e,1)}v[g+23|0]=b;h=x[t>>2];if(!(x[g>>2]|!h)){cc(e,20);break c}l:{if(b&255){i=Gn(e,h);break l}i=be(e,h);x[g+8>>2]=i}if(!i){cc(e,3);break c}r=0;if(f){break k}b=0;while(1){f=x[t>>2];if((f|0)<=(b|0)){break j}m:{n:{if(y[g+23|0]){if(!nc(e,1)){break n}}f=nc(e,5)+1|0;v[b+i|0]=f;if((f&255)!=32){r=r+1|0;break m}cc(e,20);break c}v[b+i|0]=255}b=b+1|0;continue}}f=nc(e,6)+1&255;b=0;o:{while(1){if((b|0)==(f|0)){break o}b=b+1|0;if(!nc(e,16)){continue}break}cc(e,20);break c}b=nc(e,6)+1|0;x[e+128>>2]=b;b=be(e,D(b,1596));x[e+260>>2]=b;p:{q:{if(b){r=0;h=0;r:while(1){if(x[e+128>>2]<=(h|0)){break q}b=nc(e,16);w[((h<<1)+e|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){cc(e,20);break c}if(!b){f=x[e+260>>2]+D(h,1596)|0;M=f,N=nc(e,8),v[M|0]=N;M=f,N=nc(e,16),w[M+2>>1]=N;M=f,N=nc(e,16),w[M+4>>1]=N;M=f,N=nc(e,6),v[M+6|0]=N;M=f,N=nc(e,8),v[M+7|0]=N;k=nc(e,4)+1|0;v[f+8|0]=k;b=0;while(1){if((k&255)>>>0>b>>>0){M=b+f|0,N=nc(e,8),v[M+9|0]=N;b=b+1|0;k=y[f+8|0];continue}break}cc(e,4);break c}n=x[e+260>>2]+D(h,1596)|0;f=nc(e,5);v[n|0]=f;i=0;k=-1;while(1)if((f&255)>>>0<=i>>>0){g=k+1|0;f=0;while(1){if((f|0)!=(g|0)){j=f+n|0;M=j,N=nc(e,3)+1|0,v[M+33|0]=N;b=nc(e,2);v[j+49|0]=b;if(b&255){b=nc(e,8);v[j+65|0]=b;if(x[e+120>>2]<=(b&255)){break p}}i=0;while(1){if(1<<y[j+49|0]>(i|0)){b=nc(e,8)-1|0;w[((n+(f<<4)|0)+(i<<1)|0)+82>>1]=b;i=i+1|0;if(x[e+120>>2]>b<<16>>16){continue}break p}break}f=f+1|0;continue}break}k=2;M=n,N=nc(e,2)+1|0,v[M+1588|0]=N;b=nc(e,4);x[n+1592>>2]=2;m=0;w[n+338>>1]=0;v[n+1589|0]=b;w[n+340>>1]=1<<b;G=n+338|0;l=0;while(1){if(y[n|0]>l>>>0){f=n+y[(l+n|0)+1|0]|0;i=0;while(1){if(y[f+33|0]>i>>>0){b=nc(e,y[n+1589|0]);w[(n+(x[n+1592>>2]<<1)|0)+338>>1]=b;k=x[n+1592>>2]+1|0;x[n+1592>>2]=k;i=i+1|0;continue}break}l=l+1|0;continue}break}while(1){if((k|0)>(m|0)){f=z[(n+(m<<1)|0)+338>>1];b=(q+16|0)+(m<<2)|0;w[b+2>>1]=m;w[b>>1]=f;m=m+1|0;k=x[n+1592>>2];continue}break}vI(q+16|0,k,1071);k=x[n+1592>>2];g=((k|0)<=1?1:k)-1|0;i=0;f=0;while(1){if((f|0)!=(g|0)){b=q+16|0;j=z[b+(f<<2)>>1];f=f+1|0;if((j|0)!=z[b+(f<<2)>>1]){continue}break p}break}while(1){if((i|0)<(k|0)){v[(i+n|0)+838|0]=y[((q+16|0)+(i<<2)|0)+2|0];i=i+1|0;k=x[n+1592>>2];continue}break}i=2;while(1){if((i|0)<(k|0)){x[q+12>>2]=0;x[q+8>>2]=0;f=0;b=(i|0)>0?i:0;o=G+(i<<1)|0;k=65536;j=-1;while(1){if((b|0)!=(f|0)){g=G+(f<<1)|0;l=z[g>>1];if(!((j|0)>=(l|0)|z[o>>1]<=l>>>0)){x[q+12>>2]=f;l=z[g>>1];j=l}if(!((k|0)<=(l|0)|z[o>>1]>=l>>>0)){x[q+8>>2]=f;k=z[g>>1]}f=f+1|0;continue}break}b=n+(i<<1)|0;v[b+1088|0]=x[q+12>>2];v[b+1089|0]=x[q+8>>2];i=i+1|0;k=x[n+1592>>2];continue}break}r=(k|0)>(r|0)?k:r;h=h+1|0;continue r}else{b=nc(e,4);v[(i+n|0)+1|0]=b;b=b&255;k=(b|0)>(k|0)?b:k;i=i+1|0;f=y[n|0];continue}}}cc(e,3);break c}b=nc(e,6)+1|0;x[e+264>>2]=b;b=be(e,D(b,24));x[e+396>>2]=b;if(!b){cc(e,3);break c}f=0;Vb(b,0,D(x[e+264>>2],24));s:{t:{while(1){if(x[e+264>>2]>(f|0)){h=x[e+396>>2];b=nc(e,16);w[((f<<1)+e|0)+268>>1]=b;k=20;if((b&65535)>>>0>2){break s}o=h+D(f,24)|0;M=o,N=nc(e,24),x[M>>2]=N;b=nc(e,24);x[o+4>>2]=b;if(b>>>0<A[o>>2]){break s}M=o,N=nc(e,24)+1|0,x[M+8>>2]=N;M=o,N=nc(e,6)+1|0,v[M+12|0]=N;b=nc(e,8);v[o+13|0]=b;if(x[e+120>>2]<=(b&255)){break s}b=0;while(1){h=y[o+12|0];if(h>>>0>b>>>0){j=(q+16|0)+b|0;l=nc(e,3);if(nc(e,1)){h=nc(e,5)}else{h=0}v[j|0]=l+(h<<3);b=b+1|0;continue}break}b=be(e,h<<4);x[o+20>>2]=b;if(!b){break t}h=0;while(1){if(y[o+12|0]>h>>>0){i=y[(q+16|0)+h|0];b=0;while(1){if((b|0)!=8){u:{if(i>>>b&1){l=nc(e,8);g=b<<1;j=h<<4;w[g+(j+x[o+20>>2]|0)>>1]=l;if(x[e+120>>2]<=w[g+(j+x[o+20>>2]|0)>>1]){break s}break u}w[(x[o+20>>2]+(h<<4)|0)+(b<<1)>>1]=65535}b=b+1|0;continue}break}h=h+1|0;continue}break}b=be(e,x[(x[e+124>>2]+D(y[o+13|0],2096)|0)+4>>2]<<2);x[o+16>>2]=b;if(!b){break t}l=0;Vb(b,0,x[(x[e+124>>2]+D(y[o+13|0],2096)|0)+4>>2]<<2);while(1){b=x[e+124>>2]+D(y[o+13|0],2096)|0;if(x[b+4>>2]>(l|0)){b=x[b>>2];h=be(e,b);g=l<<2;x[g+x[o+16>>2]>>2]=h;i=l;if(!x[g+x[o+16>>2]>>2]){break t}while(1){if((b|0)>0){b=b-1|0;v[b+x[g+x[o+16>>2]>>2]|0]=(i|0)%y[o+12|0];i=(i|0)/y[o+12|0]|0;continue}break}l=l+1|0;continue}break}f=f+1|0;continue}break}b=nc(e,6)+1|0;x[e+400>>2]=b;b=be(e,D(b,40));x[e+404>>2]=b;if(!b){cc(e,3);break c}Vb(b,0,D(x[e+400>>2],40));h=0;while(1){v:{if(x[e+400>>2]>(h|0)){b=x[e+404>>2];if(nc(e,16)){cc(e,20);break c}f=b+D(h,40)|0;b=be(e,D(x[e+4>>2],3));x[f+4>>2]=b;if(!b){cc(e,3);break c}if(nc(e,1)){b=nc(e,4)+1|0}else{b=1}v[f+8|0]=b;w:{if(nc(e,1)){g=nc(e,8)+1|0;w[f>>1]=g;b=0;k=x[e+4>>2];if((k|0)<(g&65535)){cc(e,20);break c}while(1){if(z[f>>1]<=b>>>0){break w}g=nc(e,Wl(k-1|0));j=D(b,3);v[j+x[f+4>>2]|0]=g;g=nc(e,Wl(x[e+4>>2]-1|0));v[(j+x[f+4>>2]|0)+1|0]=g;k=x[e+4>>2];g=j+x[f+4>>2]|0;j=y[g|0];if((k|0)<=(j|0)){cc(e,20);break c}g=y[g+1|0];if((g|0)>=(k|0)){cc(e,20);break c}b=b+1|0;if((g|0)!=(j|0)){continue}break}cc(e,20);break c}w[f>>1]=0}if(nc(e,2)){cc(e,20);break c}b=0;if(y[f+8|0]>=2){while(1){if(x[e+4>>2]<=(b|0)){break v}j=nc(e,4);g=D(b,3);v[(g+x[f+4>>2]|0)+2|0]=j;b=b+1|0;if(y[(g+x[f+4>>2]|0)+2|0]<y[f+8|0]){continue}break}cc(e,20);break c}while(1){if(x[e+4>>2]<=(b|0)){break v}v[(x[f+4>>2]+D(b,3)|0)+2|0]=0;b=b+1|0;continue}}M=e,N=nc(e,6)+1|0,x[M+408>>2]=N;f=e+412|0;i=0;x:{while(1){if(x[e+408>>2]<=(i|0)){break x}h=f+D(i,6)|0;M=h,N=nc(e,1),v[M|0]=N;M=h,N=nc(e,16),w[M+2>>1]=N;M=h,N=nc(e,16),w[M+4>>1]=N;b=nc(e,8);v[h+1|0]=b;if(z[h+2>>1]){cc(e,20);break c}if(z[h+4>>1]){cc(e,20);break c}i=i+1|0;if(x[e+400>>2]>(b&255)){continue}break}cc(e,20);break c}BI(e);x[e+992>>2]=0;g=r<<1;b=0;while(1){if(x[e+4>>2]>(b|0)){j=(b<<2)+e|0;M=j,N=be(e,x[e+116>>2]<<2),x[M+800>>2]=N;M=j,N=be(e,x[e+116>>2]<<1&2147483646),x[M+928>>2]=N;h=be(e,g);x[j+996>>2]=h;f=x[j+800>>2];if(h?!f|!x[j+928>>2]:1){cc(e,3);break c}Vb(f,0,x[e+116>>2]<<2);b=b+1|0;continue}break}b=0;if(!uI(e,0,x[e+112>>2])){break a}if(!uI(e,1,x[e+116>>2])){break a}x[e+104>>2]=x[e+112>>2];j=x[e+116>>2];x[e+108>>2]=j;f=x[e+264>>2];h=(f|0)>0?f:0;l=(j|0)/2|0;k=0;while(1){if((b|0)!=(h|0)){g=x[e+396>>2]+D(b,24)|0;f=x[g+4>>2];i=f>>>0<l>>>0?f:l;f=x[g>>2];f=(i-(f>>>0<l>>>0?f:l)>>>0)/A[g+8>>2]|0;k=(f|0)>(k|0)?f:k;b=b+1|0;continue}break}f=j<<1&2147483646;b=D(x[e+4>>2],(k<<2)+4|0);f=b>>>0<f>>>0?f:b;x[e+12>>2]=f;y:{z:{if(!x[e+80>>2]){break z}b=x[e+92>>2];if((b|0)!=x[e+84>>2]){break y}if(b>>>0>=(f+x[e+88>>2]|0)+1512>>>0){break z}cc(e,3);break c}A:{if(x[e+1380>>2]==-1){x[e+52>>2]=y[e+48|0]?0:x[e+32>>2]-x[e+36>>2]|0;break A}x[e+52>>2]=0}b=1;break a}_(7242,13048,4196,8727);p()}b=0;B:{while(1){if(y[f+8|0]<=b>>>0){break B}nc(e,8);j=b+f|0;M=j,N=nc(e,8),v[M+9|0]=N;g=nc(e,8);v[j+24|0]=g;if(x[e+128>>2]<=y[j+9|0]){cc(e,20);break c}b=b+1|0;if(x[e+264>>2]>(g&255)){continue}break}cc(e,20);break c}h=h+1|0;continue}}k=3}cc(e,k);break c}cc(e,20);break c}m=nc(e,5);b=0;while(1){f=x[t>>2];if((f|0)<=(b|0)){break j}h=nc(e,Wl(f-b|0));m=m+1|0;if((m|0)>=32){cc(e,20);break c}f=b+h|0;if((f|0)>x[t>>2]){cc(e,20);break c}else{Vb(b+i|0,m,h);b=f;continue}}}C:{D:{E:{F:{G:{H:{if(y[g+23|0]){if(f>>2>(r|0)){break H}if(x[e+16>>2]<(f|0)){x[e+16>>2]=f;f=x[t>>2]}b=be(e,f);x[g+8>>2]=b;if(!b){cc(e,3);break c}rc(b,i,x[t>>2]);Ti(e,i,x[t>>2]);i=x[g+8>>2];v[g+23|0]=0;f=x[t>>2]}m=0;h=(f|0)>0?f:0;b=0;while(1){if((b|0)==(h|0)){break G}m=((y[b+i|0]-11&255)>>>0<244)+m|0;b=b+1|0;continue}}x[g+2092>>2]=r;l=g+2092|0;if(r){break F}b=0;h=0;break E}x[g+2092>>2]=m;b=be(e,f<<2);x[g+32>>2]=b;if(b){l=g+2092|0;b=0;break D}cc(e,3);break c}b=be(e,r);x[g+8>>2]=b;if(!b){cc(e,3);break c}b=Gn(e,x[l>>2]<<2);x[g+32>>2]=b;if(!b){cc(e,3);break c}b=Gn(e,x[l>>2]<<2);if(!b){break C}f=x[t>>2];h=x[l>>2]}f=(h<<3)+f|0;if(f>>>0<=A[e+16>>2]){break D}x[e+16>>2]=f}s=x[t>>2];f=0;h=db-128|0;db=h;u=Vb(h,0,128);h=(s|0)>0?s:0;while(1){I:{J:{if((f|0)!=(h|0)){if(y[f+i|0]==255){break J}h=f}if((h|0)==(s|0)){f=1;if(!x[g+2092>>2]){break I}_(15349,13048,1103,7486);p()}j=h+i|0;f=y[j|0];if(f>>>0<32){sI(g,0,h,0,f,b);n=1;j=y[j|0]+1|0;f=1;K:{while(1){if((f|0)==(j|0)){L:while(1){M:{f=1;h=h+1|0;if((s|0)<=(h|0)){break I}G=h+i|0;j=y[G|0];if((j|0)==255){continue}f=j;if(f>>>0>=32){break M}while(1){if((f|0)<=0){f=0;break I}o=u+(f<<2)|0;r=x[o>>2];if(!r){f=f-1|0;continue}break}x[o>>2]=0;sI(g,Ul(r),h,n,j,b);n=n+1|0;m=y[G|0];if((m|0)==(f|0)){continue}while(1){if((f|0)>=(m|0)){continue L}j=u+(m<<2)|0;if(x[j>>2]){break K}x[j>>2]=r+(1<<32-m);m=m-1|0;continue}}break}}else{x[u+(f<<2)>>2]=1<<32-f;f=f+1|0;continue}break}_(14823,13048,1118,7486);p()}_(15393,13048,1133,7486);p()}_(14830,13048,1104,7486);p()}f=f+1|0;continue}break}db=u+128|0;if(!f){if(y[g+23|0]){Ti(e,b,0)}cc(e,20);break c}f=x[l>>2];if(f){f=be(e,(f<<2)+4|0);x[g+2084>>2]=f;if(!f){cc(e,3);break c}f=be(e,(x[l>>2]<<2)+4|0);x[g+2088>>2]=f;if(!f){cc(e,3);break c}x[g+2088>>2]=f+4;x[f>>2]=-1;f=0;m=0;N:{O:{P:{if(y[g+23|0]){while(1){m=x[g+2092>>2];if((m|0)<=(f|0)){break P}h=f<<2;M=h+x[g+2084>>2]|0,N=Ul(x[h+x[g+32>>2]>>2]),x[M>>2]=N;f=f+1|0;continue}}while(1){if(x[g+4>>2]>(f|0)){if(rI(y[g+23|0],y[f+i|0])){M=x[g+2084>>2]+(m<<2)|0,N=Ul(x[x[g+32>>2]+(f<<2)>>2]),x[M>>2]=N;m=m+1|0}f=f+1|0;continue}break}if(x[g+2092>>2]!=(m|0)){break O}}vI(x[g+2084>>2],m,1072);x[x[g+2084>>2]+(x[g+2092>>2]<<2)>>2]=-1;h=0;f=x[g+(y[g+23|0]?2092:4)>>2];r=(f|0)>0?f:0;Q:{while(1){if((h|0)!=(r|0)){f=h;j=y[g+23|0];f=j?x[(f<<2)+b>>2]:f;G=y[f+i|0];R:{if(!rI(j,G)){break R}o=h<<2;s=Ul(x[o+x[g+32>>2]>>2]);f=x[g+2092>>2];m=0;while(1){if((f|0)>=2){u=f>>>1|0;j=u+m|0;n=s>>>0<A[x[g+2084>>2]+(j<<2)>>2];f=n?u:f-u|0;m=n?m:j;continue}break}f=m<<2;if((s|0)!=x[f+x[g+2084>>2]>>2]){break Q}if(y[g+23|0]){x[f+x[g+2088>>2]>>2]=x[b+o>>2];v[x[g+8>>2]+m|0]=G;break R}x[f+x[g+2088>>2]>>2]=h}h=h+1|0;continue}break}break N}_(12089,13048,1230,9865);p()}_(7427,13048,1200,9865);p()}}if(y[g+23|0]){Ti(e,b,x[l>>2]<<2);Ti(e,x[g+32>>2],x[l>>2]<<2);Ti(e,i,x[t>>2]);x[g+32>>2]=0}b=0;h=0;while(1){if((b|0)!=1024){w[(g+(b<<1)|0)+36>>1]=65535;b=b+1|0;continue}break}b=x[g+(y[g+23|0]?2092:4)>>2];b=(b|0)>=32767?32767:b;f=(b|0)>0?b:0;while(1){if((f|0)!=(h|0)){S:{if(y[x[g+8>>2]+h|0]>10){break S}T:{if(y[g+23|0]){b=Ul(x[x[g+2084>>2]+(h<<2)>>2]);break T}b=x[x[g+32>>2]+(h<<2)>>2]}while(1){if(b>>>0>1023){break S}w[(g+(b<<1)|0)+36>>1]=h;b=(1<<y[x[g+8>>2]+h|0])+b|0;continue}}h=h+1|0;continue}break}b=nc(e,4);v[g+21|0]=b;b=b&255;if(b>>>0>=3){cc(e,20);break c}if(b){M=g,O=tI(nc(e,32)),B[M+12>>2]=O;M=g,O=tI(nc(e,32)),B[M+16>>2]=O;M=g,N=nc(e,4)+1|0,v[M+20|0]=N;M=g,N=nc(e,1),v[M+22|0]=N;f=x[g>>2];h=x[t>>2];U:{if(y[g+21|0]==1){H=J(Ir(+E(E(lp(+E(h|0)))/E(f|0))));V:{if(F(H)<2147483648){b=~~H;break V}b=-2147483648}L=+(f|0);H=J(Ej(+E(E(b|0)+E(1)),L));W:{if(F(H)<2147483648){f=~~H;break W}f=-2147483648}b=((f|0)<=(h|0))+b|0;I=E(b|0);if(Ej(+E(I+E(1)),L)<=+(h|0)){b=-1}else{H=J(Ej(+I,L));X:{if(F(H)<2147483648){f=~~H;break X}f=-2147483648}b=(f|0)>(h|0)?-1:b}if((b|0)>=0){break U}cc(e,20);break c}b=D(f,h)}x[g+24>>2]=b;if(!b){cc(e,20);break c}s=Gn(e,b<<1);if(!s){break i}b=0;while(1){i=x[g+24>>2];if((i|0)>(b|0)){f=nc(e,y[g+20|0]);if((f|0)==-1){Ti(e,s,x[g+24>>2]<<1);cc(e,20);break c}else{w[s+(b<<1)>>1]=f;b=b+1|0;continue}}break}Y:{Z:{if(y[g+21|0]==1){n=y[g+23|0];_:{if(n){b=x[l>>2];if(b){break _}break Y}b=x[t>>2]}b=be(e,D(x[g>>2],b)<<2);x[g+28>>2]=b;if(!b){Ti(e,s,x[g+24>>2]<<1);cc(e,3);break c}h=0;b=x[(n?l:t)>>2];r=(b|0)>0?b:0;G=g+2088|0;K=E(0);while(1){if((h|0)==(r|0)){break Z}f=h;f=n?x[x[G>>2]+(f<<2)>>2]:f;i=x[g>>2];b=0;l=1;while(1){if((b|0)<(i|0)){I=E(K+E(E(E(z[s+(((f>>>0)/(l>>>0)>>>0)%A[g+24>>2]<<1)>>1])*B[g+16>>2])+B[g+12>>2]));B[x[g+28>>2]+(D(h,i)+b<<2)>>2]=I;K=y[g+22|0]?I:K;b=b+1|0;i=x[g>>2];if((b|0)>=(i|0)){continue}u=x[g+24>>2];yka(u,0,l,0);if(hb){Ti(e,s,u<<1);cc(e,20);break c}else{l=D(l,u);continue}}break}h=h+1|0;continue}}b=be(e,i<<2);x[g+28>>2]=b;if(!b){break h}b=0;K=E(0);while(1){i=x[g+24>>2];if((i|0)<=(b|0)){break Y}I=E(K+E(E(E(z[s+(b<<1)>>1])*B[g+16>>2])+B[g+12>>2]));B[x[g+28>>2]+(b<<2)>>2]=I;K=y[g+22|0]?I:K;b=b+1|0;continue}}v[g+21|0]=2;i=x[g+24>>2]}Ti(e,s,i<<1)}k=k+1|0;continue}break}cc(e,3);break c}cc(e,3);break c}Ti(e,s,x[g+24>>2]<<1);cc(e,3);break c}cc(e,20);break c}cc(e,3);break c}v[j+x[g+x[e+28>>2]>>2]|0]=0;m=m+1|0;continue}}b=0}db=q+1024|0;$:{aa:{if(!b){x[d>>2]=x[C+104>>2]?1:x[C+108>>2];break aa}b=be(C+8|0,1512);if(b){M=c,N=x[rc(b,C+8|0,1512)+32>>2]-a|0,x[M>>2]=N;x[d>>2]=0;break $}}EI(C+8|0);b=0}db=C+1520|0;return b}function qH(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,w=0,z=0,B=0,C=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0;r=db-48|0;db=r;a:{if(c>>>0<=2){c=c<<2;I=x[c+78348>>2];J=x[c+78336>>2];while(1){c=x[b+4>>2];b:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break b}c=jd(b)}if(Ik(c)){continue}break}o=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}o=(c|0)==45?-1:1;c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break c}c=jd(b)}e:{f:{while(1){if(v[g+4893|0]==(c|32)){g:{if(g>>>0>6){break g}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break g}c=jd(b)}g=g+1|0;if((g|0)!=8){continue}break f}break}if((g|0)!=3){if((g|0)==8){break f}if(!d|g>>>0<4){break e}if((g|0)==8){break f}}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}if(!d|g>>>0<4){break f}c=(c|0)<0;while(1){if(!c){x[b+4>>2]=x[b+4>>2]-1}g=g-1|0;if(g>>>0>3){continue}break}}l=db-16|0;db=l;h=(q(E(E(o|0)*E(Infinity))),j(2));b=h&2147483647;h:{if(b-8388608>>>0<=2130706431){c=b;b=b>>>7|0;c=c<<25;d=b+1065353216|0;break h}c=h<<25;d=h>>>7|2147418112;if(b>>>0>=2139095040){break h}c=0;d=0;if(!b){break h}c=b;b=G(b);zf(l,c,0,0,0,b+81|0);k=x[l>>2];i=x[l+4>>2];c=x[l+8>>2];d=x[l+12>>2]^65536|16265-b<<16}x[r>>2]=k;x[r+4>>2]=i;x[r+8>>2]=c;x[r+12>>2]=h&-2147483648|d;db=l+16|0;k=x[r+8>>2];i=x[r+12>>2];h=x[r>>2];m=x[r+4>>2];break a}i:{j:{k:{if(g){break k}g=0;while(1){if(v[g+9861|0]!=(c|32)){break k}l:{if(g>>>0>1){break l}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break l}c=jd(b)}g=g+1|0;if((g|0)!=3){continue}break}break j}m:{switch(g|0){case 0:n:{if((c|0)!=48){break n}g=x[b+4>>2];o:{if((g|0)!=x[b+104>>2]){x[b+4>>2]=g+1;g=y[g|0];break o}g=jd(b)}if((g&-33)==88){f=db-432|0;db=f;c=x[b+4>>2];p:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;g=y[c|0];break p}g=jd(b)}q:{r:{while(1){if((g|0)!=48){s:{if((g|0)!=46){break q}c=x[b+4>>2];if((c|0)==x[b+104>>2]){break s}x[b+4>>2]=c+1;g=y[c|0];break r}}else{c=x[b+4>>2];if((c|0)!=x[b+104>>2]){H=1;x[b+4>>2]=c+1;g=y[c|0]}else{H=1;g=jd(b)}continue}break}g=jd(b)}s=1;if((g|0)!=48){break q}while(1){c=t;t=c-1|0;u=u-!c|0;c=x[b+4>>2];t:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;g=y[c|0];break t}g=jd(b)}if((g|0)==48){continue}break}H=1}m=1073676288;u:{while(1){v:{c=g|32;w:{x:{K=g-48|0;if(K>>>0<10){break x}if((g|0)!=46&c-97>>>0>5){break u}if((g|0)!=46){break x}if(s){break v}s=1;t=k;u=i;break w}c=(g|0)>57?c-87|0:K;y:{if((i|0)<=0&k>>>0<=7|(i|0)<0){e=c+(e<<4)|0;break y}if(!i&k>>>0<=28){Jg(f+48|0,c);Ed(f+32|0,C,F,h,m,0,0,0,1073414144);C=x[f+32>>2];F=x[f+36>>2];h=x[f+40>>2];m=x[f+44>>2];Ed(f+16|0,x[f+48>>2],x[f+52>>2],x[f+56>>2],x[f+60>>2],C,F,h,m);ug(f,x[f+16>>2],x[f+20>>2],x[f+24>>2],x[f+28>>2],l,p,z,B);z=x[f+8>>2];B=x[f+12>>2];l=x[f>>2];p=x[f+4>>2];break y}if(!c|n){break y}Ed(f+80|0,C,F,h,m,0,0,0,1073610752);ug(f- -64|0,x[f+80>>2],x[f+84>>2],x[f+88>>2],x[f+92>>2],l,p,z,B);z=x[f+72>>2];B=x[f+76>>2];n=1;l=x[f+64>>2];p=x[f+68>>2]}k=k+1|0;i=k?i:i+1|0;H=1}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;g=y[c|0]}else{g=jd(b)}continue}break}g=46}z:{if(!H){c=x[b+116>>2];A:{B:{if((c|0)>0|(c|0)>=0){c=x[b+4>>2];x[b+4>>2]=c-1;if(!d){break B}x[b+4>>2]=c-2;if(!s){break A}x[b+4>>2]=c-3;break A}if(d){break A}}fi(b,0,0)}Fi(f+96|0,+(o|0)*0);l=x[f+96>>2];p=x[f+100>>2];c=x[f+108>>2];b=x[f+104>>2];break z}if((i|0)<=0&k>>>0<=7|(i|0)<0){h=k;m=i;while(1){e=e<<4;h=h+1|0;m=h?m:m+1|0;if((h|0)!=8|m){continue}break}}C:{D:{E:{if((g&-33)==80){h=pH(b,d);c=hb;m=c;if(h|(c|0)!=-2147483648){break C}if(d){c=x[b+116>>2];if((c|0)>0|(c|0)>=0){break E}break D}l=0;p=0;fi(b,0,0);c=0;b=0;break z}h=0;m=0;if(x[b+116>>2]<0){break C}}x[b+4>>2]=x[b+4>>2]-1}h=0;m=0}if(!e){Fi(f+112|0,+(o|0)*0);l=x[f+112>>2];p=x[f+116>>2];c=x[f+124>>2];b=x[f+120>>2];break z}b=s?t:k;i=(s?u:i)<<2|b>>>30;c=h+(b<<2)|0;b=i+m|0;k=c-32|0;i=(c>>>0<h>>>0?b+1|0:b)-(c>>>0<32)|0;b=i;if(k>>>0>0-I>>>0&(b|0)>=0|(b|0)>0){x[23424]=68;Jg(f+160|0,o);Ed(f+144|0,x[f+160>>2],x[f+164>>2],x[f+168>>2],x[f+172>>2],-1,-1,-1,2147418111);Ed(f+128|0,x[f+144>>2],x[f+148>>2],x[f+152>>2],x[f+156>>2],-1,-1,-1,2147418111);l=x[f+128>>2];p=x[f+132>>2];c=x[f+140>>2];b=x[f+136>>2];break z}b=I-226|0;c=b>>31;if((i|0)>=(c|0)&b>>>0<=k>>>0|(c|0)<(i|0)){if((e|0)>=0){while(1){ug(f+416|0,l,p,z,B,0,0,0,-1073807360);b=kO(l,p,z,B,1073610752);c=(b|0)>=0;b=c;ug(f+400|0,l,p,z,B,b?x[f+416>>2]:l,b?x[f+420>>2]:p,b?x[f+424>>2]:z,b?x[f+428>>2]:B);b=k;k=b-1|0;i=i-!b|0;z=x[f+408>>2];B=x[f+412>>2];l=x[f+400>>2];p=x[f+404>>2];e=c|e<<1;if((e|0)>=0){continue}break}}b=i-((I>>31)+(k>>>0<I>>>0)|0)|0;c=(k-I|0)+32|0;b=c>>>0<32?b+1|0:b;c=c>>>0<J>>>0&(b|0)<=0|(b|0)<0?(c|0)>0?c:0:J;F:{if((c|0)>=113){Jg(f+384|0,o);t=x[f+392>>2];u=x[f+396>>2];C=x[f+384>>2];F=x[f+388>>2];h=0;b=0;break F}Fi(f+352|0,zj(1,144-c|0));Jg(f+336|0,o);C=x[f+336>>2];F=x[f+340>>2];t=x[f+344>>2];u=x[f+348>>2];sH(f+368|0,x[f+352>>2],x[f+356>>2],x[f+360>>2],x[f+364>>2],C,F,t,u);w=x[f+376>>2];L=x[f+380>>2];h=x[f+372>>2];b=x[f+368>>2]}d=!(e&1)&((mm(l,p,z,B,0,0,0,0)|0)!=0&(c|0)<32);bn(f+320|0,d+e|0);Ed(f+304|0,C,F,t,u,x[f+320>>2],x[f+324>>2],x[f+328>>2],x[f+332>>2]);c=b;ug(f+272|0,x[f+304>>2],x[f+308>>2],x[f+312>>2],x[f+316>>2],b,h,w,L);b=d;Ed(f+288|0,C,F,t,u,b?0:l,b?0:p,b?0:z,b?0:B);ug(f+256|0,x[f+288>>2],x[f+292>>2],x[f+296>>2],x[f+300>>2],x[f+272>>2],x[f+276>>2],x[f+280>>2],x[f+284>>2]);sw(f+240|0,x[f+256>>2],x[f+260>>2],x[f+264>>2],x[f+268>>2],c,h,w,L);b=x[f+240>>2];d=x[f+244>>2];c=x[f+248>>2];h=x[f+252>>2];if(!mm(b,d,c,h,0,0,0,0)){x[23424]=68}rH(f+224|0,b,d,c,h,k);l=x[f+224>>2];p=x[f+228>>2];c=x[f+236>>2];b=x[f+232>>2];break z}x[23424]=68;Jg(f+208|0,o);Ed(f+192|0,x[f+208>>2],x[f+212>>2],x[f+216>>2],x[f+220>>2],0,0,0,65536);Ed(f+176|0,x[f+192>>2],x[f+196>>2],x[f+200>>2],x[f+204>>2],0,0,0,65536);l=x[f+176>>2];p=x[f+180>>2];c=x[f+188>>2];b=x[f+184>>2]}x[r+16>>2]=l;x[r+20>>2]=p;x[r+24>>2]=b;x[r+28>>2]=c;db=f+432|0;k=x[r+24>>2];i=x[r+28>>2];h=x[r+16>>2];m=x[r+20>>2];break a}if(x[b+116>>2]<0){break n}x[b+4>>2]=x[b+4>>2]-1}g=b;w=o;f=d;b=0;o=0;e=db-8976|0;db=e;K=0-I|0;L=K-J|0;G:{H:{while(1){if((c|0)!=48){I:{if((c|0)!=46){break G}c=x[g+4>>2];if((c|0)==x[g+104>>2]){break I}x[g+4>>2]=c+1;c=y[c|0];break H}}else{b=x[g+4>>2];if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;c=y[b|0]}else{c=jd(g)}b=1;continue}break}c=jd(g)}n=1;if((c|0)!=48){break G}while(1){b=k;k=b-1|0;i=i-!b|0;b=x[g+4>>2];J:{if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;c=y[b|0];break J}c=jd(g)}if((c|0)==48){continue}break}b=1}x[e+784>>2]=0;K:{L:{d=(c|0)==46;l=c-48|0;M:{N:{O:{if(d|l>>>0<=9){while(1){P:{if(d&1){if(!n){k=h;i=m;n=1;break P}d=!b;break O}h=h+1|0;m=h?m:m+1|0;if((o|0)<=2044){H=(c|0)==48?H:h;b=(e+784|0)+(o<<2)|0;if(s){l=(D(x[b>>2],10)+c|0)-48|0}x[b>>2]=l;b=1;d=s+1|0;c=(d|0)==9;s=c?0:d;o=c+o|0;break P}if((c|0)==48){break P}x[e+8960>>2]=x[e+8960>>2]|1;H=18396}c=x[g+4>>2];Q:{if((c|0)!=x[g+104>>2]){x[g+4>>2]=c+1;c=y[c|0];break Q}c=jd(g)}d=(c|0)==46;l=c-48|0;if(d|l>>>0<10){continue}break}}k=n?k:h;i=n?i:m;if(!(!b|(c&-33)!=69)){l=pH(g,f);b=hb;p=b;R:{if(l|(b|0)!=-2147483648){break R}if(!f){break M}l=0;p=0;if(x[g+116>>2]<0){break R}x[g+4>>2]=x[g+4>>2]-1}i=i+p|0;k=k+l|0;i=k>>>0<l>>>0?i+1|0:i;break L}d=!b;if((c|0)<0){break N}}if(x[g+116>>2]<0){break N}x[g+4>>2]=x[g+4>>2]-1}if(!d){break L}x[23424]=28}h=0;m=0;fi(g,0,0);c=0;b=0;break K}b=x[e+784>>2];if(!b){Fi(e,+(w|0)*0);h=x[e>>2];m=x[e+4>>2];c=x[e+12>>2];b=x[e+8>>2];break K}if(!((h|0)!=(k|0)|(i|0)!=(m|0)|(h>>>0>9&(m|0)>=0|(m|0)>0)|(b>>>J|0?(J|0)<=30:0))){Jg(e+48|0,w);bn(e+32|0,b);Ed(e+16|0,x[e+48>>2],x[e+52>>2],x[e+56>>2],x[e+60>>2],x[e+32>>2],x[e+36>>2],x[e+40>>2],x[e+44>>2]);h=x[e+16>>2];m=x[e+20>>2];c=x[e+28>>2];b=x[e+24>>2];break K}if(k>>>0>K>>>1>>>0&(i|0)>=0|(i|0)>0){x[23424]=68;Jg(e+96|0,w);Ed(e+80|0,x[e+96>>2],x[e+100>>2],x[e+104>>2],x[e+108>>2],-1,-1,-1,2147418111);Ed(e- -64|0,x[e+80>>2],x[e+84>>2],x[e+88>>2],x[e+92>>2],-1,-1,-1,2147418111);h=x[e+64>>2];m=x[e+68>>2];c=x[e+76>>2];b=x[e+72>>2];break K}b=I-226|0;c=k>>>0<b>>>0;b=b>>31;if(c&(i|0)<=(b|0)|(b|0)>(i|0)){x[23424]=68;Jg(e+144|0,w);Ed(e+128|0,x[e+144>>2],x[e+148>>2],x[e+152>>2],x[e+156>>2],0,0,0,65536);Ed(e+112|0,x[e+128>>2],x[e+132>>2],x[e+136>>2],x[e+140>>2],0,0,0,65536);h=x[e+112>>2];m=x[e+116>>2];c=x[e+124>>2];b=x[e+120>>2];break K}if(s){if((s|0)<=8){b=(e+784|0)+(o<<2)|0;g=x[b>>2];while(1){g=D(g,10);s=s+1|0;if((s|0)!=9){continue}break}x[b>>2]=g}o=o+1|0}n=k;S:{if((k|0)<(H|0)|(H|0)>=9|(k|0)>17){break S}if((n|0)==9){Jg(e+192|0,w);bn(e+176|0,x[e+784>>2]);Ed(e+160|0,x[e+192>>2],x[e+196>>2],x[e+200>>2],x[e+204>>2],x[e+176>>2],x[e+180>>2],x[e+184>>2],x[e+188>>2]);h=x[e+160>>2];m=x[e+164>>2];c=x[e+172>>2];b=x[e+168>>2];break K}if((n|0)<=8){Jg(e+272|0,w);bn(e+256|0,x[e+784>>2]);Ed(e+240|0,x[e+272>>2],x[e+276>>2],x[e+280>>2],x[e+284>>2],x[e+256>>2],x[e+260>>2],x[e+264>>2],x[e+268>>2]);Jg(e+224|0,x[(0-n<<2)+78336>>2]);aL(e+208|0,x[e+240>>2],x[e+244>>2],x[e+248>>2],x[e+252>>2],x[e+224>>2],x[e+228>>2],x[e+232>>2],x[e+236>>2]);h=x[e+208>>2];m=x[e+212>>2];c=x[e+220>>2];b=x[e+216>>2];break K}b=(D(n,-3)+J|0)+27|0;c=x[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break S}Jg(e+352|0,w);bn(e+336|0,c);Ed(e+320|0,x[e+352>>2],x[e+356>>2],x[e+360>>2],x[e+364>>2],x[e+336>>2],x[e+340>>2],x[e+344>>2],x[e+348>>2]);Jg(e+304|0,x[(n<<2)+78264>>2]);Ed(e+288|0,x[e+320>>2],x[e+324>>2],x[e+328>>2],x[e+332>>2],x[e+304>>2],x[e+308>>2],x[e+312>>2],x[e+316>>2]);h=x[e+288>>2];m=x[e+292>>2];c=x[e+300>>2];b=x[e+296>>2];break K}while(1){c=o;o=c-1|0;if(!x[(e+784|0)+(o<<2)>>2]){continue}break}s=0;b=(n|0)%9|0;T:{if(!b){d=0;break T}d=0;b=(n|0)<0?b+9|0:b;U:{if(!c){c=0;break U}k=x[(0-b<<2)+78336>>2];i=1e9/(k|0)|0;l=0;g=0;while(1){h=l;l=(e+784|0)+(g<<2)|0;m=x[l>>2];o=(m>>>0)/(k>>>0)|0;h=h+o|0;x[l>>2]=h;h=!h&(d|0)==(g|0);d=h?d+1&2047:d;n=h?n-9|0:n;l=D(i,m-D(k,o)|0);g=g+1|0;if((g|0)!=(c|0)){continue}break}if(!l){break U}x[(e+784|0)+(c<<2)>>2]=l;c=c+1|0}n=(n-b|0)+9|0}while(1){g=(e+784|0)+(d<<2)|0;V:{while(1){W:{if((n|0)<36){break W}if((n|0)!=36){break V}if(A[g>>2]<=10384592){break W}n=36;break V}o=c+2047|0;l=0;b=c;while(1){c=b;h=o&2047;o=(e+784|0)+(h<<2)|0;b=x[o>>2];m=b>>>3|0;k=l;l=b<<29;k=k+l|0;b=m;i=k>>>0<l>>>0?b+1|0:b;if(!i&k>>>0<1000000001){l=0}else{l=Bka(k,i,1e9,0);b=yka(l,hb,-1e9,-1);k=b+k|0}x[o>>2]=k;b=(h|0)!=(c-1&2047)?c:(d|0)==(h|0)?c:k?c:h;o=h-1|0;if((d|0)!=(h|0)){continue}break}s=s-29|0;if(!l){continue}break}d=d-1&2047;if((d|0)==(b|0)){k=e+784|0;c=k+((b+2046&2047)<<2)|0;g=c;m=x[c>>2];c=b-1&2047;x[g>>2]=m|x[k+(c<<2)>>2]}n=n+9|0;x[(e+784|0)+(d<<2)>>2]=l;continue}break}X:{Y:while(1){k=c+1&2047;l=(e+784|0)+((c-1&2047)<<2)|0;while(1){h=(n|0)>45?9:1;Z:{while(1){b=d;g=0;_:{while(1){$:{d=b+g&2047;if((d|0)==(c|0)){break $}d=x[(e+784|0)+(d<<2)>>2];i=x[(g<<2)+78288>>2];if(d>>>0<i>>>0){break $}if(d>>>0>i>>>0){break _}g=g+1|0;if((g|0)!=4){continue}}break}if((n|0)!=36){break _}g=0;k=0;i=0;h=0;m=0;while(1){d=b+g&2047;if((d|0)==(c|0)){c=c+1&2047;x[(e+(c<<2)|0)+780>>2]=0}bn(e+768|0,x[(e+784|0)+(d<<2)>>2]);Ed(e+752|0,k,i,h,m,0,0,1342177280,1075633366);ug(e+736|0,x[e+752>>2],x[e+756>>2],x[e+760>>2],x[e+764>>2],x[e+768>>2],x[e+772>>2],x[e+776>>2],x[e+780>>2]);h=x[e+744>>2];m=x[e+748>>2];k=x[e+736>>2];i=x[e+740>>2];g=g+1|0;if((g|0)!=4){continue}break}Jg(e+720|0,w);Ed(e+704|0,k,i,h,m,x[e+720>>2],x[e+724>>2],x[e+728>>2],x[e+732>>2]);h=x[e+712>>2];m=x[e+716>>2];k=0;i=0;l=x[e+704>>2];p=x[e+708>>2];f=s+113|0;g=f-I|0;o=(g|0)<(J|0);d=o?(g|0)>0?g:0:J;if((d|0)<=112){break Z}break X}s=h+s|0;d=c;if((b|0)==(c|0)){continue}break}m=1e9>>>h|0;o=-1<<h^-1;g=0;d=b;while(1){i=g;g=(e+784|0)+(b<<2)|0;f=x[g>>2];i=i+(f>>>h|0)|0;x[g>>2]=i;i=!i&(b|0)==(d|0);d=i?d+1&2047:d;n=i?n-9|0:n;g=D(m,f&o);b=b+1&2047;if((c|0)!=(b|0)){continue}break}if(!g){continue}if((d|0)!=(k|0)){x[(e+784|0)+(c<<2)>>2]=g;c=k;continue Y}x[l>>2]=x[l>>2]|1;continue}break}break}Fi(e+656|0,zj(1,225-d|0));sH(e+688|0,x[e+656>>2],x[e+660>>2],x[e+664>>2],x[e+668>>2],l,p,h,m);C=x[e+696>>2];F=x[e+700>>2];z=x[e+688>>2];B=x[e+692>>2];Fi(e+640|0,zj(1,113-d|0));zK(e+672|0,l,p,h,m,x[e+640>>2],x[e+644>>2],x[e+648>>2],x[e+652>>2]);k=x[e+672>>2];i=x[e+676>>2];t=x[e+680>>2];u=x[e+684>>2];sw(e+624|0,l,p,h,m,k,i,t,u);ug(e+608|0,z,B,C,F,x[e+624>>2],x[e+628>>2],x[e+632>>2],x[e+636>>2]);h=x[e+616>>2];m=x[e+620>>2];l=x[e+608>>2];p=x[e+612>>2]}n=b+4&2047;aa:{if((n|0)==(c|0)){break aa}n=x[(e+784|0)+(n<<2)>>2];ba:{if(n>>>0<=499999999){if(!n&(b+5&2047)==(c|0)){break ba}Fi(e+496|0,+(w|0)*.25);ug(e+480|0,k,i,t,u,x[e+496>>2],x[e+500>>2],x[e+504>>2],x[e+508>>2]);t=x[e+488>>2];u=x[e+492>>2];k=x[e+480>>2];i=x[e+484>>2];break ba}if((n|0)!=5e8){Fi(e+592|0,+(w|0)*.75);ug(e+576|0,k,i,t,u,x[e+592>>2],x[e+596>>2],x[e+600>>2],x[e+604>>2]);t=x[e+584>>2];u=x[e+588>>2];k=x[e+576>>2];i=x[e+580>>2];break ba}M=+(w|0);if((b+5&2047)==(c|0)){Fi(e+528|0,M*.5);ug(e+512|0,k,i,t,u,x[e+528>>2],x[e+532>>2],x[e+536>>2],x[e+540>>2]);t=x[e+520>>2];u=x[e+524>>2];k=x[e+512>>2];i=x[e+516>>2];break ba}Fi(e+560|0,M*.75);ug(e+544|0,k,i,t,u,x[e+560>>2],x[e+564>>2],x[e+568>>2],x[e+572>>2]);t=x[e+552>>2];u=x[e+556>>2];k=x[e+544>>2];i=x[e+548>>2]}if((d|0)>111){break aa}zK(e+464|0,k,i,t,u,0,0,0,1073676288);if(mm(x[e+464>>2],x[e+468>>2],x[e+472>>2],x[e+476>>2],0,0,0,0)){break aa}ug(e+448|0,k,i,t,u,0,0,0,1073676288);t=x[e+456>>2];u=x[e+460>>2];k=x[e+448>>2];i=x[e+452>>2]}ug(e+432|0,l,p,h,m,k,i,t,u);sw(e+416|0,x[e+432>>2],x[e+436>>2],x[e+440>>2],x[e+444>>2],z,B,C,F);h=x[e+424>>2];m=x[e+428>>2];l=x[e+416>>2];p=x[e+420>>2];ca:{if((L-2|0)>=(f&2147483647)){break ca}x[e+408>>2]=h;x[e+412>>2]=m&2147483647;x[e+400>>2]=l;x[e+404>>2]=p;Ed(e+384|0,l,p,h,m,0,0,0,1073610752);c=kO(x[e+400>>2],x[e+404>>2],x[e+408>>2],x[e+412>>2],1081081856);b=(c|0)>=0;h=b?x[e+392>>2]:h;m=b?x[e+396>>2]:m;l=b?x[e+384>>2]:l;p=b?x[e+388>>2]:p;s=b+s|0;if(!(o&((d|0)!=(g|0)|(c|0)<0)&(mm(k,i,t,u,0,0,0,0)|0)!=0)&(s+110|0)<=(L|0)){break ca}x[23424]=68}rH(e+368|0,l,p,h,m,s);h=x[e+368>>2];m=x[e+372>>2];c=x[e+380>>2];b=x[e+376>>2]}x[r+40>>2]=b;x[r+44>>2]=c;x[r+32>>2]=h;x[r+36>>2]=m;db=e+8976|0;k=x[r+40>>2];i=x[r+44>>2];h=x[r+32>>2];m=x[r+36>>2];break a;case 3:break j;default:break m}}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}break i}da:{c=x[b+4>>2];ea:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break ea}c=jd(b)}if((c|0)==40){g=1;break da}i=2147450880;if(x[b+116>>2]<0){break a}x[b+4>>2]=x[b+4>>2]-1;break a}while(1){c=x[b+4>>2];fa:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break fa}c=jd(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){g=g+1|0;continue}break}i=2147450880;if((c|0)==41){break a}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}ga:{if(d){if(g){break ga}break a}break i}while(1){if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}g=g-1|0;if(g){continue}break}break a}x[23424]=28;fi(b,0,0)}i=0}x[a>>2]=h;x[a+4>>2]=m;x[a+8>>2]=k;x[a+12>>2]=i;db=r+48|0}function Zha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;d=db-416|0;db=d;wc(b);g=d+411|0;e=Ju(b,g);if(!e){FT(g)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!e){break k}if(!GT(d+411|0)){break k}if(!c){m=1;break k}H=le(d+388|0,b);x[23549]=0;P(447,d+376|0,H|0);b=x[23549];x[23549]=0;l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if((b|0)!=1){x[23549]=0;S(448,d+356|0,d+376|0,20041);b=x[23549];x[23549]=0;if((b|0)==1){break u}x[23549]=0;e=R(164,x[d+356>>2])|0;b=x[23549];x[23549]=0;if((b|0)==1){break m}if(!e){break l}x[23549]=0;e=O(449,d+356|0,d+265|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break m}if(!e){break l}x[23549]=0;P(235,a|0,16384);b=x[23549];x[23549]=0;if((b|0)==1){break m}x[a+480208>>2]=8;x[23549]=0;e=U(253,a+1074312|0,9,1)|0;b=x[23549];x[23549]=0;if((b|0)==1){break m}x[23549]=0;e=U(253,e|0,114,1)|0;b=x[23549];x[23549]=0;if((b|0)==1){break m}x[23549]=0;e=O(254,e|0,21)|0;b=x[23549];x[23549]=0;if((b|0)==1){break m}x[23549]=0;O(254,e|0,30)|0;b=x[23549];x[23549]=0;if((b|0)==1){break m}x[23549]=0;e=O(1,d+252|0,8178)|0;b=x[23549];x[23549]=0;if((b|0)==1){break r}zb(a+1298344|0,e);tb(e);x[23549]=0;e=O(1,d+240|0,10605)|0;b=x[23549];x[23549]=0;if((b|0)==1){break q}zb(a+1298356|0,e);tb(e);x[23549]=0;h=O(1,d+228|0,17089)|0;b=x[23549];x[23549]=0;if((b|0)==1){break p}e=14704;b=y[d+415|0];switch(b-16|0){case 1:break n;case 0:break t;default:break s}}f=N()|0;break a}f=N()|0;break b}e=14685;break n}if(!b){break o}e=21204;break n}f=N()|0;break c}f=N()|0;break c}f=N()|0;break c}e=13112}x[23549]=0;g=O(1,d+216|0,e|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break e}x[23549]=0;S(2,d+176|0,h|0,g|0);b=x[23549];x[23549]=0;if((b|0)==1){break f}e=d+176|0;zb(a+1298368|0,e);tb(e);tb(g);tb(h);x[a+1298404>>2]=5;b=d+80|0;_e(b,3,d+265|0);x[23549]=0;P(208,e|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break g}b=d+176|0;zb(a+1298308|0,b);tb(b);b=d+204|0;nj(b,3,d+297|0);x[23549]=0;P(208,d+80|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break h}x[23549]=0;S(11,d+176|0,5,d+80|0);b=x[23549];x[23549]=0;if((b|0)==1){break i}b=d+176|0;zb(a+1298320|0,b);tb(b);tb(d+80|0);x[a+480200>>2]=y[d+321|0]+1;I=a,J=Vd(y[d+322|0],1,255),x[I+480196>>2]=J;I=a,J=D(Vd(y[d+323|0],4,255),1e4),x[I+480204>>2]=J;e=y[a+484376|0];b=x[a+484360>>2];x[23549]=0;aa(332,Wb(b,e)|0,d+356|0,y[d+317|0]|y[d+318|0]<<8,65535,65535);b=x[23549];x[23549]=0;if((b|0)==1){break m}$e(Wb(x[a+484360>>2],y[a+484376|0]),y[d+319|0]|y[d+320|0]<<8);w[a+480188>>1]=0;b=0;while(1){if((b|0)==32){x[23549]=0;S(448,d+176|0,d+376|0,17741);b=x[23549];x[23549]=0;if((b|0)!=1){b=d+176|0;g=Zc(d+356|0,b);ub(b);b=x[g>>2];x[23549]=0;e=R(146,b|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break m}x[23549]=0;V(321,a+1298332|0,g|0,e|0,0);b=x[23549];x[23549]=0;if((b|0)==1){break m}x[23549]=0;S(448,d+176|0,d+376|0,21321);b=x[23549];x[23549]=0;if((b|0)!=1){b=d+176|0;j=Zc(g,b);ub(b);b=x[j>>2];x[23549]=0;e=R(164,b|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break m}v:{w:{if(e){x[23549]=0;S(448,d+176|0,d+376|0,16723);b=x[23549];x[23549]=0;if((b|0)==1){break v}x[23549]=0;n=R(192,j|0)|0;b=x[23549];x[23549]=0;x:{if((b|0)!=1){h=c&2;g=0;while(1){if(n>>>0<=(g&255)>>>0){break x}x[23549]=0;i=R(192,j|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break w}if(!i){break x}e=x[j+8>>2];b=x[j>>2];x[23549]=0;e=U(142,b|0,e|0,56)|0;b=x[23549];x[23549]=0;if((b|0)==1){break w}if(!e){break x}if(i>>>0>z[a+480190>>1]){w[a+480190>>1]=i}x[23549]=0;m=D(i,104)+a|0;t=m+484380|0;P(266,t|0,0);b=x[23549];x[23549]=0;if((b|0)==1){break w}wB(t);x[23549]=0;S(302,j|0,((i<<5)+a|0)+946304|0,32);b=x[23549];x[23549]=0;if((b|0)==1){break w}x[23549]=0;P(305,j|0,m+484423|0);b=x[23549];x[23549]=0;if((b|0)==1){break w}y:{if(y[d+415|0]<=15){x[23549]=0;f=R(180,j|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break y}break w}x[23549]=0;f=R(143,j|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break w}}x[m+484404>>2]=f<<1;x[23549]=0;e=R(143,j|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break w}x[t>>2]=e;x[23549]=0;e=R(143,j|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break w}E=m+484384|0;x[E>>2]=e;x[23549]=0;e=R(143,j|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break w}o=m+484388|0;x[o>>2]=e;if(e){b=m+484414|0;w[b>>1]=z[b>>1]|2;x[o>>2]=e+x[E>>2]}x[23549]=0;e=R(192,j|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break w}if(y[d+415|0]<=15){w[m+484410>>1]=e}x[23549]=0;i=R(192,j|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break w}b=m+484414|0;e=z[b>>1];B=8;if(i&1){e=e|1;w[b>>1]=e;x[t>>2]=x[t>>2]>>>1;x[E>>2]=x[E>>2]>>>1;x[o>>2]=x[o>>2]>>>1;B=16}w[b>>1]=e&65531|i<<1&4;b=Xc(d+80|0,B,1,0,((i&12)!=0)<<3);z:{if(!h){break z}x[23549]=0;U(205,b|0,t|0,d+176|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break z}break w}g=g+1|0;continue}}break w}ub(d+176|0)}x[23549]=0;S(448,d+176|0,d+376|0,18761);b=x[23549];x[23549]=0;A:{if((b|0)!=1){b=d+176|0;k=Zc(j,b);ub(b);b=x[k>>2];x[23549]=0;e=R(164,b|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break m}if(!e){break A}q=Nb(d+80|0);r=Nb(d+204|0);u=Nb(d+164|0);x[23549]=0;S(448,d+144|0,d+376|0,17750);b=x[23549];x[23549]=0;B:{if((b|0)==1){break B}b=x[d+156>>2];x[d+56>>2]=x[d+152>>2];x[d+60>>2]=b;x[d- -64>>2]=x[d+160>>2];x[23549]=0;b=x[d+148>>2];x[d+48>>2]=x[d+144>>2];x[d+52>>2]=b;P(450,d+48|0,q|0);b=x[23549];x[23549]=0;if((b|0)==1){break B}x[23549]=0;S(448,d+124|0,d+376|0,17744);b=x[23549];x[23549]=0;if((b|0)==1){break B}b=x[d+136>>2];x[d+32>>2]=x[d+132>>2];x[d+36>>2]=b;x[d+40>>2]=x[d+140>>2];x[23549]=0;b=x[d+128>>2];x[d+24>>2]=x[d+124>>2];x[d+28>>2]=b;P(450,d+24|0,r|0);b=x[23549];x[23549]=0;if((b|0)==1){break B}x[23549]=0;S(448,d+104|0,d+376|0,17734);b=x[23549];x[23549]=0;if((b|0)==1){break B}b=x[d+116>>2];x[d+8>>2]=x[d+112>>2];x[d+12>>2]=b;x[d+16>>2]=x[d+120>>2];x[23549]=0;b=x[d+108>>2];x[d>>2]=x[d+104>>2];x[d+4>>2]=b;P(450,d|0,u|0);b=x[23549];x[23549]=0;if((b|0)==1){break B}x[23549]=0;m=R(192,k|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break B}B=0;while(1){if(m>>>0<=(B&255)>>>0){wo(u);wo(r);wo(q);break A}x[23549]=0;P(249,d+68|0,k|0);b=x[23549];x[23549]=0;C:{if((b|0)!=1){F=fd(d+68|0);D:{E:{if(!y[d+68|0]){break E}g=x[k+8>>2];e=x[k>>2];b=y[F|0];x[23549]=0;e=U(142,e|0,g|0,D(b,14)+32|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break B}if(!e){break E}x[23549]=0;l=U(240,a|0,y[d+68|0],0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break B}if(l){break D}}b=y[F|0];x[23549]=0;O(174,k|0,D(b,14)+32|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break C}break B}x[23549]=0;S(302,k|0,l+492|0,32);b=x[23549];x[23549]=0;if((b|0)==1){break B}t=l+88|0;E=l+68|0;o=l+48|0;i=l+236|0;b=0;g=0;while(1){if(y[F|0]<=(g&255)>>>0){break C}x[23549]=0;P(451,k|0,d+176|0);e=x[23549];x[23549]=0;if((e|0)==1){break B}e=y[d+176|0];F:{if(!e|e>>>0>z[a+480190>>1]){break F}if(y[d+177|0]>=129){v[d+177|0]=128}while(1){h=b&255;n=y[d+177|0];if(h>>>0>n>>>0){e=x[q+4>>2];b=x[q>>2];x[23549]=0;V(452,o|0,y[d+179|0],b|0,e|0);b=x[23549];x[23549]=0;if((b|0)==1){break B}e=x[r+4>>2];b=x[r>>2];x[23549]=0;V(452,E|0,y[d+181|0],b|0,e|0);b=x[23549];x[23549]=0;if((b|0)==1){break B}e=x[u+4>>2];b=x[u>>2];x[23549]=0;V(452,t|0,y[d+189|0],b|0,e|0);b=x[23549];x[23549]=0;if((b|0)==1){break B}x[l>>2]=(y[d+182|0]|y[d+183|0]<<8)+1>>>1;e=y[d+176|0];G:{if(y[d+179|0]&64){w[(D(e,104)+a|0)+484410>>1]=y[d+178|0];break G}b=(D(e,104)+a|0)+484414|0;w[b>>1]=z[b>>1]|32768}w[d+102>>1]=y[d+180|0]<<1;w[d+100>>1]=254;s=D(e,104)+a|0;I=s+484408|0,J=z[Uc(d+102|0,d+100|0)>>1],w[I>>1]=J;v[s+484418|0]=y[(y[d+187|0]&3)+26724|0];e=s+484419|0;j=y[d+186|0];v[e|0]=j;h=y[d+185|0]+3>>>2|0;v[s+484420|0]=h;v[s+484421|0]=y[d+184|0];b=n+1|0;if(j){h=Km(Qc(((h<<8|j>>>1)>>>0)/(j>>>0)|0,0))}else{h=255}v[e|0]=h;if(!(y[d+181|0]&64)){break F}e=s+484414|0;w[e>>1]=z[e>>1]|32}else{e=y[d+176|0];I=_b(i,h),J=e,w[I>>1]=J;b=b+1|0;continue}break}}g=g+1|0;continue}}break B}B=B+1|0;continue}}f=N()|0;wo(u);wo(r);wo(q);break c}f=N()|0;break c}m=1;l=Nb(d+204|0);H:{if(!(c&1)){break H}x[23549]=0;S(448,d+176|0,d+376|0,21076);b=x[23549];x[23549]=0;I:{J:{K:{L:{M:{N:{if((b|0)!=1){h=Zc(k,d+176|0);b=x[h>>2];x[23549]=0;c=R(164,b|0)|0;b=x[23549];x[23549]=0;O:{P:{Q:{if((b|0)!=1){ub(d+176|0);if(!c){break O}x[23549]=0;e=R(180,h|0)|0;c=x[23549];x[23549]=0;b=1;if((c|0)==1){break Q}x[23549]=0;g=e+1|0;P(453,l|0,g|0);c=x[23549];x[23549]=0;if((c|0)==1){break Q}while(1){if((b|0)==(g|0)){break O}x[23549]=0;e=R(180,h|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break P}x[23549]=0;S(176,d+80|0,h|0,e|0);c=x[23549];x[23549]=0;if((c|0)==1){break P}c=d+80|0;e=hc(d+176|0,c);Zc(Cg(x[l>>2],b),e);ub(e);b=b+1|0;ub(c);continue}}f=N()|0;ub(d+176|0);break I}f=N()|0;break I}f=N()|0;break I}x[23549]=0;S(448,d+176|0,d+376|0,16720);b=x[23549];x[23549]=0;if((b|0)==1){break K}C=Zc(h,d+176|0);b=x[C>>2];x[23549]=0;c=R(164,b|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break L}ub(d+176|0);if(!c){break N}x[23549]=0;F=R(192,C|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break J}q=0;R:{S:{T:while(1){U:{if(F>>>0<=(q&65535)>>>0){x[23549]=0;O(141,C|0,1)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break U}break J}g=32;V:{if(y[d+415|0]<16){break V}x[23549]=0;P(454,C|0,d+176|0);b=x[23549];x[23549]=0;if((b|0)==1){break R}g=y[d+176|0];if(g>>>0<=z[a+480188>>1]|g>>>0>32){break V}w[a+480188>>1]=g}b=0;while(1){h=b&65535;if(h>>>0>=g>>>0){q=q+1|0;continue T}x[23549]=0;e=R(180,C|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break S}if(!(!e|h>>>0>31|h>>>0<z[a+480188>>1])){w[a+480188>>1]=b+1}b=b+1|0;continue}}break}x[23549]=0;r=a+484344|0;P(211,r|0,F|0);b=x[23549];x[23549]=0;if((b|0)==1){break J}t=d+178|0;while(1){if((G|0)==(F|0)){break N}u=Gb(d+80|0);W:{if(y[d+415|0]<16){c=32;n=64;break W}x[23549]=0;P(454,C|0,d+176|0);b=x[23549];x[23549]=0;if((b|0)==1){break M}e=y[d+177|0];c=y[d+176|0];b=d+68|0;gf(b,t,16,3);x[23549]=0;P(208,d+164|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break M}b=d+164|0;zb(u,b);tb(b);n=e+1|0}x[23549]=0;e=U(212,r|0,G&65535,n|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break M}X:{if(!e){x[23549]=0;O(174,C|0,c<<1)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break X}break M}b=x[r>>2];x[23549]=0;P(270,Yb(b,G)|0,u|0);b=x[23549];x[23549]=0;if((b|0)==1){break M}E=n-1|0;j=0;while(1){s=j&65535;if(s>>>0>=c>>>0){break X}x[23549]=0;e=R(180,C|0)|0;b=x[23549];x[23549]=0;Y:{if((b|0)!=1){if(!e){break Y}b=x[l>>2];if(Ef(b,x[l+4>>2])>>>0<=e>>>0|s>>>0>=z[a+480188>>1]){break Y}A=Cg(b,e);wc(A);g=0;Z:while(1){e=g;if(n>>>0<=e>>>0){break Y}g=x[A+8>>2];b=x[A>>2];x[23549]=0;g=U(142,b|0,g|0,1)|0;b=x[23549];x[23549]=0;_:{$:{aa:{ba:{ca:{if((b|0)!=1){if(!g){break Y}b=Yb(x[r>>2],G);b=$c(x[b>>2],x[x[b+48>>2]+12>>2],e,s);x[23549]=0;h=R(192,A|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break M}o=h<<24>>24;f=(o&252)>>>2|0;switch((o&3)-1|0){case 2:break $;case 1:break aa;case 0:break ba;default:break ca}}break M}g=(e+f|0)+1|0;continue}g=0;if(!e){continue}g=Yb(x[r>>2],G);i=$c(x[g>>2],x[x[g+48>>2]+12>>2],e-1|0,s);while(1){g=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);v[b|0]=g;v[b+1|0]=g>>>8;v[b+2|0]=g>>>16;v[b+3|0]=g>>>24;g=y[i+4|0]|y[i+5|0]<<8;v[b+4|0]=g;v[b+5|0]=g>>>8;g=e+1|0;if((e|0)==(E|0)){continue Z}b=D(z[a+480188>>1],6)+b|0;h=f&255;e=g;f=f-1|0;if(h){continue}break}continue}if(e>>>0<=f>>>0){break _}g=Yb(x[r>>2],G);h=$c(x[g>>2],x[x[g+48>>2]+12>>2],f,s);g=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);v[b|0]=g;v[b+1|0]=g>>>8;v[b+2|0]=g>>>16;v[b+3|0]=g>>>24;g=y[h+4|0]|y[h+5|0]<<8;v[b+4|0]=g;v[b+5|0]=g>>>8;break _}if(f&1){x[23549]=0;h=R(192,A|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break M}v[b|0]=h>>>0>120?-1:h}if(f&2){x[23549]=0;h=R(192,A|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break M}v[b+1|0]=h}q=0;g=0;da:{if(f&4){x[23549]=0;g=R(192,A|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break da}}k=0;if(f&8){x[23549]=0;i=R(192,A|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break da}k=i>>>4|0;q=i&15}B=0;i=0;if(f&16){x[23549]=0;i=R(192,A|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break da}}if((o|0)<0){x[23549]=0;B=R(192,A|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break da}}f=db-16|0;db=f;v[f+14|0]=k;v[f+15|0]=q;v[f+13|0]=i;v[f+12|0]=B;if((k-1&255)>>>0<=5){v[f+14|0]=k+15}DT(f+15|0,f+13|0);DT(f+14|0,f+12|0);ea:{fa:{k=y[f+15|0];ga:{if((k|0)==10){o=y[f+12|0];i=y[f+13|0]&15;v[f+13|0]=i?-1:o;h=y[f+14|0];k=(h|0)!=10?h:0;v[f+14|0]=k;h=o|i<<8;break ga}if(y[f+14|0]!=10){break fa}h=y[f+12|0]&15;v[f+12|0]=h?-1:0;h=h<<8}if(h-256>>>0>4294967038){break fa}if(th(k)>>>0>=th(10)>>>0){break fa}v[b+5|0]=h;v[b+2|0]=15;v[b+3|0]=10;v[b+4|0]=h>>>8;break ea}if(g){v[b+2|0]=1;v[b+4|0]=g+2>>>2}Ou(f+15|0,f+13|0,f+14|0,f+12|0);i=y[f+15|0];ha:{if(!i){break ha}h=y[f+14|0];if(!h){v[f+14|0]=i;v[f+12|0]=y[f+13|0];break ha}if((h|0)==(i|0)&(i|0)!=20){break ha}if(!g){Gq(f+10|0,f+15|0,f+13|0,f+14|0,f+12|0);v[b+2|0]=y[f+15|0];v[b+4|0]=y[f+13|0];break ha}if(th(i)>>>0<=th(h)>>>0){break ha}sh(f+15|0,f+14|0);sh(f+13|0,f+12|0)}v[b+3|0]=y[f+14|0];v[b+5|0]=y[f+12|0]}db=f+16|0;break _}break M}g=e+1|0;continue}}break M}j=j+1|0;continue}}tb(u);G=G+1|0;continue}}f=N()|0;break I}f=N()|0;break I}f=N()|0;break I}x[23549]=0;S(448,d+176|0,d+376|0,20048);b=x[23549];x[23549]=0;ia:{ja:{if((b|0)!=1){e=Zc(C,d+176|0);b=x[e>>2];x[23549]=0;c=R(164,b|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break ja}ub(d+176|0);if(!c){break H}while(1){if(!qf(x[a+484344>>2],x[a+484348>>2])){break H}c=x[e+8>>2];b=x[e>>2];x[23549]=0;c=U(142,b|0,c|0,16)|0;b=x[23549];x[23549]=0;if((b|0)==1){break ia}if(!c){break H}x[23549]=0;P(455,e|0,d+176|0);b=x[23549];x[23549]=0;if((b|0)!=1){b=x[a+484344>>2];x[23549]=0;P(456,Yb(b,0)|0,d+176|0);b=x[23549];x[23549]=0;if((b|0)!=1){continue}}break}f=N()|0;break I}f=N()|0;break I}f=N()|0;ub(d+176|0);break I}f=N()|0;break I}f=N()|0;tb(u);break I}f=N()|0;ub(d+176|0);break I}f=N()|0;break I}f=N()|0}kd(l);break c}kd(l);break l}f=N()|0;ub(d+176|0);break c}f=N()|0;break c}f=N()|0;break c}f=N()|0;break c}n=(b<<5)+a|0;h=n+480280|0;Te(h);g=v[(b+d|0)+324|0];e=g<<1&254;w[n+480284>>1]=(e|0)==254?256:e;ka:{if((g|0)<0){x[h>>2]=x[h>>2]|1024;break ka}w[a+480188>>1]=b+1}x[23549]=0;P(457,d+356|0,n+480289|0);e=x[23549];x[23549]=0;if((e|0)==1){break j}b=b+1|0;continue}}f=N()|0;break c}ub(d+356|0);_d(d+376|0);ub(H)}db=d+416|0;return m|0}f=N()|0;break c}f=N()|0;tb(d+80|0);break c}f=N()|0;break c}f=N()|0;break c}f=N()|0;tb(g);break d}f=N()|0}tb(h)}ub(d+356|0)}_d(d+376|0)}ub(H);Q(f|0);p()}function Vfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;d=db-320|0;db=d;wc(b);a:{if(!Bo(b,d+308|0)){break a}if(!cS(d+308|0)){break a}q=le(d+288|0,b);n=Nb(d+276|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if(!c){x[23549]=0;P(602,d+28|0,q|0);b=x[23549];x[23549]=0;if((b|0)==1){break y}break A}x[23549]=0;P(603,d+28|0,q|0);b=x[23549];x[23549]=0;if((b|0)==1){break z}}b=d+28|0;Rt(n,b);_d(b);x[23549]=0;S(604,b|0,n|0,1413891155);b=x[23549];x[23549]=0;B:{C:{if((b|0)!=1){x[23549]=0;e=O(605,d+28|0,13847)|0;b=x[23549];x[23549]=0;if((b|0)==1){break C}ub(d+28|0);if((c|0)!=0&e){break B}break b}b=N()|0;break c}b=N()|0;ub(d+28|0);break c}x[23549]=0;P(235,a|0,4194304);b=x[23549];x[23549]=0;if((b|0)==1){break d}x[a+480208>>2]=12;x[23549]=0;S(604,d+256|0,n|0,1280592212);b=x[23549];x[23549]=0;if((b|0)==1){break e}x[23549]=0;b=R(146,x[d+256>>2])|0;e=x[23549];x[23549]=0;if((e|0)==1){break g}x[23549]=0;S(397,d+256|0,a+1298308|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break g}Dc(Wb(x[a+484360>>2],y[a+484376|0]));l=Nb(d+244|0);v[d+243|0]=0;v[d+242|0]=0;x[23549]=0;S(606,d+228|0,n|0,1196314451);b=x[23549];x[23549]=0;if((b|0)==1){break i}m=a+484360|0;s=d,t=yb(x[d+228>>2]),x[s+224>>2]=t;g=d+212|0;o=yb(x[d+232>>2]);D:{while(1){b=x[d+224>>2];if(!Kb(b,o)){break D}j=le(d+28|0,b);x[23549]=0;e=O(607,j|0,d+16|0)|0;b=x[23549];x[23549]=0;E:{F:{if((b|0)!=1){b=1;if(!(e&y[d+25|0]==1)){break E}s=a,t=Vd(y[d+26|0],z[a+480188>>1],127),w[s+480188>>1]=t;x[23549]=0;f=R(608,d+168|0)|0;b=x[23549];x[23549]=0;G:{H:{I:{J:{if((b|0)!=1){b=d+156|0;gf(b,d+16|0,9,1);x[23549]=0;P(208,d+132|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break J}b=d+4|0;ec(b,g,10);e=b;b=d+132|0;Al(e,b);tb(b);b=Wb(x[a+484360>>2],y[a+484376|0]);if(qc(x[b>>2],x[b+4>>2])){break G}x[23549]=0;b=R(261,m|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break I}if((b|0)!=255){break H}b=2;break F}b=N()|0;break k}b=N()|0;break l}b=N()|0;break l}b=Wb(x[a+484360>>2],y[a+484376|0])}x[23549]=0;S(5,d+132|0,5,g|0);e=x[23549];x[23549]=0;if((e|0)==1){break n}x[23549]=0;P(262,b|0,d+132|0);b=x[23549];x[23549]=0;if((b|0)==1){break o}tb(d+132|0);x[23549]=0;P(603,d+156|0,j|0);b=x[23549];x[23549]=0;if((b|0)==1){break p}s=d,t=yb(x[d+156>>2]),x[s+152>>2]=t;r=yb(x[d+160>>2]);while(1){K:{L:{M:{b=x[d+152>>2];if(!Kb(b,r)){b=0;if(z[d+204>>1]==65535|z[d+206>>1]==65535){break M}b=y[a+484376|0];e=x[a+484360>>2];x[23549]=0;W(609,Wb(e,b)|0);b=x[23549];x[23549]=0;if((b|0)!=1){b=0;x[23549]=0;P(610,l|0,f|0);e=x[23549];x[23549]=0;if((e|0)!=1){break M}}b=N()|0;break m}Go(d+132|0,b);zi(d+4|0,x[b>>2],x[b+4>>2]);e=x[d+4>>2];if((e|0)!=1212960847){b=0;if((e|0)!=1312903248){break K}N:{while(1){e=b&65535;if(e>>>0>=z[a+480188>>1]){break K}x[23549]=0;i=U(142,x[d+132>>2],x[d+140>>2],2)|0;h=x[23549];x[23549]=0;if((h|0)==1){break N}if(!i){break K}x[23549]=0;P(249,d+124|0,d+132|0);i=x[23549];x[23549]=0;if((i|0)!=1){hA(f,e,y[d+124|0],y[fd(d+124|0)|0],d+243|0,l);b=b+1|0;continue}break}break L}break L}if(A[d+8>>2]<9){break K}e=0;x[23549]=0;O(174,d+132|0,2)|0;b=x[23549];x[23549]=0;i=65535;O:{if((b|0)!=1){while(1){x[23549]=0;b=U(142,x[d+132>>2],x[d+140>>2],1)|0;h=x[23549];x[23549]=0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{if((h|0)!=1){if(!b){break K}x[23549]=0;h=R(192,d+132|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break L}b=4;switch(h|0){case 0:break K;case 14:break Q;case 13:break R;case 12:break T;case 8:break U;case 7:break V;case 2:break W;case 6:break X;case 5:break Y;case 3:case 4:break Z;case 1:break _;default:break S}}break L}b=Wb(x[a+484360>>2],y[a+484376|0]);if(z[d+204>>1]==65535){s=d,t=vl(x[b>>2],x[b+4>>2]),w[s+204>>1]=t}b=vl(x[b>>2],x[b+4>>2]);x[23549]=0;w[d+206>>1]=b;b=O(611,d+132|0,d+242|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break L}$:{aa:{switch(b-254|0){case 1:b=65535;break $;case 0:break aa;default:break $}}b=65534}h=y[a+484376|0];k=x[a+484360>>2];x[23549]=0;P(479,Wb(k,h)|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break L}i=(i&65535)==65535?e:i;break P}x[23549]=0;b=R(180,d+132|0)|0;k=x[23549];x[23549]=0;if((k|0)!=1){ba:{if(b>>>0<(i&65535)>>>0){b=z[d+208>>1];break ba}b=b-i|0;w[d+208>>1]=b}$e(Wb(x[a+484360>>2],y[a+484376|0]),b&65535);if((h|0)!=3){break P}x[23549]=0;O(174,d+132|0,1)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break P}}break L}x[23549]=0;P(249,d+124|0,d+132|0);b=x[23549];x[23549]=0;if((b|0)!=1){hA(f,y[d+124|0],y[fd(d+124|0)|0],-1,d+243|0,l);break P}break L}b=1}x[23549]=0;O(174,d+132|0,b|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break P}break L}x[23549]=0;b=R(192,d+132|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break L}v[d+211|0]=b;break P}x[23549]=0;b=R(192,d+132|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break L}v[d+210|0]=b;break P}x[23549]=0;b=O(580,d+132|0,d+124|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break L}if(y[d+124|0]|!b|(y[d+126|0]|y[d+125|0]!=255)){break S}if(y[d+127|0]|y[d+128|0]!=1){break S}if(!y[d+129|0]){break P}}ub(d+132|0);b=1;break M}x[23549]=0;P(491,d+124|0,d+132|0);b=x[23549];x[23549]=0;if((b|0)!=1){b=d+124|0;h=fd(b);hA(f,y[d+124|0],y[Ue(b)|0],y[h|0],d+243|0,l);break P}break L}x[23549]=0;P(249,d+124|0,d+132|0);b=x[23549];x[23549]=0;if((b|0)==1){break O}b=x[d+180>>2];k=Pc(b,x[d+184>>2]);h=y[d+124|0];if(k>>>0<=h>>>0){break P}k=fd(d+124|0);s=Db(b,h),t=(y[k|0]>>>2|0)+1|0,v[s|0]=t}e=e+1|0;continue}}break L}break L}_d(d+156|0);break F}b=N()|0;ub(d+132|0);break m}ub(d+132|0);hk(d+152|0);continue}}b=N()|0;break k}cq(f)}ub(j);if(!b){yg(d+224|0);continue}break}e=0;if((b|0)!=2){break v}}e=0;oj(m,0);b=x[l>>2];if(qc(b,x[l+4>>2])){break v}if(!(c&2)){break w}x[23549]=0;S(606,d+132|0,n|0,1347244868);b=x[23549];x[23549]=0;ca:{if((b|0)!=1){s=d,t=yb(x[d+132>>2]),x[s+4>>2]=t;e=a+480190|0;f=d+41|0;i=d+45|0;j=yb(x[d+136>>2]);m=y[d+242|0];while(1){b=x[d+4>>2];if(!Kb(b,j)){kd(d+132|0);b=x[l>>2];break w}da:{ea:{fa:{if(!m){x[23549]=0;g=O(612,b|0,d+28|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break da}if(!g){break ea}g=y[d+80|0]|y[d+81|0]<<8;h=g+1|0;w[d+124>>1]=h;if(g>>>0>3998){break fa}s=a,t=z[Ve(e,d+124|0)>>1],w[s+480190>>1]=t;x[23549]=0;P(613,d+28|0,(D(h&65535,104)+a|0)+484380|0);g=x[23549];x[23549]=0;if((g|0)==1){break da}g=d+16|0;bS(g,f);x[23549]=0;P(208,d+156|0,g|0);g=x[23549];x[23549]=0;if((g|0)==1){break x}g=d+156|0;zc(((z[d+124>>1]<<5)+a|0)+946304|0,g);tb(g);break fa}x[23549]=0;g=O(614,b|0,d+28|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break x}if(!g){break ea}g=y[d+84|0]|y[d+85|0]<<8;h=g+1|0;w[d+124>>1]=h;if(g>>>0>3998){break fa}s=a,t=z[Ve(e,d+124|0)>>1],w[s+480190>>1]=t;x[23549]=0;P(615,d+28|0,(D(h&65535,104)+a|0)+484380|0);g=x[23549];x[23549]=0;if((g|0)==1){break x}g=d+16|0;bS(g,i);x[23549]=0;P(208,d+156|0,g|0);g=x[23549];x[23549]=0;if((g|0)==1){break ca}g=d+156|0;zc(((z[d+124>>1]<<5)+a|0)+946304|0,g);tb(g)}g=z[d+124>>1];if((g-1&65535)>>>0>3998){break ea}h=Xc(d+28|0,8,1,0,2);x[23549]=0;U(205,h|0,(D(g,104)+a|0)+484380|0,b|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break ea}break x}yg(d+4|0);continue}break}break x}b=N()|0;break j}break x}b=N()|0;break c}b=N()|0;break c}b=N()|0;kd(d+132|0);break j}b=fA(b,0);x[a+480196>>2]=y[b+43|0];x[a+480204>>2]=D(y[b+42|0],1e4);$e(Wb(x[a+484360>>2],y[a+484376|0]),z[b+40>>1]);b=0;while(1){if(z[a+480188>>1]>b>>>0){e=(b<<5)+a|0;f=e+480280|0;Te(f);i=fA(x[l>>2],0);s=e+480286|0,t=y[Db(x[i+12>>2],b)|0],w[s>>1]=t;s=e+480284|0,t=y[Db(x[i>>2],b)|0],w[s>>1]=t;Fb(d+28|0,x[i+24>>2],b);s=f,t=x[f>>2]&-257|(Ib(x[x[d+28>>2]>>2],x[d+32>>2])?256:0),x[s>>2]=t;b=b+1|0;continue}break}x[23549]=0;b=O(1,d+156|0,(y[d+242|0]?16719:16592)|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break q}zb(a+1298344|0,b);tb(b);x[23549]=0;b=O(1,d+16|0,10020)|0;e=x[23549];x[23549]=0;if((e|0)==1){break r}zb(a+1298356|0,b);tb(b);x[a+1298404>>2]=5;e=1;if(!(c&1)|!z[a+480188>>1]){break v}x[23549]=0;S(606,d+4|0,n|0,1146045008);b=x[23549];x[23549]=0;if((b|0)==1){break s}b=x[d+8>>2];c=x[d+4>>2];x[23549]=0;m=a+484344|0;P(211,m|0,Ef(c,b)&65535);b=x[23549];x[23549]=0;if((b|0)==1){break u}s=d,t=yb(x[d+4>>2]),x[s+124>>2]=t;r=yb(x[d+8>>2]);while(1){j=x[d+124>>2];if(!Kb(j,r)){ga:{ha:{b=x[l>>2];e=x[l+4>>2];if(Pt(b,e)>>>0<2){break ha}j=y[d+243|0];c=0;while(1){if(Pt(b,e)>>>0<=c>>>0){break ha}h=x[a+484344>>2];k=x[a+484348>>2];i=jj(x[a+484360>>2],c&255);o=x[i>>2];f=fA(b,c);g=z[f+36>>1];if(se(h,k,z[_b(o,g)>>1])){x[23549]=0;e=O(352,i|0,g|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break ga}ia:{if(!j){break ia}b=0;while(1){if(z[a+480188>>1]<=b>>>0){break ia}g=eA(x[f+24>>2],b);i=Yb(x[m>>2],e);ja:{if(g){me(i,wh(Co(Fe(Be(d+28|0,20,145),0),b&65535)));break ja}me(i,wh(Co(Fe(Be(d+28|0,9,y[Db(x[f>>2],b)|0]),0),b&65535)))}b=b+1|0;continue}}b=d+28|0;me(Yb(x[m>>2],e),wh(Fe(Be(b,16,y[f+43|0]),0)));me(Yb(x[m>>2],e),wh(Fe(Be(b,17,y[f+42|0]),0)));e=x[l+4>>2];b=x[l>>2]}c=c+1|0;continue}}kd(d+4|0);e=1;break v}b=N()|0;break t}b=x[j>>2];x[23549]=0;b=R(146,b|0)|0;c=x[23549];x[23549]=0;ka:{la:{ma:{na:{oa:{pa:{qa:{if((c|0)==1){break qa}x[23549]=0;c=R(143,j|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break qa}if((b|0)!=(c|0)){break ka}b=x[j>>2];x[23549]=0;b=O(616,b|0,8)|0;c=x[23549];x[23549]=0;if((c|0)==1){break qa}if(!b){break ka}x[23549]=0;h=O(611,j|0,d+242|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break la}x[23549]=0;o=R(180,j|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break ma}x[23549]=0;b=U(212,m|0,h|0,o|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break ma}if(!b){break ka}g=0;while(1){if((g|0)==(o|0)){break ka}b=Yb(x[m>>2],h);c=sf(x[b>>2],x[x[b+48>>2]+12>>2],g);x[23549]=0;b=R(180,j|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break pa}ra:{if(b>>>0>=3){x[23549]=0;S(176,d+132|0,j|0,b-2|0);b=x[23549];x[23549]=0;if((b|0)==1){break na}b=d+132|0;i=hc(d+28|0,b);ub(b);while(1){b=x[i>>2];x[23549]=0;b=U(142,b|0,x[d+36>>2],3)|0;e=x[23549];x[23549]=0;if((e|0)==1){break ra}if(b){x[23549]=0;P(249,d+132|0,i|0);b=x[23549];x[23549]=0;sa:{ta:{ua:{va:{if((b|0)!=1){w[d+224>>1]=z[a+480188>>1]-1;s=d,t=y[fd(d+132|0)|0],w[s+152>>1]=t;e=z[Uc(d+224|0,d+152|0)>>1];f=c+D(e,6)|0;b=v[d+132|0];if((b|0)>=0){break sa}x[23549]=0;b=R(192,i|0)|0;k=x[23549];x[23549]=0;if((k|0)==1){break oa}if(y[d+242|0]){break ua}if((b|0)!=255){break va}b=254;break ta}break oa}if(b>>>0>128){break ta}b=(D(b>>>4|0,12)+(b&15)|0)+13|0;break ta}b=b>>>0<85?b+36|0:b}v[f|0]=b;b=y[d+132|0]}if(b&64){x[23549]=0;b=R(192,i|0)|0;k=x[23549];x[23549]=0;if((k|0)==1){break oa}v[f+1|0]=b+1;b=y[d+132|0]}if(b&32){x[23549]=0;b=R(192,i|0)|0;k=x[23549];x[23549]=0;if((k|0)==1){break oa}v[d+224|0]=b;v[f+2|0]=1;v[d+152|0]=127;s=f,t=y[Sb(d+224|0,d+152|0)|0]+1>>>1|0,v[s+4|0]=t;b=y[d+132|0]}if(!(b&16)){continue}x[23549]=0;P(249,d+224|0,i|0);b=x[23549];x[23549]=0;wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{if((b|0)!=1){b=y[fd(d+224|0)|0];v[f+5|0]=b;switch(y[d+224|0]-1|0){case 72:break xa;case 71:break ya;case 70:break za;case 61:break Aa;case 60:break Ba;case 53:break Ca;case 52:break Da;case 51:break Ea;case 50:break Ga;case 43:break Ha;case 42:break Ia;case 41:break Ja;case 40:break Ka;case 31:break La;case 30:break Ma;case 23:break Na;case 22:break Oa;case 21:break Pa;case 20:break Qa;case 18:break Ra;case 17:break Sa;case 15:break Ta;case 16:break Ua;case 14:break Va;case 13:break Wa;case 12:break Xa;case 11:break Ya;case 10:break Za;case 3:break _a;case 2:break $a;case 1:break ab;case 0:break bb;default:break wa}}break oa}v[(c+D(e,6)|0)+3|0]=11;if(y[d+242|0]){v[f+5|0]=b<<4|15;continue}v[f+5|0]=b<<3|15;continue}v[(c+D(e,6)|0)+3|0]=11;if(y[d+242|0]){v[f+5|0]=b<<4;continue}v[f+5|0]=b<<3&240;continue}v[(c+D(e,6)|0)+3|0]=11;if(y[d+242|0]){v[f+5|0]=b|240;continue}v[f+5|0]=b>>>1|240;continue}v[(c+D(e,6)|0)+3|0]=11;if(y[d+242|0]){v[f+5|0]=b&15;continue}if(b>>>0<=1){v[f+5|0]=b|240;continue}v[f+5|0]=b>>>1&15;continue}v[(c+D(e,6)|0)+3|0]=2;s=f,t=Ot(b,y[d+242|0])|240,v[s+5|0]=t;continue}v[(c+D(e,6)|0)+3|0]=2;s=f,t=Ot(b,y[d+242|0]),v[s+5|0]=t;continue}v[(c+D(e,6)|0)+3|0]=3;s=f,t=Ot(b,y[d+242|0])|240,v[s+5|0]=t;continue}v[(c+D(e,6)|0)+3|0]=3;s=f,t=Ot(b,y[d+242|0]),v[s+5|0]=t;continue}v[(c+D(e,6)|0)+3|0]=4;if(y[d+242|0]){continue}v[f+5|0]=(b&252)>>>2;continue}v[(c+D(e,6)|0)+3|0]=20;v[f+5|0]=b&1|16;continue}v[(c+D(e,6)|0)+3|0]=6;v[f+5|0]=b&240;continue}v[(c+D(e,6)|0)+3|0]=6;v[f+5|0]=(b&240)>>>4;continue}v[(c+D(e,6)|0)+3|0]=20;continue}v[(c+D(e,6)|0)+3|0]=5;continue}v[(c+D(e,6)|0)+3|0]=20;v[f+5|0]=b&15|48;continue}v[(c+D(e,6)|0)+3|0]=7;v[f+5|0]=b|240;continue}v[(c+D(e,6)|0)+3|0]=7;continue}v[(c+D(e,6)|0)+3|0]=8;continue}v[(c+D(e,6)|0)+3|0]=20;v[f+5|0]=b&15|64;continue}v[(c+D(e,6)|0)+3|0]=10;x[23549]=0;b=R(192,i|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){break Fa}break oa}v[(c+D(e,6)|0)+3|0]=15;continue}v[(c+D(e,6)|0)+3|0]=20;v[f+5|0]=b&15|192;continue}v[(c+D(e,6)|0)+3|0]=20;v[f+5|0]=b&15|208;continue}v[(c+D(e,6)|0)+3|0]=12;b=(b&254)>>>1|0}v[f+5|0]=b;x[23549]=0;O(174,i|0,1)|0;b=x[23549];x[23549]=0;if((b|0)!=1){continue}break oa}v[(c+D(e,6)|0)+3|0]=14;v[f+5|0]=0;continue}v[(c+D(e,6)|0)+3|0]=20;v[f+5|0]=b&15|176;continue}v[(c+D(e,6)|0)+3|0]=20;v[f+5|0]=b&15|224;continue}v[(c+D(e,6)|0)+3|0]=16;continue}v[(c+D(e,6)|0)+3|0]=17;continue}v[(c+D(e,6)|0)+3|0]=1;continue}v[(c+D(e,6)|0)+3|0]=20;v[f+5|0]=b&15|32;continue}v[(c+D(e,6)|0)+3|0]=20;v[f+5|0]=b&15|128;continue}v[(c+D(e,6)|0)+3|0]=0;continue}break}ub(i)}g=g+1|0;continue}break}break oa}b=N()|0;break t}b=N()|0;break t}b=N()|0;ub(i);break t}b=N()|0;break t}b=N()|0;break t}b=N()|0;break t}yg(d+124|0);continue}}kd(d+228|0);aS(l);ub(d+256|0);break b}b=N()|0}kd(d+4|0);break j}b=N()|0;break j}b=N()|0;break j}b=N()|0;break j}b=N()|0;break l}b=N()|0;tb(d+132|0);break l}b=N()|0;break l}_d(d+156|0)}cq(f)}ub(j)}kd(d+228|0);break h}b=N()|0}aS(l);break f}b=N()|0}ub(d+256|0);break c}b=N()|0;break c}b=N()|0}_d(n);ub(q);Q(b|0);p()}_d(n);ub(q)}db=d+320|0;return e|0}function hW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;d=db-400|0;db=d;wc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if(!$h(b,d+392|0)){break F}if(!RB(d+392|0)){break F}if(!c){q=1;break F}r=le(d+372|0,b);x[23549]=0;P(250,d+360|0,r|0);b=x[23549];x[23549]=0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((b|0)!=1){x[23549]=0;S(251,d+208|0,d+360|0,1229866575);b=x[23549];x[23549]=0;if((b|0)==1){break da}x[23549]=0;q=O(252,d+208|0,d+350|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break fa}ub(d+208|0);if(!q){break G}x[23549]=0;P(235,a|0,524288);b=x[23549];x[23549]=0;ga:{if((b|0)==1){break ga}Dg(a);x[a+480208>>2]=12;G=a,H=Vd(Hb(z[d+358>>1]),1,127),w[G+480188>>1]=H;G=d,H=Hb(z[d+350>>1]),w[G+208>>1]=H;w[d+304>>1]=255;G=a,H=z[Uc(d+208|0,d+304|0)>>1],w[G+480192>>1]=H;G=d,H=Hb(z[d+352>>1]),w[G+208>>1]=H;w[d+304>>1]=3999;G=a,H=z[Uc(d+208|0,d+304|0)>>1],w[G+480190>>1]=H;x[23549]=0;b=U(253,a+1074312|0,6,1)|0;g=x[23549];x[23549]=0;if((g|0)==1){break ga}x[23549]=0;b=O(254,b|0,21)|0;g=x[23549];x[23549]=0;if((g|0)==1){break ga}x[23549]=0;O(254,b|0,13)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break ea}}b=N()|0;break b}b=N()|0;break a}b=N()|0;ub(d+208|0);break b}x[23549]=0;b=O(1,d+336|0,9180)|0;g=x[23549];x[23549]=0;if((g|0)==1){break c}zb(a+1298344|0,b);tb(b);x[23549]=0;b=O(1,d+324|0,10200)|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}zb(a+1298356|0,b);tb(b);x[23549]=0;P(255,d+304|0,4277);b=x[23549];x[23549]=0;if((b|0)==1){break e}x[23549]=0;P(256,d+284|0,d+396|0);b=x[23549];x[23549]=0;if((b|0)==1){break g}x[23549]=0;P(256,d+264|0,d+397|0);b=x[23549];x[23549]=0;if((b|0)==1){break i}x[23549]=0;V(97,d+208|0,d+304|0,d+284|0,d+264|0);b=x[23549];x[23549]=0;if((b|0)==1){break j}b=d+208|0;zb(a+1298368|0,b);tb(b);tb(d+264|0);tb(d+284|0);b=d+304|0;Ab(b);x[a+1298404>>2]=13;x[23549]=0;S(251,b|0,d+360|0,1312902469);b=x[23549];x[23549]=0;if((b|0)==1){break k}x[23549]=0;b=R(146,x[d+304>>2])|0;g=x[23549];x[23549]=0;if((g|0)==1){break m}x[23549]=0;h=a+1298308|0;S(257,d+304|0,h|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break m}x[23549]=0;S(251,d+284|0,d+360|0,1397706311);b=x[23549];x[23549]=0;if((b|0)==1){break n}Dc(Wb(x[a+484360>>2],y[a+484376|0]));e=a+484360|0;f=Hb(z[d+354>>1]);g=0;ha:{ia:{while(1){if(f>>>0<=(g&65535)>>>0){break ha}x[23549]=0;b=U(142,x[d+284>>2],x[d+292>>2],46)|0;i=x[23549];x[23549]=0;ja:{if((i|0)!=1){if(!b){break ha}x[23549]=0;P(258,d+284|0,d+208|0);b=x[23549];x[23549]=0;if((b|0)!=1){if(!xd(x[a+1298312>>2],y[a+1298319|0])){break ja}x[23549]=0;P(259,h|0,d+208|0);b=x[23549];x[23549]=0;if((b|0)!=1){break ja}}b=N()|0;break o}b=N()|0;break o}x[23549]=0;i=R(260,d+284|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break ca}b=Wb(x[a+484360>>2],y[a+484376|0]);if(!qc(x[b>>2],x[b+4>>2])){x[23549]=0;b=R(261,e|0)|0;j=x[23549];x[23549]=0;if((j|0)==1){break ca}if((b|0)==255){break ha}b=Wb(x[a+484360>>2],y[a+484376|0])}x[23549]=0;S(5,d+264|0,13,d+208|0);j=x[23549];x[23549]=0;if((j|0)!=1){x[23549]=0;P(262,b|0,d+264|0);b=x[23549];x[23549]=0;if((b|0)==1){break ia}tb(d+264|0);b=y[a+484376|0];j=x[a+484360>>2];x[23549]=0;S(263,Wb(j,b)|0,d+284|0,i|0);b=x[23549];x[23549]=0;if((b|0)==1){break ca}g=g+1|0;continue}break}b=N()|0;break o}b=N()|0;tb(d+264|0);break o}oj(e,0);x[23549]=0;S(251,d+264|0,d+360|0,1229869908);b=x[23549];x[23549]=0;if((b|0)==1){break ba}x[23549]=0;b=R(264,x[d+264>>2])|0;g=x[23549];x[23549]=0;if((g|0)==1){break p}ka:{if(!b){break ka}g=1;la:{while(1){b=g&65535;if(b>>>0>z[a+480192>>1]){x[23549]=0;S(251,d+188|0,d+360|0,1447382614);b=x[23549];x[23549]=0;if((b|0)!=1){break la}break p}x[23549]=0;P(265,d+264|0,d+208|0);e=x[23549];x[23549]=0;if((e|0)==1){break p}e=y[d+238|0]|y[d+239|0]<<8;x[23549]=0;b=U(240,a|0,b|0,Hb(e)|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break p}ma:{na:{if(!b){break na}if(Hb(y[d+238|0]|y[d+239|0]<<8)>>>0>3999){break na}e=d+112|0;OB(e,2,d+208|0);x[23549]=0;P(208,d+132|0,e|0);e=x[23549];x[23549]=0;if((e|0)==1){break ma}e=d+132|0;zc(b+492|0,e);tb(e);h=d+112|0;OB(h,2,d+208|0);x[23549]=0;P(208,e|0,h|0);e=x[23549];x[23549]=0;if((e|0)==1){break p}e=d+132|0;zc(((Hb(y[d+238|0]|y[d+239|0]<<8)<<5)+a|0)+946304|0,e);tb(e);x[b>>2]=0;G=b,H=Hb(y[d+254|0]|y[d+255|0]<<8)+128&65535,x[G+8>>2]=H;tc(b+8|0,256);v[b+15|0]=y[b+15|0]|1;b=y[d+238|0]|y[d+239|0]<<8;x[23549]=0;b=D(Hb(b),104)+a|0;P(266,b+484380|0,0);e=x[23549];x[23549]=0;if((e|0)==1){break p}G=d,H=Hb(y[d+240|0]|y[d+241|0]<<8),w[G+132>>1]=H;w[d+112>>1]=64;G=b+484410|0,H=z[Uc(d+132|0,d+112|0)>>1]<<2,w[G>>1]=H;h=b+484404|0;e=$b(y[d+242|0]|y[d+243|0]<<8|(y[d+244|0]<<16|y[d+245|0]<<24));f=yka(e,e>>31,8303,0);e=hb;f=f+4181|0;e=f>>>0<4181?e+1|0:e;G=h,H=Cc(zka(f,e,8363,0),hb),x[G>>2]=H;e=$b(y[d+250|0]|y[d+251|0]<<8|(y[d+252|0]<<16|y[d+253|0]<<24));if(!e){break na}h=Hb(y[d+256|0]|y[d+257|0]<<8);if(!(h&3)){break na}l=e;e=$b(y[d+246|0]|y[d+247|0]<<8|(y[d+248|0]<<16|y[d+249|0]<<24));x[b+484388>>2]=l+e;x[b+484384>>2]=e;b=b+484414|0;e=z[b>>1];w[b>>1]=e|2;if(!(h&2)){break na}w[b>>1]=e|6}g=g+1|0;continue}break}break p}b=x[d+200>>2];x[d+40>>2]=x[d+196>>2];x[d+44>>2]=b;x[d+48>>2]=x[d+204>>2];x[23549]=0;b=x[d+192>>2];x[d+32>>2]=x[d+188>>2];x[d+36>>2]=b;V(267,d+32|0,0,a|0,0);b=x[23549];x[23549]=0;if((b|0)==1){break p}x[23549]=0;S(251,d+168|0,d+360|0,1346719318);b=x[23549];x[23549]=0;if((b|0)==1){break p}b=x[d+180>>2];x[d+16>>2]=x[d+176>>2];x[d+20>>2]=b;x[d+24>>2]=x[d+184>>2];x[23549]=0;b=x[d+172>>2];x[d+8>>2]=x[d+168>>2];x[d+12>>2]=b;V(267,d+8|0,1,a|0,y[d+396|0]>2|0);b=x[23549];x[23549]=0;if((b|0)==1){break p}b=z[a+480192>>1]+1&65535;e=b>>>0<=1?1:b;b=1;while(1){if((b|0)==(e|0)){break ka}g=x[((b<<2)+a|0)+900380>>2];if(!(!g|v[g+60|0]&1)){x[g>>2]=32767}b=b+1|0;continue}}ub(d+264|0);x[23549]=0;S(251,d+208|0,d+360|0,1346458708);b=x[23549];x[23549]=0;if((b|0)==1){break q}x[23549]=0;b=R(164,x[d+208>>2])|0;g=x[23549];x[23549]=0;if((g|0)==1){break s}if(!(!(c&1)|b^1)){x[23549]=0;S(251,d+264|0,d+360|0,1347305805);b=x[23549];x[23549]=0;if((b|0)==1){break t}x[23549]=0;O(174,d+264|0,1)|0;b=x[23549];x[23549]=0;if((b|0)==1){break v}b=z[d+356>>1];x[23549]=0;m=a+484344|0;P(211,m|0,Hb(b)|0);b=x[23549];x[23549]=0;if((b|0)==1){break v}t=d+117|0;u=d+115|0;A=d+116|0;B=d+114|0;C=d+113|0;h=Nb(d+152|0);g=0;b=0;while(1){if(Hb(z[d+356>>1])>>>0<=g>>>0){id(h);g=b;ub(d+264|0);if(!(c&4)){break $}e=0;if(!E){break aa}h=z[a+480188>>1];b=0;e=1;while(1){if((b|0)==(h|0)){break aa}f=(b<<5)+a|0;v[f+480288|0]=1;f=f+480280|0;x[f>>2]=x[f>>2]|67108864;b=b+1|0;continue}}x[23549]=0;f=R(260,d+208|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break x}x[23549]=0;e=R(268,d+208|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break y}x[23549]=0;S(176,d+112|0,d+208|0,e|0);e=x[23549];x[23549]=0;if((e|0)==1){break z}i=d+112|0;e=hc(d+132|0,i);ub(i);x[23549]=0;i=U(212,m|0,g&65535,f|0)|0;j=x[23549];x[23549]=0;if((j|0)==1){break B}oa:{if(i){o=Gb(d+100|0);x[23549]=0;P(269,d+264|0,o|0);i=x[23549];x[23549]=0;if((i|0)==1){break oa}i=x[m>>2];x[23549]=0;P(270,Yb(i,g)|0,o|0);i=x[23549];x[23549]=0;if((i|0)==1){break oa}n=0;i=Yb(x[m>>2],g);s=sf(x[i>>2],x[x[i+48>>2]+12>>2],0);Dc(h);F=(f>>>0<=1?1:f)-1|0;pa:while(1){f=x[e>>2];x[23549]=0;f=U(142,f|0,x[d+140>>2],1)|0;i=x[23549];x[23549]=0;if((i|0)==1){break C}qa:{if(!f){break qa}x[23549]=0;j=R(192,e|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break C}if(!j){G=d,H=yb(x[h>>2]),x[G+96>>2]=H;i=yb(x[h+4>>2]);while(1){f=x[d+96>>2];if(Kb(f,i)){me(Yb(x[m>>2],g),Fe(Be(d+112|0,y[f|0],y[f+1|0]),n));Se(d+96|0);continue}else{Dc(h);if((n|0)==(F|0)){break qa}f=Yb(x[m>>2],g);n=n+1|0;s=sf(x[f>>2],x[x[f+48>>2]+12>>2],n);continue pa}}}Uh(d+112|0);i=z[a+480188>>1];x[23549]=0;f=R(192,e|0)|0;k=x[23549];x[23549]=0;ra:{sa:{if((k|0)!=1){i=i>>>0<j>>>0;j=D(j-1|0,6)+s|0;ta:{if(!(f&1)){break ta}x[23549]=0;k=R(192,e|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break C}l=i?d+112|0:j;if((k|0)!=31){if((k-1&255)>>>0>252){break ta}k=(D(k>>>4|0,12)+(k&15)|0)+13|0}else{k=255}v[l|0]=k}if(!(f&2)){break ra}x[23549]=0;k=R(192,e|0)|0;l=x[23549];x[23549]=0;if((l|0)!=1){break sa}}break C}v[(i?C:j+1|0)|0]=k}if(!(f&60)){continue}v[d+95|0]=0;v[d+94|0]=0;v[d+93|0]=0;v[d+92|0]=0;if(f&4){x[23549]=0;k=R(192,e|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break C}v[d+94|0]=k}if(f&8){x[23549]=0;k=R(192,e|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break C}v[d+92|0]=k}if(f&16){x[23549]=0;k=R(192,e|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break C}v[d+95|0]=k}if(f&32){x[23549]=0;f=R(192,e|0)|0;k=x[23549];x[23549]=0;if((k|0)==1){break C}v[d+93|0]=f}bW(d+95|0,d+93|0);bW(d+94|0,d+92|0);f=y[d+94|0];if(!(y[d+95|0]==13|f?(f|0)!=13:0)){sh(d+95|0,d+94|0);sh(d+93|0,d+92|0)}Gq(d+96|0,d+95|0,d+93|0,d+94|0,d+92|0);if(aW(y[d+96|0],y[d+97|0])){f=x[vb(d+88|0,yb(x[h>>2]))>>2];x[23549]=0;S(271,h|0,f|0,d+96|0);f=x[23549];x[23549]=0;if((f|0)==1){break C}}v[(i?B:j+2|0)|0]=y[d+95|0];v[(i?A:j+4|0)|0]=y[d+93|0];f=y[d+94|0];v[(i?u:j+3|0)|0]=f;v[(i?t:j+5|0)|0]=y[d+92|0];if((f|0)==43){E=1;continue}if((f|0)!=31){continue}b=1;continue}break}tb(o)}ub(e);g=g+1|0;continue}break}break C}g=0;e=0;if(c&4){break aa}break H}b=N()|0;break b}b=N()|0;break o}b=N()|0;break o}x[d+152>>2]=-1778364416;x[d+156>>2]=-16756736;x[23549]=0;S(251,d+264|0,d+360|0,1146310725);b=x[23549];x[23549]=0;if((b|0)==1){break E}x[23549]=0;b=R(264,x[d+264>>2])|0;h=x[23549];x[23549]=0;if((h|0)==1){break D}if(b){x[23549]=0;i=R(260,d+264|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break D}b=0;h=e;while(1){ua:{if((b|0)==(i|0)){x[23549]=0;P(272,d+264|0,d+152|0);b=x[23549];x[23549]=0;if((b|0)!=1){break ua}break D}x[23549]=0;f=R(192,d+264|0)|0;j=x[23549];x[23549]=0;va:{wa:{if((j|0)!=1){if(z[a+480188>>1]<=b>>>0){break va}if(!e){break wa}j=((b<<5)+a|0)+480280|0;x[j>>2]=x[j>>2]&-67108865|((f|0)!=0)<<26;break va}break D}if(f){break va}h=1;v[((b<<5)+a|0)+480288|0]=1}b=b+1|0;continue}break}e=h&1}ub(d+264|0);if(!e){break $}x[23549]=0;W(273,a+906300|0);b=x[23549];x[23549]=0;if((b|0)==1){break _}b=a+906324|0;x[b>>2]=655376;x[b+4>>2]=0;b=a+906316|0;x[b>>2]=810369604;x[b+4>>2]=1869112133;x[d+264>>2]=0;e=a+906348|0;ZV(a+906332|0,e,d+264|0);x[23549]=0;b=O(54,d+132|0,9454)|0;h=x[23549];x[23549]=0;if((h|0)==1){break Z}NB(e,b);tb(b);x[23549]=0;b=O(54,d+112|0,9418)|0;e=x[23549];x[23549]=0;if((e|0)==1){break Y}Eu(a+906380|0,b);tb(b);x[23549]=0;b=a+906304|0;P(274,b|0,8);e=x[23549];x[23549]=0;if((e|0)==1){break _}YV(d+264|0,y[d+153|0],y[d+155|0],y[d+157|0],y[d+159|0]);e=x[d+268>>2];b=x[b>>2];h=x[d+264>>2];v[b|0]=h;v[b+1|0]=h>>>8;v[b+2|0]=h>>>16;v[b+3|0]=h>>>24;v[b+4|0]=e;v[b+5|0]=e>>>8;v[b+6|0]=e>>>16;v[b+7|0]=e>>>24}if(!g){break H}g=a+902204|0;b=0;while(1){if((b|0)==32){break H}x[d+96>>2]=D(b,127)>>>5;x[23549]=0;P(275,d+152|0,4034);e=x[23549];x[23549]=0;if((e|0)==1){break X}x[23549]=0;P(276,d+100|0,d+96|0);e=x[23549];x[23549]=0;if((e|0)==1){break W}x[23549]=0;S(277,d+264|0,d+152|0,d+100|0);e=x[23549];x[23549]=0;if((e|0)==1){break V}e=d+264|0;ze(d+80|0,e);Xe(te(g,b),x[d+80>>2],x[d+84>>2]);tb(e);tb(d+100|0);e=d+152|0;Ab(e);x[23549]=0;P(275,e|0,4016);e=x[23549];x[23549]=0;if((e|0)==1){break T}x[23549]=0;P(276,d+100|0,d+96|0);e=x[23549];x[23549]=0;if((e|0)==1){break S}x[23549]=0;S(277,d+264|0,d+152|0,d+100|0);e=x[23549];x[23549]=0;if((e|0)==1){break R}e=d+264|0;ze(d+72|0,e);Xe(te(g,b+32|0),x[d+72>>2],x[d+76>>2]);tb(e);tb(d+100|0);e=d+152|0;Ab(e);x[23549]=0;P(275,e|0,4007);e=x[23549];x[23549]=0;if((e|0)==1){break P}x[23549]=0;P(276,d+100|0,d+96|0);e=x[23549];x[23549]=0;if((e|0)==1){break O}x[23549]=0;S(277,d+264|0,d+152|0,d+100|0);e=x[23549];x[23549]=0;if((e|0)==1){break N}e=d+264|0;ze(d- -64|0,e);Xe(te(g,b- -64|0),x[d+64>>2],x[d+68>>2]);tb(e);tb(d+100|0);e=d+152|0;Ab(e);x[23549]=0;P(275,e|0,3980);e=x[23549];x[23549]=0;if((e|0)==1){break L}x[23549]=0;P(276,d+100|0,d+96|0);e=x[23549];x[23549]=0;if((e|0)==1){break K}x[23549]=0;S(277,d+264|0,d+152|0,d+100|0);e=x[23549];x[23549]=0;if((e|0)==1){break J}e=d+264|0;ze(d+56|0,e);Xe(te(g,b+96|0),x[d+56>>2],x[d+60>>2]);b=b+1|0;tb(e);tb(d+100|0);Ab(d+152|0);continue}}b=N()|0;break r}b=N()|0;break r}b=N()|0;break r}b=N()|0;break r}b=N()|0;break U}b=N()|0;tb(d+100|0)}Ab(d+152|0);break r}b=N()|0;break r}b=N()|0;break Q}b=N()|0;tb(d+100|0)}Ab(d+152|0);break r}b=N()|0;break r}b=N()|0;break M}b=N()|0;tb(d+100|0)}Ab(d+152|0);break r}b=N()|0;break r}b=N()|0;break I}b=N()|0;tb(d+100|0)}Ab(d+152|0);break r}x[23549]=0;S(251,d+264|0,d+360|0,1397575756);b=x[23549];x[23549]=0;xa:{if((b|0)!=1){x[23549]=0;b=R(164,x[d+264>>2])|0;g=x[23549];x[23549]=0;if((g|0)!=1){ya:{g=1;if(!(c&2)|b^1){break xa}while(1){c=g&65535;if(c>>>0>z[a+480190>>1]){break xa}x[23549]=0;b=R(268,d+264|0)|0;e=x[23549];x[23549]=0;za:{if((e|0)!=1){x[23549]=0;e=R(268,d+264|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break ya}if(!(b&7)){break za}c=(D(c,104)+a|0)+484380|0;x[c>>2]=e;b=Xc(d+152|0,b&4?32:b&2?16:8,1,1,0);x[23549]=0;U(205,b|0,c|0,d+264|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break za}break ya}break ya}g=g+1|0;continue}}}b=N()|0;ub(d+264|0);break r}b=N()|0;break r}ub(d+264|0);ub(d+208|0);ub(d+284|0);ub(d+304|0)}_d(d+360|0);ub(r)}db=d+400|0;return q|0}b=N()|0;break r}b=N()|0;ub(d+264|0);break r}b=N()|0;tb(o);break A}b=N()|0}ub(e);break w}b=N()|0;break w}b=N()|0;break w}b=N()|0}id(h);break u}b=N()|0}ub(d+264|0);break r}b=N()|0;break r}b=N()|0}ub(d+208|0);break o}b=N()|0;break o}b=N()|0;ub(d+264|0)}ub(d+284|0);break l}b=N()|0;break l}b=N()|0}ub(d+304|0);break b}b=N()|0;break b}b=N()|0;tb(d+264|0);break h}b=N()|0}tb(d+284|0);break f}b=N()|0}Ab(d+304|0);break b}b=N()|0;break b}b=N()|0;break b}b=N()|0}_d(d+360|0)}ub(r);Q(b|0);p()}function zja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0;d=db-240|0;db=d;wc(b);e=db-16|0;db=e;i=d+218|0;ou(e+8|0,i);g=x[e+12>>2];lc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);j=x[e+4>>2];if((j|0)==(g|0)){Zb(b,x[e+12>>2])}db=e+16|0;e=(g|0)==(j|0);if(!e){UU(i)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!e){break n}if(!VU(d+218|0)){break n}if(!c){f=1;break n}Bd(a,1024);Dg(a);x[a+480208>>2]=x[a+480208>>2]|12;Of(a+1074312|0,21);e=Hb(y[d+234|0]|y[d+235|0]<<8);if(e){x[a+480204>>2]=D(e,1e4)}e=Hb(y[d+232|0]|y[d+233|0]<<8);if(e){x[a+480196>>2]=e}if(!y[d+228|0]){vh(a,1)}QB(b,a+1298308|0,$b(y[d+222|0]|y[d+223|0]<<8|(y[d+224|0]<<16|y[d+225|0]<<24))-14|0);b=le(d+112|0,b);x[23549]=0;P(330,d+204|0,b|0);e=x[23549];x[23549]=0;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((e|0)!=1){ub(b);x[23549]=0;S(331,d+112|0,d+204|0,1395544366);b=x[23549];x[23549]=0;if((b|0)==1){break s}x[23549]=0;b=R(264,x[d+112>>2])|0;e=x[23549];x[23549]=0;if((e|0)==1){break y}if(!b){break r}x[23549]=0;b=R(260,d+112|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break y}x[23549]=0;e=R(260,d+112|0)|0;f=x[23549];x[23549]=0;A:{if((f|0)==1){break A}x[23549]=0;O(174,d+112|0,4)|0;f=x[23549];x[23549]=0;if((f|0)==1){break A}f=y[a+484376|0];g=x[a+484360>>2];x[23549]=0;aa(332,Wb(g,f)|0,d+112|0,b|0,65535,65535);b=x[23549];x[23549]=0;if((b|0)!=1){break z}}break y}a=N()|0;ub(b);break a}$e(Wb(x[a+484360>>2],y[a+484376|0]),e);b=d+112|0;ub(b);x[23549]=0;S(331,b|0,d+204|0,1346458708);b=x[23549];x[23549]=0;if((b|0)==1){break x}x[23549]=0;e=R(264,x[d+112>>2])|0;b=x[23549];x[23549]=0;if((b|0)==1){break w}f=0;b=0;if(!e){break t}x[23549]=0;e=R(260,d+112|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break w}w[a+480188>>1]=e;if((e-33&65535)>>>0<65504){break t}x[23549]=0;b=R(260,d+112|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break w}x[23549]=0;P(211,a+484344|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break w}b=0;x[23549]=0;m=R(268,d+112|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break w}switch(m-841887796|0){case 1:break t;case 0:case 2:break u;default:break v}}a=N()|0;ub(d+112|0);break b}a=N()|0;break b}a=N()|0;ub(d+112|0);break b}if(m){break t}}b=1}ub(d+112|0);if(!b){break o}x[23549]=0;S(331,d+184|0,d+204|0,1398157625);b=x[23549];x[23549]=0;if((b|0)==1){break d}x[23549]=0;b=R(264,x[d+184>>2])|0;e=x[23549];x[23549]=0;if((e|0)==1){break c}if(!b){break q}x[23549]=0;O(174,d+184|0,2)|0;b=x[23549];x[23549]=0;if((b|0)==1){break c}x[23549]=0;b=R(268,d+184|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break c}G=a,H=Le((+(b>>>0)*2.3283064365386963e-10+ +(A[a+480204>>2]/1e4>>>0))*1e4),x[G+480204>>2]=H;b=0;x[23549]=0;O(333,d+184|0,d+112|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break c}f=z[a+480188>>1];while(1){if((b|0)!=32&(b|0)!=(f|0)){G=d,H=Hb(z[(d+112|0)+(b<<1)>>1]),x[G+48>>2]=H;x[d+32>>2]=180;e=x[qd(d+48|0,d+32|0)>>2]-90|0;i=e>>31<<7|e>>>25;G=((b<<5)+a|0)+480284|0,H=Cc(zka(e<<7|45,i,90,0),hb)+128|0,w[G>>1]=H;b=b+1|0;continue}else{B:{x[23549]=0;O(174,d+184|0,16)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break B}break c}}break}x[23549]=0;b=U(142,x[d+184>>2],x[d+192>>2],2)|0;e=x[23549];x[23549]=0;if((e|0)==1){break c}C:{if(b){x[23549]=0;b=R(260,d+184|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break C}w[d+48>>1]=b;w[d+32>>1]=256;G=a,H=z[Uc(d+48|0,d+32|0)>>1],x[G+480200>>2]=H}x[23549]=0;O(174,d+184|0,128)|0;b=x[23549];x[23549]=0;if((b|0)==1){break c}x[23549]=0;b=O(333,d+184|0,d+48|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){if(!b){break q}e=z[a+480188>>1];b=0;while(1)if((b|0)!=32&(b|0)!=(e|0)){G=d,H=Hb(z[(d+48|0)+(b<<1)>>1]),x[G+32>>2]=H;x[d+20>>2]=128;G=((b<<5)+a|0)+480286|0,H=x[qd(d+32|0,d+20|0)>>2]/2&255,w[G>>1]=H;b=b+1|0;continue}else{x[a+480228>>2]=x[a+480228>>2]<<1;break q}}break c}break c}a=N()|0;break b}ub(d+112|0);break p}ub(d+184|0);x[23549]=0;S(331,d+112|0,d+204|0,1413830740);b=x[23549];x[23549]=0;D:{E:{if((b|0)!=1){x[23549]=0;b=R(264,x[d+112>>2])|0;e=x[23549];x[23549]=0;if((e|0)==1){break e}if(!b){break D}x[23549]=0;P(334,d+112|0,d+48|0);b=x[23549];x[23549]=0;if((b|0)==1){break e}if((Hb(y[d+58|0]|y[d+59|0]<<8)|0)!=65535){break E}x[23549]=0;O(174,d+112|0,1)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break E}break e}a=N()|0;break b}x[23549]=0;b=R(188,d+112|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break e}x[23549]=0;V(321,a+1298332|0,d+112|0,b|0,2);b=x[23549];x[23549]=0;if((b|0)==1){break e}}ub(d+112|0);x[23549]=0;S(331,d+48|0,d+204|0,1229869908);b=x[23549];x[23549]=0;if((b|0)==1){break h}x[23549]=0;b=R(264,x[d+48>>2])|0;e=x[23549];x[23549]=0;if((e|0)==1){break l}F:{if(!b){break F}x[23549]=0;b=R(260,d+48|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break i}G:{H:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break H}x[23549]=0;e=U(142,x[d+48>>2],x[d+56>>2],D(f,(b>>>14&2)+50|0)|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break g}if(!e){break H}w[a+480190>>1]=f;g=a+480190|0;i=d+130|0;j=(b|0)>=0;b=1;I:{J:{K:{L:{while(1){if(f>>>0<(b&65535)>>>0){x[23549]=0;b=R(260,d+48|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){break I}break g}M:{if(j){o=b}else{x[23549]=0;e=R(260,d+48|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break M}o=e+1|0}w[d+20>>1]=o;x[23549]=0;P(335,d+48|0,d+112|0);e=x[23549];x[23549]=0;if((e|0)==1){break L}e=z[d+20>>1];if((e-4e3&65535)>>>0>=61537){G=a,H=z[Ve(g,d+20|0)>>1],w[G+480190>>1]=H;l=y[d+236|0]|y[d+237|0]<<8|(y[d+238|0]<<16|y[d+239|0]<<24);x[23549]=0;V(336,d+112|0,(D(e,104)+a|0)+484380|0,$b(l)|0,m|0);e=x[23549];x[23549]=0;if((e|0)==1){break K}e=d+32|0;zl(e,2,i);x[23549]=0;P(208,d+184|0,e|0);e=x[23549];x[23549]=0;if((e|0)==1){break J}e=d+184|0;zc(((z[d+20>>1]<<5)+a|0)+946304|0,e);tb(e)}b=b+1|0;continue}break}a=N()|0;break f}a=N()|0;break f}a=N()|0;break f}a=N()|0;break f}if((b|0)!=4){break F}w[d+112>>1]=z[a+480190>>1];w[d+184>>1]=255;b=d+184|0;G=a,H=z[Uc(d+112|0,b)>>1],w[G+480192>>1]=H;x[23549]=0;S(331,b|0,d+204|0,1229278806);b=x[23549];x[23549]=0;if((b|0)==1){break j}N:while(1){O:{x[23549]=0;b=U(142,x[d+48>>2],x[d+56>>2],15)|0;e=x[23549];x[23549]=0;if((e|0)==1){break O}if(!b){break G}x[23549]=0;P(337,d+48|0,d+32|0);b=x[23549];x[23549]=0;if((b|0)==1){break k}b=Hb(z[d+32>>1]);if(b>>>0>=z[a+480192>>1]){continue}e=D(b,104)+a|0;v[e+484524|0]=y[d+40|0];f=y[d+39|0];v[e+484523|0]=255;v[e+484525|0]=f;x[23549]=0;b=b+1&65535;e=U(240,a|0,b|0,b|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break k}if(!e){continue}G=d,H=Hb(y[d+37|0]|y[d+38|0]<<8),w[G+112>>1]=H;w[d+20>>1]=4095;G=e,H=z[Uc(d+112|0,d+20|0)>>1],x[G>>2]=H;b=y[d+35|0];if((b|0)==255){continue}x[23549]=0;b=O(141,d+184|0,D(b,34)+2|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break k}if(!b){continue}x[23549]=0;P(338,d+184|0,d+112|0);b=x[23549];x[23549]=0;if((b|0)==1){break k}v[e+60|0]=y[e+60|0]|1;b=z[d+112>>1];x[d+24>>2]=16;x[d+28>>2]=240;G=d,H=Hb(b),x[G+20>>2]=H;b=LB(d+20|0);x[23549]=0;P(280,e+48|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break k}b=0;f=x[e+48>>2];i=x[e+52>>2];g=ne(f,i);while(1)if(b>>>0>=g>>>0){b=y[d+36|0];if((b|0)!=255){v[e- -64|0]=b;v[e+63|0]=b;v[e+60|0]=y[e+60|0]|4}if(qc(f,i)){continue N}b=g-1|0;v[e+62|0]=b;v[e+61|0]=b;v[e+60|0]=y[e+60|0]|2;continue N}else{v[d+20|0]=64;j=(d+112|0)+(b<<1)|0;v[d+16|0]=y[j+2|0];l=Sb(d+20|0,d+16|0);h=xb(f,b);v[h+2|0]=y[l|0];w[h>>1]=y[j+3|0];b=b+1|0;continue}}break}break k}ub(d+48|0);break p}ub(d+184|0)}ub(d+48|0);x[23549]=0;S(339,d+184|0,d+204|0,1145131092);b=x[23549];x[23549]=0;if((b|0)==1){break m}G=d,H=yb(x[d+184>>2]),x[G+20>>2]=H;l=a+484344|0;B=c&1;s=d+48|4;C=yb(x[d+188>>2]);t=(m|0)!=841887798;E=(m|0)!=841887796;while(1){P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{g=x[d+20>>2];if(!Kb(g,C)){kd(d+184|0);x[23549]=0;S(331,d+112|0,d+204|0,1346458702);b=x[23549];x[23549]=0;if((b|0)!=1){break ba}a=N()|0;break b}x[23549]=0;O(174,g|0,4)|0;b=x[23549];x[23549]=0;if((b|0)!=1){x[23549]=0;f=R(260,g|0)|0;b=x[23549];x[23549]=0;ca:{if((b|0)!=1){x[23549]=0;j=R(260,g|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break R}j=t?j:(j>>>0)/A[a+480196>>2]|0;if(!B|f>>>0>255){break P}x[23549]=0;b=U(212,l|0,f|0,j|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break R}if(b){break ca}break P}a=N()|0;break Q}if(!t){i=0;x[23549]=0;O(174,g|0,4)|0;b=x[23549];x[23549]=0;if((b|0)==1){break R}while(1){u=i&65535;if(u>>>0>=z[a+480188>>1]){break P}x[23549]=0;b=R(260,g|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break aa}x[23549]=0;S(176,d+48|0,g|0,b+(b&1)&65535);b=x[23549];x[23549]=0;if((b|0)==1){break S}b=d+48|0;e=hc(d+112|0,b);ub(b);x[d+48>>2]=0;x[d+52>>2]=0;n=0;da:{while(1){b=x[e>>2];x[23549]=0;b=U(142,b|0,x[d+120>>2],6)|0;h=x[23549];x[23549]=0;if((h|0)==1){break da}h=x[d+48>>2];if(b&h>>>0<j>>>0){b=Yb(x[l>>2],f);b=$c(x[b>>2],x[x[b+48>>2]+12>>2],h,u);x[23549]=0;P(340,d+32|0,e|0);h=x[23549];x[23549]=0;ea:{fa:{if((h|0)!=1){h=d+32|0;k=fd(h);F=Ue(h);o=Ai(h);q=gc(h);r=v[d+32|0];if((r-1&255)>>>0>95){break fa}v[b|0]=r+13;if(!x[d+52>>2]){break ea}v[b+3|0]=19;x[d+16>>2]=15;G=b,H=y[qd(s,d+16|0)|0]|208,v[G+5|0]=H;break ea}break T}if((r|0)>=0){break ea}if(x[d+52>>2]){v[b+3|0]=19;x[d+16>>2]=15;G=b,H=y[qd(s,d+16|0)|0]|192,v[G+5|0]=H;break ea}v[b|0]=254}if(y[k|0]){v[b+2|0]=1;v[d+16|0]=64;G=b,H=y[Sb(k,d+16|0)|0],v[G+4|0]=H}k=y[F|0];if(k){v[b+1|0]=k}k=y[o|0];if(k|y[q|0]){v[b+3|0]=k;v[b+5|0]=y[q|0];Qf(b)}h=v[h+5|0];b=h&255;k=d+48|0;if((h|0)<0){x[23549]=0;h=R(192,e|0)|0;q=x[23549];x[23549]=0;if((q|0)==1){break T}b=h|b<<8&32512}n=b+n|0;CB(k,n,x[a+480196>>2]);continue}break}ub(e);i=i+1|0;continue}break}break T}i=0;b=Yb(x[l>>2],f);b=$c(x[b>>2],x[x[b+48>>2]+12>>2],0,0);ga:while(1){f=0;if((i|0)==(j|0)){break P}while(1){if(z[a+480188>>1]<=(f&65535)>>>0){i=i+1|0;continue ga}x[23549]=0;P(341,d+112|0,g|0);e=x[23549];x[23549]=0;if((e|0)==1){break $}ha:{if(!E){e=x[d+112>>2];x[d+48>>2]=e;h=d+48|0;n=fd(h);k=Ue(h);h=Ai(h);if(e<<24>>24>0){v[b|0]=(D((e&240)>>>4|0,12)+(e&15)|0)+12}e=y[n|0];if(e>>>0>=4){v[b+2|0]=1;v[b+4|0]=(e>>>2|0)-1;e=y[n|0]}v[b+1|0]=e<<4&48|y[k|0]>>>4;v[b+3|0]=y[k|0]&15;v[b+5|0]=y[h|0];break ha}e=x[d+112>>2];x[d+12>>2]=e;x[d+8>>2]=e;nu(d+8|0,b);e=Db(d+112|0,0);v[b+1|0]=y[b+1|0]|y[e|0]&48}Qf(b);e=y[b+3|0];ia:{if(e>>>0>11){break ia}e=1<<e;ja:{if(!(e&2240)){if(!(e&12)){break ia}if(!y[b+5|0]){break ja}break ia}e=y[b+5|0];h=e&240;if(h){v[b+5|0]=h;break ia}if(e){break ia}}v[b+3|0]=0}b=b+6|0;f=f+1|0;continue}}}a=N()|0;break Q}x[23549]=0;b=R(264,x[d+112>>2])|0;e=x[23549];x[23549]=0;ka:{la:{ma:{na:{oa:{if((e|0)!=1){if(b){e=Gb(d+48|0);b=0;pa:{while(1){qa:{x[23549]=0;f=U(142,x[d+112>>2],x[d+120>>2],1)|0;g=x[23549];x[23549]=0;if((g|0)==1){break qa}if(!f){break pa}if(qf(x[a+484344>>2],x[a+484348>>2])>>>0<=b>>>0){break pa}x[23549]=0;S(342,d+112|0,e|0,32);f=x[23549];x[23549]=0;if((f|0)==1){break qa}f=x[l>>2];x[23549]=0;P(270,Yb(f,b)|0,e|0);f=x[23549];x[23549]=0;if((f|0)==1){break qa}b=b+1|0;continue}break}a=N()|0;tb(e);break oa}tb(e)}b=d+112|0;ub(b);x[23549]=0;S(331,b|0,d+204|0,1414679374);b=x[23549];x[23549]=0;if((b|0)==1){break na}x[23549]=0;b=R(264,x[d+112>>2])|0;e=x[23549];x[23549]=0;if((e|0)==1){break V}if(!b){break ka}e=Gb(d+48|0);b=0;while(1){x[23549]=0;f=U(142,x[d+112>>2],x[d+120>>2],1)|0;g=x[23549];x[23549]=0;if((g|0)==1){break ma}if(!(f&z[a+480188>>1]>b>>>0)){break la}x[23549]=0;S(342,d+112|0,e|0,32);f=x[23549];x[23549]=0;if((f|0)==1){break ma}Em(((b<<5)+a|0)+480289|0,e);b=b+1|0;continue}}a=N()|0}ub(d+112|0);break b}a=N()|0;break b}a=N()|0;tb(e);break U}tb(e)}b=d+112|0;ub(b);x[23549]=0;S(339,b|0,d+204|0,1145129300);b=x[23549];x[23549]=0;if((b|0)==1){break W}G=d,H=yb(x[d+112>>2]),x[G+48>>2]=H;e=c&2;f=yb(x[d+116>>2]);ra:{sa:{ta:{ua:{va:{wa:{while(1){b=x[d+48>>2];if(!Kb(b,f)){kd(d+112|0);b=Gb(d+48|0);if((m|0)!=841887798){break va}x[23549]=0;c=O(1,d+112|0,9388)|0;e=x[23549];x[23549]=0;if((e|0)==1){break wa}zb(b,c);tb(c);break ua}x[23549]=0;c=R(260,b|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break X}xa:{if(!(!e|c>>>0>=z[a+480190>>1])){c=D(c,104)+a|0;g=z[c+484518>>1];g=Xc(d+184|0,g&1?16:8,g&64?2:1,1,0);x[23549]=0;U(205,g|0,c+484484|0,b|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break xa}}yg(d+48|0);continue}break}break X}a=N()|0;break Y}x[23549]=0;S(331,d+112|0,d+204|0,1447383635);c=x[23549];x[23549]=0;ya:{za:{Aa:{Ba:{Ca:{if((c|0)!=1){x[23549]=0;c=R(264,x[d+112>>2])|0;e=x[23549];x[23549]=0;if((e|0)==1){break ta}if(!c){break za}x[23549]=0;c=R(268,d+112|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break Ca}x[23549]=0;P(255,d+32|0,4233);e=x[23549];x[23549]=0;if((e|0)==1){break Ba}x[d+20>>2]=c>>>4;x[23549]=0;x[d+16>>2]=c&15;V(343,d+184|0,d+32|0,d+20|0,d+16|0);c=x[23549];x[23549]=0;if((c|0)==1){break Aa}c=d+184|0;zb(b,c);tb(c);Ab(d+32|0);break ya}a=N()|0;break Y}a=N()|0;break Z}a=N()|0;break Z}a=N()|0;Ab(d+32|0);break Z}x[23549]=0;c=O(1,d+184|0,8407)|0;e=x[23549];x[23549]=0;if((e|0)==1){break _}zb(b,c);tb(c)}ub(d+112|0)}x[23549]=0;c=O(1,d+32|0,8407)|0;e=x[23549];x[23549]=0;if((e|0)==1){break sa}zb(a+1298344|0,c);tb(c);x[23549]=0;c=O(1,d+20|0,10016)|0;e=x[23549];x[23549]=0;if((e|0)==1){break ra}zb(a+1298356|0,c);tb(c);zb(a+1298368|0,b);x[a+1298404>>2]=13;tb(b);f=1;break o}a=N()|0;break Z}a=N()|0;break Y}a=N()|0;break Y}a=N()|0;break Q}a=N()|0;break Q}a=N()|0}ub(d+112|0)}tb(b);break b}a=N()|0;kd(d+112|0);break b}a=N()|0;break b}a=N()|0}ub(d+112|0);break b}a=N()|0;ub(e);break Q}a=N()|0;break Q}a=N()|0}kd(d+184|0);break b}yg(d+20|0);continue}}f=0}_d(d+204|0)}db=d+240|0;return f|0}a=N()|0;break b}a=N()|0;break f}a=N()|0;ub(d+184|0);break f}a=N()|0;break f}a=N()|0;break f}a=N()|0;break b}a=N()|0}ub(d+48|0);break b}a=N()|0;ub(d+112|0);break b}a=N()|0;break b}a=N()|0;ub(d+184|0)}_d(d+204|0)}Q(a|0);p()}function ofa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,V=0,W=0;e=db-464|0;db=e;wc(b);j=db-16|0;db=j;h=e+260|0;pR(j+8|0,h);f=x[j+12>>2];n=b;lc(j,x[b>>2],x[b+8>>2],x[j+8>>2],x[j+12>>2]);b=x[j+4>>2];if((b|0)==(f|0)){Zb(n,x[j+12>>2])}db=j+16|0;b=(b|0)==(f|0);if(!b){oR(h)}a:{if(!b){break a}if(!qR(e+260|0)){break a}if(!c){d=1;break a}Bd(a,134217728);hf(e,3916);x[23549]=0;S(640,e+108|0,e|0,y[e+264|0]|y[e+265|0]<<8);b=x[23549];x[23549]=0;b:{c:{d:{if((b|0)!=1){b=e+108|0;zb(a+1298344|0,b);tb(b);Ab(e);b=Tb(b,8872);zb(a+1298356|0,b);tb(b);x[a+480188>>2]=4;x[a+1298404>>2]=13;V=a,W=Hb(y[e+396|0]|y[e+397|0]<<8),x[V+480196>>2]=W;b=y[e+400|0]|y[e+401|0]<<8;x[a+480260>>2]=56;x[a+480264>>2]=13696;V=a,W=mR(Hb(b)),x[V+480204>>2]=W;Bu(Wb(x[a+484360>>2],y[a+484376|0]),e+268|0,y[e+266|0]);o=a+480190|0;m=a+480188|0;q=Nb(e+248|0);u=Nb(e+236|0);e:{while(1){f:{g:{h:{i:{j:{k:{l:{if(Hb(y[e+460|0]|y[e+461|0]<<8)>>>0>(g&65535)>>>0){x[23549]=0;b=R(260,n|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break i}w[e+216>>1]=b;if((b-4e3&65535)>>>0<=61536){break c}d=Hb(y[e+462|0]|y[e+463|0]<<8);if((Hb(y[e+264|0]|y[e+265|0]<<8)|0)==2){x[23549]=0;b=R(268,n|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break j}d=b-2|0}x[23549]=0;S(176,e|0,n|0,d|0);b=x[23549];x[23549]=0;if((b|0)==1){break k}j=hc(e+108|0,e);ub(e);C=z[Ve(o,e+216|0)>>1];w[a+480190>>1]=C;x[23549]=0;h=D(z[e+216>>1],104)+a|0;f=h+484380|0;P(266,f|0,1);b=x[23549];x[23549]=0;m:{n:{o:{if((b|0)==1){break o}if(Hb(y[e+264|0]|y[e+265|0]<<8)>>>0>1){break n}x[23549]=0;P(641,j|0,h+484423|0);b=x[23549];x[23549]=0;if((b|0)==1){break o}x[23549]=0;O(174,j|0,1)|0;b=x[23549];x[23549]=0;if((b|0)==1){break o}x[23549]=0;S(316,j|0,((z[e+216>>1]<<5)+a|0)+946304|0,30);b=x[23549];x[23549]=0;if((b|0)!=1){break m}}f=N()|0;break f}b=Gb(e);x[23549]=0;S(342,j|0,b|0,257);d=x[23549];x[23549]=0;p:{q:{if((d|0)==1){break q}Ce(h+484423|0,b);x[23549]=0;O(174,j|0,1)|0;d=x[23549];x[23549]=0;if((d|0)==1){break q}x[23549]=0;S(342,j|0,b|0,31);d=x[23549];x[23549]=0;if((d|0)==1){break q}zc(((z[e+216>>1]<<5)+a|0)+946304|0,b);if(!(v[e+116|0]&1)){break p}x[23549]=0;O(174,j|0,1)|0;d=x[23549];x[23549]=0;if((d|0)!=1){break p}}f=N()|0;tb(b);break f}tb(b)}x[23549]=0;P(642,j|0,e|0);b=x[23549];x[23549]=0;r:{if((b|0)==1){break r}i=db-16|0;db=i;d=$b(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24));x[f>>2]=d;v[i+15|0]=y[e+4|0];v[i+14|0]=64;V=f,W=y[Sb(i+15|0,i+14|0)|0]<<2,w[V+30>>1]=W;k=$b(y[e+6|0]|y[e+7|0]<<8|(y[e+8|0]<<16|y[e+9|0]<<24));x[f+4>>2]=k;b=$b(y[e+6|0]|y[e+7|0]<<8|(y[e+8|0]<<16|y[e+9|0]<<24))+$b(y[e+10|0]|y[e+11|0]<<8|(y[e+12|0]<<16|y[e+13|0]<<24))|0;x[f+8>>2]=b;if(d>>>0<=k>>>0){k=d-1|0;x[f+4>>2]=k}if(b>>>0>d>>>0){x[f+8>>2]=d;b=d}s:{if(b>>>0<k>>>0){x[f+4>>2]=0;x[f+8>>2]=0;break s}if(b>>>0<=k>>>0){break s}w[f+34>>1]=z[f+34>>1]|2;V=xb(f+68|0,0),W=k,x[V>>2]=W}db=i+16|0;t:{switch(Hb(y[e+264|0]|y[e+265|0]<<8)|0){case 2:v[h+484417|0]=y[e+18|0]<<3;break;case 0:break g;default:break t}}x[23549]=0;P(200,u|0,C|0);b=x[23549];x[23549]=0;if((b|0)==1){break r}x[23549]=0;P(643,q|0,C|0);b=x[23549];x[23549]=0;if((b|0)==1){break r}f=$d(x[q>>2],z[e+216>>1]-1|0);Dc(f);x[23549]=0;b=R(260,n|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break l}d=x[n+8>>2];i=x[n>>2];x[23549]=0;d=U(142,i|0,d|0,b<<3)|0;i=x[23549];x[23549]=0;if((i|0)==1){break l}if(d){x[23549]=0;P(644,f|0,b|0);d=x[23549];x[23549]=0;if((d|0)==1){break l}x[e+232>>2]=0;if(!(y[h+484414|0]&2)|b){break h}b=x[h+484384>>2];x[e+224>>2]=b;d=x[h+484388>>2];x[23549]=0;x[e+228>>2]=d-b;P(645,f|0,e+224|0);b=x[23549];x[23549]=0;if((b|0)!=1){break g}f=N()|0;break f}ub(j);break c}f=N()|0;break f}u:{v:{w:{x:{if(Hb(y[e+264|0]|y[e+265|0]<<8)){B=y[e+267|0];w[e+222>>1]=4;E=128;break x}x[23549]=0;E=R(260,n|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){f=N()|0;break e}b=y[e+264|0]|y[e+265|0]<<8;B=y[e+267|0];w[e+222>>1]=4;if(!Hb(b)){break w}}d=x[n+8>>2];f=0;while(1){y:{if((f&65535)>>>0>=E>>>0){break y}x[23549]=0;b=R(260,n|0)|0;j=x[23549];x[23549]=0;if((j|0)==1){break v}if((b|0)==65535){break y}x[23549]=0;B=R(260,n|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break v}x[23549]=0;b=R(260,n|0)|0;j=x[23549];x[23549]=0;if((j|0)==1){break v}w[e+222>>1]=b;if(b>>>0>127){break c}V=m,W=z[Ve(m,e+222|0)>>1],w[V>>1]=W;x[23549]=0;O(174,n|0,D(b,B)<<2)|0;b=x[23549];x[23549]=0;if((b|0)==1){break v}f=f+1|0;continue}break}x[23549]=0;O(141,n|0,d|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break u}}b=z[m>>1];x[23549]=0;F=O(646,e+224|0,b|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){K=a+484344|0;T=c&1;G=Hb(y[e+398|0]|y[e+399|0]<<8);b=0;j=0;while(1){z:{A:{B:{C:{if((b&65535)>>>0>=E>>>0){break C}D:{if(!Hb(y[e+264|0]|y[e+265|0]<<8)){d=z[e+222>>1];f=b;break D}x[23549]=0;f=R(260,n|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break z}if((f|0)==65535){break C}x[23549]=0;B=R(260,n|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break z}x[23549]=0;d=R(260,n|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break z}w[e+222>>1]=d}g=x[n+8>>2];h=x[n>>2];x[23549]=0;i=d&65535;H=B&65535;d=H<<2;g=U(142,h|0,g|0,D(i,d)|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break z}if(!g){break C}if(!T){break B}x[23549]=0;L=f&65535;f=U(212,K|0,L|0,H|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break z}if(!f){break B}s=0;E:while(1){if((s|0)==(H|0)){break A}f=0;d=Yb(x[K>>2],L);i=sf(x[d>>2],x[x[d+48>>2]+12>>2],s);t=0;F:{G:{switch((G&3)-1|0){case 0:t=!(s&3);break F;case 1:t=!(s&1);break F;case 2:break G;default:break F}}t=(s&3)!=3}I=0;while(1){if(z[e+222>>1]<=f>>>0){s=s+1|0;continue E}d=x[F>>2];x[23549]=0;P(341,e+216|0,n|0);g=x[23549];x[23549]=0;if((g|0)==1){break z}h=D(f,9)+d|0;d=e+216|0;g=fd(d);r=Ue(d);k=i+D(f,6)|0;v[k+1|0]=y[e+216|0];l=y[g|0];v[k|0]=l;g=y[Ai(d)|0];v[k+5|0]=g;m=k+5|0;if(l){v[k|0]=l+25;v[h+8|0]=0;v[h|0]=0;v[h+1|0]=0;v[h+2|0]=0;v[h+3|0]=0;v[h+4|0]=0;v[h+5|0]=0;v[h+6|0]=0;v[h+7|0]=0;g=y[m|0]}l=g&255;r=y[r|0];H:{if(r>>>0>=240){d=l|(r&15)<<8;if(d){V=m,W=uo(+(mR(d)>>>0)/1e4),v[V|0]=W;v[k+3|0]=17;break H}v[k+3|0]=0;break H}J=l>>>4|0;M=l<<4;d=J|M;I:{switch(r|0){case 0:d=i+D(f,6)|0;if(g&255){v[d+3|0]=1;break H}v[d+3|0]=0;break H;case 1:v[(i+D(f,6)|0)+3|0]=2;break H;case 2:v[(i+D(f,6)|0)+3|0]=3;break H;case 3:v[e+212|0]=15;V=h,W=y[Sb(m,e+212|0)|0]|16,v[V|0]=W;v[h+7|0]=0;v[h+1|0]=0;v[h+2|0]=0;v[(i+D(f,6)|0)+3|0]=0;break H;case 4:v[e+212|0]=15;V=h,W=y[Sb(m,e+212|0)|0]|32,v[V|0]=W;v[h+7|0]=0;v[h+1|0]=0;v[h+2|0]=0;v[(i+D(f,6)|0)+3|0]=0;break H;case 5:v[h+7|0]=0;v[h+2|0]=0;v[h+1|0]=g;v[h|0]=0;v[(i+D(f,6)|0)+3|0]=0;break H;case 6:v[h+7|0]=0;v[h+2|0]=g;v[h|0]=0;v[h+1|0]=0;v[(i+D(f,6)|0)+3|0]=0;break H;case 7:v[(i+D(f,6)|0)+3|0]=23;j=0;break H;case 8:v[(i+D(f,6)|0)+3|0]=0;j=d;break H;case 9:v[(i+D(f,6)|0)+3|0]=19;v[e+212|0]=15;V=m,W=y[Sb(m,e+212|0)|0]|16,v[V|0]=W;break H;case 10:v[(i+D(f,6)|0)+3|0]=19;v[e+212|0]=15;V=m,W=y[Sb(m,e+212|0)|0]|32,v[V|0]=W;break H;case 11:v[h+3|0]=d;v[(i+D(f,6)|0)+3|0]=0;break H;case 12:d=i+D(f,6)|0;v[d+4|0]=g;v[d+2|0]=1;v[h+3|0]=0;v[d+3|0]=0;break H;case 13:J:{K:{if((g&255)>>>0>=16){v[(i+D(f,6)|0)+2|0]=4;g=(g&240)>>>4|0;break K}if(!(l&15)){break J}v[(i+D(f,6)|0)+2|0]=3}v[(i+D(f,6)|0)+4|0]=g}v[h+3|0]=0;v[(i+D(f,6)|0)+3|0]=0;break H;case 14:v[(i+D(f,6)|0)+3|0]=19;v[m|0]=!(g&255);break H;case 15:v[(i+D(f,6)|0)+3|0]=16;v[m|0]=(g&240)>>>4;G=g&15;break H;case 16:v[h+5|0]=0;v[h+4|0]=g;v[(i+D(f,6)|0)+3|0]=0;break H;case 17:v[h+6|0]=l&15?g:0;v[(i+D(f,6)|0)+3|0]=0;break H;case 18:v[(i+D(f,6)|0)+3|0]=14;break H;case 19:v[h+8|0]=0;v[h+7|0]=g;v[h+2|0]=0;v[h|0]=0;v[h+1|0]=0;v[(i+D(f,6)|0)+3|0]=0;break H;case 20:v[(i+D(f,6)|0)+3|0]=12;break H;case 22:d=y[k+1|0];L:{if(!d){break L}l=x[q>>2];if(Cd(l,x[q+4>>2])>>>0<d>>>0){break L}g=g-1|0;v[m|0]=g;x[23549]=0;R(647,e+108|0)|0;r=x[23549];x[23549]=0;if((r|0)==1){break z}x[e+212>>2]=9;d=$d(l,d-1|0);V=e,W=Cd(x[d>>2],x[d+4>>2]),x[V+104>>2]=W;if(A[Cb(e+212|0,e+104|0)>>2]<=(g&255)>>>0){break L}d=i+D(f,6)|0;v[d+2|0]=15;v[d+4|0]=y[m|0]}v[(i+D(f,6)|0)+3|0]=0;break H;case 23:d=y[k+1|0];M:{if(!d){break M}l=x[q>>2];if(Cd(l,x[q+4>>2])>>>0<d>>>0){break M}g=g-1|0;v[m|0]=g;d=$d(l,d-1|0);l=x[d>>2];r=Cd(l,x[d+4>>2]);d=g&255;if(r>>>0<=d>>>0){break M}d=$d(l,d);g=z[d+8>>1];N:{if(g){break N}g=0;l=z[o>>1];if(!Th(l)){break N}g=l+1|0;w[o>>1]=g;w[d+8>>1]=g}v[k+1|0]=g}v[(i+D(f,6)|0)+3|0]=0;break H;case 24:d=y[k+1|0];O:{if(!d){break O}l=x[q>>2];if(Cd(l,x[q+4>>2])>>>0<d>>>0){break O}g=g-1|0;v[m|0]=g;x[23549]=0;R(647,e|0)|0;r=x[23549];x[23549]=0;if((r|0)==1){break z}x[e+212>>2]=9;d=$d(l,d-1|0);V=e,W=Cd(x[d>>2],x[d+4>>2]),x[V+104>>2]=W;if(A[Cb(e+212|0,e+104|0)>>2]>(g&255)>>>0){d=i+D(f,6)|0;v[d+2|0]=15;v[d+4|0]=y[m|0]}d=_b(x[u>>2],y[k+1|0]-1|0);g=z[d>>1];P:{if(g){break P}g=0;l=z[o>>1];if(!Th(l)){break P}g=l+1|0;w[o>>1]=g;w[d>>1]=g}v[k+1|0]=g}v[(i+D(f,6)|0)+3|0]=0;break H;case 25:d=y[k+1|0];Q:{if(!d){break Q}l=x[q>>2];if(Cd(l,x[q+4>>2])>>>0<d>>>0){break Q}g=g-1|0;v[m|0]=g;d=$d(l,d-1|0);l=x[d>>2];r=Cd(l,x[d+4>>2]);d=g&255;if(r>>>0<=d>>>0){break Q}d=$d(l,d);g=z[d+10>>1];R:{if(g){break R}g=0;l=z[o>>1];if(!Th(l)){break R}g=l+1|0;w[o>>1]=g;w[d+10>>1]=g}v[k+1|0]=g}v[(i+D(f,6)|0)+3|0]=0;break H;case 29:v[(i+D(f,6)|0)+3|0]=11;v[m|0]=d;if(l&15){v[m|0]=M|15;break H}if((g&255)>>>0<16){break H}v[m|0]=J|240;break H;case 32:if((g&255)>>>0>=16){v[h+3|0]=J;v[(i+D(f,6)|0)+3|0]=0;break H}v[(i+D(f,6)|0)+3|0]=19;v[m|0]=g|192;break H;case 33:v[(i+D(f,6)|0)+3|0]=19;v[e+212|0]=15;V=m,W=y[Sb(m,e+212|0)|0]|208,v[V|0]=W;break H;case 34:v[(i+D(f,6)|0)+3|0]=19;v[e+212|0]=15;V=m,W=y[Sb(m,e+212|0)|0]|144,v[V|0]=W;break H;case 73:v[(i+D(f,6)|0)+3|0]=10;break H;case 78:if((g&112|128)==224){v[(i+D(f,6)|0)+3|0]=19;break H}v[(i+D(f,6)|0)+3|0]=0;break H;case 79:d=i+D(f,6)|0;if((g&255)>>>0<=31){v[d+3|0]=16;G=0;break H}v[d+3|0]=17;break H;default:break I}}v[(i+D(f,6)|0)+3|0]=0}g=0;d=y[h+3|0];if(!(y[k+2|0]|!d)){g=d>>>0<16;v[k+2|0]=g?6:5;v[k+4|0]=g?d:d>>>4|0;g=1}S:{if(y[k+3|0]){break S}d=y[h+1|0];T:{if(d){v[k+3|0]=2;break T}d=y[h+2|0];if(d){v[k+3|0]=3;break T}d=y[h|0];if(d){v[k+3|0]=19;break T}d=y[h+7|0];if(d){v[k+3|0]=4;v[h+8|0]=d;break T}d=y[h+4|0];if(d){v[k+3|0]=5;v[h+5|0]=d;break T}d=y[h+3|0];if(!(!d|g)){v[k+3|0]=11;v[m|0]=d;if(d&15){d=d|-16;break T}if(d>>>0<16){break S}d=d|15;break T}d=y[h+6|0];if(d){v[k+3|0]=8;break T}if(t){v[k+3|0]=20;t=0;d=97;break T}t=0;d=j&255;if(!d|I){break S}v[k+3|0]=24;v[m|0]=j;if(j&15){d=j|-16}else{I=1;if(d>>>0<16){break S}d=j|15}I=1}v[m|0]=d}f=f+1|0;continue}}}x[a+480228>>2]=256/z[a+480188>>1];g=1;vh(a,1);if(Hb(y[e+264|0]|y[e+265|0]<<8)){U:{while(1){b=x[n+8>>2];d=x[n>>2];x[23549]=0;b=U(142,d|0,b|0,2)|0;d=x[23549];x[23549]=0;if((d|0)==1){break z}if(!b){break U}x[23549]=0;b=R(260,n|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break z}if((b|0)==65535){break U}x[23549]=0;O(174,n|0,2)|0;b=x[23549];x[23549]=0;if((b|0)==1){break z}x[23549]=0;b=R(268,n|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){x[23549]=0;O(174,n|0,b|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){continue}}break}break z}x[23549]=0;O(174,n|0,34)|0;b=x[23549];x[23549]=0;if((b|0)==1){break z}}V:{if(!(c&2)){break V}while(1){b=g&65535;if(b>>>0>C>>>0){break V}W:{d=(D(b,104)+a|0)+484380|0;if(!x[d>>2]){break W}c=Xc(e+216|0,8,1,0,0);x[23549]=0;U(205,c|0,d|0,n|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break z}c=x[q>>2];if(Cd(c,x[q+4>>2])>>>0<b>>>0){break W}k=b-1|0;h=$d(c,k);c=0;b=0;m=db-112|0;db=m;X:{i=x[d>>2];if(!Sd(i,x[d+20>>2])){break X}s=x[h>>2];j=Cd(s,x[h+4>>2]);if(j>>>0<2){break X}f=ro(m+8|0,d);x[f+20>>2]=0;x[f>>2]=0;Y:{while(1){if((c|0)==(j|0)){break Y}Z:{o=$d(s,c);t=x[o>>2];if(t>>>0>=i>>>0){break Z}o=x[o+4>>2];if(o>>>0>i-t>>>0|268435456-o>>>0<b>>>0){break Z}b=b+o|0;x[f>>2]=b;c=c+1|0;continue}break}j=c}if(!zg(f)){break X}o=f+68|0;b=0;c=0;while(1){if((c|0)==(j|0)){vm(d);b=ro(d,f);x[b+4>>2]=0;x[b+8>>2]=x[b>>2];w[b+34>>1]=z[b+34>>1]|2;break X}l=x[f+20>>2]+b|0;s=x[d+20>>2];i=$d(x[h>>2],c);rc(l,s+x[i>>2]|0,x[i+4>>2]);x[i>>2]=b;if(c-10>>>0>=4294967287){V=xb(o,c-1|0),W=b,x[V>>2]=W}c=c+1|0;b=x[i+4>>2]+b|0;continue}}db=m+112|0;b=z[_b(x[u>>2],k)>>1];if(b){_z(d,(D(b,104)+a|0)+484380|0,0,x[d>>2],0)}b=$d(x[q>>2],k);V=e,W=yb(x[b>>2]),x[V+216>>2]=W;c=yb(x[b+4>>2]);while(1){b=x[e+216>>2];if(!Kb(b,c)){break W}j=z[b+8>>1];if(j){_z(d,(D(j,104)+a|0)+484380|0,x[b>>2],x[b+4>>2],1)}j=z[b+10>>1];if(j){_z(d,(D(j,104)+a|0)+484380|0,x[b>>2],x[b+4>>2],0)}Bj(e+216|0);continue}}g=g+1|0;continue}}Kt(F);d=1;break b}x[23549]=0;O(174,n|0,D(d,z[e+222>>1])|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){break A}break z}b=b+1|0;continue}break}f=N()|0;Kt(F);break e}f=N()|0;break e}f=N()|0;break e}f=N()|0;break e}f=N()|0;break f}f=N()|0;break e}f=N()|0;break e}f=N()|0;break e}d=0;while(1){if(b>>>0<=(d&65535)>>>0){break g}x[23549]=0;h=R(268,n|0)|0;i=x[23549];x[23549]=0;_:{if((i|0)==1){break _}x[23549]=0;x[e+224>>2]=h;h=R(268,n|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break _}x[23549]=0;x[e+228>>2]=h;P(645,f|0,e+224|0);h=x[23549];x[23549]=0;if((h|0)==1){break _}d=d+1|0;continue}break}f=N()|0;break f}ub(j);g=g+1|0;continue}break}ub(j)}id(u);kR(q);break d}f=N()|0;Ab(e)}Q(f|0);p()}d=0}id(u);kR(q)}db=e+464|0;return d|0}function wea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0;d=db-560|0;db=d;wc(b);a:{if(!fB(b,d+480|0)){break a}if(!xQ(d+480|0)){break a}if(!Lb(x[b>>2],x[b+8>>2],Qc(wQ(d+480|0),hb))){break a}b:{if(!c){break b}Bd(a,4);Dg(a);v[a+1074368|0]=4;l=Gb(d+468|0);c:{d:{e:{f:{k=d+518|0;g:{if(!(cd(k,17375,20)|(y[d+540|0]|y[d+541|0]<<8|(y[d+542|0]<<16|y[d+543|0]<<24))!=276)){if((y[d+538|0]|y[d+539|0]<<8)>>>0<260){break g}e=au(d+497|0,0,20)?1154:34;break e}if(!cd(k,17354,20)){e=1;break e}g=d+56|0;nj(g,3,k);x[23549]=0;P(208,d+88|0,g|0);g=x[23549];x[23549]=0;h:{i:{if((g|0)!=1){x[23549]=0;S(11,d+176|0,5,d+88|0);g=x[23549];x[23549]=0;if((g|0)==1){break i}g=d+176|0;zb(l,g);tb(g);tb(d+88|0);if((y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24))!=1852141647|(y[k+4|0]|y[k+5|0]<<8|(y[k+6|0]<<16|y[k+7|0]<<24))!=542396493){break h}e=1048;break e}f=N()|0;break c}f=N()|0;tb(d+88|0);break c}if(!cd(k,17102,12)){e=16;if((y[d+530|0]|y[d+531|0]<<8|(y[d+532|0]<<16|y[d+533|0]<<24))==538976288&(y[d+534|0]|y[d+535|0]<<8|(y[d+536|0]<<16|y[d+537|0]<<24))==538976288){break e}v[a+1074368|0]=5;break e}if(cd(k,11515,20)){break f}}e=48;break e}if(!cd(k,27152,15)){x[23549]=0;g=O(254,a+1074312|0,54)|0;e=x[23549];x[23549]=0;C=1;if((e|0)==1){break d}x[23549]=0;O(254,g|0,51)|0;g=x[23549];x[23549]=0;e=16;if((g|0)==1){break d}break e}j:{if(cd(k,27168,14)){if(cd(k,27183,14)){break j}}x[23549]=0;g=O(254,a+1074312|0,57)|0;e=x[23549];x[23549]=0;if((e|0)==1){break d}x[23549]=0;O(254,g|0,51)|0;g=x[23549];x[23549]=0;e=16;if((g|0)!=1){break e}break d}e=cd(k,17190,11)?16:256}g=d+88|0;t=d+497|0;nj(g,3,t);x[23549]=0;P(208,d+176|0,g|0);g=x[23549];x[23549]=0;k:{l:{m:{n:{o:{p:{q:{if((g|0)!=1){g=d+176|0;zb(a+1298308|0,g);tb(g);x[a+480260>>2]=1;x[a+480264>>2]=31999;$e(Wb(x[a+484360>>2],y[a+484376|0]),y[d+546|0]|y[d+547|0]<<8);w[a+480188>>1]=y[d+548|0]|y[d+549|0]<<8;w[d+176>>1]=y[d+552|0]|y[d+553|0]<<8;w[d+88>>1]=255;F=a,G=z[Uc(g,d+88|0)>>1],w[F+480192>>1]=G;g=y[d+556|0]|y[d+557|0]<<8;if(g){x[a+480196>>2]=g}g=y[d+558|0]|y[d+559|0]<<8;if(g){g=D(g,1e4);g=g>>>0>=1e7?1e7:g;x[a+480204>>2]=g>>>0<=32e4?32e4:g}g=y[d+554|0]|y[d+555|0]<<8;x[a+480208>>2]=g<<4&16|g<<3&32768;f=x[a+484360>>2];m=y[a+484376|0];x[23549]=0;aa(332,Wb(f,m)|0,b|0,y[d+544|0]|y[d+545|0]<<8,65535,65535);f=x[23549];x[23549]=0;if((f|0)==1){break d}f=g>>>12&1?(e|0)==34?146:e:e;if(!(y[d+544|0]|y[d+545|0]<<8|f>>>0>1023)){g=y[a+484376|0];e=x[a+484360>>2];x[23549]=0;W(701,Wb(e,g)|0);g=x[23549];x[23549]=0;if((g|0)==1){break d}}x[23549]=0;O(141,b|0,(y[d+540|0]|y[d+541|0]<<8|(y[d+542|0]<<16|y[d+543|0]<<24))+60|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}if((y[d+538|0]|y[d+539|0]<<8)>>>0>=260){x[23549]=0;S(702,b|0,d+480|0,a|0);g=x[23549];x[23549]=0;if((g|0)==1){break d}}v[d+467|0]=0;u=c&2;E=d+106|0;n=d+209|0;m=Nb(d+452|0);q=1;g=-1;while(1){e=q&65535;if(e>>>0>z[a+480192>>1]){if(!(!(f&2)|r&255)){f=au(t,0,20)?f|16:f}if((y[d+538|0]|y[d+539|0]<<8)>>>0>259){break o}if(c&3){x[23549]=0;S(702,b|0,d+480|0,a|0);c=x[23549];x[23549]=0;if((c|0)==1){break n}}if(!u){break o}e=1;while(1){c=e&65535;if(c>>>0>z[a+480190>>1]){break o}n=x[m>>2];x[23549]=0;U(205,xb(n,c-1|0)|0,(D(c,104)+a|0)+484380|0,b|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){e=e+1|0;continue}break}f=N()|0;break k}x[23549]=0;i=R(143,b|0)|0;h=x[23549];x[23549]=0;r:{s:{if((h|0)!=1){ng(b,4);x[23549]=0;S(703,b|0,d+176|0,(i?i:263)|0);i=x[23549];x[23549]=0;if((i|0)==1){break p}t:{if((f|0)==1){i=x[d+176>>2];if((i|0)!=263){f=16;if((i|0)!=245){break t}x[a+1074308>>2]=16777381;x[23549]=0;f=O(1,d+164|0,13199)|0;i=x[23549];x[23549]=0;if((i|0)!=1){zb(l,f);tb(f);f=17;break t}f=N()|0;break k}x[a+1074308>>2]=16777395;x[23549]=0;f=O(1,d+152|0,13123)|0;i=x[23549];x[23549]=0;if((i|0)!=1){zb(l,f);tb(f);f=17;break t}f=N()|0;break k}if(y[d+203|0]|y[d+204|0]<<8){break t}i=x[d+176>>2];if(!(!(f&2)|(y[d+205|0]|y[d+206|0]<<8|(y[d+207|0]<<16|y[d+208|0]<<24))|(i|0)!=263)){f=f|16;break t}if(!(!(f&256)|(i|0)==29)){f=f&-257;break t}if(!(f&160)){break t}f=(i|0)==33?f:0}x[23549]=0;i=U(240,a|0,e|0,0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break p}if(!i){break r}i=((e<<2)+a|0)+900380|0;e=x[i>>2];x[23549]=0;P(704,d+176|0,e|0);e=x[23549];x[23549]=0;if((e|0)==1){break p}e=y[d+202|0];u:{if((g|0)==-1){g=e;break u}if(!(f&32)|(e|0)==(g|0)){break u}f=f&-161|128}e=y[d+203|0]|y[d+204|0]<<8;if(!e){break r}x[23549]=0;h=y[d+423|0];j=y[d+419|0]|y[d+420|0]<<8;o=y[d+418|0];s=y[d+417|0];S(705,d+140|0,a|0,e|0);e=x[23549];x[23549]=0;if((e|0)==1){break q}f=h|(j|(o|s))?f&-4:f;i=x[i>>2]+236|0;e=12;h=x[d+140>>2];j=Ic(h,x[d+144>>2]);v:{while(1){w:{if((e|0)==108){if((y[d+538|0]|y[d+539|0]<<8)>>>0>259){Dc(m)}e=0;x[23549]=0;i=O(706,d+128|0,y[d+203|0]|y[d+204|0]<<8)|0;h=x[23549];x[23549]=0;if((h|0)!=1){break w}f=N()|0;break v}if(j>>>0>z[_b(i,e)>>1]){o=z[_b(h,z[_b(i,e)>>1])>>1];F=_b(i,e),G=o,w[F>>1]=G}e=e+1|0;continue}break}x:{y:{z:{A:{while(1){h=y[d+203|0]|y[d+204|0]<<8;if(e>>>0>=h>>>0){e=0;if((y[d+538|0]|y[d+539|0]<<8)>>>0<=259){break s}B:{while(1){if(e>>>0>=h>>>0){break s}j=y[xb(x[m>>2],e)+3|0];h=x[xb(x[i>>2],e)>>2];x[23549]=0;S(176,d+56|0,b|0,((j|0)==10?(h+1>>>1|0)+16|0:h)|0);h=x[23549];x[23549]=0;if((h|0)!=1){j=d+56|0;h=hc(d+88|0,j);ub(j);j=x[d+140>>2];if(!(!u|Ic(j,x[d+144>>2])>>>0<=e>>>0)){o=z[_b(j,e)>>1];j=xb(x[m>>2],e);j=y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24);x[23549]=0;x[d+52>>2]=j;x[d>>2]=j;j=ba(707,(D(o,104)+a|0)+484380|0,d|0,h|0,d+467|0)|0;o=x[23549];x[23549]=0;if((o|0)==1){break B}B=j^1|B}ub(h);e=e+1|0;h=y[d+203|0]|y[d+204|0]<<8;continue}break}f=N()|0;break x}f=N()|0;ub(h);break x}x[23549]=0;P(708,b|0,d+88|0);h=x[23549];x[23549]=0;if((h|0)==1){break y}h=d+56|0;j=y[d+102|0];C:{if(!(j&48|y[d+105|0]!=173)){Xc(h,8,1,0,10);break C}Xc(h,j&16?16:8,j&32?3:1,0,2)}x[23549]=0;P(709,m|0,h|0);h=x[23549];x[23549]=0;if((h|0)!=1){F=xb(x[i>>2],e),G=x[d+88>>2],x[F>>2]=G;o=y[d+105|0];h=x[d+140>>2];if(Ic(h,x[d+144>>2])>>>0>e>>>0){j=z[_b(h,e)>>1];x[23549]=0;h=(D(j,104)+a|0)+484380|0;P(710,d+88|0,h|0);s=x[23549];x[23549]=0;if((s|0)==1){break A}v[h+38|0]=y[n+202|0];v[h+39|0]=y[n+203|0];v[h+40|0]=y[n+204|0];v[h+41|0]=y[n+205|0];h=d+76|0;zl(h,3,E);x[23549]=0;P(208,d+56|0,h|0);h=x[23549];x[23549]=0;if((h|0)==1){break z}h=d+56|0;zc(((j<<5)+a|0)+946304|0,h);tb(h);f=(y[d+102|0]&3)==3?(f&2)>>>1|0?f|4:f:f}r=o|r;e=e+1|0;continue}break}f=N()|0;break x}f=N()|0;break x}f=N()|0;break x}f=N()|0}sc(i)}id(d+140|0);break k}f=N()|0;break k}sc(i);id(d+140|0)}q=q+1|0;continue}}f=N()|0;break c}f=N()|0;break k}f=N()|0;break k}D:{if(!(B&1)){break D}x[23549]=0;c=O(1,d+88|0,16240)|0;e=x[23549];x[23549]=0;E:{if((e|0)!=1){e=x[a+1298464>>2];x[23549]=0;S(359,e|0,2,c|0);e=x[23549];x[23549]=0;if((e|0)==1){break E}tb(c);break D}f=N()|0;break k}f=N()|0;tb(c);break k}x[23549]=0;c=O(354,b|0,5499)|0;e=x[23549];x[23549]=0;if((e|0)==1){break n}if(c){x[23549]=0;c=R(143,b|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break n}x[23549]=0;V(321,a+1298332|0,b|0,c|0,0);c=x[23549];x[23549]=0;if((c|0)==1){break n}f=f|16}x[23549]=0;n=O(354,b|0,13827)|0;c=x[23549];x[23549]=0;if((c|0)==1){break l}if(n){x[23549]=0;c=R(143,b|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break l}x[23549]=0;e=a+901404|0;S(711,b|0,e|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break l}gB(e);f=f|16}x[23549]=0;c=O(354,b|0,13608)|0;e=x[23549];x[23549]=0;if((e|0)==1){break l}if(!c){break m}x[23549]=0;c=R(143,b|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){w[d+176>>1]=c>>>5;F=d,G=qf(x[a+484344>>2],x[a+484348>>2]),w[F+56>>1]=G;c=z[Uc(d+176|0,d+56|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break m}x[23549]=0;P(525,b|0,d+176|0);i=x[23549];x[23549]=0;F:{if((i|0)==1){break F}i=x[a+484344>>2];x[23549]=0;P(526,Yb(i,e)|0,d+176|0);i=x[23549];x[23549]=0;if((i|0)==1){break F}e=e+1|0;continue}break}f=N()|0;break k}f=N()|0;break k}f=N()|0;break k}x[23549]=0;c=O(354,b|0,13613)|0;e=x[23549];x[23549]=0;if((e|0)==1){break l}G:{if(!c){break G}x[23549]=0;c=R(143,b|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){w[d+176>>1]=(c>>>0)/20;w[d+56>>1]=z[a+480188>>1];c=z[Uc(d+176|0,d+56|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break G}x[23549]=0;S(365,b|0,((e<<5)+a|0)+480289|0,20);i=x[23549];x[23549]=0;if((i|0)!=1){e=e+1|0;continue}break}f=N()|0;break k}f=N()|0;break k}c=x[b+8>>2];e=x[b>>2];x[23549]=0;c=U(142,e|0,c|0,8)|0;e=x[23549];x[23549]=0;if((e|0)==1){break l}H:{I:{J:{K:{if(c){c=x[b+8>>2];x[23549]=0;O(366,a|0,b|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break K}f=(c|0)==x[b+8>>2]?f:f|16}L:{if(!(f&16)){break L}if(f&4){x[a+1074308>>2]=17367040;x[23549]=0;c=O(1,d+176|0,14354)|0;e=x[23549];x[23549]=0;if((e|0)!=1){zb(l,c);tb(c);break L}f=N()|0;break k}if(!(f&2)){break L}x[a+1074308>>2]=18219008;x[23549]=0;c=O(1,d+176|0,14520)|0;e=x[23549];x[23549]=0;if((e|0)==1){break J}zb(l,c);tb(c)}M:{N:{O:{P:{Q:{R:{S:{if((y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24))==1852141647&(y[k+4|0]|y[k+5|0]<<8|(y[k+6|0]<<16|y[k+7|0]<<24))==542396493){x[23549]=0;c=O(712,d+56|0,d+526|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break S}x[23549]=0;S(11,d+140|0,1,c|0);e=x[23549];x[23549]=0;if((e|0)==1){break R}x[23549]=0;e=R(713,d+140|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break Q}x[a+1074308>>2]=e;tb(d+140|0);v[a+1074368|0]=A[a+1074308>>2]<19007257?4:5;tb(c);f=24}if(!(!x[a+1074308>>2]|f&8)){v[a+1074368|0]=0;iu(a+1074312|0)}c=f&32;T:{if(!c){break T}v[a+1074368|0]=5;if(!n){sq(a+901404|0)}if((y[d+538|0]|y[d+539|0]<<8)>>>0<260){break T}x[23549]=0;U(253,a+1074312|0,4,1)|0;e=x[23549];x[23549]=0;if((e|0)==1){break l}}if(!xd(x[l+4>>2],y[l+11|0])){break M}if(!(f&256)|r&255|g+1>>>0>1){break N}x[23549]=0;c=O(1,d+140|0,8190)|0;g=x[23549];x[23549]=0;if((g|0)==1){break O}zb(l,c);tb(c);break M}f=N()|0;break k}f=N()|0;break P}f=N()|0;tb(d+140|0)}tb(c);break k}f=N()|0;break k}if(c){x[23549]=0;c=O(1,d+140|0,11927)|0;g=x[23549];x[23549]=0;if((g|0)!=1){zb(l,c);tb(c);break M}f=N()|0;break k}x[23549]=0;c=O(1,d+140|0,9633)|0;g=x[23549];x[23549]=0;if((g|0)==1){break I}zb(l,c);tb(c)}v[d+51|0]=0;U:{if(z[a+480192>>1]){x[23549]=0;c=O(375,a|0,b|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break U}v[d+51|0]=c}x[23549]=0;V(376,a|0,b|0,1,d+51|0);b=x[23549];x[23549]=0;if((b|0)==1){break U}e=x[a+1074308>>2];V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{if(y[d+51|0]){if(e>>>0>18284543){break ha}x[a+1074308>>2]=18284544;break ha}if(e>>>0<18284544){break ga}}x[23549]=0;b=O(1,d+36|0,17202)|0;c=x[23549];x[23549]=0;if((c|0)==1){break fa}c=x[a+1074308>>2];x[23549]=0;P(714,d+24|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break ea}x[23549]=0;S(2,d+76|0,b|0,d+24|0);c=x[23549];x[23549]=0;if((c|0)==1){break da}c=d+76|0;zb(l,c);tb(c);tb(d+24|0);tb(b);e=x[a+1074308>>2]}ia:{if(e-1>>>0>19005952){break ia}b=x[a+484344>>2];f=x[a+484348>>2];if(!se(b,f,254)){b=y[a+484376|0];c=x[a+484360>>2];x[23549]=0;W(715,Wb(c,b)|0);b=x[23549];x[23549]=0;if((b|0)==1){break U}f=x[a+484348>>2];b=x[a+484344>>2]}if(se(b,f,255)){break ia}wA(Wb(x[a+484360>>2],y[a+484376|0]),255,65535)}x[23549]=0;P(716,d+24|0,4043);b=x[23549];x[23549]=0;if((b|0)==1){break ba}b=y[d+538|0]|y[d+539|0]<<8;x[d+20>>2]=b>>>8;x[23549]=0;x[d+4>>2]=b&255;P(386,d+8|0,d+4|0);b=x[23549];x[23549]=0;if((b|0)==1){break aa}x[23549]=0;V(372,d+76|0,d+24|0,d+20|0,d+8|0);b=x[23549];x[23549]=0;if((b|0)==1){break $}c=d+76|0;b=zb(a+1298344|0,c);tb(c);tb(d+8|0);Ab(d+24|0);zb(a+1298368|0,l);x[a+1298404>>2]=C?8:x[a+1074308>>2]?8:5;if(!y[d+467|0]){break W}zb(a+1298380|0,b);x[23549]=0;c=O(1,d+76|0,14871)|0;g=x[23549];x[23549]=0;if((g|0)==1){break Z}zb(b,c);tb(c);x[23549]=0;b=O(1,d+24|0,9984)|0;c=x[23549];x[23549]=0;if((c|0)==1){break Y}zb(a+1298356|0,b);tb(b);x[23549]=0;b=O(1,d+8|0,9985)|0;c=x[23549];x[23549]=0;if((c|0)==1){break X}zb(a+1298392|0,b);break V}f=N()|0;break k}f=N()|0;break ca}f=N()|0;tb(d+24|0)}tb(b);break k}f=N()|0;break k}f=N()|0;break _}f=N()|0;tb(d+8|0)}Ab(d+24|0);break k}f=N()|0;break k}f=N()|0;break k}f=N()|0;break k}x[23549]=0;b=O(1,d+76|0,9985)|0;c=x[23549];x[23549]=0;if((c|0)==1){break H}zb(a+1298356|0,b)}tb(b);sc(m);tb(l);break b}f=N()|0;break k}f=N()|0;break k}f=N()|0;break k}f=N()|0;break k}f=N()|0;break k}f=N()|0}sc(m);break c}f=N()|0}tb(l);Q(f|0);p()}e=1}db=d+560|0;return e|0}function Afa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;e=db-288|0;db=e;wc(b);a:{b:{c:{if(!St(b,e+192|0)){break c}if(!LR(e+192|0)){break c}if(!Lb(x[b>>2],x[b+8>>2],Qc(KR(e+192|0),hb))){break c}if(!c){n=1;break c}Bd(a,2);x[a+480260>>2]=64;x[a+480264>>2]=32767;j=Gb(e+180|0);d=y[e+232|0]|y[e+233|0]<<8;l=(d|0)==20479?y[e+246|0]|y[e+247|0]<<8:d-16464|0;d:{e:{f:{g:{h:{i:{j:{switch(d>>>12|0){case 0:if((d|0)!=520){break d}x[23549]=0;d=O(1,e+168|0,12167)|0;g=x[23549];x[23549]=0;if((g|0)!=1){zb(j,d);break e}b=N()|0;break a;case 1:k:{if((d|0)!=4896){break k}d=y[e+254|0]|y[e+255|0]<<8;if(d){break k}if(!((y[e+230|0]|y[e+231|0]<<8)&65455|(y[e+244|0]|y[e+224|0]&15))){l:{if(v[e+243|0]<0){x[a+1074308>>2]=18219008;x[23549]=0;d=O(1,e+168|0,14433)|0;f=x[23549];x[23549]=0;if((f|0)!=1){break l}b=N()|0;break a}x[a+1074308>>2]=16777216;x[23549]=0;d=O(1,e+168|0,13199)|0;f=x[23549];x[23549]=0;if((f|0)==1){break i}}zb(j,d);tb(d);x[23549]=0;h=1;U(253,a+1074312|0,81,1)|0;d=x[23549];x[23549]=0;f=1;if((d|0)!=1){break d}break b}if(y[e+244|0]|d|(y[e+245|0]|(y[e+230|0]|y[e+231|0]<<8))){break k}x[23549]=0;d=O(1,e+168|0,9374)|0;g=x[23549];x[23549]=0;if((g|0)!=1){zb(j,d);break e}b=N()|0;break a}x[23549]=0;d=O(1,e+168|0,8392)|0;g=x[23549];x[23549]=0;i=1;if((g|0)!=1){zb(j,d);tb(d);break f}b=N()|0;break a;case 2:x[23549]=0;d=O(1,e+168|0,6714)|0;g=x[23549];x[23549]=0;f=1;if((g|0)!=1){zb(j,d);tb(d);break f}b=N()|0;break a;case 3:m:{n:{o:{p:{if(d>>>0<=12820){x[23549]=0;f=O(1,e+168|0,8455)|0;g=x[23549];x[23549]=0;if((g|0)!=1){zb(j,f);tb(f);break p}b=N()|0;break a}x[23549]=0;P(384,e+168|0,3956);f=x[23549];x[23549]=0;if((f|0)==1){break o}x[23549]=0;x[e+156>>2]=(y[e+232|0]|y[e+233|0]<<8)-12820;S(385,e+32|0,e+168|0,e+156|0);f=x[23549];x[23549]=0;if((f|0)==1){break n}f=e+32|0;zb(j,f);tb(f);Ab(e+168|0)}f=y[e+232|0]|y[e+233|0]<<8;if(f>>>0<12807){break g}g=y[e+248|0]|y[e+249|0]<<8|(y[e+250|0]<<16|y[e+251|0]<<24);if(g){break m}break g}b=N()|0;break a}b=N()|0;Ab(e+168|0);break a}f=$C(f,g);g=Eq(e+32|0);x[g+44>>2]=f;x[23549]=0;P(387,a+1298408|0,g|0);f=x[23549];x[23549]=0;if((f|0)!=1){break g}b=N()|0;break a;case 4:if((d|0)==16640){x[23549]=0;d=O(1,e+168|0,8238)|0;g=x[23549];x[23549]=0;f=1;if((g|0)!=1){zb(j,d);tb(d);x[23549]=0;U(253,a+1074312|0,81,1)|0;d=x[23549];x[23549]=0;g=0;if((d|0)==1){break b}break d}b=N()|0;break a}x[23549]=0;S(388,e+32|0,d|0,y[e+246|0]|y[e+247|0]<<8);d=x[23549];x[23549]=0;q:{if((d|0)!=1){d=e+32|0;zb(j,d);tb(d);x[a+480260>>2]=1;if((l|0)<4201){break q}x[23549]=0;U(253,a+1074312|0,7,1)|0;d=x[23549];x[23549]=0;if((d|0)==1){break b}break h}b=N()|0;break a}if((l|0)>=2386){break h}f=1;g=1;break d;case 5:if((d|0)!=21575){d=d&4095;x[a+1074308>>2]=d<<16|(d>>>0>296?y[e+246|0]|y[e+247|0]<<8:0)&65535;x[23549]=0;d=O(1,e+168|0,17202)|0;g=x[23549];x[23549]=0;r:{s:{t:{if((g|0)!=1){g=x[a+1074308>>2];x[23549]=0;P(126,e+156|0,g|0);g=x[23549];x[23549]=0;if((g|0)==1){break t}x[23549]=0;S(2,e+32|0,d|0,e+156|0);g=x[23549];x[23549]=0;if((g|0)==1){break s}g=e+32|0;zb(j,g);tb(g);tb(e+156|0);break e}b=N()|0;break a}b=N()|0;break r}b=N()|0;tb(e+156|0)}tb(d);break a}x[23549]=0;d=O(1,e+168|0,8439)|0;g=x[23549];x[23549]=0;if((g|0)!=1){zb(j,d);break e}b=N()|0;break a;case 6:x[23549]=0;d=O(1,e+168|0,8238)|0;g=x[23549];x[23549]=0;if((g|0)!=1){zb(j,d);tb(d);x[23549]=0;U(253,a+1074312|0,81,1)|0;d=x[23549];x[23549]=0;g=0;if((d|0)==1){break b}break d}b=N()|0;break a;case 7:x[23549]=0;d=O(1,e+168|0,8250)|0;g=x[23549];x[23549]=0;if((g|0)!=1){zb(j,d);break e}b=N()|0;break a;default:break j}}if((d|0)!=51712){break d}x[23549]=0;d=O(1,e+168|0,9173)|0;g=x[23549];x[23549]=0;if((g|0)!=1){zb(j,d);break e}b=N()|0;break a}b=N()|0;break a}x[23549]=0;f=1;U(253,a+1074312|0,38,1)|0;d=x[23549];x[23549]=0;g=1;if((d|0)==1){break b}break d}x[23549]=0;f=U(253,a+1074312|0,7,1)|0;g=x[23549];x[23549]=0;if((g|0)==1){break b}x[23549]=0;f=U(253,f|0,23,1)|0;g=x[23549];x[23549]=0;if((g|0)==1){break b}x[23549]=0;f=U(253,f|0,38,1)|0;g=x[23549];x[23549]=0;if((g|0)==1){break b}x[23549]=0;U(253,f|0,107,1)|0;f=x[23549];x[23549]=0;if((f|0)==1){break b}f=1;x[a+480260>>2]=1;g=0;if(d>>>0>12820){break d}}x[23549]=0;W(632,e+156|0);d=x[23549];x[23549]=0;u:{v:{w:{if((d|0)!=1){d=y[e+232|0]|y[e+233|0]<<8;x[e+132>>2]=d>>>8&15;x[23549]=0;x[e+116>>2]=d&255;P(386,e+144|0,e+116|0);d=x[23549];x[23549]=0;if((d|0)==1){break w}x[23549]=0;aa(633,e+32|0,e+156|0,j|0,e+132|0,e+144|0);d=x[23549];x[23549]=0;if((d|0)==1){break v}d=e+32|0;zb(j,d);tb(d);tb(e+144|0);Ab(e+156|0);g=0;break d}b=N()|0;break a}b=N()|0;break u}b=N()|0;tb(e+144|0)}Ab(e+156|0);break a}tb(d);g=0}x[23549]=0;d=O(1,e+156|0,14689)|0;m=x[23549];x[23549]=0;x:{y:{z:{A:{B:{C:{D:{E:{if((m|0)!=1){zb(a+1298344|0,d);tb(d);x[23549]=0;d=O(1,e+144|0,10357)|0;m=x[23549];x[23549]=0;if((m|0)==1){break E}zb(a+1298356|0,d);tb(d);r=zb(a+1298368|0,j);x[a+1298404>>2]=x[a+1074308>>2]?8:5;if(f){x[23549]=0;d=O(254,a+1074312|0,77)|0;f=x[23549];x[23549]=0;if((f|0)==1){break b}x[23549]=0;d=O(254,d|0,78)|0;f=x[23549];x[23549]=0;if((f|0)==1){break b}x[23549]=0;d=O(254,d|0,79)|0;f=x[23549];x[23549]=0;if((f|0)==1){break b}x[23549]=0;d=O(254,d|0,80)|0;f=x[23549];x[23549]=0;if((f|0)==1){break b}x[23549]=0;d=O(254,d|0,82)|0;f=x[23549];x[23549]=0;if((f|0)==1){break b}x[23549]=0;d=O(254,d|0,96)|0;f=x[23549];x[23549]=0;if((f|0)==1){break b}x[23549]=0;O(254,d|0,113)|0;d=x[23549];x[23549]=0;if((d|0)==1){break b}}d=y[e+232|0]|y[e+233|0]<<8;f=d&61440;if(f>>>0>=4097){h=(f|0)!=12288|d>>>0>12819|h}x[23549]=0;d=a+901404|0;W(634,d|0);f=x[23549];x[23549]=0;if((f|0)==1){break b}if(!h){sq(d)}d=e+132|0;tl(d,1,e+192|0);x[23549]=0;P(208,e+32|0,d|0);d=x[23549];x[23549]=0;if((d|0)==1){break B}d=e+32|0;zb(a+1298308|0,d);tb(d);d=y[e+230|0]|y[e+231|0]<<8;if(d&16){x[a+480208>>2]=x[a+480208>>2]|65536}if(d&1){x[a+480208>>2]=x[a+480208>>2]|131072}f=y[e+232|0]|y[e+233|0]<<8;if(!(!(d&64)&(f|0)!=4864)){x[a+480208>>2]=x[a+480208>>2]|2}d=y[e+241|0];x[a+480196>>2]=d;if(!(!i|(d|0)!=255?d:0)){x[a+480196>>2]=6}d=y[e+242|0];x[a+480204>>2]=d>>>0<33?i?125e4:32e4:D(d,1e4);v[e+32|0]=y[e+240|0];v[e+132|0]=64;d=y[Sb(e+32|0,e+132|0)|0];x[a+480200>>2]=d<<2;if(!(d|f>>>0>4895)){x[a+480200>>2]=256}h=y[e+243|0];if((y[e+234|0]|y[e+235|0]<<8)!=1|h>>>0>7){break D}x[e+32>>2]=(h<<4)+16;x[e+132>>2]=127;f=x[qd(e+32|0,e+132|0)>>2];break C}b=N()|0;break a}b=N()|0;break a}f=32;if((h|16)==18){break C}d=h&127;f=48;if(!d){break C}x[e+32>>2]=d;x[e+132>>2]=16;f=x[Re(e+32|0,e+132|0)>>2]}x[a+480228>>2]=f;d=0;m=x[a+1074308>>2]!=0|h<<24>>24<0;if(!m){H=a,I=Qc(Bka(f<<3|5,f>>>29|0,11,0),hb),x[H+480228>>2]=I}w[a+480188>>1]=4;x[a+480232>>2]=g?(l|0)<3299?64:36:36;f=xc(e+128|0);while(1){if((d|0)==32){if(!z[a+480188>>1]){w[a+480188>>1]=1}d=y[a+484376|0];g=x[a+484360>>2];x[23549]=0;aa(332,Wb(g,d)|0,b|0,y[e+224|0]|y[e+225|0]<<8,255,254);d=x[23549];x[23549]=0;if((d|0)!=1){l=Nb(e+132|0);x[23549]=0;U(203,b|0,l|0,y[e+226|0]|y[e+227|0]<<8)|0;d=x[23549];x[23549]=0;if((d|0)!=1){m=Nb(e+116|0);x[23549]=0;U(203,b|0,m|0,y[e+228|0]|y[e+229|0]<<8)|0;d=x[23549];x[23549]=0;F:{if((d|0)!=1){if(y[e+245|0]!=252){break A}d=0;x[23549]=0;P(635,b|0,e+32|0);g=x[23549];x[23549]=0;if((g|0)==1){break F}while(1){if((d|0)==32){break A}g=y[(e+32|0)+d|0];G:{if(!(g&32)){break G}if(i){Ll(e+20|0,f,d);if(Ib(x[x[e+20>>2]>>2],x[e+24>>2])){break G}}w[((d<<5)+a|0)+480284>>1]=(((g&15)<<8|8)>>>0)/15}d=d+1|0;continue}}break z}break z}b=N()|0;break y}b=N()|0;break a}g=(d<<5)+a|0;l=g+480280|0;Te(l);h=y[(d+e|0)+256|0];o=h&126;H:{if((h|0)!=255){h=h<<24>>24;w[a+480188>>1]=d+1;if(m){w[g+480284>>1]=h&8?204:51}if((h|0)>=0){break H}}x[l>>2]=1024}if((o-16&255)>>>0<=13){w[g+480284>>1]=128;g=e+32|0;Ll(g,f,d);xm(g)}d=d+1|0;continue}}b=N()|0;break a}w[e+32>>1]=y[e+226|0]|y[e+227|0]<<8;w[e+20>>1]=3999;h=z[Uc(e+32|0,e+20|0)>>1];w[a+480190>>1]=h;o=c&2;s=e+80|0;d=0;f=0;g=0;I:{J:{K:{while(1){if((h&65535)>>>0<=d>>>0){if(!(!(f&i)|g&65535)&(y[e+232|0]|y[e+233|0]<<8)!=4864){break K}if(!i){break J}x[23549]=0;d=g&65535;f=U(253,a+1074312|0,79,d>>>0>1|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break z}x[23549]=0;d=d>>>0<2;f=U(253,f|0,107,d|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break z}x[23549]=0;U(253,f|0,38,d|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break z}x[23549]=0;d=g&65535;O(119,r|0,(d>>>0>1?16763:16770)|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break z}if(d>>>0<2){break J}x[a+480228>>2]=48;break J}h=_b(x[l>>2],d);h=y[h|0]|y[h+1|0]<<8;x[23549]=0;h=O(141,b|0,h<<4)|0;n=x[23549];x[23549]=0;if((n|0)==1){break I}L:{M:{if(!h){break M}x[23549]=0;h=O(636,b|0,e+32|0)|0;n=x[23549];x[23549]=0;if((n|0)==1){break I}if(!h){break M}x[23549]=0;h=d+1|0;n=(D(h,104)+a|0)+484380|0;S(637,e+32|0,n|0,i|0);k=x[23549];x[23549]=0;if((k|0)==1){break I}k=e+8|0;tl(k,1,s);x[23549]=0;P(208,e+20|0,k|0);k=x[23549];x[23549]=0;if((k|0)==1){break L}k=((h<<5)+a|0)+946304|0;h=e+20|0;zc(k,h);tb(h);if(y[e+32|0]>1){break M}N:{if(!o|!(y[e+48|0]|y[e+49|0]<<8|(y[e+50|0]<<16|y[e+51|0]<<24))){break N}h=IR(e+32|0);x[23549]=0;h=O(141,b|0,h|0)|0;k=x[23549];x[23549]=0;if((k|0)==1){break z}if(!h){break N}f=e+20|0;GR(f,y[e+62|0],y[e+63|0],(y[e+234|0]|y[e+235|0]<<8)==1);x[23549]=0;U(205,f|0,n|0,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break z}f=1}g=y[e+72|0]|y[e+73|0]<<8|g}d=d+1|0;h=z[a+480190>>1];continue}break}break z}x[23549]=0;d=O(1,e+32|0,9633)|0;f=x[23549];x[23549]=0;if((f|0)==1){break z}zb(r,d);tb(d)}n=1;if(!(c&1)){break x}c=y[e+232|0]|y[e+233|0]<<8;w[e+20>>1]=y[e+228|0]|y[e+229|0]<<8;w[e+8>>1]=255;k=z[Uc(e+20|0,e+8|0)>>1];x[23549]=0;h=a+484344|0;P(211,h|0,k|0);d=x[23549];x[23549]=0;if((d|0)==1){break I}t=c>>>0<4896;C=e+25|0;E=e+23|0;u=e+24|0;F=e+22|0;G=e+21|0;g=0;r=0;o=0;while(1){if((g|0)==(k|0)){if(!t){break x}a=z[a+480188>>1];if((a|0)>(o+r|0)|(a|0)<=(r-o|0)){break x}d=qf(x[h>>2],x[h+4>>2])-1&65535;b=0;O:{if(qf(x[h>>2],x[h+4>>2])>>>0<=d>>>0){break O}while(1){c=b&65535;if(c>>>0>d>>>0){break O}a=Rf(x[h>>2],c);f=x[a>>2];if(Kb(f,x[a+4>>2])){a=yb(f);f=yb(x[Rf(x[h>>2],c)+4>>2]);c=db-16|0;db=c;x[c+12>>2]=a;while(1){if(Kb(a,f)){if(y[a+3|0]==31){v[a+3|0]=20;v[a+5|0]=y[a+5|0]|128}a=x[lk(c+12|0)>>2];continue}break}db=c+16|0}b=b+1|0;continue}}break x}x[23549]=0;c=U(212,h|0,g&65535,64)|0;d=x[23549];x[23549]=0;if((d|0)==1){break I}P:{if(!c){break P}c=_b(x[m>>2],g);c=y[c|0]|y[c+1|0]<<8;if(!c){break P}x[23549]=0;c=O(141,b|0,c<<4)|0;d=x[23549];x[23549]=0;if((d|0)==1){break I}if(!c){break P}x[23549]=0;O(174,b|0,2)|0;c=x[23549];x[23549]=0;if((c|0)==1){break I}d=0;c=Yb(x[h>>2],g);A=sf(x[c>>2],x[x[c+48>>2]+12>>2],0);while(1){if(d>>>0>63){break P}c=d;x[23549]=0;d=R(192,b|0)|0;f=x[23549];x[23549]=0;Q:{if((f|0)!=1){s=d<<24>>24;if(s){break Q}d=64;if(c>>>0>62){continue}d=Yb(x[h>>2],g);f=x[d>>2];i=x[x[d+48>>2]+12>>2];d=c+1|0;A=sf(f,i,d);continue}break z}f=s&31;d=D(f,6)+A|0;q=Wh(e+20|0);i=f>>>0<z[a+480188>>1];B=i?d:q;if(s&32){x[23549]=0;P(249,e+8|0,b|0);f=x[23549];x[23549]=0;R:{S:{T:{if((f|0)!=1){q=fd(e+8|0);f=y[e+8|0];if(f>>>0>239){break T}f=FR((D(f>>>4|0,12)+(f&15)|0)+13|0);break S}break z}U:{switch(f-254|0){case 0:break S;case 1:break U;default:break R}}f=0}v[B|0]=f}v[(i?d+1|0:G)|0]=y[q|0]}V:{if(!(s&64)){break V}x[23549]=0;q=R(192,b|0)|0;f=x[23549];x[23549]=0;W:{if((f|0)!=1){f=i?d+2|0:F;q=q<<24>>24;v[e+8|0]=q;if((q|0)>-64){break W}v[f|0]=2;v[(i?d+4|0:u)|0]=y[e+8|0]^128;break V}break z}v[f|0]=1;v[e+7|0]=64;H=i?d+4|0:u,I=y[Sb(e+8|0,e+7|0)|0],v[H|0]=I}X:{if((s|0)>=0){break X}x[23549]=0;P(249,e+8|0,b|0);f=x[23549];x[23549]=0;Y:{Z:{if((f|0)!=1){f=i?d+3|0:E;v[f|0]=y[e+8|0];d=i?d+5|0:C;H=d,I=y[fd(e+8|0)|0],v[H|0]=I;eB(B,0);i=y[f|0];if((i|0)==10){break Y}if((i|0)==31){break Z}if((i|0)!=20){break X}f=y[d|0];if((f&240)!=160|(y[e+232|0]|y[e+233|0]<<8)>>>0>4895){break X}v[d|0]=f&15^136;break X}break z}d=y[d|0];if(d>>>0>15){t=0;break X}if(d>>>0<=7){o=o+1|0;break X}r=((d|0)!=8)+r|0;break X}if(y[d|0]|(y[e+232|0]|y[e+233|0]<<8)>>>0>4865){break X}v[f|0]=37}d=c;continue}}g=g+1|0;continue}}}b=N()|0;id(m)}id(l);break a}id(m);id(l);tb(j)}db=e+288|0;return n|0}b=N()|0}tb(j);Q(b|0);p()}function aba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,n=0,o=0,s=0,t=0,u=0,B=0,C=0,F=0,G=0,H=0,I=0,J=E(0),K=E(0),L=0,M=0;g=db-32|0;db=g;b=x[a+1074308>>2];if(!(b>>>0>18285125|(b|0)==18284544)){Of(a+1074312|0,0)}b=g+20|0;h=a+1074312|0;Fb(b,h,0);d=Ib(x[x[g+20>>2]>>2],x[g+24>>2]);f=x[a+480180>>2];Fb(b,h,0);n=d&(f&16777248)!=0;G=Ib(x[x[g+20>>2]>>2],x[g+24>>2]);H=x[a+480180>>2];a:{b=x[a+1074308>>2];if(b>>>0>18874367){break a}d=1;while(1){b:{b=d&65535;if(b>>>0<=z[a+480192>>1]){b=x[((b<<2)+a|0)+900380>>2];if(!b){break b}x[g+20>>2]=D(y[b+20|0],100)>>>6;x[g+8>>2]=100;L=b,M=x[Cb(g+20|0,g+8|0)>>2],v[L+20|0]=M;if(A[a+1074308>>2]>18350079&n){break b}f=v[b+26|0];v[b+26|0]=((f>>31|1)+f|0)/2;if(A[a+1074308>>2]>18285313&n){break b}hB(Ci(b,2),x[a+480180>>2]);f=x[a+1074308>>2];c:{if(f>>>0<18284544){break c}if(f>>>0>18285135){break b}if(!y[b+34|0]){break c}if(!ej(y[b+31|0])){break c}Jb(h,2,1);if(A[a+1074308>>2]>18285135){break b}}if(!(y[b+24|0]|(y[b+23|0]|(y[b+19|0]|y[b+20|0])))){break b}Jb(h,1,1)}d:{if(!(x[a+480180>>2]&16777248)|A[a+1074308>>2]>18285313&n){break d}b=z[a+480190>>1]+1&65535;d=b>>>0<=1?1:b;c=1;while(1){if((c|0)==(d|0)){break d}b=D(c,104)+a|0;f=b+484419|0;if(!(y[f|0]|!(y[b+484421|0]|y[b+484420|0]))){v[f|0]=255}c=c+1|0;continue}}b=a+901404|0;d=b+288|0;f=pQ(d);while(1){if((d|0)==(f|0)){e:{d=b+800|0;b=Wz(d);while(1){if((b|0)==(d|0)){break e}oQ(d);d=d+32|0;continue}}}else{oQ(d);d=d+32|0;continue}break}b=x[a+1074308>>2];break a}d=d+1|0;continue}}f:{if(!(x[a+480180>>2]&16777252)|((b|0)==18874368|b>>>0>18874895)){break f}d=z[a+480192>>1]+1&65535;e=d>>>0<=1?1:d;d=0;c=1;while(1){if((c|0)==(e|0)){if(!d){break f}Jb(h,3,1);b=x[a+1074308>>2]}else{f=x[((c<<2)+a|0)+900380>>2];if(!(!f|!y[f+31|0])){v[f+33|0]=13;d=1}c=c+1|0;continue}break}}g:{if(!(x[a+480180>>2]&16777248)|((b|0)==19005440|b>>>0>19006225)){break g}Fb(g+20|0,h,0);if(!Ib(x[x[g+20>>2]>>2],x[g+24>>2])){Fb(g+8|0,h,1);if(!Ib(x[x[g+8>>2]>>2],x[g+12>>2])){break g}}b=z[a+480192>>1]+1&65535;d=b>>>0<=1?1:b;c=1;while(1){if((c|0)==(d|0)){break g}b=x[((c<<2)+a|0)+900380>>2];if(!(!b|!y[b+19|0]|!(v[b+80|0]&1))){v[b+19|0]=0}c=c+1|0;continue}}h:{i:{j:{k:{d=x[a+1074308>>2];if(d>>>0<=19007232){b=a+946300|0;c=a+906300|0;while(1){if((c|0)!=(b|0)){d=g+8|0;f=c+80|0;aN(d,f);x[23549]=0;V(224,g+20|0,0,8,d|0);d=x[23549];x[23549]=0;if((d|0)==1){break k}tb(g+8|0);d=g+20|0;Eu(f,d);c=c+160|0;tb(d);continue}break}d=x[a+1074308>>2]}l:{m:{if(x[a+480180>>2]!=4){break m}if(d>>>0<19007257){break l}if(y[a+1074368|0]!=4|d>>>0>19071235){break m}Ay(a,5);d=x[a+1074308>>2]}if(d>>>0>19202054){break j}b=19202048;if((d|0)==19202048){break i}}b=z[a+480192>>1]+1&65535;e=b>>>0<=1?1:b;b=1;while(1){if((b|0)==(e|0)){break j}f=x[((b<<2)+a|0)+900380>>2];n:{if(!f|!y[f+20|0]|!y[f+31|0]){break n}c=f+236|0;i=uq(c);while(1){if((c|0)!=(i|0)){k=z[c>>1];c=c+2|0;if(!k){continue}break n}break}v[f+20|0]=0}b=b+1|0;continue}}a=N()|0;tb(g+8|0);Q(a|0);p()}b=d;if(b>>>0>19267583){break h}}d=z[a+480192>>1]+1&65535;f=d>>>0<=1?1:d;c=1;while(1){if((c|0)==(f|0)){break h}d=x[((c<<2)+a|0)+900380>>2];o:{if(!d){break o}b=v[d+26|0];v[d+26|0]=((b>>31|1)+b|0)/2;b=x[a+1074308>>2];if(b>>>0>18350079&n){break o}v[d+19|0]=y[d+19|0]+3>>>2}c=c+1|0;continue}}p:{if(b>>>0>19398673){break p}d=z[a+480192>>1];c=1;while(1){f=c&65535;if(f>>>0>d>>>0){break p}f=x[((f<<2)+a|0)+900380>>2];if(!f|y[f+65|0]==255){c=c+1|0;continue}else{Jb(h,94,1);b=x[a+1074308>>2]}break}}q:{if(b>>>0>19399427){break q}d=z[a+480192>>1];c=1;while(1){f=c&65535;if(f>>>0>d>>>0){break q}f=x[((f<<2)+a|0)+900380>>2];if(!f|y[f+36|0]>1){c=c+1|0;continue}else{Jb(h,101,1);b=x[a+1074308>>2]}break}}r:{if(b>>>0>19923027){break r}d=z[a+480190>>1];c=1;while(1){b=c&65535;if(b>>>0>d>>>0){break r}b=D(b,104)+a|0;if(!Sd(x[b+484380>>2],x[b+484400>>2])|!(y[b+484414|0]&20)){c=c+1|0;continue}else{Jb(h,116,1)}break}}b=db-16|0;db=b;w[g+4>>1]=0;x[g>>2]=a;Fb(b+8|0,a+1074312|0,0);L=g,M=Ib(x[x[b+8>>2]>>2],x[b+12>>2]),v[L+6|0]=M;db=b+16|0;f=x[g>>2];t=x[g+4>>2];b=a+484344|0;B=b;C=qf(x[b>>2],x[b+4>>2])-1&65535;d=db-32|0;db=d;s:{if(qf(x[b>>2],x[b+4>>2])>>>0<=C>>>0){break s}while(1){b=F&65535;if(b>>>0>C>>>0){break s}c=Rf(x[B>>2],b);e=x[c>>2];if(Kb(e,x[c+4>>2])){c=yb(e);I=yb(x[Rf(x[B>>2],b)+4>>2]);x[d+24>>2]=f;x[d+28>>2]=t;x[d+8>>2]=f;x[d+12>>2]=t;k=d+8|0;s=db-16|0;db=s;x[s+12>>2]=c;while(1){if(Kb(c,I)){u=z[k+4>>1];b=u+1|0;w[k+4>>1]=b;e=x[k>>2];w[k+4>>1]=z[e+480188>>1]>(b&65535)>>>0?b:0;t:{if(Sg(y[c|0])){break t}i=x[e+1074308>>2];u:{m=x[e+480180>>2];v:{w:{if((m|0)==2){if(i>>>0>18415615){break w}if(y[c+3|0]!=23){break v}pf(c+5|0,64);break v}x:{if(m&16777248){y:{z:{if(i>>>0>=18285314){if(y[k+6|0]){break z}b=0;e=0;if(i>>>0>18874367){break y}}A:{switch(y[c+3|0]-20|0){case 3:pf(c+5|0,128);break z;case 0:break A;default:break z}}b=y[c+5|0];if((b|0)!=208){if((b|0)!=192){break z}v[c|0]=254;v[c+3|0]=0;break z}v[c+3|0]=0}B:{C:{if(i>>>0>=18350080){if(y[k+6|0]){break C}b=0;e=0;if(i>>>0>18874367){break y}}e=y[c+3|0];b=0;if(e>>>0>29){break B}b=536873152>>>e&1;break B}b=0;e=0;if(i>>>0>18874367){break y}e=y[c+3|0];b=0}e=(e|0)==24|(e|0)==22}D:{if(!(b|e)){break D}e=y[c+5|0];b=e&15;if(!b|(b|0)==15){break D}e=e&240;if(!e|(e|0)==240){break D}v[c+5|0]=y[c+3|0]==24?e:b}E:{if((i|0)==19005440|i>>>0>19005699){break E}b=z[x[k>>2]+480192>>1];if(y[k+6|0]|(!b|b>>>0>=y[c+1|0])){break E}v[c+4|0]=0;v[c+2|0]=1}if(y[c+3|0]!=18|y[c+5|0]!=17){break w}if(i>>>0>19468801){break u}if(!Ob(x[k>>2]+1074312|0,22)|y[x[k>>2]+480208|0]&4){break w}b=c+5|0;break x}if((m|0)!=4){break w}F:{if((!y[k+6|0]|i>>>0<18285314)&i>>>0<18874368){break F}if(i>>>0>19137025){break u}if(y[c+3|0]!=23|y[c+5|0]<65){break F}v[c+3|0]=0}G:{H:{I:{if(!(y[k+6|0]|i>>>0>18874367?i>>>0>=18415616:0)){b=y[c+3|0];e=y[c+2|0];if((b|0)!=10|(e|0)!=11){break I}b=0;v[c+3|0]=0;break G}if(i>>>0>18874639){break H}b=y[c+3|0];e=y[c+2|0]}if((e|0)!=11|(b&255)!=4){break G}e=y[c+4|0];if(!(e|y[k+6|0])){b=4;break G}b=4;o=y[c+5|0];if(!o){break G}v[c+2|0]=0;L=c,M=ru((e<<4)+o|0),v[L+5|0]=M;break G}if(i>>>0>19007240){break u}b=y[c+3|0]}if(y[c+5|0]|(b&255)!=16){break w}b=c+3|0}v[b|0]=0}if(i>>>0>18874367){break u}}b=y[c+3|0];o=y[c+5|0]&240;J:{K:{if((b|0)!=28|(o|0)!=96){e=0}else{if(!y[k+6|0]|(m|0)!=4){break K}e=i>>>0<18350080}if(!(e|(b|0)==20&(o|0)==96)){break J}}e=D(u,-6)+c|0;while(1){if(c>>>0>e>>>0){if(!((y[e+3|0]|8)!=28|(y[e+5|0]&240)!=96)){v[e+3|0]=0}e=e+6|0;continue}break}b=y[c+3|0]}if((b&255)!=20|(y[c+5|0]&240)!=224){break u}e=D(u,-6)+c|0;while(1){if(c>>>0<=e>>>0){break u}if(!(y[e+3|0]!=20|(y[e+5|0]&240)!=224)){v[e+3|0]=0}e=e+6|0;continue}}e=c+2|0;b=y[c+2|0];L:{if((b|0)==8){if((i|0)==19333120|i>>>0>19333174){break t}i=y[c+4|0];b=y[c+3|0];if(!(!i|(b|0)!=7)){v[c+3|0]=11;break t}M:{switch(b-5|0){default:if((b|0)!=26){break t}break;case 1:break t;case 2:break L;case 0:break M}}m=y[c+5|0];if(!(m&15)){v[c+3|0]=5;v[c+5|0]=m|i&15;break L}N:{switch(b-5|0){case 1:break t;case 0:case 2:break L;default:break N}}if((b|0)==26){break L}break t}O:{if(!((m|0)==16777216|(b|0)!=15)){b=y[c+3|0];if(b){break O}v[c+3|0]=10;v[c+5|0]=y[c+4|0]<<3;break L}if((b|0)!=15){break t}b=y[c+3|0]}if((b|0)!=10|i>>>0>19922963){break t}e=y[c+5|0]?e:y[c+4|0]?c+3|0:e}v[e|0]=0}c=x[lk(s+12|0)>>2];continue}break}b=x[k+4>>2];x[d+16>>2]=x[k>>2];x[d+20>>2]=b;db=s+16|0}F=F+1|0;continue}}x[g+20>>2]=f;x[g+24>>2]=t;db=d+32|0;P:{b=A[a+1074308>>2]<19267584;if(b&n){c=42096;while(1){if((c|0)==42440){break P}b=x[a+1074308>>2];d=x[c+4>>2];Jb(h,x[c>>2],b>>>0>=d>>>0|(b|0)==(d&-65536));c=c+8|0;continue}}if(!(b&((H|0)==4&G))){break P}c=42448;while(1){if((c|0)==42688){break P}Jb(h,x[c>>2],A[a+1074308>>2]>=A[c+4>>2]);c=c+8|0;continue}}Q:{b=x[a+480180>>2];if(b&16777248){c=42688;while(1){if((c|0)==42752){break Q}b=x[a+1074308>>2];d=x[c+4>>2];f=d&-65536;if(!(b>>>0>=f>>>0&(b>>>0<=f>>>0|b>>>0>=d>>>0))){Of(h,x[c>>2])}c=c+8|0;continue}}c=42816;d=42752;R:{switch(b-2|0){case 2:while(1){if((d|0)==42816){break Q}if(A[a+1074308>>2]<A[d+4>>2]){Of(h,x[d>>2])}d=d+8|0;continue};case 0:break R;default:break Q}}while(1){if((c|0)==42904){break Q}if(A[a+1074308>>2]<A[c+4>>2]){Of(h,x[c>>2])}c=c+8|0;continue}}d=8;c=x[a+1074308>>2];if(!(x[a+480180>>2]!=4|c>>>0>18415615)){Jb(h,98,1);c=x[a+1074308>>2]}if(c-19333159>>>0<=33){c=0;while(1){if((c|0)!=5){b=c+77|0;Fb(g+20|0,h,b);Of(Jb(h,c+86|0,Ib(x[x[g+20>>2]>>2],x[g+24>>2])),b);c=c+1|0;continue}break}c=x[a+1074308>>2]}S:{if(c>>>0>=18284544){if(c>>>0>18874627){break S}d=6;if((c|0)==18874368){break S}}Jb(h,d,1)}b=x[a+1074308>>2];T:{if(y[a+480208|0]&16){if(b>>>0<=19136511){Of(h,7);break T}if(!(x[a+480180>>2]&16777248)|b>>>0>19267583){break T}Jb(h,7,1);break T}if((b|0)==19922944|b>>>0>19922997){break T}Of(h,7)}Fb(g+20|0,h,31);U:{if(!Ib(x[x[g+20>>2]>>2],x[g+24>>2])){break U}b=x[a+1074308>>2];if(b>>>0<19071234|b>>>0>19398722){break U}d=z[a+480192>>1];c=1;while(1){b=c&65535;if(b>>>0>d>>>0){break U}V:{b=x[((b<<2)+a|0)+900380>>2];if(!b){break V}f=y[b+65|0];if(!(y[b+60|0]&4)|(f|0)==255|f>>>0<=y[b- -64|0]){break V}Jb(h,97,1);break U}c=c+1|0;continue}}b=x[a+480180>>2];W:{if(!(b&16777218)){break W}d=z[a+480190>>1];c=1;while(1){f=c&65535;if(f>>>0>d>>>0){break W}c=c+1|0;if(!(y[(D(f,104)+a|0)+484415|0]&2)){continue}break}X:{Y:{Z:{if(!(!z[a+480192>>1]|(b|0)!=16777216)){c=x[a+1074308>>2];if(c>>>0<19398688){break Y}if(c>>>0>19464277){break Z}Jb(h,109,1)}c=x[a+1074308>>2]}if((c|0)==19922944|c>>>0>19922996){break X}}Of(h,111);c=x[a+1074308>>2]}b=x[a+480180>>2];if(!((b|0)!=2|c>>>0>19464191)){Jb(h,108,1);break W}if((b|0)==2){break W}Of(h,108)}_:{c=x[a+1074308>>2];$:{aa:{if(c>>>0>=19333186){if(c>>>0>19923013){break aa}if(!(x[a+480180>>2]&16777252)){break $}b=a+946300|0;c=a+906300|0;while(1){if((c|0)!=(b|0)){ba:{if((y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24))!=1146637647|(y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24))!=-271958638){break ba}if((Pc(x[c+4>>2],x[c+8>>2])|0)!=32){break ba}d=Tb(g+20|0,16440);Eu(c+80|0,d);tb(d)}c=c+160|0;continue}break}c=x[a+1074308>>2]}if(c>>>0<19333120){break _}}if(c>>>0>19924479){break _}}if(!(x[a+480180>>2]&16777252)){break _}f=a+946300|0;a=a+906300|0;while(1){if((a|0)==(f|0)){break _}ca:{if((y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24))!=1146637647|(y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24))!=-281111764){break ca}b=x[a+4>>2];if((Pc(b,x[a+8>>2])|0)!=24){break ca}J=Fd(E(E(E((l(2,y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24)),r())*E(2e3))+E(-1))/E(1999)),E(0));K=Fd(E(E(E((l(2,y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24)),r())*E(2e3))+E(-1))/E(1999)),E(0));d=(q(J),j(2));v[b+12|0]=d;v[b+13|0]=d>>>8;v[b+14|0]=d>>>16;v[b+15|0]=d>>>24;b=x[a+4>>2];d=(q(K),j(2));v[b+16|0]=d;v[b+17|0]=d>>>8;v[b+18|0]=d>>>16;v[b+19|0]=d>>>24}a=a+160|0;continue}}db=g+32|0}function a7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=db-32|0;db=f;a:{b:{c:{d:{e:{f:{if(ie(b,21204)){Gb(a);break f}if(ie(b,9776)){b=db-112|0;db=b;g=Gb(a);x[23549]=0;W(120,b+80|0);a=x[23549];x[23549]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[23549]=0;x[b+56>>2]=0;P(1028,b+68|0,b+56|0);a=x[23549];x[23549]=0;if((a|0)==1){break q}x[23549]=0;a=O(777,g|0,b+68|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break p}tb(b+68|0);x[23549]=0;a=O(916,a|0,16359)|0;c=x[23549];x[23549]=0;r:{if((c|0)==1){break r}x[23549]=0;x[b+56>>2]=6;P(1028,b+68|0,b+56|0);c=x[23549];x[23549]=0;if((c|0)==1){break o}x[23549]=0;a=O(777,a|0,b+68|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break n}tb(b+68|0);x[23549]=0;a=O(916,a|0,16359)|0;c=x[23549];x[23549]=0;if((c|0)==1){break r}x[23549]=0;x[b+56>>2]=12;P(1028,b+68|0,b+56|0);c=x[23549];x[23549]=0;if((c|0)==1){break m}x[23549]=0;e=O(777,a|0,b+68|0)|0;a=x[23549];x[23549]=0;if((a|0)==1){break l}a=b+68|0;tb(a);x[23549]=0;a=O(54,a|0,15261)|0;c=x[23549];x[23549]=0;if((c|0)==1){break k}c=Oc(x[a+4>>2],y[a+11|0]);tb(a);if(!c){break j}x[23549]=0;O(916,e|0,15261)|0;a=x[23549];x[23549]=0;if((a|0)!=1){break j}}a=N()|0;break i}a=N()|0;break h}a=N()|0;break i}a=N()|0;tb(b+68|0);break i}a=N()|0;break i}a=N()|0;tb(b+68|0);break i}a=N()|0;break i}a=N()|0;tb(b+68|0);break i}a=N()|0;break i}c=Nb(b+56|0);s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{a=x[b+92>>2];if(a){x[23549]=0;x[b+20>>2]=a;P(1028,b+32|0,b+20|0);a=x[23549];x[23549]=0;if((a|0)==1){break E}x[23549]=0;S(942,b+44|0,8862,b+32|0);a=x[23549];x[23549]=0;if((a|0)==1){break D}x[23549]=0;P(169,c|0,b+44|0);a=x[23549];x[23549]=0;if((a|0)==1){break C}tb(b+44|0);tb(b+32|0)}if(!vd(y[b+96|0])){break y}x[23549]=0;d=O(54,b+44|0,12628)|0;a=x[23549];x[23549]=0;if((a|0)==1){break A}x[23549]=0;P(169,c|0,d|0);a=x[23549];x[23549]=0;if((a|0)==1){break z}tb(d);break x}a=N()|0;break s}a=N()|0;break B}a=N()|0;tb(b+44|0)}tb(b+32|0);break s}a=N()|0;break s}a=N()|0;tb(d);break s}if(!vd(y[b+97|0])){break x}x[23549]=0;d=O(54,b+44|0,12399)|0;a=x[23549];x[23549]=0;if((a|0)==1){break w}x[23549]=0;P(169,c|0,d|0);a=x[23549];x[23549]=0;if((a|0)==1){break v}tb(d)}if(vd(y[b+98|0])){break u}break t}a=N()|0;break s}a=N()|0;tb(d);break s}x[23549]=0;d=O(54,b+32|0,10978)|0;a=x[23549];x[23549]=0;F:{if((a|0)!=1){x[23549]=0;P(169,c|0,d|0);a=x[23549];x[23549]=0;if((a|0)==1){break F}tb(d);break t}a=N()|0;break s}a=N()|0;tb(d);break s}if(qc(x[c>>2],x[c+4>>2])){break g}x[23549]=0;a=O(916,e|0,16389)|0;d=x[23549];x[23549]=0;if((d|0)!=1){x[23549]=0;d=O(54,b+8|0,16359)|0;e=x[23549];x[23549]=0;G:{H:{I:{if((e|0)!=1){x[23549]=0;S(1029,b+20|0,c|0,d|0);e=x[23549];x[23549]=0;if((e|0)==1){break I}x[23549]=0;O(777,a|0,b+20|0)|0;a=x[23549];x[23549]=0;if((a|0)==1){break H}tb(b+20|0);tb(d);break g}a=N()|0;break s}a=N()|0;break G}a=N()|0;tb(b+20|0)}tb(d);break s}a=N()|0}Yd(c)}uf(b+80|0)}tb(g);break b}Yd(c);uf(b+80|0);db=b+112|0;break f}if(ie(b,8030)){x[f>>2]=0;yp(a,f);break f}if(ie(b,8008)){x[f>>2]=6;yp(a,f);break f}if(ie(b,10703)){x[f>>2]=12;yp(a,f);break f}if(ie(b,10479)){Tb(a,15261);break f}if(ie(b,11261)){b=Tb(f,15261);c=y[b+11|0];d=x[b+4>>2];x[23549]=0;O(54,a|0,(Oc(d,c)?15422:15044)|0)|0;a=x[23549];x[23549]=0;if((a|0)==1){break e}tb(b);break f}if(ie(b,7310)){b=db-48|0;db=b;lE(b+24|0);x[23549]=0;W(137,b+12|0);c=x[23549];x[23549]=0;J:{K:{L:{M:{if((c|0)!=1){x[23549]=0;S(138,b+36|0,b+24|0,b+12|0);c=x[23549];x[23549]=0;if((c|0)==1){break M}x[23549]=0;P(989,a|0,b+36|0);a=x[23549];x[23549]=0;if((a|0)==1){break L}tb(b+36|0);tb(b+12|0);tb(b+24|0);db=b+48|0;break f}a=N()|0;break J}a=N()|0;break K}a=N()|0;tb(b+36|0)}tb(b+12|0)}tb(b+24|0);break b}if(ie(b,9792)){b=db-16|0;db=b;e=db-16|0;db=e;x[e+12>>2]=101;i=b+4|0;c=db-96|0;db=c;g=Nb(c+84|0);N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{d=x[e+12>>2];if(d&1){x[23549]=0;P(126,c+52|0,19927555);d=x[23549];x[23549]=0;if((d|0)==1){break aa}x[23549]=0;P(110,g|0,c+52|0);d=x[23549];x[23549]=0;if((d|0)==1){break $}tb(c+52|0);d=x[e+12>>2]}if(!(d&4)){break Z}x[23549]=0;d=ca(127)|0;h=x[23549];x[23549]=0;if((h|0)==1){break Y}if(!d){break _}break Z}d=N()|0;break O}d=N()|0;tb(c+52|0);break O}x[23549]=0;W(128,c+52|0);d=x[23549];x[23549]=0;ba:{if((d|0)!=1){x[23549]=0;P(110,g|0,c+52|0);d=x[23549];x[23549]=0;if((d|0)==1){break ba}tb(c+52|0);break Z}d=N()|0;break O}d=N()|0;tb(c+52|0);break O}ca:{d=x[e+12>>2];if(!(d&32)){break ca}x[23549]=0;W(120,c+52|0);d=x[23549];x[23549]=0;da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{if((d|0)!=1){x[23549]=0;P(129,c+40|0,c+52|0);d=x[23549];x[23549]=0;if((d|0)==1){break ea}d=xd(x[c+44>>2],y[c+51|0]);tb(c+40|0);if(!d){x[23549]=0;W(130,c+28|0);d=x[23549];x[23549]=0;if((d|0)==1){break va}x[23549]=0;P(129,c+16|0,c+52|0);d=x[23549];x[23549]=0;if((d|0)==1){break ua}x[23549]=0;S(131,c+40|0,c+28|0,c+16|0);d=x[23549];x[23549]=0;if((d|0)==1){break ta}x[23549]=0;P(110,g|0,c+40|0);d=x[23549];x[23549]=0;if((d|0)==1){break sa}tb(c+40|0);tb(c+16|0);Ab(c+28|0)}d=cp(c+52|0);if(!xd(x[d+4>>2],y[d+11|0])){x[23549]=0;W(132,c+28|0);h=x[23549];x[23549]=0;if((h|0)==1){break pa}x[23549]=0;S(133,c+40|0,c+28|0,d|0);d=x[23549];x[23549]=0;if((d|0)==1){break oa}x[23549]=0;P(110,g|0,c+40|0);d=x[23549];x[23549]=0;if((d|0)==1){break na}tb(c+40|0);Ab(c+28|0)}x[23549]=0;P(134,c+40|0,c+52|0);d=x[23549];x[23549]=0;if((d|0)==1){break la}d=xd(x[c+44>>2],y[c+51|0]);tb(c+40|0);if(!d){x[23549]=0;W(130,c+28|0);d=x[23549];x[23549]=0;if((d|0)==1){break ka}x[23549]=0;P(134,c+16|0,c+52|0);d=x[23549];x[23549]=0;if((d|0)==1){break ja}x[23549]=0;S(131,c+40|0,c+28|0,c+16|0);d=x[23549];x[23549]=0;if((d|0)==1){break ia}x[23549]=0;P(110,g|0,c+40|0);d=x[23549];x[23549]=0;if((d|0)==1){break ha}tb(c+40|0);tb(c+16|0);Ab(c+28|0)}uf(c+52|0);d=x[e+12>>2];break ca}d=N()|0;break O}d=N()|0;break da}d=N()|0;break qa}d=N()|0;break ra}d=N()|0;tb(c+40|0)}tb(c+16|0)}Ab(c+28|0);break da}d=N()|0;break da}d=N()|0;break ma}d=N()|0;tb(c+40|0)}Ab(c+28|0);break da}d=N()|0;break da}d=N()|0;break da}d=N()|0;break fa}d=N()|0;break ga}d=N()|0;tb(c+40|0)}tb(c+16|0)}Ab(c+28|0);break da}d=N()|0}uf(c+52|0);break O}wa:{if(!(d&64)){break wa}x[23549]=0;d=ca(127)|0;h=x[23549];x[23549]=0;if((h|0)==1){break Y}if(d){break wa}d=c+52|0;Gb(d);x[23549]=0;P(110,g|0,d|0);d=x[23549];x[23549]=0;if((d|0)==1){break P}tb(c+52|0)}if(y[e+12|0]&128){x[23549]=0;W(135,c+52|0);d=x[23549];x[23549]=0;if((d|0)==1){break X}x[23549]=0;P(110,g|0,c+52|0);d=x[23549];x[23549]=0;if((d|0)==1){break W}tb(c+52|0)}x[23549]=0;h=O(1,c+52|0,21204)|0;d=x[23549];x[23549]=0;if((d|0)==1){break V}x[23549]=0;S(136,c+4|0,g|0,h|0);d=x[23549];x[23549]=0;if((d|0)==1){break U}x[23549]=0;W(137,c+40|0);d=x[23549];x[23549]=0;if((d|0)==1){break T}x[23549]=0;S(138,i|0,c+4|0,c+40|0);d=x[23549];x[23549]=0;if((d|0)==1){break S}tb(c+40|0);tb(c+4|0);tb(h);Yd(g);db=c+96|0;break N}d=N()|0;break O}d=N()|0;break O}d=N()|0;tb(c+52|0);break O}d=N()|0;break O}d=N()|0;break Q}d=N()|0;break R}d=N()|0;tb(c+40|0)}tb(c+4|0)}tb(h);break O}d=N()|0;tb(c+52|0)}Yd(g);Q(d|0);p()}db=e+16|0;x[23549]=0;P(989,a|0,i|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(b+4|0);db=b+16|0;break f}break c}if(ie(b,10408)){b=db-48|0;db=b;c=b+4|0;ur(c);x[23549]=0;P(129,b+36|0,c|0);c=x[23549];x[23549]=0;xa:{ya:{if((c|0)!=1){x[23549]=0;P(989,a|0,b+36|0);a=x[23549];x[23549]=0;if((a|0)==1){break ya}tb(b+36|0);uf(b+4|0);db=b+48|0;break f}a=N()|0;break xa}a=N()|0;tb(b+36|0)}uf(b+4|0);break b}if(ie(b,11224)){b=db-32|0;db=b;ur(b);x[23549]=0;P(989,a|0,cp(b)|0);a=x[23549];x[23549]=0;if((a|0)!=1){uf(b);db=b+32|0;break f}a=N()|0;uf(b);break b}if(ie(b,9805)){b=db-48|0;db=b;ur(b+16|0);c=x[b+28>>2];za:{if(c){x[23549]=0;x[b+12>>2]=c;P(1028,a|0,b+12|0);a=x[23549];x[23549]=0;if((a|0)!=1){break za}a=N()|0;uf(b+16|0);break b}Gb(a)}uf(b+16|0);db=b+48|0;break f}if(ie(b,12618)){ur(f);b=y[f+16|0];x[23549]=0;O(54,a|0,(vd(b)?15044:15422)|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){uf(f);break f}a=N()|0;uf(f);break b}if(ie(b,9821)){ur(f);b=y[f+17|0];x[23549]=0;O(54,a|0,(vd(b)?15044:15422)|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){uf(f);break f}a=N()|0;uf(f);break b}if(ie(b,12071)){ur(f);b=y[f+18|0];x[23549]=0;O(54,a|0,(vd(b)?15044:15422)|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){uf(f);break f}a=N()|0;uf(f);break b}if(ie(b,12373)){b=db-16|0;db=b;c=db-32|0;db=c;g=b+4|0;d=Gb(g);x[23549]=0;W(120,c|0);e=x[23549];x[23549]=0;Aa:{Ba:{if((e|0)!=1){x[23549]=0;P(121,d|0,cp(c)|0);e=x[23549];x[23549]=0;if((e|0)==1){break Ba}uf(c);db=c+32|0;break Aa}a=N()|0;break a}a=N()|0;uf(c);break a}x[23549]=0;P(989,a|0,g|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(b+4|0);db=b+16|0;break f}break c}if(ie(b,8151)){b=db-16|0;db=b;c=db-48|0;db=c;g=b+4|0;d=Gb(g);x[23549]=0;P(123,c+24|0,4076);e=x[23549];x[23549]=0;Ca:{Da:{Ea:{Fa:{if((e|0)!=1){x[c+20>>2]=17;x[c+16>>2]=0;x[23549]=0;x[c+12>>2]=0;aa(124,c+36|0,c+24|0,c+20|0,c+16|0,c+12|0);e=x[23549];x[23549]=0;if((e|0)==1){break Fa}x[23549]=0;O(87,d|0,c+36|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break Ea}tb(c+36|0);Ab(c+24|0);db=c+48|0;break Ca}a=N()|0;break a}a=N()|0;break Da}a=N()|0;tb(c+36|0)}Ab(c+24|0);break a}x[23549]=0;P(989,a|0,g|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(b+4|0);db=b+16|0;break f}break c}if(ie(b,6763)){b=db-16|0;db=b;c=b+4|0;Wm(c,0,19155);x[23549]=0;P(989,a|0,c|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(b+4|0);db=b+16|0;break f}break c}if(ie(b,6396)){b=db-48|0;db=b;c=Tb(b+24|0,17239);x[23549]=0;P(1030,b+12|0,2);d=x[23549];x[23549]=0;Ga:{Ha:{Ia:{Ja:{if((d|0)!=1){x[23549]=0;S(2,b+36|0,c|0,b+12|0);d=x[23549];x[23549]=0;if((d|0)==1){break Ja}x[23549]=0;P(989,a|0,b+36|0);a=x[23549];x[23549]=0;if((a|0)==1){break Ia}tb(b+36|0);tb(b+12|0);tb(c);db=b+48|0;break f}a=N()|0;break Ga}a=N()|0;break Ha}a=N()|0;tb(b+36|0)}tb(b+12|0)}tb(c);break b}if(ie(b,11247)){b=db-16|0;db=b;c=b+4|0;Wm(c,0,17555);x[23549]=0;P(989,a|0,c|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(b+4|0);db=b+16|0;break f}break c}if(ie(b,10415)){b=db-16|0;db=b;c=b+4|0;qr(c,0);x[23549]=0;P(989,a|0,c|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(b+4|0);db=b+16|0;break f}break c}if(ie(b,10390)){b=db-16|0;db=b;c=b+4|0;qr(c,2);x[23549]=0;P(989,a|0,c|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(b+4|0);db=b+16|0;break f}break c}if(ie(b,10375)){b=db-16|0;db=b;c=b+4|0;qr(c,3);x[23549]=0;P(989,a|0,c|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(b+4|0);db=b+16|0;break f}break c}Gb(a)}db=f+32|0;break d}a=N()|0;tb(b);break b}return}a=N()|0;tb(b+4|0)}Q(a|0);p()}tb(d);Q(a|0);p()}function Kja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;e=db-416|0;db=e;wc(b);f=e+399|0;g=hC(b,f);if(!g){Nu(f)}a:{b:{c:{d:{e:{f:{if(!g){break f}if(!dV(e+399|0)){break f}if(!Lb(x[b>>2],x[b+8>>2],Qc(72,0))){break f}if(!c){d=1;break f}Bd(a,1);x[a+480208>>2]=x[a+480208>>2]&-25231361|16842752;j=y[e+408|0];w[a+480190>>1]=63;w[a+480188>>1]=j;g:{h:{i:{while(1){if((j&65535)>>>0<=d>>>0){j:{Vb(e+320|0,0,64);d=1;k:{l:{m:{n:{while(1){o:{f=d&65535;if(f>>>0>z[a+480190>>1]){mC(b,a+1298308|0);f=e+312|0;d=db-16|0;db=d;p:{if(!Lb(x[b>>2],x[b+8>>2],8)){v[d|0]=0;Sh(f,8,d);break p}Vm(d+8|0,f);pd(d,b,x[d+8>>2],x[d+12>>2])}db=d+16|0;o=Nb(e+300|0);f=y[e+409|0]|y[e+410|0]<<8;if(f){d=Nb(e+212|0);x[23549]=0;f=U(311,b|0,d|0,D(f,y[e+408|0])<<1)|0;g=x[23549];x[23549]=0;if((g|0)==1){break k}if(!f){break j}ge(e+272|0,x[d>>2],x[d+4>>2]);f=Xd(e+264|0);x[23549]=0;g=x[f+4>>2];x[e+40>>2]=x[f>>2];x[e+44>>2]=g;f=Xf(312,e+280|0,x[e+272>>2],x[e+276>>2],e+40|0);g=x[23549];x[23549]=0;if((g|0)==1){break o}g=x[d+4>>2];j=x[d>>2];x[23549]=0;U(203,f|0,o|0,Pc(j,g)>>>1|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break n}ub(f);bc(d)}m=Nb(e+252|0);x[23549]=0;P(313,m|0,(y[e+411|0]|y[e+412|0]<<8)<<8);d=x[23549];x[23549]=0;if((d|0)==1){break i}d=0;while(1){g=y[e+411|0]|y[e+412|0]<<8;f=d&65535;if(g>>>0<=f>>>0){break l}x[e+212>>2]=g-f;x[e+160>>2]=2e3;d=e+212|0;g=x[qd(d,e+160|0)>>2];d=Nb(d);x[23549]=0;g=U(311,b|0,d|0,g<<8)|0;j=x[23549];x[23549]=0;if((j|0)==1){break d}if(!g){break m}g=vb(e+248|0,yb(x[m+4>>2]));j=yb(x[d>>2]);i=yb(x[e+216>>2]);g=x[g>>2];x[23549]=0;V(314,m|0,g|0,j|0,i|0);g=x[23549];x[23549]=0;if((g|0)==1){break d}bc(d);d=f+2e3|0;continue}}g=(D(f,104)+a|0)+484380|0;nd(g,1);h=f+(e+320|0)|0;f=ee(b);v[h|0]=f;if(f<<24>>24>=0){A=g,B=bV(b)<<1,x[A>>2]=B}d=d+1|0;continue}break}a=N()|0;break b}a=N()|0;ub(f);break b}bc(d);d=0;break h}ge(e+232|0,x[m>>2],x[m+4>>2]);Ng(e+240|0,x[e+232>>2],x[e+236>>2]);d=y[a+484376|0];f=x[a+484360>>2];x[23549]=0;P(315,Wb(f,d)|0,y[e+409|0]|y[e+410|0]<<8);d=x[23549];x[23549]=0;if((d|0)==1){break e}q=a+484344|0;s=c&1;i=0;while(1){if((y[e+409|0]|y[e+410|0]<<8)>>>0<=i>>>0){g=c&2;j=1;q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{while(1){c=j&65535;if(c>>>0>z[a+480190>>1]){break x}x[23549]=0;d=y[c+(e+320|0)|0];S(316,b|0,((c<<5)+a|0)+946304|0,d&63);f=x[23549];x[23549]=0;if((f|0)==1){break v}C:{D:{if(d<<24>>24<0){break D}x[23549]=0;d=R(317,b|0)|0;f=x[23549];x[23549]=0;E:{F:{G:{H:{I:{J:{K:{L:{if((f|0)==1){break L}c=D(c,104)+a|0;f=c+484392|0;x[f>>2]=d<<1;x[23549]=0;d=R(317,b|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break K}if(d>>>0>=2){x[c+484396>>2]=x[f>>2]+(d<<1);d=c+484414|0;w[d>>1]=z[d>>1]|8}x[23549]=0;d=R(192,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break u}v[e+84|0]=d;v[e+180|0]=64;A=c+484410|0,B=y[Sb(e+84|0,e+180|0)|0]<<2,w[A>>1]=B;x[23549]=0;d=R(192,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break L}v[c+484417|0]=d<<4;c=c+484380|0;wB(c);if(!x[c>>2]){break D}x[23549]=0;f=R(192,b|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break F}d=0;switch(f|0){case 4:case 5:break E;case 2:case 3:break H;case 1:break I;case 0:break J;default:break h}}a=N()|0;break c}a=N()|0;break c}if(g){f=Nb(e+84|0);i=x[b+8>>2];h=x[b>>2];k=x[c>>2];x[23549]=0;i=U(142,h|0,i|0,k|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break t}if(!i){break y}d=x[c>>2];x[23549]=0;S(318,b|0,f|0,d|0);d=x[23549];x[23549]=0;if((d|0)==1){break t}A=e,B=yb(x[f>>2]),x[A+180>>2]=B;i=yb(x[e+88>>2]);while(1){d=x[e+180>>2];if(Kb(d,i)){h=d;d=y[d|0];v[h|0]=d<<7|(d^-1)>>>1&127;Oe(e+180|0);continue}break}ge(e+200|0,x[f>>2],x[e+88>>2]);d=Xd(e+192|0);x[23549]=0;i=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=i;d=Xf(312,e+212|0,x[e+200>>2],x[e+204>>2],e+16|0);i=x[23549];x[23549]=0;M:{if((i|0)!=1){i=Xc(e+180|0,16,1,0,16);x[23549]=0;U(205,i|0,c|0,d|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break M}ub(d);bc(f);break D}a=N()|0;break q}a=N()|0;ub(d);break q}c=x[c>>2];break G}f=Nb(e+84|0);d=x[c>>2];x[23549]=0;S(319,e+180|0,b|0,d|0);d=x[23549];x[23549]=0;N:{O:{P:{if((d|0)!=1){d=e+180|0;i=zm(f,d);bc(d);if(g){ge(e+152|0,x[i>>2],x[e+88>>2]);d=Xd(e+144|0);x[23549]=0;h=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=h;d=Xf(312,e+160|0,x[e+152>>2],x[e+156>>2],e+24|0);h=x[23549];x[23549]=0;if((h|0)==1){break P}h=Xc(e+180|0,8,1,0,2);x[23549]=0;U(205,h|0,c|0,d|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break O}ub(d)}bc(i);break D}a=T(30544)|0;if((eb|0)!=($(30544)|0)){break N}Y(a|0)|0;d=0;x[23549]=0;X(17);a=x[23549];x[23549]=0;if((a|0)!=1){break w}a=N()|0;break N}a=N()|0;break N}a=N()|0;ub(d)}bc(f);break c}if(g){d=Xc(e+84|0,(f|0)==2?8:16,1,0,0);x[23549]=0;U(205,d|0,c|0,b|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break D}a=N()|0;break c}c=D(x[c>>2],f-1|0)}x[23549]=0;O(174,b|0,c|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break D}}a=N()|0;break c}i=Nb(e+84|0);d=x[c>>2];x[23549]=0;S(320,e+180|0,b|0,d|0);d=x[23549];x[23549]=0;Q:{R:{if((d|0)!=1){h=e+180|0;d=zm(i,h);bc(h);if(!g){break Q}if((f|0)!=5){break R}A=e,B=yb(x[d>>2]),x[A+180>>2]=B;k=yb(x[e+88>>2]);while(1){h=x[e+180>>2];if(!Kb(h,k)){break R}l=h;h=y[h|0];v[l|0]=y[(h>>>7|0)+26433|0]^h;Oe(e+180|0);continue}}a=T(30544)|0;if((eb|0)!=($(30544)|0)){break z}Y(a|0)|0;d=0;x[23549]=0;X(17);a=x[23549];x[23549]=0;if((a|0)!=1){break C}a=N()|0;break z}ge(e+112|0,x[d>>2],x[e+88>>2]);h=Xd(e+104|0);x[23549]=0;k=x[h+4>>2];x[e+32>>2]=x[h>>2];x[e+36>>2]=k;h=Xf(312,e+124|0,x[e+112>>2],x[e+116>>2],e+32|0);k=x[23549];x[23549]=0;if((k|0)==1){break B}f=(f|0)==5;f=Xc(e+180|0,f?16:8,1,0,f?16:1);x[23549]=0;U(205,f|0,c|0,h|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break A}ub(h)}bc(d)}j=j+1|0;continue}break}bc(i);break h}a=N()|0;break z}a=N()|0;ub(h)}bc(i);break c}bc(f);break h}S:{T:{U:{V:{d=y[e+413|0]|y[e+414|0]<<8|y[e+415|0]<<16;if(d){c=Nb(e+180|0);x[23549]=0;b=U(311,b|0,c|0,d|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break s}if(!b){break T}ge(e+72|0,x[c>>2],x[c+4>>2]);b=Xd(e- -64|0);x[23549]=0;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;b=Xf(312,e+84|0,x[e+72>>2],x[e+76>>2],e+8|0);f=x[23549];x[23549]=0;if((f|0)==1){break V}x[23549]=0;V(321,a+1298332|0,b|0,d|0,1);d=x[23549];x[23549]=0;if((d|0)==1){break U}ub(b);bc(c)}x[23549]=0;W(322,e+52|0);b=x[23549];x[23549]=0;if((b|0)!=1){break S}a=N()|0;break c}a=N()|0;break r}a=N()|0;ub(b);break r}bc(c);d=0;break h}x[23549]=0;S(199,e+180|0,e+52|0,y[e+407|0]);b=x[23549];x[23549]=0;W:{X:{if((b|0)!=1){b=e+180|0;zb(a+1298344|0,b);tb(b);Ab(e+52|0);x[23549]=0;b=O(1,b|0,9979)|0;c=x[23549];x[23549]=0;if((c|0)==1){break X}zb(a+1298356|0,b);tb(b);x[23549]=0;b=O(1,e+52|0,5042)|0;c=x[23549];x[23549]=0;if((c|0)==1){break W}zb(a+1298368|0,b);tb(b);x[a+1298404>>2]=10;d=1;break h}a=N()|0;Ab(e+52|0);break c}a=N()|0;break c}a=N()|0;break c}bc(f);break h}a=N()|0;break c}a=N()|0;break c}a=N()|0;break q}a=N()|0}bc(c);break c}bc(f);break c}A=_b(x[Wb(x[a+484360>>2],y[a+484376|0])>>2],i),B=i,w[A>>1]=B;Y:{Z:{if(!s){break Z}x[23549]=0;r=i&65535;d=U(212,q|0,r|0,64)|0;f=x[23549];x[23549]=0;if((f|0)==1){break Y}if(!d){break Z}f=z[a+480188>>1];h=0;while(1){d=f&65535;if(d>>>0<=h>>>0){break Z}d=_b(x[o>>2],D(d,i)+h|0);d=y[d|0]|y[d+1|0]<<8;_:{if(d>>>0>=(y[e+411|0]|y[e+412|0]<<8)>>>0){break _}j=0;t=0-h|0;u=d<<8;d=Yb(x[q>>2],i);d=$c(x[d>>2],x[x[d+48>>2]+12>>2],0,h&65535);while(1){if((j|0)==64){break _}yq(e+212|0,x[e+240>>2],x[e+244>>2],(j<<2)+u|0,4);f=x[e+212>>2];g=Db(f,0);n=y[g|0]&63;v[d|0]=n?n+48|0:0;k=Db(f,1);v[d+1|0]=y[k|0]<<2&60|y[g|0]>>>6;g=y[k|0];l=Db(f,2);k=y[Db(f,3)|0];l=y[l|0];f=k<<4|l>>>4;w[e+84>>1]=f;l=l<<2&60;g=l|g>>>6;$:{if(!(y[Db(e+312|0,l>>>3|0)|0]>>>(g&7)&1)|!(f|g)){break $}v[d+5|0]=f;v[d+3|0]=g;l=k>>>4|0;v[d+4|0]=l;aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{switch(g|0){case 0:case 1:case 2:case 32:case 33:case 34:v[d+3|0]=g&15;Qf(d);if(!y[d+4|0]){break $}v[d+2|0]=g>>>0<32?3:4;break $;case 9:v[d+3|0]=10;v[d+5|0]=f>>>1;if(f>>>0<512){break $}v[d+2|0]=15;v[d+4|0]=k>>>5;break $;case 10:case 42:if(f>>>0>254){break ka}v[d+3|0]=g&15;break;case 50:break ba;case 48:break ca;case 43:break da;case 47:break ea;case 17:case 18:case 26:case 27:break fa;case 22:case 25:case 28:case 29:case 30:break ga;case 16:case 19:case 20:case 21:case 23:case 31:break ha;case 13:break ia;case 11:case 15:break ja;case 3:case 4:case 5:case 6:case 7:case 12:break la;default:break aa}}Qf(d);break $}v[d+3|0]=19;v[d+5|0]=l|(g>>>0<32?16:32);if(k&15){v[d+2|0]=3;v[d+4|0]=(f&240)>>>4;break $}v[d+2|0]=4;v[d+4|0]=f&15;break $}v[d+3|0]=(g|0)==11?12:16;A=d,B=ru(f),v[A+5|0]=B;break $}v[d+3|0]=14;if((f&255)>>>0<64){break $}v[d+5|0]=0;break $}v[d+3|0]=19;v[d+5|0]=f&15|g<<4;break $}v[d+3|0]=19;w[e+160>>1]=15;A=d,B=y[Uc(e+84|0,e+160|0)|0]|g<<4,v[A+5|0]=B;break $}v[d+3|0]=19;if(f&255){v[d+5|0]=f&15|((g|0)==17?16:(g|0)==26?16:32);if(k>>>0<16){break $}v[d+2|0]=g>>>0>25?6:5;break $}v[d+5|0]=l|(g>>>0>25?-80:-96);break $}if(!f){break aa}v[d+3|0]=17;x[e+160>>2]=8;x[e+124>>2]=f+4;A=d,B=xi(x[Re(e+160|0,e+124|0)>>2]/8|0),v[A+5|0]=B;break $}v[d+3|0]=14;k=D(t,6)+d|0;n=z[a+480188>>1];f=0;while(1){if((f|0)==(n|0)){break $}g=k+D(f,6)|0;if(!y[g+3|0]){v[g+3|0]=12;A=g,B=ru(r),v[A+5|0]=B}f=f+1|0;continue}}v[d+3|0]=9;g=f&7;if(g){v[d+5|0]=y[g+26425|0];break $}g=f>>>4|0;if((g|0)==128){break aa}v[d+5|0]=g;if(f>>>0<=2047){v[d+5|0]=g^128;break $}v[d+5|0]=g^-1;break $}v[d+5|0]=0;v[d+3|0]=0;if(!n){v[d|0]=255;break $}v[d+3|0]=25;break $}v[d+3|0]=0}j=j+1|0;f=z[a+480188>>1];d=D(f,6)+d|0;continue}}h=h+1|0;continue}}i=i+1|0;continue}break}a=N()|0;break c}a=N()|0;break b}}else{uB(a,d&65535);w[((d<<5)+a|0)+480284>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;j=z[a+480188>>1];continue}break}bc(d);d=0;break g}a=N()|0;break c}bc(m)}id(o)}db=e+416|0;return d|0}a=N()|0;break c}a=N()|0;bc(d)}bc(m);break a}bc(d)}id(o);Q(a|0);p()}function _W(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;a:{n=Bi(b,13587);if(!n){break a}b:while(1){if(!Lb(x[b>>2],x[b+8>>2],6)){break a}f=pg(b);if(!(!((f|0)==(Jm(13437)|0)|!(f&1616928864)|f&-2139062144)&(f|0)!=70791730)){ng(b,4);break a}l=1;c=Fg(b);while(1){e=l&65535;if(e>>>0>z[a+480192>>1]){continue b}e=x[((e<<2)+a|0)+900380>>2];if(e){c:{g=0;if((Jm(16343)|0)==(f|0)){Zb(b,c);break c}h=db-48|0;db=h;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{switch(f-1349079874|0){default:if((f|0)==1095062094){break t}if((f|0)==1095126087){break q}if((f|0)==1129524782){break z}if((f|0)==1145263150){break W}if((f|0)==1145979182){break V}if((f|0)==1179463214){break x}if((f|0)==1851469358){break D}if((f|0)==1179931728){break l}Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{if((f|0)!=1196830254){if((f|0)==1229341486){break S}if((f|0)==1229345326){break R}if((f|0)==1264266798){break E}if((f|0)==1296182830){break Q}if((f|0)==1296248366){break O}if((f|0)==1297100334){break P}if((f|0)==1297110852){break o}if((f|0)==1298747438){break B}if((f|0)==1313692462){break F}if((f|0)==1313751342){break X}if((f|0)==1345203758){break ha}if((f|0)==1346711086){break j}if((f|0)==1346720334){break u}if((f|0)==1346722606){break H}if((f|0)==1346784327){break r}if((f|0)==1347175726){break ba}if((f|0)==1347179310){break ca}if((f|0)==1347437358){break M}if((f|0)==1347441454){break N}if((f|0)==1347443502){break K}if((f|0)==1347628590){break U}if((f|0)==1347633710){break aa}if((f|0)==1347634478){break $}if((f|0)==1347703884){break m}if((f|0)==1347831112){break w}if((f|0)==1347833672){break v}if((f|0)==1349076270){break i}if((f|0)==1349076315){break G}if((f|0)==1349078085){break Z}if((f|0)==1349078099){break _}if((f|0)==1349079131){break J}if((f|0)==1378758190){break n}if((f|0)==1381183022){break y}if((f|0)==1447374382){break k}if((f|0)==1447383630){break s}if((f|0)==1447385902){break I}if((f|0)==1447447623){break p}if((f|0)==1447839022){break fa}if((f|0)==1447842606){break ga}if((f|0)==1448106798){break L}if((f|0)==1448226350){break A}if((f|0)==1448291886){break T}if((f|0)==1448297006){break ea}if((f|0)==1448297774){break da}if((f|0)!=1682320942){if((f|0)==1718508334){break C}if((f|0)!=1179594286|c>>>0>4){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=ev(b,c),x[o>>2]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+15|0]=q;break e}if(c>>>0>4){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=ev(b,c),x[o+4>>2]=q;break e}if(c>>>0>4){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=ev(b,c),x[o+8>>2]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+61|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+62|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+63|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e- -64|0,q=wd(b,c),v[o|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+81|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+82|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+83|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+84|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+101|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+102|0]=q;break e;case 0:if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+103|0]=q;break e;case 3:break Y;case 1:case 2:break d}}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+104|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+16|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+17|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+18|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+19|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+20|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+21|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+22|0]=q;break e}if(c>>>0>2){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=_C(b,c),w[o+28>>1]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+30|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+31|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=ZC(b,c),v[o+26|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+27|0]=q;break e}d=h+8|0;Wd(d,b,c);j=hc(h+28|0,d);ub(d);i=Ci(e,0);g=x[i>>2];d=0;while(1){if(ne(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[23549]=0;k=R(183,j|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break h}g=x[i>>2];o=xb(g,d),q=k,w[o>>1]=q;d=d+1|0;continue}}d=h+8|0;Wd(d,b,c);j=hc(h+28|0,d);ub(d);i=Ci(e,1);g=x[i>>2];d=0;while(1){if(ne(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[23549]=0;k=R(183,j|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){g=x[i>>2];o=xb(g,d),q=k,w[o>>1]=q;d=d+1|0;continue}break}d=N()|0;break g}d=h+8|0;Wd(d,b,c);j=hc(h+28|0,d);ub(d);i=Ci(e,2);g=x[i>>2];d=0;while(1){if(ne(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[23549]=0;k=R(183,j|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){g=x[i>>2];o=xb(g,d),q=k,w[o>>1]=q;d=d+1|0;continue}break}d=N()|0;break g}d=h+8|0;Wd(d,b,c);j=hc(h+28|0,d);ub(d);i=Ci(e,0);g=x[i>>2];d=0;while(1){if(ne(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[23549]=0;k=R(184,j|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){g=x[i>>2];o=xb(g,d),q=k,v[o+2|0]=q;d=d+1|0;continue}break}d=N()|0;break g}d=h+8|0;Wd(d,b,c);j=hc(h+28|0,d);ub(d);i=Ci(e,1);g=x[i>>2];d=0;while(1){if(ne(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[23549]=0;k=R(184,j|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){g=x[i>>2];o=xb(g,d),q=k,v[o+2|0]=q;d=d+1|0;continue}break}d=N()|0;break g}d=h+8|0;Wd(d,b,c);j=hc(h+28|0,d);ub(d);i=Ci(e,2);g=x[i>>2];d=0;while(1){if(ne(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[23549]=0;k=R(184,j|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){g=x[i>>2];o=xb(g,d),q=k,v[o+2|0]=q;d=d+1|0;continue}break}d=N()|0;break g}if(c>>>0>128){break d}g=e+108|0;d=h+8|0;Wd(d,b,c);j=hc(h+28|0,d);ub(d);d=0;while(1){if((d|0)==128){ub(j);break e}x[23549]=0;i=R(184,j|0)|0;k=x[23549];x[23549]=0;if((k|0)!=1){o=Db(g,d),q=i,v[o|0]=q;d=d+1|0;continue}break}d=N()|0;break g}if(c>>>0>256){break d}g=e+236|0;d=h+8|0;Wd(d,b,c);j=hc(h+28|0,d);ub(d);d=0;while(1){if((d|0)==128){ub(j);break e}x[23549]=0;i=R(183,j|0)|0;k=x[23549];x[23549]=0;if((k|0)!=1){o=_b(g,d),q=i,w[o>>1]=q;d=d+1|0;continue}break}d=N()|0;break g}if(c>>>0>32){break d}i=e+492|0;d=h+8|0;Wd(d,b,c);j=hc(h+28|0,d);ub(d);g=Gb(d);d=0;while(1){if((c|0)==(d|0)){break f}x[23549]=0;k=R(185,j|0)|0;m=x[23549];x[23549]=0;ia:{if((m|0)==1){break ia}x[23549]=0;O(186,g|0,k|0)|0;k=x[23549];x[23549]=0;if((k|0)==1){break ia}d=d+1|0;continue}break}d=N()|0;tb(g);break g}if(c>>>0>32){break d}i=e+524|0;d=h+8|0;Wd(d,b,c);j=hc(h+28|0,d);ub(d);g=Gb(d);d=0;ja:{while(1){if((c|0)!=(d|0)){x[23549]=0;k=R(185,j|0)|0;m=x[23549];x[23549]=0;if((m|0)==1){break ja}x[23549]=0;O(186,g|0,k|0)|0;k=x[23549];x[23549]=0;if((k|0)==1){break ja}d=d+1|0;continue}break}zc(i,g);tb(g);ub(j);break e}d=N()|0;tb(g);break g}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+34|0]=q;break e}if(c>>>0>2){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=_C(b,c),w[o+12>>1]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+23|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+24|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+25|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+35|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+36|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+105|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+85|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+65|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+100|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+80|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=wd(b,c),v[o+60|0]=q;break e}if(c>>>0>1){break d}if(!Lb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=ZC(b,c),v[o+33|0]=q;break e}g=1;d=No(b,c);if(!Mo(d)){break d}v[e+14|0]=d;break d}o=e,q=D(cv(b,c),1e4)+(A[e+40>>2]%1e4|0)|0,x[o+40>>2]=q;break e}g=(cv(b,c)>>>0)%1e4|0;d=x[e+40>>2];x[e+40>>2]=g+d-(d>>>0)%1e4;break e}x[h+28>>2]=240;o=h,q=No(b,c),x[o+8>>2]=q;ah(e+48|0,x[Cb(h+28|0,h+8|0)>>2]);break e}x[h+28>>2]=240;o=h,q=No(b,c),x[o+8>>2]=q;ah(e+68|0,x[Cb(h+28|0,h+8|0)>>2]);break e}x[h+28>>2]=240;o=h,q=No(b,c),x[o+8>>2]=q;ah(e+88|0,x[Cb(h+28|0,h+8|0)>>2]);break e}d=N()|0}ub(j);Q(d|0);p()}zc(i,g);tb(g);ub(j)}g=1}db=h+48|0;if(!g){Zb(b,c);break c}if((Jm(16348)|0)==(f|0)){d=y[e+15|0];v[e+15|0]=0;v[e+100|0]=y[e+100|0]&224|(d>>>5&4|d>>>6&1);v[e+60|0]=d>>>1&2|(d<<1&4|(y[e+60|0]&240|d&1));v[e+80|0]=y[e+80|0]&240|(d>>>4&2|(d>>>2&4|d>>>3&1))}}}l=l+1|0;continue}}}return n|0}function Nd(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=db-16|0;db=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(a>>>0<=244){g=x[23425];h=a>>>0<11?16:a+11&-8;c=h>>>3|0;b=g>>>c|0;if(b&3){c=c+((b^-1)&1)|0;a=c<<3;b=a+93740|0;d=x[a+93748>>2];a=x[d+8>>2];o:{if((b|0)==(a|0)){m=93700,n=Cka(-2,c)&g,x[m>>2]=n;break o}x[a+12>>2]=b;x[b+8>>2]=a}a=d+8|0;b=c<<3;x[d+4>>2]=b|3;b=b+d|0;x[b+4>>2]=x[b+4>>2]|1;break a}k=x[23427];if(k>>>0>=h>>>0){break n}if(b){a=2<<c;a=(0-a|a)&b<<c;d=xka(0-a&a);a=d<<3;b=a+93740|0;e=x[a+93748>>2];a=x[e+8>>2];p:{if((b|0)==(a|0)){g=Cka(-2,d)&g;x[23425]=g;break p}x[a+12>>2]=b;x[b+8>>2]=a}x[e+4>>2]=h|3;c=e+h|0;a=d<<3;d=a-h|0;x[c+4>>2]=d|1;x[a+e>>2]=d;if(k){b=(k&-8)+93740|0;f=x[23430];a=1<<(k>>>3);q:{if(!(a&g)){x[23425]=a|g;a=b;break q}a=x[b+8>>2]}x[b+8>>2]=f;x[a+12>>2]=f;x[f+12>>2]=b;x[f+8>>2]=a}a=e+8|0;x[23430]=c;x[23427]=d;break a}j=x[23426];if(!j){break n}c=x[(xka(0-j&j)<<2)+94004>>2];f=(x[c+4>>2]&-8)-h|0;b=c;while(1){r:{a=x[b+16>>2];if(!a){a=x[b+20>>2];if(!a){break r}}b=(x[a+4>>2]&-8)-h|0;d=b>>>0<f>>>0;f=d?b:f;c=d?a:c;b=a;continue}break}i=x[c+24>>2];d=x[c+12>>2];if((d|0)!=(c|0)){a=x[c+8>>2];x[a+12>>2]=d;x[d+8>>2]=a;break b}b=c+20|0;a=x[b>>2];if(!a){a=x[c+16>>2];if(!a){break m}b=c+16|0}while(1){e=b;d=a;b=a+20|0;a=x[b>>2];if(a){continue}b=d+16|0;a=x[d+16>>2];if(a){continue}break}x[e>>2]=0;break b}h=-1;if(a>>>0>4294967231){break n}a=a+11|0;h=a&-8;j=x[23426];if(!j){break n}f=0-h|0;g=0;s:{if(h>>>0<256){break s}g=31;if(h>>>0>16777215){break s}a=G(a>>>8|0);g=((h>>>38-a&1)-(a<<1)|0)+62|0}b=x[(g<<2)+94004>>2];t:{u:{v:{if(!b){a=0;break v}a=0;c=h<<((g|0)!=31?25-(g>>>1|0)|0:0);while(1){w:{e=(x[b+4>>2]&-8)-h|0;if(e>>>0>=f>>>0){break w}d=b;f=e;if(e){break w}f=0;a=b;break u}e=x[b+20>>2];b=x[((c>>>29&4)+b|0)+16>>2];a=e?(e|0)==(b|0)?a:e:a;c=c<<1;if(b){continue}break}}if(!(a|d)){d=0;a=2<<g;a=(0-a|a)&j;if(!a){break n}a=x[(xka(a&0-a)<<2)+94004>>2]}if(!a){break t}}while(1){b=(x[a+4>>2]&-8)-h|0;c=b>>>0<f>>>0;f=c?b:f;d=c?a:d;b=x[a+16>>2];if(b){a=b}else{a=x[a+20>>2]}if(a){continue}break}}if(!d|x[23427]-h>>>0<=f>>>0){break n}g=x[d+24>>2];c=x[d+12>>2];if((d|0)!=(c|0)){a=x[d+8>>2];x[a+12>>2]=c;x[c+8>>2]=a;break c}b=d+20|0;a=x[b>>2];if(!a){a=x[d+16>>2];if(!a){break l}b=d+16|0}while(1){e=b;c=a;b=a+20|0;a=x[b>>2];if(a){continue}b=c+16|0;a=x[c+16>>2];if(a){continue}break}x[e>>2]=0;break c}a=x[23427];if(a>>>0>=h>>>0){d=x[23430];b=a-h|0;x:{if(b>>>0>=16){c=d+h|0;x[c+4>>2]=b|1;x[a+d>>2]=b;x[d+4>>2]=h|3;break x}x[d+4>>2]=a|3;a=a+d|0;x[a+4>>2]=x[a+4>>2]|1;c=0;b=0}x[23427]=b;x[23430]=c;a=d+8|0;break a}i=x[23428];if(i>>>0>h>>>0){b=i-h|0;x[23428]=b;c=x[23431];a=c+h|0;x[23431]=a;x[a+4>>2]=b|1;x[c+4>>2]=h|3;a=c+8|0;break a}a=0;j=h+47|0;if(x[23543]){c=x[23545]}else{x[23546]=-1;x[23547]=-1;x[23544]=4096;x[23545]=4096;x[23543]=l+12&-16^1431655768;x[23548]=0;x[23536]=0;c=4096}e=j+c|0;f=0-c|0;b=e&f;if(b>>>0<=h>>>0){break a}d=x[23535];if(d){c=x[23533];g=c+b|0;if(d>>>0<g>>>0|c>>>0>=g>>>0){break a}}y:{if(!(y[94144]&4)){z:{A:{B:{C:{d=x[23431];if(d){a=94148;while(1){c=x[a>>2];if(c>>>0<=d>>>0&d>>>0<c+x[a+4>>2]>>>0){break C}a=x[a+8>>2];if(a){continue}break}}c=xo(0);if((c|0)==-1){break z}g=b;d=x[23544];a=d-1|0;if(a&c){g=(b-c|0)+(a+c&0-d)|0}if(g>>>0<=h>>>0){break z}d=x[23535];if(d){a=x[23533];f=a+g|0;if(d>>>0<f>>>0|a>>>0>=f>>>0){break z}}a=xo(g);if((c|0)!=(a|0)){break B}break y}g=f&e-i;c=xo(g);if((c|0)==(x[a>>2]+x[a+4>>2]|0)){break A}a=c}if((a|0)==-1){break z}if(h+48>>>0<=g>>>0){c=a;break y}c=x[23545];c=c+(j-g|0)&0-c;if((xo(c)|0)==-1){break z}g=c+g|0;c=a;break y}if((c|0)!=-1){break y}}x[23536]=x[23536]|4}c=xo(b);a=xo(0);if((c|0)==-1|(a|0)==-1|a>>>0<=c>>>0){break i}g=a-c|0;if(g>>>0<=h+40>>>0){break i}}a=x[23533]+g|0;x[23533]=a;if(a>>>0>A[23534]){x[23534]=a}D:{e=x[23431];if(e){a=94148;while(1){d=x[a>>2];b=x[a+4>>2];if((d+b|0)==(c|0)){break D}a=x[a+8>>2];if(a){continue}break}break k}a=x[23429];if(!(a>>>0<=c>>>0?a:0)){x[23429]=c}a=0;x[23538]=g;x[23537]=c;x[23433]=-1;x[23434]=x[23543];x[23540]=0;while(1){d=a<<3;b=d+93740|0;x[d+93748>>2]=b;x[d+93752>>2]=b;a=a+1|0;if((a|0)!=32){continue}break}d=g-40|0;a=c+8&7?-8-c&7:0;b=d-a|0;x[23428]=b;a=a+c|0;x[23431]=a;x[a+4>>2]=b|1;x[(c+d|0)+4>>2]=40;x[23432]=x[23547];break j}if(x[a+12>>2]&8|(c>>>0<=e>>>0|d>>>0>e>>>0)){break k}x[a+4>>2]=b+g;a=e+8&7?-8-e&7:0;c=a+e|0;x[23431]=c;b=x[23428]+g|0;a=b-a|0;x[23428]=a;x[c+4>>2]=a|1;x[(b+e|0)+4>>2]=40;x[23432]=x[23547];break j}d=0;break b}c=0;break c}if(A[23429]>c>>>0){x[23429]=c}b=c+g|0;a=94148;E:{F:{G:{while(1){if((b|0)!=x[a>>2]){a=x[a+8>>2];if(a){continue}break G}break}if(!(y[a+12|0]&8)){break F}}a=94148;while(1){b=x[a>>2];if(b>>>0<=e>>>0){f=b+x[a+4>>2]|0;if(f>>>0>e>>>0){break E}}a=x[a+8>>2];continue}}x[a>>2]=c;x[a+4>>2]=x[a+4>>2]+g;j=(c+8&7?-8-c&7:0)+c|0;x[j+4>>2]=h|3;g=b+(b+8&7?-8-b&7:0)|0;i=h+j|0;a=g-i|0;if((e|0)==(g|0)){x[23431]=i;a=x[23428]+a|0;x[23428]=a;x[i+4>>2]=a|1;break d}if(x[23430]==(g|0)){x[23430]=i;a=x[23427]+a|0;x[23427]=a;x[i+4>>2]=a|1;x[a+i>>2]=a;break d}f=x[g+4>>2];if((f&3)!=1){break e}e=f&-8;if(f>>>0<=255){c=x[g+12>>2];b=x[g+8>>2];if((c|0)==(b|0)){m=93700,n=x[23425]&Cka(-2,f>>>3|0),x[m>>2]=n;break f}x[b+12>>2]=c;x[c+8>>2]=b;break f}h=x[g+24>>2];c=x[g+12>>2];if((g|0)!=(c|0)){b=x[g+8>>2];x[b+12>>2]=c;x[c+8>>2]=b;break g}b=g+20|0;f=x[b>>2];if(!f){f=x[g+16>>2];if(!f){break h}b=g+16|0}while(1){d=b;c=f;b=c+20|0;f=x[b>>2];if(f){continue}b=c+16|0;f=x[c+16>>2];if(f){continue}break}x[d>>2]=0;break g}d=g-40|0;a=c+8&7?-8-c&7:0;b=d-a|0;x[23428]=b;a=a+c|0;x[23431]=a;x[a+4>>2]=b|1;x[(c+d|0)+4>>2]=40;x[23432]=x[23547];a=(f+(f-39&7?39-f&7:0)|0)-47|0;d=a>>>0<e+16>>>0?e:a;x[d+4>>2]=27;a=x[23540];x[d+16>>2]=x[23539];x[d+20>>2]=a;a=x[23538];x[d+8>>2]=x[23537];x[d+12>>2]=a;x[23539]=d+8;x[23538]=g;x[23537]=c;x[23540]=0;a=d+24|0;while(1){x[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<f>>>0){continue}break}if((d|0)==(e|0)){break j}x[d+4>>2]=x[d+4>>2]&-2;f=d-e|0;x[e+4>>2]=f|1;x[d>>2]=f;if(f>>>0<=255){b=(f&-8)+93740|0;c=x[23425];a=1<<(f>>>3);H:{if(!(c&a)){x[23425]=a|c;a=b;break H}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a;break j}a=31;if(f>>>0<=16777215){a=G(f>>>8|0);a=((f>>>38-a&1)-(a<<1)|0)+62|0}x[e+28>>2]=a;x[e+16>>2]=0;x[e+20>>2]=0;b=(a<<2)+94004|0;I:{d=x[23426];c=1<<a;J:{if(!(d&c)){x[23426]=c|d;x[b>>2]=e;break J}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);d=x[b>>2];while(1){b=d;if((f|0)==(x[b+4>>2]&-8)){break I}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;d=x[c+16>>2];if(d){continue}break}x[c+16>>2]=e}x[e+24>>2]=b;x[e+12>>2]=e;x[e+8>>2]=e;break j}a=x[b+8>>2];x[a+12>>2]=e;x[b+8>>2]=e;x[e+24>>2]=0;x[e+12>>2]=b;x[e+8>>2]=a}a=x[23428];if(a>>>0<=h>>>0){break i}b=a-h|0;x[23428]=b;c=x[23431];a=c+h|0;x[23431]=a;x[a+4>>2]=b|1;x[c+4>>2]=h|3;a=c+8|0;break a}x[23424]=48;a=0;break a}c=0}if(!h){break f}d=x[g+28>>2];b=(d<<2)+94004|0;K:{if(x[b>>2]==(g|0)){x[b>>2]=c;if(c){break K}m=93704,n=x[23426]&Cka(-2,d),x[m>>2]=n;break f}x[h+(x[h+16>>2]==(g|0)?16:20)>>2]=c;if(!c){break f}}x[c+24>>2]=h;b=x[g+16>>2];if(b){x[c+16>>2]=b;x[b+24>>2]=c}b=x[g+20>>2];if(!b){break f}x[c+20>>2]=b;x[b+24>>2]=c}a=a+e|0;g=e+g|0;f=x[g+4>>2]}x[g+4>>2]=f&-2;x[i+4>>2]=a|1;x[a+i>>2]=a;if(a>>>0<=255){b=(a&-8)+93740|0;c=x[23425];a=1<<(a>>>3);L:{if(!(c&a)){x[23425]=a|c;a=b;break L}a=x[b+8>>2]}x[b+8>>2]=i;x[a+12>>2]=i;x[i+12>>2]=b;x[i+8>>2]=a;break d}f=31;if(a>>>0<=16777215){b=G(a>>>8|0);f=((a>>>38-b&1)-(b<<1)|0)+62|0}x[i+28>>2]=f;x[i+16>>2]=0;x[i+20>>2]=0;b=(f<<2)+94004|0;M:{d=x[23426];c=1<<f;N:{if(!(d&c)){x[23426]=c|d;x[b>>2]=i;break N}f=a<<((f|0)!=31?25-(f>>>1|0)|0:0);c=x[b>>2];while(1){b=c;if((x[c+4>>2]&-8)==(a|0)){break M}c=f>>>29|0;f=f<<1;d=(c&4)+b|0;c=x[d+16>>2];if(c){continue}break}x[d+16>>2]=i}x[i+24>>2]=b;x[i+12>>2]=i;x[i+8>>2]=i;break d}a=x[b+8>>2];x[a+12>>2]=i;x[b+8>>2]=i;x[i+24>>2]=0;x[i+12>>2]=b;x[i+8>>2]=a}a=j+8|0;break a}O:{if(!g){break O}b=x[d+28>>2];a=(b<<2)+94004|0;P:{if(x[a>>2]==(d|0)){x[a>>2]=c;if(c){break P}j=Cka(-2,b)&j;x[23426]=j;break O}x[g+(x[g+16>>2]==(d|0)?16:20)>>2]=c;if(!c){break O}}x[c+24>>2]=g;a=x[d+16>>2];if(a){x[c+16>>2]=a;x[a+24>>2]=c}a=x[d+20>>2];if(!a){break O}x[c+20>>2]=a;x[a+24>>2]=c}Q:{if(f>>>0<=15){a=f+h|0;x[d+4>>2]=a|3;a=a+d|0;x[a+4>>2]=x[a+4>>2]|1;break Q}x[d+4>>2]=h|3;e=d+h|0;x[e+4>>2]=f|1;x[e+f>>2]=f;if(f>>>0<=255){b=(f&-8)+93740|0;c=x[23425];a=1<<(f>>>3);R:{if(!(c&a)){x[23425]=a|c;a=b;break R}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a;break Q}a=31;if(f>>>0<=16777215){a=G(f>>>8|0);a=((f>>>38-a&1)-(a<<1)|0)+62|0}x[e+28>>2]=a;x[e+16>>2]=0;x[e+20>>2]=0;b=(a<<2)+94004|0;S:{c=1<<a;T:{if(!(c&j)){x[23426]=c|j;x[b>>2]=e;break T}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);h=x[b>>2];while(1){b=h;if((x[b+4>>2]&-8)==(f|0)){break S}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;h=x[c+16>>2];if(h){continue}break}x[c+16>>2]=e}x[e+24>>2]=b;x[e+12>>2]=e;x[e+8>>2]=e;break Q}a=x[b+8>>2];x[a+12>>2]=e;x[b+8>>2]=e;x[e+24>>2]=0;x[e+12>>2]=b;x[e+8>>2]=a}a=d+8|0;break a}U:{if(!i){break U}b=x[c+28>>2];a=(b<<2)+94004|0;V:{if(x[a>>2]==(c|0)){x[a>>2]=d;if(d){break V}m=93704,n=Cka(-2,b)&j,x[m>>2]=n;break U}x[i+(x[i+16>>2]==(c|0)?16:20)>>2]=d;if(!d){break U}}x[d+24>>2]=i;a=x[c+16>>2];if(a){x[d+16>>2]=a;x[a+24>>2]=d}a=x[c+20>>2];if(!a){break U}x[d+20>>2]=a;x[a+24>>2]=d}W:{if(f>>>0<=15){a=f+h|0;x[c+4>>2]=a|3;a=a+c|0;x[a+4>>2]=x[a+4>>2]|1;break W}x[c+4>>2]=h|3;d=c+h|0;x[d+4>>2]=f|1;x[d+f>>2]=f;if(k){b=(k&-8)+93740|0;e=x[23430];a=1<<(k>>>3);X:{if(!(a&g)){x[23425]=a|g;a=b;break X}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a}x[23430]=d;x[23427]=f}a=c+8|0}db=l+16|0;return a}function tW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;e=db-272|0;db=e;wc(b);if(Oq(b,17396)){o=Gb(e+260|0);x[23549]=0;g=O(219,b|0,o|0)|0;d=x[23549];x[23549]=0;a:{b:{c:{d:{e:{f:{if((d|0)!=1){if(!g){break a}x[23549]=0;g=O(234,b|0,e+253|0)|0;d=x[23549];x[23549]=0;g:{if((d|0)==1){break g}if(!g){break a}if(!eC(y[e+253|0],y[e+254|0])){break a}h=Qc(dC(e+253|0),hb);g=x[b+8>>2];d=x[b>>2];x[23549]=0;g=U(142,d|0,g|0,h|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break g}if(!g){break a}if(!c){break b}x[23549]=0;P(235,a|0,4096);d=x[23549];x[23549]=0;if((d|0)==1){break g}x[23549]=0;P(236,a+1298308|0,o|0);d=x[23549];x[23549]=0;if((d|0)==1){break g}d=y[e+255|0];w[a+480188>>1]=32;w[a+480192>>1]=d;vh(a,1);x[23549]=0;f=O(1,e+240|0,9374)|0;d=x[23549];x[23549]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{if((d|0)!=1){zb(a+1298344|0,f);tb(f);x[23549]=0;f=O(1,e+228|0,6991)|0;d=x[23549];x[23549]=0;if((d|0)==1){break p}zb(a+1298356|0,f);tb(f);x[23549]=0;W(237,e+32|0);d=x[23549];x[23549]=0;if((d|0)==1){break o}v[e+204|0]=y[e+254|0];x[23549]=0;v[e|0]=y[e+253|0];P(238,e+216|0,e|0);d=x[23549];x[23549]=0;if((d|0)==1){break n}x[23549]=0;V(239,e+80|0,e+32|0,e+204|0,e+216|0);d=x[23549];x[23549]=0;if((d|0)==1){break m}d=e+80|0;zb(a+1298368|0,d);tb(d);tb(e+216|0);Ab(e+32|0);x[a+1298404>>2]=5;if(y[e+253|0]<2){break i}w[e+80>>1]=8192;x[23549]=0;f=R(180,b|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break k}w[e+32>>1]=f;r=a,s=D(z[Ve(e+80|0,e+32|0)>>1],1e4)>>>8|0,x[r+480204>>2]=s;x[23549]=0;v[e+80|0]=1;f=R(192,b|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break j}v[e+32|0]=f;r=a,s=y[af(e+80|0,e+32|0)|0],x[r+480196>>2]=s;x[23549]=0;O(174,b|0,3)|0;d=x[23549];x[23549]=0;if((d|0)!=1){x[23549]=0;f=R(180,b|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){break h}}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break l}b=N()|0;tb(e+216|0)}Ab(e+32|0);break c}b=N()|0;break c}b=N()|0;break c}v[e+80|0]=32;x[23549]=0;f=R(192,b|0)|0;d=x[23549];x[23549]=0;q:{if((d|0)!=1){v[e+32|0]=f;r=a,s=D(y[af(e+80|0,e+32|0)|0],1e4),x[r+480204>>2]=s;x[23549]=0;v[e+80|0]=1;f=R(192,b|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break q}v[e+32|0]=f;r=a,s=y[af(e+80|0,e+32|0)|0],x[r+480196>>2]=s;x[23549]=0;f=R(192,b|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){break h}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}x[a+480208>>2]=f>>>2&16|12;m=Nb(e+216|0);k=e+80|12;n=Nb(e+204|0);q=1;while(1){r:{s:{d=q&65535;if(d>>>0>z[a+480192>>1]){break s}x[23549]=0;i=U(240,a|0,d|0,0)|0;d=x[23549];x[23549]=0;t:{if((d|0)==1){break t}if(!i){break s}x[23549]=0;f=O(229,b|0,i+492|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break t}if(!f){break s}x[23549]=0;l=R(192,b|0)|0;d=x[23549];x[23549]=0;u:{v:{w:{if((d|0)!=1){Vb(e+80|0,0,120);if(!l){break r}x:{if(y[e+253|0]){x[23549]=0;f=O(241,b|0,e+80|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break w}if(!f){break r}if(y[e+253|0]){break x}}d=ec(e+72|0,k,96);f=x[d>>2];d=x[d+4>>2];x[23549]=0;hn(151,e+32|0,b,f,d);d=x[23549];x[23549]=0;if((d|0)==1){break v}if(!x[e+36>>2]){break r}}h=i+236|0;f=0;break u}b=N()|0;break d}b=N()|0;break d}b=N()|0;break d}while(1){if((f|0)!=120){g=z[a+480190>>1];d=y[(e+80|0)+f|0];r=_b(h,f),s=(d+g|0)+1|0,w[r>>1]=s;f=f+1|0;continue}break}x[23549]=0;f=i+48|0;S(242,e|0,f|0,b|0);d=x[23549];x[23549]=0;if((d|0)==1){break e}x[23549]=0;j=i+68|0;S(242,e+16|0,j|0,b|0);d=x[23549];x[23549]=0;if((d|0)==1){break e}x[23549]=0;h=i+88|0;S(242,e- -64|0,h|0,b|0);d=x[23549];x[23549]=0;if((d|0)==1){break e}x[23549]=0;P(243,b|0,e+56|0);d=x[23549];x[23549]=0;if((d|0)==1){break f}x[i>>2]=(y[e+57|0]|y[e+58|0]<<8)&4095;d=y[e+57|0]|y[e+58|0]<<8;Ku(y[e+59|0]|y[e+60|0]<<8,f,0);Ku(y[e+59|0]|y[e+60|0]<<8,j,1);Ku(y[e+59|0]|y[e+60|0]<<8,h,2);r=e,s=yb(x[f>>2]),x[r+32>>2]=s;f=d>>>12|0;d=yb(x[i+52>>2]);while(1){g=x[e+32>>2];if(Kb(g,d)){v[e+28|0]=64;v[e+54|0]=((y[g+2|0]<<6)- -64>>>0)/127;r=g,s=y[Sb(e+28|0,e+54|0)|0],v[r+2|0]=s;Ae(e+32|0);continue}else{r=e,s=yb(x[j>>2]),x[r+32>>2]=s;d=yb(x[i+72>>2])}break}while(1){g=x[e+32>>2];if(Kb(g,d)){v[e+28|0]=64;v[e+54|0]=((y[g+2|0]<<6)+128>>>0)/255;r=g,s=y[Sb(e+28|0,e+54|0)|0],v[r+2|0]=s;Ae(e+32|0);continue}break}r=e,s=yb(x[h>>2]),x[r+32>>2]=s;j=f&3;h=yb(x[i+92>>2]);while(1){f=x[e+32>>2];if(Kb(f,h)){g=v[f+2|0];d=g>>31^-1;g=g^-128;i=j&31;if((j&63)>>>0>=32){d=g<<i;i=0}else{d=(1<<i)-1&g>>>32-i|d<<i;i=g<<i}y:{if((d|0)>=-1&i>>>0>=4294967292|(d|0)>=0){g=i+4|0;d=(((g>>>0<4?d+1|0:d)&7)<<29|g>>>3)&536870911;g=0;break y}g=0-((i>>>0>3)+d|0)|0;d=3-i|0;g=((g&7)<<29|d>>>3)&536870911;d=0-g|0;g=0-((g|0)!=0)|0}r=f,s=Cc(d,g)^128,v[r+2|0]=s;Ae(e+32|0);continue}else{d=z[a+480190>>1]+1|0;w[e+54>>1]=d;f=0;j=d&65535;d=4e3-j|0;h=d>>>0<=4e3?d:0;z:{A:{B:{while(1){if((f|0)==(l|0)){break A}if((f|0)==(h|0)){x[23549]=0;O(174,b|0,20)|0;d=x[23549];x[23549]=0;if((d|0)!=1){break A}b=N()|0;break d}x[23549]=0;g=f+j|0;O(229,b|0,((g<<5)+a|0)+946304|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break z}x[23549]=0;P(244,b|0,e+32|0);d=x[23549];x[23549]=0;C:{if((d|0)==1){break C}x[23549]=0;P(245,e+32|0,(D(g,104)+a|0)+484380|0);d=x[23549];x[23549]=0;if((d|0)==1){break C}x[23549]=0;w[e+28>>1]=y[e+56|0]|f<<8&32512|((y[e+51|0]&3)!=0)<<15;P(246,n|0,e+28|0);d=x[23549];x[23549]=0;if((d|0)==1){break B}f=f+1|0;continue}break}b=N()|0;break d}b=N()|0;break d}x[23549]=0;P(246,m|0,e+54|0);d=x[23549];x[23549]=0;if((d|0)!=1){x[e+32>>2]=3999;x[e+28>>2]=l+z[a+480190>>1];r=a,s=x[qd(e+32|0,e+28|0)>>2],w[r+480190>>1]=s;break r}b=N()|0;break d}b=N()|0;break d}}}b=N()|0;break d}g=Gb(e+80|0);x[23549]=0;f=O(219,b|0,g|0)|0;d=x[23549];x[23549]=0;D:{E:{F:{G:{H:{if((d|0)!=1){I:{if(f){x[23549]=0;S(11,e+32|0,7,g|0);d=x[23549];x[23549]=0;if((d|0)==1){break I}d=e+32|0;zb(a+1298320|0,d);tb(d)}tb(g);f=0;J:{while(1){if((f|0)==32){x[23549]=0;f=O(247,b|0,e+16|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break G}if(!f){break F}g=x[e+16>>2];if(g>>>0<12){break H}f=x[b+8>>2];d=x[b>>2];x[23549]=0;f=U(142,d|0,f|0,g-11|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break G}if(f){break J}break H}d=(f<<5)+a|0;Te(d+480280|0);x[23549]=0;P(220,b|0,d+480289|0);d=x[23549];x[23549]=0;if((d|0)!=1){f=f+1|0;continue}break}b=N()|0;break d}d=x[e+16>>2]-11|0;x[e+64>>2]=d;k=Nb(e+80|0);x[23549]=0;S(223,b|0,k|0,d|0);d=x[23549];x[23549]=0;K:{if((d|0)!=1){x[e+32>>2]=50529027;d=e+32|0;r=e,s=D(x[Cb(e- -64|0,d)>>2],85),x[r+56>>2]=s;l=Gb(d);x[e>>2]=x[e+20>>2];d=x[Cb(e+56|0,e)>>2];x[23549]=0;P(45,l|0,d|0);d=x[23549];x[23549]=0;L:{if((d|0)==1){break L}f=0;M:{while(1){d=x[e+64>>2];if(d>>>0<=f>>>0){break M}j=x[k>>2];g=y[Db(j,f)|0];i=d;d=f+1|0;if(!((g|0)!=255|i-d>>>0<2)){h=v[Db(j,d)|0];g=y[Db(j,f+2|0)|0];d=x[vb(e+12|0,tf(l))>>2];x[23549]=0;V(226,l|0,d|0,g|0,h|0);d=x[23549];x[23549]=0;if((d|0)!=1){f=f+3|0;continue}break L}x[23549]=0;P(46,l|0,g<<24>>24);g=x[23549];x[23549]=0;f=d;if((g|0)!=1){continue}break}break L}x[23549]=0;V(224,e|0,5,7,l|0);d=x[23549];x[23549]=0;if((d|0)!=1){N:{h=zb(l,e);tb(e);g=Mb(h);f=y[h+11|0];d=x[h+4>>2];x[23549]=0;aa(225,a+1298332|0,g|0,Oc(d,f)|0,74,0);d=x[23549];x[23549]=0;if((d|0)==1){break N}tb(h);bc(k);break H}}}b=N()|0;tb(l);break K}b=N()|0}bc(k);break d}}b=N()|0;tb(g);break d}f=y[a+484376|0];d=x[a+484360>>2];x[23549]=0;S(227,Wb(d,f)|0,b|0,y[e+258|0]|y[e+259|0]<<8);d=x[23549];x[23549]=0;if((d|0)==1){break G}h=c&1;if(h){x[23549]=0;P(211,a+484344|0,y[e+256|0]|y[e+257|0]<<8);d=x[23549];x[23549]=0;if((d|0)==1){break G}}j=a+484344|0;f=0;while(1){O:{if((y[e+256|0]|y[e+257|0]<<8)>>>0>f>>>0){g=x[b+8>>2];d=x[b>>2];x[23549]=0;g=U(142,d|0,g|0,4)|0;d=x[23549];x[23549]=0;if((d|0)==1){break D}if(g){break O}}if(!(c&2)){break F}f=0;while(1){c=z[a+480190>>1];if(f>>>0>=c>>>0){f=0;while(1){if(c>>>0<=f>>>0){break F}g=z[_b(x[n>>2],f)>>1];b=g&255;P:{if(!b){break P}d=x[m>>2];b=b-1&65535;if(Ic(d,x[m+4>>2])>>>0<=b>>>0){break P}b=z[_b(d,b)>>1]+(g>>>8&127)&65535;if(b>>>0>c>>>0){break P}c=D(b,104);b=c+a|0;h=b+484380|0;g=x[h>>2];if(!Sd(g,x[b+484400>>2])){break P}d=a+484380|0;c=d+c|0;b=z[c+34>>1];d=d+D(f+1|0,104)|0;x[d>>2]=g;w[d+34>>1]=z[d+34>>1]&65534|b&1;if(!zg(d)){break P}rc(x[d+20>>2],x[c+20>>2],pj(x[h>>2],z[h+34>>1]))}f=f+1|0;c=z[a+480190>>1];continue}}c=z[_b(x[n>>2],f)>>1];if(c&255){f=f+1|0;continue}f=f+1|0;d=D(f,104)+a|0;c=Xc(e+80|0,w[d+484414>>1]&1?16:8,1,0,c<<16>>16<0?6:0);x[23549]=0;U(205,c|0,d+484380|0,b|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){continue}break}b=N()|0;break d}x[23549]=0;g=R(143,b|0)|0;d=x[23549];x[23549]=0;Q:{R:{S:{T:{if((d|0)!=1){x[23549]=0;S(176,e+32|0,b|0,g|0);d=x[23549];x[23549]=0;if((d|0)==1){break T}d=e+32|0;k=hc(e+80|0,d);ub(d);if(!h){break R}x[23549]=0;g=R(192,k|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break Q}x[23549]=0;O(174,k|0,1)|0;d=x[23549];x[23549]=0;if((d|0)==1){break Q}x[23549]=0;g=U(212,j|0,f&65535,g+1|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break Q}if(!g){break R}x[23549]=0;g=O(221,k|0,e+32|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break E}if(!g){break S}d=x[j>>2];x[23549]=0;P(222,Yb(d,f)|0,e+32|0);d=x[23549];x[23549]=0;if((d|0)!=1){break S}break E}b=N()|0;break d}b=N()|0;break d}d=x[j>>2];x[23549]=0;S(228,Yb(d,f)|0,1,k|0);d=x[23549];x[23549]=0;if((d|0)==1){break E}}ub(k);f=f+1|0;continue}break}break E}b=N()|0;break d}id(n);id(m);break b}b=N()|0;ub(k);break d}b=N()|0;break d}q=q+1|0;continue}}b=N()|0;break c}b=N()|0;break c}b=N()|0;break d}b=N()|0}id(n);id(m)}tb(o);Q(b|0);p()}f=1}tb(o)}db=e+272|0;return f|0}function nH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,F=0,G=0,H=E(0),I=0;d=db-144|0;db=d;while(1){v[d+f|0]=0;f=f+1|0;g=f?g:g+1|0;if(!g&f>>>0<144){continue}break}x[d+76>>2]=-1;x[d+44>>2]=a;x[d+32>>2]=1097;x[d+84>>2]=a;t=c;a=0;j=db-304|0;db=j;a:{b:{c:{d:{if(x[d+4>>2]){break d}Uw(d);if(x[d+4>>2]){break d}break c}i=y[b|0];if(!i){break a}e:{f:{g:{h:{while(1){i:{c=i&255;j:{if(Ik(c)){while(1){i=b;b=b+1|0;if(Ik(y[i+1|0])){continue}break}fi(d,0,0);while(1){b=x[d+4>>2];k:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break k}b=jd(d)}if(Ik(b)){continue}break}b=x[d+4>>2];c=x[d+116>>2];if((c|0)>0|(c|0)>=0){b=b-1|0;x[d+4>>2]=b}b=b-x[d+44>>2]|0;c=b;g=n+x[d+124>>2]|0;e=b>>31;b=m+x[d+120>>2]|0;g=e+(b>>>0<m>>>0?g+1|0:g)|0;m=b+c|0;n=m>>>0<b>>>0?g+1|0:g;break j}l:{m:{n:{if((c|0)==37){c=y[b+1|0];if((c|0)==42){break n}if((c|0)!=37){break m}}fi(d,0,0);o:{if(y[b|0]==37){while(1){c=x[d+4>>2];p:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;i=y[c|0];break p}i=jd(d)}if(Ik(i)){continue}break}b=b+1|0;break o}c=x[d+4>>2];if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;i=y[c|0];break o}i=jd(d)}if(y[b|0]!=(i|0)){b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}if((i|0)>=0){break a}h=0;if(u){break a}break c}c=x[d+4>>2]-x[d+44>>2]|0;f=c;i=c>>31;c=n+x[d+124>>2]|0;e=m+x[d+120>>2]|0;h=(e>>>0<m>>>0?c+1|0:c)+i|0;m=e+f|0;n=m>>>0<e>>>0?h+1|0:h;i=b;break j}l=0;b=b+2|0;break l}if(!(!Kj(c)|y[b+2|0]!=36)){e=db-16|0;x[e+12>>2]=t;c=c-48|0;c=(c>>>0>1?(c<<2)-4|0:0)+t|0;x[e+8>>2]=c+4;l=x[c>>2];b=b+3|0;break l}l=x[t>>2];t=t+4|0;b=b+1|0}c=0;while(1){e=y[b|0];if(Kj(e)){b=b+1|0;c=(D(c,10)+e|0)-48|0;continue}break}r=0;if((e|0)==109){o=0;r=(l|0)!=0;e=y[b+1|0];b=b+1|0;a=0}i=b+1|0;k=3;h=r;q:{r:{switch((e&255)-65|0){case 39:e=b+2|0;b=y[b+1|0]==104;i=b?e:i;k=b?-2:-1;break q;case 43:e=b+2|0;b=y[b+1|0]==108;i=b?e:i;k=b?3:1;break q;case 51:case 57:k=1;break q;case 11:k=2;break q;case 41:break q;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break r;default:break e}}k=0;i=b}b=y[i|0];e=(b&47)==3;z=e?1:k;q=e?b|32:b;s:{if((q|0)==91){break s}t:{if((q|0)!=110){if((q|0)!=99){break t}c=(c|0)<=1?1:c;break s}oH(l,z,m,n);break j}fi(d,0,0);while(1){b=x[d+4>>2];u:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break u}b=jd(d)}if(Ik(b)){continue}break}b=x[d+4>>2];e=x[d+116>>2];if((e|0)>0|(e|0)>=0){b=b-1|0;x[d+4>>2]=b}b=b-x[d+44>>2]|0;e=b;g=n+x[d+124>>2]|0;f=b>>31;b=m+x[d+120>>2]|0;n=f+(b>>>0<m>>>0?g+1|0:g)|0;m=b+e|0;n=m>>>0<b>>>0?n+1|0:n}s=c;p=c>>31;fi(d,c,p);b=x[d+4>>2];v:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;break v}if((jd(d)|0)<0){break f}}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}b=16;w:{x:{y:{z:{A:{switch(q-88|0){default:b=q-65|0;if(b>>>0>6|!(1<<b&113)){break w}case 9:case 13:case 14:case 15:qH(j+8|0,d,z,0);b=x[d+4>>2]-x[d+44>>2]|0;if(x[d+120>>2]!=(0-b|0)|x[d+124>>2]!=(0-((b>>31)+((b|0)!=0)|0)|0)){break y}break g;case 3:case 11:case 27:if((q|16)==115){Vb(j+32|0,-1,257);v[j+32|0]=0;if((q|0)!=115){break x}v[j+65|0]=0;v[j+46|0]=0;w[j+42>>1]=0;w[j+44>>1]=0;break x}e=y[i+1|0];f=(e|0)==94;Vb(j+32|0,f,257);v[j+32|0]=0;b=f?i+2|0:i+1|0;B:{C:{D:{f=y[(f?2:1)+i|0];if((f|0)!=45){if((f|0)==93){break D}k=(e|0)!=94;break B}k=(e|0)!=94;v[j+78|0]=k;break C}k=(e|0)!=94;v[j+126|0]=k}b=b+1|0}i=b;while(1){e=y[i|0];E:{if((e|0)!=45){if(!e){break f}if((e|0)==93){break x}break E}e=45;f=y[i+1|0];if(!f|(f|0)==93){break E}g=i+1|0;b=y[i-1|0];F:{if(f>>>0<=b>>>0){e=f;break F}while(1){b=b+1|0;v[b+(j+32|0)|0]=k;e=y[g|0];if(e>>>0>b>>>0){continue}break}}i=g}v[(e+j|0)+33|0]=k;i=i+1|0;continue};case 23:b=8;break z;case 12:case 29:b=10;break z;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break w;case 0:case 24:case 32:break z;case 17:break A}}b=0}f=0;g=0;e=0;h=0;s=0;A=db-16|0;db=A;G:{if((b|0)==1){x[23424]=28;break G}while(1){c=x[d+4>>2];H:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break H}c=jd(d)}if(Ik(c)){continue}break}I:{J:{switch(c-43|0){case 0:case 2:break J;default:break I}}s=(c|0)==45?-1:0;c=x[d+4>>2];if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break I}c=jd(d)}K:{L:{M:{N:{if(!((b|0)!=0&(b|0)!=16|(c|0)!=48)){c=x[d+4>>2];O:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break O}c=jd(d)}if((c&-33)==88){b=16;c=x[d+4>>2];P:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break P}c=jd(d)}if(y[c+78017|0]<16){break M}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}fi(d,0,0);break G}if(b){break N}b=8;break M}b=b?b:10;if(b>>>0>y[c+78017|0]){break N}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}fi(d,0,0);x[23424]=28;break G}if((b|0)!=10){break M}e=c-48|0;if(e>>>0<=9){b=0;while(1){b=D(b,10)+e|0;f=b>>>0<429496729;c=x[d+4>>2];Q:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break Q}c=jd(d)}e=c-48|0;if(f&e>>>0<=9){continue}break}f=b}R:{if(e>>>0>9){break R}h=yka(f,0,10,0);k=hb;b=e;while(1){g=k;f=b+h|0;g=f>>>0<b>>>0?g+1|0:g;b=(g|0)==429496729&f>>>0>=2576980378|g>>>0>429496729;c=x[d+4>>2];S:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break S}c=jd(d)}e=c-48|0;if(b|e>>>0>9){break R}h=yka(f,g,10,0);k=hb;b=e;if((k|0)==-1&(b^-1)>>>0>=h>>>0|(k|0)!=-1){continue}break}b=10;break L}b=10;if(e>>>0<=9){break L}break K}if(b-1&b){h=y[c+78017|0];if(h>>>0<b>>>0){while(1){e=D(b,e)+h|0;f=e>>>0<119304647;c=x[d+4>>2];T:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break T}c=jd(d)}h=y[c+78017|0];if(f&h>>>0<b>>>0){continue}break}f=e}if(b>>>0<=h>>>0){break L}while(1){e=yka(f,g,b,0);k=hb;h=h&255;if((k|0)==-1&(h^-1)>>>0<e>>>0){break L}g=k;f=e+h|0;g=f>>>0<h>>>0?g+1|0:g;c=x[d+4>>2];U:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break U}c=jd(d)}h=y[c+78017|0];if(b>>>0<=h>>>0){break L}nf(A,b,0,0,0,f,g,0,0);if(!(x[A+8>>2]|x[A+12>>2])){continue}break}break L}k=v[(D(b,23)>>>5&7)+78273|0];e=y[c+78017|0];if(e>>>0<b>>>0){while(1){h=h<<k|e;f=h>>>0<134217728;c=x[d+4>>2];V:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break V}c=jd(d)}e=y[c+78017|0];if(f&e>>>0<b>>>0){continue}break}f=h}if(b>>>0<=e>>>0){break L}p=k&31;if((k&63)>>>0>=32){h=0;p=-1>>>p|0}else{h=-1>>>p|0;p=h|(1<<p)-1<<32-p}if(!h&f>>>0>p>>>0){break L}while(1){F=e&255;e=f;c=k&31;if((k&63)>>>0>=32){g=e<<c;c=0}else{g=(1<<c)-1&e>>>32-c|g<<c;c=e<<c}f=F|c;c=x[d+4>>2];W:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break W}c=jd(d)}e=y[c+78017|0];if(b>>>0<=e>>>0){break L}if((g|0)==(h|0)&f>>>0<=p>>>0|g>>>0<h>>>0){continue}break}}if(y[c+78017|0]>=b>>>0){break K}while(1){c=x[d+4>>2];X:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break X}c=jd(d)}if(y[c+78017|0]<b>>>0){continue}break}x[23424]=68;f=-1;g=-1;s=0}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}b=f^s;f=b-s|0;c=s>>31;g=(c^g)-((b>>>0<s>>>0)+c|0)|0}db=A+16|0;b=x[d+4>>2]-x[d+44>>2]|0;if(x[d+120>>2]==(0-b|0)&x[d+124>>2]==(0-((b>>31)+((b|0)!=0)|0)|0)){break g}if(!(!l|(q|0)!=112)){x[l>>2]=f;break w}oH(l,z,f,g);break w}if(!l){break w}b=x[j+16>>2];e=x[j+20>>2];c=x[j+8>>2];f=x[j+12>>2];Y:{switch(z|0){case 0:G=l,H=eE(c,f,b,e),B[G>>2]=H;break w;case 1:G=l,I=Lv(c,f,b,e),C[G>>3]=I;break w;case 2:break Y;default:break w}}x[l>>2]=c;x[l+4>>2]=f;x[l+8>>2]=b;x[l+12>>2]=e;break w}f=(q|0)!=99;c=f?31:c+1|0;Z:{if((z|0)==1){e=l;if(r){e=Nd(c<<2);if(!e){break h}}x[j+296>>2]=0;x[j+300>>2]=0;b=0;while(1){a=e;_:{while(1){e=x[d+4>>2];$:{if((e|0)!=x[d+104>>2]){x[d+4>>2]=e+1;e=y[e|0];break $}e=jd(d)}if(!y[(e+j|0)+33|0]){break _}v[j+27|0]=e;e=Vr(j+28|0,j+27|0,1,j+296|0);if((e|0)==-2){continue}o=0;if((e|0)==-1){break f}if(a){x[(b<<2)+a>>2]=x[j+28>>2];b=b+1|0}if(!r|(b|0)!=(c|0)){continue}break}h=1;b=c;c=b<<1|1;e=Qt(a,c<<2);if(e){continue}break e}break}o=0;c=a;if(j+296|0?x[j+296>>2]:0){break f}break Z}if(r){b=0;e=Nd(c);if(!e){break h}while(1){a=e;while(1){e=x[d+4>>2];aa:{if((e|0)!=x[d+104>>2]){x[d+4>>2]=e+1;e=y[e|0];break aa}e=jd(d)}if(!y[(e+j|0)+33|0]){c=0;o=a;break Z}v[a+b|0]=e;b=b+1|0;if((c|0)!=(b|0)){continue}break}h=1;b=c;c=b<<1|1;e=Qt(a,c);if(e){continue}break}o=a;a=0;break e}b=0;if(l){while(1){a=x[d+4>>2];ba:{if((a|0)!=x[d+104>>2]){x[d+4>>2]=a+1;a=y[a|0];break ba}a=jd(d)}if(y[(a+j|0)+33|0]){v[b+l|0]=a;b=b+1|0;continue}else{c=0;a=l;o=a;break Z}}}while(1){a=x[d+4>>2];ca:{if((a|0)!=x[d+104>>2]){x[d+4>>2]=a+1;a=y[a|0];break ca}a=jd(d)}if(y[(a+j|0)+33|0]){continue}break}a=0;o=0;c=0}e=x[d+4>>2];g=x[d+116>>2];if((g|0)>0|(g|0)>=0){e=e-1|0;x[d+4>>2]=e}g=e-x[d+44>>2]|0;e=g+x[d+120>>2]|0;h=x[d+124>>2]+(g>>31)|0;h=e>>>0<g>>>0?h+1|0:h;if(!(h|e)|!(f|(e|0)==(s|0)&(h|0)==(p|0))){break i}if(r){x[l>>2]=a}da:{if((q|0)==99){break da}if(c){x[(b<<2)+c>>2]=0}if(!o){o=0;break da}v[b+o|0]=0}a=c}b=x[d+4>>2]-x[d+44>>2]|0;e=b;c=n+x[d+124>>2]|0;f=b>>31;b=m+x[d+120>>2]|0;g=f+(b>>>0<m>>>0?c+1|0:c)|0;m=b+e|0;n=m>>>0<b>>>0?g+1|0:g;u=((l|0)!=0)+u|0}b=i+1|0;i=y[i+1|0];if(i){continue}break a}break}a=c;break g}h=1;o=0;a=0;break e}h=r;break b}h=r}if(u){break b}}u=-1}if(!h){break a}Eb(o);Eb(a)}db=j+304|0;db=d+144|0;return u}function u5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;h=db-32|0;db=h;e=Tb(h+20|0,11458);d=Qg(c,e);tb(e);a:{b:{c:{d:{e:{if(d){Uk(a,x[b+24>>2]+1298356|0);break e}e=Tb(h+20|0,10855);d=Qg(c,e);tb(e);if(d){Uk(a,x[b+24>>2]+1298344|0);break e}e=Tb(h+20|0,11288);d=Qg(c,e);tb(e);if(d){Uk(a,x[b+24>>2]+1298392|0);break e}e=Tb(h+20|0,10847);d=Qg(c,e);tb(e);if(d){Uk(a,x[b+24>>2]+1298380|0);break e}e=Tb(h+20|0,8141);d=Qg(c,e);tb(e);if(d){c=h+20|0;e=x[x[b+24>>2]+480184>>2];b=32848;f:{g:{while(1){if((b|0)==32896){break g}if((e|0)!=x[b>>2]){b=b+12|0;continue}break}Wm(c,0,x[b+8>>2]);break f}Gb(c)}x[23549]=0;P(989,a|0,c|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}tb(h+20|0);break e}e=Tb(h+20|0,10832);d=Qg(c,e);tb(e);if(d){f=x[x[b+24>>2]+480184>>2];c=db-48|0;db=c;b=32848;g=ig(c+36|0);j=h+20|0;e=Gb(j);while(1){if((b|0)!=32896){if((f|0)==x[b>>2]){x[23549]=0;d=O(1,c+24|0,x[b+4>>2])|0;i=x[23549];x[23549]=0;h:{i:{j:{k:{l:{m:{if((i|0)!=1){x[23549]=0;S(823,c+16|0,g|0,d|0);i=x[23549];x[23549]=0;if((i|0)==1){break k}if(!y[c+20|0]){break h}if(!xd(x[e+4>>2],y[e+11|0])){x[23549]=0;i=O(1,c+4|0,17350)|0;m=x[23549];x[23549]=0;if((m|0)==1){break m}x[23549]=0;O(87,e|0,i|0)|0;m=x[23549];x[23549]=0;if((m|0)==1){break l}tb(i)}x[23549]=0;O(87,e|0,d|0)|0;i=x[23549];x[23549]=0;if((i|0)!=1){break h}b=N()|0;break j}b=N()|0;break i}b=N()|0;break j}b=N()|0;tb(i);break j}b=N()|0}tb(d)}tb(e);DM(g);Q(b|0);p()}tb(d)}b=b+12|0;continue}break}DM(g);db=c+48|0;x[23549]=0;P(989,a|0,j|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(h+20|0);break e}c=N()|0;tb(h+20|0);break a}e=Tb(h+20|0,8207);d=Qg(c,e);tb(e);if(d){Uk(a,x[b+24>>2]+1298368|0);break e}e=Tb(h+20|0,5561);d=Qg(c,e);tb(e);if(d){Uk(a,x[b+24>>2]+1298320|0);break e}e=Tb(h+20|0,11862);d=Qg(c,e);tb(e);if(d){c=h+20|0;qg(c,x[b+24>>2]+1298308|0);b=x[b+24>>2];x[23549]=0;S(983,a|0,b|0,c|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(h+20|0);break e}c=N()|0;tb(h+20|0);break a}e=Tb(h+20|0,11231);d=Qg(c,e);tb(e);if(d){c=x[b+24>>2]+1298408|0;b=x[c+4>>2];n:{if(!qc(x[c>>2],b)){b=AB(b);if(ud(x[b+12>>2])){break n}}Gb(a);break e}m=h+20|0;g=db-144|0;db=g;rc(g+100|0,b,44);i=x[b+44>>2];if(i){rc(g+44|0,b,44);e=db-16|0;db=e;f=e+8|0;b=dx(x[g+64>>2]+1900|0,x[g+60>>2]+1|0,x[g+56>>2])-dx(1970,1,1)|0;b=yka(b,b>>31,86400,0);c=D(x[g+52>>2],3600);b=b+c|0;d=hb+(c>>31)|0;d=b>>>0<c>>>0?d+1|0:d;c=D(x[g+48>>2],60);j=c;b=c+b|0;c=(c>>31)+d|0;c=b>>>0<j>>>0?c+1|0:c;d=x[g+44>>2];j=d;b=d+b|0;d=(d>>31)+c|0;c=Ph(f,b,b>>>0<j>>>0?d+1|0:d);b=x[c>>2];d=x[c+4>>2];db=e+16|0;f=g+88|0;e=2147483647;l=je(+(i>>>0)/18.2);c=-1;o:{if(l>=0x8000000000000000){break o}e=-2147483648;c=0;if(l<=-0x8000000000000000){break o}if(F(l)<0x8000000000000000){e=F(l)>=1?~~(l>0?H(J(l*2.3283064365386963e-10),4294967295):K((l-+(~~l>>>0>>>0))*2.3283064365386963e-10))>>>0:0;c=~~l>>>0;break o}c=0}d=d+e|0;e=b;b=b+c|0;d=e>>>0>b>>>0?d+1|0:d;b=Ph(f,b,d);i=x[b>>2];c=x[b+4>>2];o=c;b=db-16|0;db=b;x[b+12>>2]=0;x[b+8>>2]=0;x[b+4>>2]=0;f=dx(1970,1,1)+zka(i,c,86400,0)|0;j=f>>31;e=yka(f,j,1e4,0);c=hb;e=e+14780|0;c=e>>>0<14780?c+1|0:c;k=zka(e,c,-14609700,-1);d=j+hb|0;k=f+k|0;d=k>>>0<f>>>0?d+1|0:d;n=zka(e,c,365242500,0);k=n+k|0;d=hb+d|0;d=k>>>0<n>>>0?d+1|0:d;n=zka(e,c,-146097e4,-1);k=n+k|0;d=hb+d|0;d=k>>>0<n>>>0?d+1|0:d;c=zka(e,c,3652425,0);e=hb;n=e;q=k;k=yka(c,e,-365,-1);e=q+k|0;d=hb+d|0;d=e>>>0<k>>>0?d+1|0:d;if(!((d|0)>0|(d|0)>=0)){e=c-1|0;c=yka(e,n-!c|0,-365,-1);d=j+hb|0;c=c+f|0;d=c>>>0<f>>>0?d+1|0:d;j=c;c=e;f=(c|0)/-4|0;e=j+f|0;d=(f>>31)+d|0;d=e>>>0<f>>>0?d+1|0:d;f=(c|0)/100|0;e=f+e|0;d=(f>>31)+d|0;d=e>>>0<f>>>0?d+1|0:d;f=(c|0)/-400|0;e=f+e|0;d=(f>>31)+d|0;d=e>>>0<f>>>0?d+1|0:d}f=c;d=yka(e,d,100,0);c=hb;d=d+52|0;c=d>>>0<52?c+1|0:c;j=f;c=zka(d,c,3060,0);d=c+2|0;f=(d|0)/12|0;x[b+12>>2]=j+f;x[b+8>>2]=(d+D(f,-12)|0)+1;c=yka(c,hb,306,0);d=hb;c=c+5|0;d=c>>>0<5?d+1|0:d;c=zka(c,d,-10,-1)+e|0;x[b+4>>2]=c+1;x[g+140>>2]=0;x[g+132>>2]=0;x[g+136>>2]=0;x[g+124>>2]=0;x[g+128>>2]=0;x[g+120>>2]=x[b+12>>2]-1900;x[g+116>>2]=x[b+8>>2]-1;c=x[b+4>>2];r=g,s=Aka(zka(i,o,3600,0),hb,24),x[r+108>>2]=s;x[g+112>>2]=c;c=zka(i,o,60,0);e=hb;r=g,s=Aka(c,e,60),x[r+104>>2]=s;c=yka(c,e,-60,0)+i|0;x[g+100>>2]=c;db=b+16|0}c=rc(g,g+100|0,44);b=db-144|0;db=b;d=Gb(b+132|0);x[23549]=0;e=O(1,b+120|0,13315)|0;g=x[23549];x[23549]=0;p:{q:{r:{s:{t:{if((g|0)!=1){g=x[c+20>>2];if(!g){break q}x[23549]=0;x[b+96>>2]=g+1900;P(86,b+108|0,b+96|0);g=x[23549];x[23549]=0;if((g|0)!=1){x[23549]=0;i=O(87,d|0,b+108|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break t}tb(b+108|0);f=x[c+16>>2];if(f>>>0>11){break q}x[23549]=0;g=O(1,b+96|0,16387)|0;j=x[23549];x[23549]=0;u:{v:{w:{x:{y:{z:{if((j|0)!=1){x[23549]=0;x[b+72>>2]=f+1;P(88,b+84|0,b+72|0);f=x[23549];x[23549]=0;if((f|0)==1){break z}x[23549]=0;S(2,b+108|0,g|0,b+84|0);f=x[23549];x[23549]=0;if((f|0)==1){break y}x[23549]=0;i=O(87,i|0,b+108|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break x}tb(b+108|0);tb(b+84|0);tb(g);if(x[c+12>>2]-32>>>0>=4294967265){break u}break q}a=N()|0;break s}a=N()|0;break v}a=N()|0;break w}a=N()|0;tb(b+108|0)}tb(b+84|0)}tb(g);break s}x[23549]=0;g=O(1,b+84|0,16387)|0;f=x[23549];x[23549]=0;A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((f|0)!=1){x[23549]=0;P(88,b+72|0,c+12|0);f=x[23549];x[23549]=0;if((f|0)==1){break Z}x[23549]=0;S(2,b+108|0,g|0,b+72|0);f=x[23549];x[23549]=0;if((f|0)==1){break Y}x[23549]=0;i=O(87,i|0,b+108|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break X}tb(b+108|0);tb(b+72|0);tb(g);j=x[c>>2];g=x[c+8>>2];f=x[c+4>>2];if(!(j|(g|f))|g>>>0>23|f>>>0>59){break q}x[23549]=0;g=O(1,b+108|0,13430)|0;f=x[23549];x[23549]=0;if((f|0)==1){break U}x[23549]=0;i=O(87,i|0,g|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break T}tb(g);if(x[c+32>>2]>0){x[23549]=0;g=O(1,b+72|0,15198)|0;f=x[23549];x[23549]=0;if((f|0)==1){break S}zb(e,g);tb(g)}x[23549]=0;P(88,b+36|0,c+8|0);g=x[23549];x[23549]=0;if((g|0)==1){break R}x[23549]=0;g=O(1,b+24|0,14304)|0;f=x[23549];x[23549]=0;if((f|0)==1){break Q}x[23549]=0;S(2,b+48|0,b+36|0,g|0);f=x[23549];x[23549]=0;if((f|0)==1){break P}x[23549]=0;P(88,b+12|0,c+4|0);f=x[23549];x[23549]=0;if((f|0)==1){break O}x[23549]=0;S(2,b+60|0,b+48|0,b+12|0);f=x[23549];x[23549]=0;if((f|0)==1){break N}x[23549]=0;i=O(87,i|0,b+60|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break M}tb(b+60|0);tb(b+12|0);tb(b+48|0);tb(g);tb(b+36|0);if(j>>>0<62){break H}x[23549]=0;S(89,m|0,i|0,e|0);g=x[23549];x[23549]=0;if((g|0)==1){break G}break p}a=N()|0;break s}a=N()|0;break V}a=N()|0;break W}a=N()|0;tb(b+108|0)}tb(b+72|0)}tb(g);break s}a=N()|0;break s}a=N()|0;tb(g);break s}a=N()|0;break s}a=N()|0;break s}a=N()|0;break I}a=N()|0;break J}a=N()|0;break K}a=N()|0;break L}a=N()|0;tb(b+60|0)}tb(b+12|0)}tb(b+48|0)}tb(g)}tb(b+36|0);break s}x[23549]=0;g=O(1,b+48|0,14304)|0;f=x[23549];x[23549]=0;if((f|0)==1){break F}x[23549]=0;P(88,b+36|0,c|0);f=x[23549];x[23549]=0;if((f|0)==1){break E}x[23549]=0;S(2,b+60|0,g|0,b+36|0);f=x[23549];x[23549]=0;if((f|0)==1){break D}x[23549]=0;i=O(87,i|0,b+60|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break C}tb(b+60|0);tb(b+36|0);tb(g);x[23549]=0;O(87,i|0,e|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){break q}}a=N()|0;break s}a=N()|0;break s}a=N()|0;break A}a=N()|0;break B}a=N()|0;tb(b+60|0)}tb(b+36|0)}tb(g);break s}a=N()|0;break s}a=N()|0;break r}a=N()|0;tb(b+108|0)}tb(e)}tb(d);Q(a|0);p()}ad(m,d)}tb(e);tb(d);db=b+144|0;db=c+144|0;x[23549]=0;P(989,a|0,m|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(h+20|0);break e}c=N()|0;tb(h+20|0);break a}e=Tb(h+20|0,12063);d=Qg(c,e);tb(e);if(d){mQ(h+20|0,x[b+24>>2]+1298332|0);_:{if(!xd(x[h+24>>2],y[h+31|0])){break _}e=x[x[b+24>>2]+480180>>2];$:{aa:{if((e|0)==33554432){break aa}c=1;if((e|0)==32){break $}if((e|0)==16384){break aa}if((e|0)==16777216){break $}}c=2}ba:{switch(c-1|0){case 0:x[23549]=0;P(990,h+8|0,b|0);c=x[23549];x[23549]=0;if((c|0)!=1){c=h+8|0;zb(h+20|0,c);tb(c);break _}break b;case 1:break ba;default:break _}}x[23549]=0;P(991,h+8|0,b|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=h+8|0;e=zb(h+20|0,c);tb(c);if(!xd(x[h+24>>2],y[h+31|0])){break _}x[23549]=0;P(990,h+8|0,b|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=h+8|0;zb(e,c);tb(c)}b=x[b+24>>2];x[23549]=0;S(983,a|0,b|0,h+20|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(h+20|0);break e}break b}e=Tb(h+20|0,5413);d=Qg(c,e);tb(e);if(d){c=h+20|0;mQ(c,x[b+24>>2]+1298332|0);b=x[b+24>>2];x[23549]=0;S(983,a|0,b|0,c|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(h+20|0);break e}c=N()|0;tb(h+20|0);break a}e=c;c=Tb(h+20|0,7233);e=Qg(e,c);tb(c);if(e){a=Gb(a);r=h,s=yb(x[b+68>>2]),x[r+20>>2]=s;b=yb(x[b+72>>2]);c=1;while(1){e=x[h+20>>2];if(!Kb(e,b)){break e}if(!(c&1)){x[23549]=0;O(916,a|0,21179)|0;c=x[23549];x[23549]=0;if((c|0)==1){break c}}x[23549]=0;O(777,a|0,e|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break c}Bj(h+20|0);c=0;continue}}Tb(a,21204)}db=h+32|0;return}c=N()|0;tb(h+20|0);break a}c=N()|0;tb(a);break a}c=N()|0;tb(h+20|0)}Q(c|0);p()}function Xea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=db-192|0;db=j;if(!Ct(a)){e=j+40|0;rc(e,a,128);f=j+168|0;gf(f,e,128,2);e=j+180|0;Bc(e,f);zc(b+492|0,e);tb(e)}w[c+34>>1]=z[c+34>>1]&65489;q=j+180|0;g=db-32|0;db=g;a:{b:{switch(y[a+128|0]-4|0){default:x[g+28>>2]=0;wm(q,0,g+28|0);break a;case 0:case 4:break b}}v[g+28|0]=y[a+129|0];v[g+24|0]=100;e=g+24|0;f=y[Sb(g+28|0,e)|0];v[g+24|0]=y[a+130|0];v[g+20|0]=100;e=y[Sb(e,g+20|0)|0];x[g+28>>2]=e;c:{if(y[a+140|0]&16){h=Hb(y[a+150|0]|y[a+151|0]<<8);k=Hb(y[a+152|0]|y[a+153|0]<<8);l=x[c>>2];s=+(l>>>0)/6553600;f=wq(s*+((h|f<<16)>>>0));x[g+24>>2]=l-f;t=g,u=wq(s*+((k|e<<16)>>>0)),x[t+20>>2]=u;t=g,u=x[Cb(g+24|0,g+20|0)>>2],x[t+28>>2]=u;break c}h=x[c>>2];k=x[c+20>>2];if(!Sd(h,k)){break c}l=h>>>7|0;f=D(l,(f<<7>>>0)/100|0);x[g+24>>2]=h-f;x[g+20>>2]=D(l,(e<<7>>>0)/100|0);e=x[Cb(g+24|0,g+20|0)>>2];l=z[c+34>>1];h=D(Jd(l),h);d:{if(l&1){dc(g+12|0,k,h);k=x[g+12>>2];l=Jd(z[c+34>>1]);h=k+(D(l,f+e|0)<<1)|0;n=w[k+(D(f,l)<<1)>>1];l=0-l<<1;while(1){e:{f:{if(e){p=w[h>>1]-n|0;k=p>>31;if((k^p)-k>>>0>=1536){break f}}else{e=0}break e}e=e-1|0;h=h+l|0;continue}break}break d}dc(g+4|0,k,h);k=x[g+4>>2];l=Jd(z[c+34>>1]);n=0-l|0;h=k+D(l,f+e|0)|0;l=v[k+D(f,l)|0];while(1){g:{h:{if(e){p=v[h|0]-l|0;k=p>>31;if((k^p)-k>>>0>=6){break h}}else{e=0}break g}e=e-1|0;h=h+n|0;continue}break}}x[g+28>>2]=e}wm(q,f,g+28|0)}db=g+32|0;q=gc(q);if(!(!x[q>>2]|y[a+128|0]!=4)){w[c+34>>1]=z[c+34>>1]|2;e=x[j+180>>2];x[c+4>>2]=e;x[c+8>>2]=e+x[q>>2]}h=j;e=y[a+134|0];if((e-1&255)>>>0<=198){v[j+40|0]=e;v[j+168|0]=100;e=(y[Sb(j+40|0,j+168|0)|0]<<7>>>0)/100|0}else{e=128}v[h+39|0]=e;v[j+40|0]=64;e=j+39|0;f=j+40|0;t=c,u=y[af(e,f)|0]>>>1|0,w[t+32>>1]=u;v[j+40|0]=64;t=b,u=y[Sb(e,f)|0],x[t+4>>2]=u;x[c+24>>2]=40460;vq(c,+v[a+139|0]/12+ +(0-y[a+143|0]|0)+ +v[a+138|0]/1536);v[b+34|0]=y[a+142|0]&2?2:1;if(y[a+142|0]&2){Mm(b,127,1);Lm(b,0,1)}i:{if(!Sd(x[c>>2],x[c+20>>2])){break i}b=y[a+140|0];if(b&1){b=x[c>>2];e=x[c+20>>2];j:{if(!Sd(b,e)|b>>>0<2){break j}k:{l:{switch(rk(z[c+34>>1])-1|0){case 3:f=0;g=b>>>1|0;while(1){if((f|0)!=(g|0)){Pb(e+(f<<2)|0,e+(b+(f^-1)<<2)|0);f=f+1|0;continue}break};break k;case 1:f=0;g=b>>>1|0;while(1){if((f|0)!=(g|0)){GM(e+(f<<1)|0,e+(b+(f^-1)<<1)|0);f=f+1|0;continue}break};break k;case 0:break l;default:break j}}f=0;g=b>>>1|0;while(1){if((f|0)!=(g|0)){sh(f+e|0,e+(b+(f^-1)|0)|0);f=f+1|0;continue}break}}dj(c,d)}b=y[a+140|0]}if(b&4){m:{e=x[c>>2];b=x[c+20>>2];if(!Sd(e,b)){break m}f=z[c+34>>1];e=D(Jd(f),e);n:{o:{switch(Sm(f)-1|0){case 1:f=0;while(1){if((f|0)!=(e|0)){g=b+(f<<1)|0;w[g>>1]=z[g>>1]^-1;f=f+1|0;continue}break};break n;case 0:break o;default:break m}}f=0;while(1){if((f|0)!=(e|0)){g=b+f|0;v[g|0]=y[g|0]^-1;f=f+1|0;continue}break}}dj(c,d)}}m=y[a+170|0]!=2|y[a+171|0]>100?m:y[a+172|0]<101;b=z[c+34>>1];if(!(!(m|y[a+160|0]!=0|y[a+141|0])|b&1)){e=Bt(x[c>>2],Jd(b)<<1&254);if(!e){break i}b=e;f=x[c>>2];g=z[c+34>>1];h=D(Jd(g),f);k=x[c+20>>2];g=pj(f,g);f=db-16|0;db=f;x[f+12>>2]=h;tc(f+12|0,g);h=x[f+12>>2];while(1){if(h){w[b>>1]=v[k|0]<<8;k=k+1|0;b=b+2|0;h=h-1|0;continue}break}db=f+16|0;w[c+34>>1]=z[c+34>>1]|1;UQ(c,e,x[c>>2],d);b=z[c+34>>1]}f=x[c>>2];e=x[c+20>>2];p:{if(v[a+141|0]>=0){break p}dc(j+40|0,e,D(Jd(b),f));g=x[j+44>>2];e=x[j+40>>2];q:while(1){if((0-v[a+141|0]|0)<=(i|0)){f=x[c>>2];e=x[c+20>>2];b=z[c+34>>1];break p}f=w[e>>1];h=_b(e,g);b=e;while(1)if((b|0)==(h|0)){i=i+1|0;continue q}else{f=gd(w[b>>1]-gd(f,1)|0,1);w[b>>1]=f;b=b+2|0;continue}}}if(m){dc(j+40|0,e,D(Jd(b),f));g=x[j+44>>2];b=(g|0)/2|0;e=b;h=e>>31;i=y[a+172|0];f=y[a+171|0];b=i-f|0;o=e;e=0-(f>>>0>i>>>0)<<24|b>>>8;m=b<<24;i=o+m|0;b=e+h|0;i=Cc(zka(i,i>>>0<m>>>0?b+1|0:b,g,g>>31),hb);m=i>>31;e=f<<24;f=e>>31;b=x[j+40>>2];g=_b(b,g);while(1){if((b|0)!=(g|0)){h=w[b>>1];k=yka(e,f,h,h>>31);h=hb;k=k+838860800|0;h=k>>>0<838860800?h+1|0:h;t=b,u=Cc(zka(k,h,1677721600,0),hb),w[t>>1]=u;b=b+2|0;f=f+m|0;e=e+i|0;f=e>>>0<i>>>0?f+1|0:f;continue}break}f=x[c>>2];e=x[c+20>>2];b=z[c+34>>1]}if(y[a+160|0]){dc(j+168|0,e,D(Jd(b),f));m=y[a+163|0];l=y[a+162|0];f=0;g=x[j+172>>2];k=0;h=0;if(y[a+161|0]>=2){b=(g|0)/2|0;i=b>>31;e=y[a+164|0];h=0-(e>>>0<l>>>0)|0;e=e-l|0;n=e<<23;k=n+b|0;e=(h<<23|e>>>9)+i|0;p=g>>31;k=Cc(zka(k,k>>>0<n>>>0?e+1|0:e,g,p),hb);e=y[a+165|0];h=0-(e>>>0<m>>>0)|0;e=e-m|0;n=b+(e<<23)|0;e=i+(h<<23|e>>>9)|0;h=Cc(zka(n,b>>>0>n>>>0?e+1|0:e,g,p),hb)}e=m<<23;i=l<<23;l=(j+40|0)+((y[a+160|0]&2)<<2)|0;b=x[j+168>>2];g=_b(b,g);m=0;while(1){if((b|0)==(g|0)){f=x[c>>2];e=x[c+20>>2];b=z[c+34>>1]}else{n=(w[b>>1]>>1)-m|0;x[j+48>>2]=n;o=n;n=(i|0)/8388608|0;f=gd(D(o,n),8)+f|0;x[j+44>>2]=f;m=gd(D(f,n),6)+m|0;m=gd(gd(D(m,(e|0)/8388608|0),6)+m|0,2);x[j+40>>2]=m;t=b,u=Sc(x[l>>2]),w[t>>1]=u;b=b+2|0;e=e+h|0;i=i+k|0;continue}break}}r:{if(v[a+141|0]<=0){break r}dc(j+40|0,e,D(Jd(b),f));i=0;g=x[j+44>>2];e=x[j+40>>2];s:while(1){if(v[a+141|0]<=(i|0)){f=x[c>>2];e=x[c+20>>2];b=z[c+34>>1];break r}f=w[e>>1];h=_b(e,g);b=e;while(1)if((b|0)==(h|0)){i=i+1|0;continue s}else{f=((w[b>>1]<<1)+f|0)/3|0;w[b>>1]=f;b=b+2|0;continue}}}f=D(Jd(b),f);t:{if(b&1){dc(j+28|0,e,f);e=db-16|0;db=e;b=x[j+28>>2];m=_b(b,x[j+32>>2]);n=db-16|0;db=n;l=db-16|0;db=l;x[l+12>>2]=b;ec(l+4|0,n+15|0,n+14|0);o=e+8|0;g=wm(o,b,l+12|0);u:{if((b|0)==(m|0)){break u}f=b+2|0;if((m|0)==(f|0)){break u}t=(hl(z[f>>1],z[x[g>>2]>>1])?0:4)+g|0,u=f,x[t>>2]=u;h=g+4|0;while(1){i=f+2|0;if((m|0)==(i|0)){break u}k=z[f+2>>1];f=f+4|0;if((m|0)==(f|0)){if(!hl(k,z[x[g>>2]>>1])){g=h;if(hl(k,z[x[g>>2]>>1])){break u}}x[g>>2]=i;break u}p=z[x[g>>2]>>1];r=z[f>>1];v:{if(hl(r,k)){if(hl(r,p)){x[g>>2]=f}if(hl(k,z[x[h>>2]>>1])){continue}break v}if(hl(k,p)){x[g>>2]=i}i=f;if(hl(r,z[x[h>>2]>>1])){continue}}x[h>>2]=i;continue}}db=l+16|0;db=n+16|0;x[e+4>>2]=0-w[x[e+8>>2]>>1];t=e,u=w[x[gc(o)>>2]>>1],x[t>>2]=u;w:{f=x[Re(e+4|0,e)>>2];if((f|0)>32766|!f){break w}while(1){if((b|0)==(m|0)){break w}w[b>>1]=(D(w[b>>1],32767)|0)/(f|0);b=b+2|0;continue}}break t}dc(j+20|0,e,f);e=db-16|0;db=e;b=x[j+20>>2];m=Db(b,x[j+24>>2]);n=db-16|0;db=n;l=db-16|0;db=l;x[l+12>>2]=b;ec(l+4|0,n+15|0,n+14|0);o=e+8|0;g=wm(o,b,l+12|0);x:{if((b|0)==(m|0)){break x}f=b+1|0;if((m|0)==(f|0)){break x}t=(il(y[f|0],y[x[g>>2]])?0:4)+g|0,u=f,x[t>>2]=u;h=g+4|0;while(1){i=f+1|0;if((m|0)==(i|0)){break x}k=y[f+1|0];f=f+2|0;if((m|0)==(f|0)){if(!il(k,y[x[g>>2]])){g=h;if(il(k,y[x[g>>2]])){break x}}x[g>>2]=i;break x}p=y[x[g>>2]];r=y[f|0];y:{if(il(r,k)){if(il(r,p)){x[g>>2]=f}if(il(k,y[x[h>>2]])){continue}break y}if(il(k,p)){x[g>>2]=i}i=f;if(il(r,y[x[h>>2]])){continue}}x[h>>2]=i;continue}}db=l+16|0;db=n+16|0;x[e+4>>2]=0-v[x[e+8>>2]];t=e,u=v[x[gc(o)>>2]],x[t>>2]=u;z:{f=x[Re(e+4|0,e)>>2];if((f|0)>126|!f){break z}while(1){if((b|0)==(m|0)){break z}v[b|0]=(D(v[b|0],127)|0)/(f|0);b=b+1|0;continue}}}db=e+16|0;A:{if((y[a+134|0]-101&255)>>>0>98){break A}f=z[c+34>>1];e=D(x[c>>2],Jd(f));b=x[c+20>>2];if(f&1){x[j+12>>2]=b;x[j+16>>2]=(b+(e<<1)|0)-b>>1;b=(3276800-(y[a+134|0]<<14)|0)/100|0;g=0-b|0;f=32768-b|0;e=x[j+12>>2];h=_b(e,x[j+16>>2]);while(1){if((e|0)!=(h|0)){i=w[e>>1];B:{if((i|0)>(b|0)){o=f+((D(b,i-b|0)|0)/(f|0)|0)|0;break B}o=((D(b,b+i|0)|0)/(f|0)|0)-f|0;if((g|0)>(i|0)){break B}o=(D(f,i)|0)/(b|0)|0}t=e,u=Sc(o),w[t>>1]=u;e=e+2|0;continue}break}break A}i=tn(j+4|0,b,b+e|0);e=x[i>>2];b=(3276800-(y[a+134|0]<<14)|0)/100|0;g=0-b|0;f=32768-b|0;h=Db(e,x[i+4>>2]);while(1){if((e|0)!=(h|0)){i=v[e|0]<<8;C:{if((i|0)>(b|0)){o=f+((D(b,i-b|0)|0)/(f|0)|0)|0;break C}o=((D(b,b+i|0)|0)/(f|0)|0)-f|0;if((g|0)>(i|0)){break C}o=(D(f,i)|0)/(b|0)|0}t=e,u=VS((o|0)/256|0),v[t|0]=u;e=e+1|0;continue}break}}TQ(c);if(y[a+128|0]!=8){break i}b=y[a+131|0];if(!b){break i}e=x[q>>2];if(!e){break i}f=x[j+180>>2];t=xb(c+68|0,0),u=f+D(e,b+1|0)|0,x[t>>2]=u;b=x[j+180>>2];x[c+12>>2]=b;x[c+16>>2]=b+x[q>>2];g=x[q>>2];i=y[a+131|0];if(g>>>0>268435456/(i>>>0)>>>0){break i}f=x[c>>2];e=D(g,i);if(f>>>0>268435456-e>>>0){break i}f=f+e|0;e=rk(z[c+34>>1]);m=Bt(f,e);if(!m){break i}h=b+D(g,i+1|0)|0;x[c>>2]=f;b=m;m=x[c+20>>2];i=x[j+180>>2];g=rc(b,m,D(e,i+x[q>>2]|0));k=m+D(e,i)|0;a=y[a+131|0];b=0;while(1){if((a|0)==(b|0)){rc(g+D(e,h)|0,m+D(e,i+x[q>>2]|0)|0,D(e,f-h|0));UQ(c,g,f,d)}else{b=b+1|0;l=x[q>>2];rc(g+D(e,i+D(b,l)|0)|0,k,D(e,l));continue}break}}db=j+192|0}function Eaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=db-720|0;db=d;wc(b);a:{b:{c:{d:{if(!$h(b,d+712|0)){break d}if(!vM(x[d+712>>2],x[d+716>>2])){break d}if(!LA(b,d+708|0)){break d}i=x[d+708>>2];if(!uM(i)){break d}e:{if((i|0)==1179012417){f=1;e=1313423693;break e}if((i|0)!=538987841){break d}f=2;e=1414090313}m=le(d+688|0,b);j=Nb(d+676|0);f:{g:{h:{i:{j:{k:{l:{if(!c){x[23549]=0;V(829,d+112|0,m|0,f|0,e|0);b=x[23549];x[23549]=0;if((b|0)!=1){break l}a=N()|0;break a}x[23549]=0;S(830,d+112|0,m|0,f|0);b=x[23549];x[23549]=0;if((b|0)==1){break k}}b=d+112|0;Rt(j,b);_d(b);x[23549]=0;S(831,d+656|0,j|0,e|0);b=x[23549];x[23549]=0;if((b|0)!=1){x[23549]=0;b=R(164,x[d+656>>2])|0;e=x[23549];x[23549]=0;if((e|0)==1){break j}f=0;if(!b){break f}x[23549]=0;b=O(832,d+656|0,d+583|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break j}if(!b){break f}b=y[d+648|0];if(!b){break f}x[23549]=0;f=U(142,x[d+656>>2],x[d+664>>2],b|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break j}if(!((c|0)!=0&f)){break f}x[23549]=0;P(235,a|0,8388608);b=x[23549];x[23549]=0;if((b|0)==1){break j}x[a+480208>>2]=y[d+647|0]<<4&16^28;w[d+112>>1]=y[d+648|0];w[d+464>>1]=127;o=a,q=z[Uc(d+112|0,d+464|0)>>1],w[o+480188>>1]=q;x[a+480196>>2]=y[d+649|0];x[a+480204>>2]=D(y[d+650|0],1e4);x[a+480200>>2]=y[d+655|0]<<1;x[23549]=0;P(122,a+1298344|0,((i|0)!=1179012417?16524:16558)|0);b=x[23549];x[23549]=0;if((b|0)==1){break j}x[23549]=0;b=O(1,d+568|0,13108)|0;e=x[23549];x[23549]=0;if((e|0)==1){break h}zb(a+1298356|0,b);tb(b);x[a+1298404>>2]=5;b=d+464|0;pA(b,2,d+583|0);x[23549]=0;P(208,d+112|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break i}b=d+112|0;zb(a+1298308|0,b);tb(b);l=(i|0)==1179012417;b=0;while(1){m:{n:{o:{if(z[a+480188>>1]<=b>>>0){b=yb(x[j>>2]);f=yb(x[j+4>>2]);e=db-16|0;db=e;x[e+12>>2]=b;while(1){p:{if(!Kb(b,f)){break p}if(tV(1380209231,x[b>>2],x[b+4>>2])){break p}b=x[hk(e+12|0)>>2];continue}break}db=e+16|0;if(Kb(b,yb(x[j+4>>2]))){break o}break g}f=(b<<5)+a|0;g=f+480280|0;Te(g);x[23549]=0;e=R(192,d+656|0)|0;k=x[23549];x[23549]=0;q:{r:{if((k|0)!=1){if(l){break q}if(e>>>0<129){break r}break n}a=N()|0;break b}w[f+480284>>1]=e<<1;break m}if(e<<24>>24<0){break n}x[d+112>>2]=e<<2;x[d+464>>2]=256;o=f+480284|0,q=x[qd(d+112|0,d+464|0)>>2],w[o>>1]=q;break m}x[23549]=0;S(831,d+112|0,j|0,1380209231);b=x[23549];x[23549]=0;s:{if((b|0)!=1){x[23549]=0;b=R(192,d+112|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break s}e=y[a+484376|0];f=x[a+484360>>2];x[23549]=0;aa(332,Wb(f,e)|0,d+112|0,b+1&255,255,254);b=x[23549];x[23549]=0;if((b|0)==1){break s}ub(d+112|0);break g}a=N()|0;break b}a=N()|0;ub(d+112|0);break b}x[g>>2]=1024}b=b+1|0;continue}}a=N()|0;break a}a=N()|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}t:{if(!(c&1)){break t}w[d+48>>1]=0;x[23549]=0;S(833,d+528|0,j|0,1414807888);b=x[23549];x[23549]=0;if((b|0)==1){break c}b=x[d+532>>2];e=x[d+528>>2];x[23549]=0;f=a+484344|0;P(211,f|0,Ef(e,b)&65535);b=x[23549];x[23549]=0;u:{if((b|0)!=1){o=d,q=yb(x[d+528>>2]),x[o+76>>2]=q;l=yb(x[d+532>>2]);g=(i|0)!=1179012417;v:{w:{x:{y:{z:{while(1){b=x[d+76>>2];if(!Kb(b,l)){b=0;break v}b=le(d+112|0,b);x[23549]=0;e=R(192,b|0)|0;k=x[23549];x[23549]=0;if((k|0)!=1){x[23549]=0;w[d+452>>1]=e;e=R(143,b|0)|0;k=x[23549];x[23549]=0;if((k|0)==1){break z}x[23549]=0;S(176,d+464|0,b|0,e|0);e=x[23549];x[23549]=0;if((e|0)==1){break y}e=hc(d+548|0,d+464|0);x[23549]=0;k=x[e+12>>2];x[d+8>>2]=x[e+8>>2];x[d+12>>2]=k;x[d+16>>2]=x[e+16>>2];k=x[e+4>>2];x[d>>2]=x[e>>2];x[d+4>>2]=k;V(834,d|0,z[d+452>>1],g|0,a|0);e=x[23549];x[23549]=0;if((e|0)==1){break x}ub(d+464|0);o=d,q=z[Ve(d+48|0,d+452|0)>>1],w[o+48>>1]=q;ub(b);yg(d+76|0);continue}break}a=N()|0;break w}a=N()|0;break w}a=N()|0;break w}a=N()|0;ub(d+464|0)}ub(b);break u}while(1){e=b&65535;if(e>>>0>=z[d+48>>1]){kd(d+528|0);break t}A:{if(!se(x[a+484344>>2],x[a+484348>>2],e)){x[23549]=0;U(212,f|0,e|0,64)|0;e=x[23549];x[23549]=0;if((e|0)==1){break A}}b=b+1|0;continue}break}a=N()|0;break u}a=N()|0}kd(d+528|0);break b}B:{C:{D:{if((i|0)==1179012417){x[23549]=0;S(833,d+76|0,j|0,1414745673);b=x[23549];x[23549]=0;if((b|0)==1){break C}o=d,q=yb(x[d+76>>2]),x[o+100>>2]=q;f=c&2;i=d+472|0;l=yb(x[d+80>>2]);while(1){b=x[d+100>>2];if(!Kb(b,l)){kd(d+76|0);break B}c=le(d+528|0,b);x[23549]=0;b=O(835,c|0,d+112|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){E:{if(!b){break E}b=y[d+113|0];if((b|0)==255){break E}x[23549]=0;e=U(240,a|0,b+1|0,0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break D}if(!e){break E}g=z[a+480190>>1];b=0;x[23549]=0;S(836,d+112|0,e|0,g|0);e=x[23549];x[23549]=0;if((e|0)==1){break D}while(1){if(y[d+142|0]<=b>>>0){break E}F:{if(!Th(z[a+480190>>1])){break F}x[23549]=0;e=O(837,c|0,d+464|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break D}if(!e){break F}e=z[a+480190>>1]+1|0;w[a+480190>>1]=e;if(x[d+464>>2]!=1347240275){break F}g=d+452|0;tl(g,2,i);x[23549]=0;P(208,d+48|0,g|0);g=x[23549];x[23549]=0;G:{if((g|0)!=1){e=e&65535;g=d+48|0;zc(((e<<5)+a|0)+946304|0,g);tb(g);x[23549]=0;e=(D(e,104)+a|0)+484380|0;S(838,d+464|0,d+112|0,e|0);g=x[23549];x[23549]=0;if((g|0)==1){break D}if(!f){break G}g=d+48|0;tM(g,z[d+502>>1]);x[23549]=0;U(205,g|0,e|0,c|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){break F}break D}break D}g=z[e+34>>1];e=x[e>>2];x[23549]=0;O(174,c|0,pj(e,g)|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break D}}b=b+1|0;continue}}ub(c);yg(d+100|0);continue}break}break D}x[23549]=0;S(833,d+452|0,j|0,1179011410);b=x[23549];x[23549]=0;if((b|0)!=1){o=d,q=yb(x[d+452>>2]),x[o+448>>2]=q;i=c&2;l=d+468|0;g=yb(x[d+456>>2]);H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{while(1){b=x[d+448>>2];if(!Kb(b,g)){kd(d+452|0);break B}c=le(d+528|0,b);x[23549]=0;b=R(143,c|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break Q}R:{S:{if((b|0)!=538986817){break S}x[23549]=0;b=O(839,c|0,d+440|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break P}if(!(b&x[d+440>>2]==1414745673)){break S}x[23549]=0;b=O(840,c|0,d+112|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break O}if(!b){break S}b=y[d+117|0];if((b|0)==255){break S}x[23549]=0;b=U(240,a|0,b+1|0,0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break N}if(!b){break S}e=z[a+480190>>1];x[23549]=0;S(841,d+112|0,b|0,e|0);b=x[23549];x[23549]=0;if((b|0)==1){break N}x[23549]=0;S(830,d+464|0,c|0,2);b=x[23549];x[23549]=0;if((b|0)==1){break R}x[23549]=0;S(833,d+100|0,d+464|0,1179011410);b=x[23549];x[23549]=0;if((b|0)==1){break M}_d(d+464|0);o=d,q=yb(x[d+100>>2]),x[o+96>>2]=q;k=yb(x[d+104>>2]);T:{U:{while(1){b=x[d+96>>2];if(!Kb(b,k)){break T}b=le(d+76|0,b);x[23549]=0;e=R(143,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break L}V:{W:{if((e|0)!=538989377){break W}e=z[a+480190>>1];if(!Th(e)){break W}f=y[d+436|0]|y[d+437|0]<<8;h=f-1|0;v[d+436|0]=h;v[d+437|0]=h>>>8;if(!f){ub(b);break T}h=e+1|0;w[a+480190>>1]=h;x[23549]=0;e=O(839,b|0,d+68|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break K}if(!(e&x[d+68>>2]==1347240275)){break U}x[23549]=0;S(176,d+464|0,b|0,x[d+72>>2]);e=x[23549];x[23549]=0;X:{if((e|0)!=1){f=d+464|0;e=hc(d+48|0,f);ub(f);x[23549]=0;f=O(842,e|0,f|0)|0;n=x[23549];x[23549]=0;if((n|0)==1){break V}if(f){break X}ub(e);ub(b);break T}a=N()|0;break I}f=d+24|0;_e(f,2,l);x[23549]=0;P(208,d+36|0,f|0);f=x[23549];x[23549]=0;if((f|0)==1){break J}f=h&65535;h=d+36|0;zc(((f<<5)+a|0)+946304|0,h);tb(h);x[23549]=0;f=(D(f,104)+a|0)+484380|0;S(843,d+464|0,d+112|0,f|0);h=x[23549];x[23549]=0;if((h|0)==1){break V}Y:{if(!i){break Y}x[23549]=0;O(141,e|0,x[d+464>>2]+4|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break V}h=d+36|0;tM(h,z[d+504>>1]);x[23549]=0;U(205,h|0,f|0,e|0)|0;f=x[23549];x[23549]=0;if((f|0)!=1){break Y}break J}ub(e)}ub(b);yg(d+96|0);continue}break}break J}ub(b)}kd(d+100|0)}ub(c);yg(d+448|0);continue}break}a=N()|0;break H}a=N()|0;break H}a=N()|0;break H}a=N()|0;break H}a=N()|0;break H}a=N()|0;_d(d+464|0);break H}a=N()|0;break I}a=N()|0;break I}a=N()|0;ub(e)}ub(b);kd(d+100|0)}ub(c);kd(d+452|0);break b}a=N()|0;break b}a=N()|0;ub(c);kd(d+76|0);break b}a=N()|0;break b}f=1}ub(d+656|0);_d(j);ub(m)}db=d+720|0;return f|0}a=N()|0}ub(d+656|0)}_d(j);ub(m);Q(a|0);p()}function Vja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0;e=db+-64|0;db=e;wc(a);a:{b:{if(b>>>0<=2){F=e,G=ee(a),v[F+56|0]=G;Zb(a,2);b=Fg(a);v[e+58|0]=b;v[e+59|0]=b>>>8;b=pg(a);v[e+60|0]=b;v[e+61|0]=b>>>8;v[e+62|0]=b>>>16;v[e+63|0]=b>>>24;break b}Cq(a,e+56|0);if(b>>>0>5){break a}}v[e+57|0]=0}c:{o=d+484344|0;B=Vd(y[e+58|0]|y[e+59|0]<<8,1,1024);n=DB(o,B);if((n|0)==65535){break c}b=Yb(x[d+484344>>2],n);g=sf(x[b>>2],x[x[b+48>>2]+12>>2],0);f=z[d+480188>>1];w[e+8>>1]=f-1;w[e+44>>1]=y[e+56|0];C=z[Uc(e+8|0,e+44|0)>>1];h=C+1|0;b=h&65535;f=b>>>0<f>>>0?f:b;while(1){if((b|0)==(f|0)){d:{v[c+13|0]=y[e+57|0]>>>4;b=y[c+12|0];v[e+8|0]=0;b=(b|0)!=0;s=wu(e+44|0,h,e+8|0);e:while(1){if((l|0)==(B|0)){bc(s);break c}f:{f=Db(x[s>>2],0);g=y[f|0];g:{if(!g){x[23549]=0;f=R(192,a|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}f=f<<24>>24;if((f|0)<0){x[23549]=0;g=R(192,a|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}F=Db(x[s>>2],0),G=g,v[F|0]=G}v[e+8|0]=0;h:{i:{f=f&63;if(!f){break i}x[23549]=0;j=R(192,a|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break h}v[e+8|0]=j;j:{k:{switch(f-1|0){case 0:v[c+12|0]=0;v[e+40|0]=1;F=c,G=y[af(e+40|0,e+8|0)|0],v[F+14|0]=G;v[c+15|0]=0;break j;case 1:if(!j){break i}v[c+15|0]=j;v[c+12|0]=1;b=y[c+13|0];if(!b){break j}v[c+14|0]=D(D(b,j),15);break j;case 2:v[c+13|0]=j>>>4;if(j>>>0>=16){b=y[c+12|0];j=0;x[e+40>>2]=0;x[e+36>>2]=0;r=0;if(b){break g}break f}j=0;v[c+12|0]=0;x[e+40>>2]=0;x[e+36>>2]=0;r=0;if(b&1){break g}break f;case 3:r=0;x[e+40>>2]=0;x[e+36>>2]=0;if(b&1){break g}break f;case 5:if(!j){break i}f=(y[c+12|0]?15:14)+c|0;b=y[f|0];v[f|0]=b>>>0>=256-j>>>0?-1:b+j|0;break j;case 6:break k;default:break i}}if(!j){break i}f=(y[c+12|0]?15:14)+c|0;b=y[f|0];v[f|0]=b>>>0<=j+1>>>0?1:b-j|0}j=0;x[e+40>>2]=0;x[e+36>>2]=0;break g}j=0;x[e+40>>2]=0;x[e+36>>2]=0;r=0;if(b&1){break g}break f}break d}v[f|0]=g-1;j=0;x[e+40>>2]=0;x[e+36>>2]=0;r=0;if(!(b&1)){break f}}b=y[c+13|0];f=y[c+12|0];if(f){r=0;if(!b){break f}}l:{if(f){x[e+8>>2]=1;x[e+32>>2]=D(b,y[c+15|0])<<1;g=x[Re(e+8|0,e+32|0)>>2];break l}g=D(y[c+14|0],30)+30|0}b=255;f=0;k=0;while(1){m:{if(b){h=D(b,g);k=(h|0)/48|0;if(h-1536>>>0>=10752){break m}f=b}x[e+36>>2]=k;x[e+40>>2]=f;ke(e+36|0,32,255);r=1;x[e+8>>2]=1;F=c,G=x[Re(e+8|0,e+40|0)>>2],v[F+16|0]=G;break f}b=b-1|0;continue}}u=l-1|0;A=1;b=Yb(x[o>>2],n);b=$c(x[b>>2],x[x[b+48>>2]+12>>2],l,1);while(1){i=A&65535;if(i>>>0>C>>>0){if(r){b=e+8|0;me(Yb(x[o>>2],n),wh(Co(Fe(Be(b,17,y[e+36|0]),l),0)));me(Yb(x[o>>2],n),wh(Fe(Be(b,16,y[e+40|0]),l)))}if(j>>>0>=16){me(Yb(x[o>>2],n),BV(Fe(Be(e+8|0,20,j>>>4|224),l)))}b=j&15;if(b){me(Yb(x[o>>2],n),BV(Fe(Be(e+8|0,20,Vd((D(b,y[c+16|0])>>>0)/15&255,1,15)|96),l)))}l=l+1|0;b=0;continue e}n:{o:{p:{q:{r:{f=Db(x[s>>2],i);g=y[f|0];if(!g){x[23549]=0;f=R(192,a|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}f=f<<24>>24;if((f|0)<0){x[23549]=0;g=R(192,a|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}F=Db(x[s>>2],i),G=g,v[F|0]=G}E=1;m=f&255;if(m&64){x[23549]=0;f=R(192,a|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}v[b+1|0]=f;E=!f}if(!(m&32)){f=y[b|0];break r}x[23549]=0;f=R(192,a|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}v[b|0]=f;if((f-1&255)>>>0<=107){f=Am(f+24|0);v[b|0]=f;F=Ad(x[c>>2],i),G=f,v[F+1|0]=G;f=y[b|0];break o}if((f+127&255)>>>0<=107){f=Am((f&127)+24|0);F=Ad(x[c>>2],i),G=f,v[F|0]=G;v[b|0]=0;break q}if((f|0)!=255){break r}f=254;break p}v[f|0]=g-1;break n}if(f&255){break o}}if(!y[b+1|0]){f=0;break o}f=y[Ad(x[c>>2],i)+1|0];v[b+1|0]=0}v[b|0]=f}if(Tc(f)){F=Ad(x[c>>2],i),G=0,v[F+5|0]=G}v[e+32|0]=0;v[e+31|0]=0;v[e+30|0]=0;v[e+29|0]=0;v[e+28|0]=0;v[e+27|0]=0;if(m&16){v[b+2|0]=1;x[23549]=0;f=R(192,a|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}v[b+4|0]=f+2>>>2}q=0;k=0;s:{if(!(m&8)){break s}x[23549]=0;f=R(192,a|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}x[23549]=0;g=R(192,a|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}v[e+29|0]=g;t:{u:{switch(f-1|0){case 1:v[b|0]=255;break t;case 2:f=Ad(x[c>>2],i);v[b|0]=y[f+1|0];v[f+5|0]=0;break t;case 3:f=vu(g,y[c+16|0]);k=f?20:0;v[e+32|0]=k;v[e+29|0]=f?f|208:0;if(y[b|0]){break s}f=Ad(x[c>>2],i);v[b|0]=y[f+1|0];v[f+5|0]=0;break s;case 4:v[e+8|0]=1;F=e,G=vu(g,y[c+16|0]),v[F+26|0]=G;F=e,G=y[af(e+8|0,e+26|0)|0],v[F+29|0]=G;v[e+32|0]=15;F=Ad(x[c>>2],i),G=0,v[F+5|0]=G;k=20;break s;case 5:case 6:case 7:case 8:k=x[c>>2];v:{if(!l){break v}if((f|0)==y[Ad(k,i)+4|0]){break v}g=me(Yb(x[o>>2],n),Bm(Co(Fe(Be(e+8|0,20,(f+122|160)&255),u),i)));k=x[c>>2];if(!g){break v}F=Ad(k,i),G=f,v[F+4|0]=G}v[e+32|0]=10;f=Ad(k,i);if(!y[b|0]){v[b|0]=y[f+1|0]}v[f+5|0]=0;k=20;break s;case 9:k=20;v[e+32|0]=20;f=Ad(x[c>>2],i);g=y[f+5|0];v[e+29|0]=g?-98:-97;v[f+5|0]=g^1;break s;case 0:break u;default:break t}}v[b|0]=254}v[e+32|0]=0}w:{if(!(m&4)){f=0;break w}x[23549]=0;f=R(192,a|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}x[23549]=0;g=R(192,a|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}v[e+28|0]=g;x:{y:{switch(f-1|0){case 0:CB(e+8|0,g<<24>>24<<3,128);f=y[b|0];if(Tc(f)){F=b,G=Am(f+x[e+8>>2]|0),v[F|0]=G}f=35;v[e+31|0]=35;v[e+28|0]=y[e+12|0]^128;break w;case 1:g=vu(g,y[c+16|0]);v[e+28|0]=g;if(g){f=20;v[e+31|0]=20;v[e+28|0]=g|208;q=1;break w}f=0;break x;case 2:f=1;break x;case 3:case 4:q=1;g=AV(g,y[c+16|0],1);f=(f|0)==4?2:3;v[e+31|0]=f;v[e+28|0]=g;break w;case 5:f=4;if(!y[b|0]){F=b,G=y[Ad(x[c>>2],i)|0],v[F|0]=G;g=y[e+28|0]}g=AV(g&255,y[c+16|0],0);v[e+31|0]=4;v[e+28|0]=g;q=1;break w;case 6:F=b,G=Am(g+25|0),v[F|0]=G;v[e+28|0]=255;f=4;break x;case 7:case 8:case 9:z:{if(!l){break z}if((f|0)==y[Ad(x[c>>2],i)+2|0]){break z}if(!me(Yb(x[o>>2],n),Bm(Co(Fe(Be(e+8|0,20,(f-8|48)&255),u),i)))){break z}F=Ad(x[c>>2],i),G=f,v[F+2|0]=G}f=5;v[e+31|0]=5;F=e,G=BB(y[e+28|0],y[c+16|0]),v[F+28|0]=G;q=1;break w;case 10:h=y[c+16|0];f=18;v[e+31|0]=18;F=e,G=zV(g,h),v[F+28|0]=G;q=1;break w;case 11:g=vu(g,y[c+16|0]);v[e+28|0]=g;if(g){f=20;v[e+31|0]=20;v[e+28|0]=g|192;q=1;break w}f=0;v[e+31|0]=0;v[b|0]=254;q=1;break w;default:break y}}f=0;v[e+31|0]=0;break w}v[e+31|0]=f;q=1}t=1;A:{B:{h=0;C:{if(!(m&2)){break C}x[23549]=0;g=R(192,a|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}x[23549]=0;m=R(192,a|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}v[e+27|0]=m;D:{switch(g-1|0){case 0:case 1:h=11;g=yV(m,y[c+16|0],(g|0)==1);v[e+30|0]=11;v[e+27|0]=g;t=0;g=1;break A;case 2:g=y[c+16|0];h=18;v[e+30|0]=18;F=e,G=zV(m,g),v[F+27|0]=G;break B;case 3:case 4:case 5:E:{if(!l){break E}if((g|0)==y[Ad(x[c>>2],i)+3|0]){break E}if(!me(Yb(x[o>>2],n),Bm(Co(Fe(Be(e+8|0,20,(g-4|64)&255),u),i)))){break E}F=Ad(x[c>>2],i),G=g,v[F+3|0]=G}h=8;v[e+30|0]=8;F=e,G=BB(y[e+27|0],y[c+16|0]),v[F+27|0]=G;break B;case 6:v[e+30|0]=9;t=0;h=9;break C;case 7:case 8:h=29;g=yV(m,y[c+16|0],(g|0)==8);v[e+30|0]=29;v[e+27|0]=g;break B;case 9:h=27;v[e+30|0]=27;F=e,G=BB(m,y[c+16|0]),v[F+27|0]=G;break B;default:break D}}v[e+30|0]=0;h=0}g=0;break A}t=0;g=1}if(q){xV(b,l,z[d+480188>>1],f,e+28|0)}if(g){xV(b,l,z[d+480188>>1],h,e+27|0)}F:{G:{if(!E){break G}if(!Tc(y[b|0])){break G}if(!f){v[e+28|0]=255;v[e+31|0]=4;g=4;break F}g=4;if(!t|(f|0)==4){break F}v[e+27|0]=255;h=4;v[e+30|0]=4;g=4;break F}g=f}H:{if(y[b+2|0]!=1){break H}I:{if(!g){v[e+31|0]=13;v[e+28|0]=y[b+4|0];break I}if(h){break H}v[e+30|0]=13;v[e+27|0]=y[b+4|0]}v[b+2|0]=0}Gq(e+8|0,e+31|0,e+28|0,e+30|0,e+27|0);J:{if(y[b+2|0]){break J}f=y[e+31|0];if(!f){break J}v[b+2|0]=f;v[b+4|0]=y[e+28|0]}K:{if(k){Gq(e+8|0,e+30|0,e+27|0,e+32|0,e+29|0);L:{if(y[b+2|0]){break L}f=y[e+30|0];if(!f){break L}v[b+2|0]=f;v[b+4|0]=y[e+27|0]}k=e+29|0;h=y[e+32|0];break K}k=e+27|0;h=y[e+30|0];if(!h){break n}}v[b+3|0]=h;v[b+5|0]=y[k|0]}b=b+6|0;A=A+1|0;continue}}}}else{v[g+D(b,6)|0]=254;b=b+1|0;continue}break}a=N()|0;bc(s);Q(a|0);p()}db=e- -64|0;return n|0}function YX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,B=0;e=db-1456|0;db=e;wc(b);ap(a);a:{b:{c:{if(!pr(b,e+1432|0)){break c}if(!gE(e+1432|0)){break c}if(!c){j=1;break c}if(!Gl(x[b>>2],y[e+1450|0]|y[e+1451|0]<<8|(y[e+1452|0]<<16|y[e+1453|0]<<24))){break c}if(!Gl(x[b>>2],(y[e+1450|0]|y[e+1451|0]<<8|(y[e+1452|0]<<16|y[e+1453|0]<<24))+((y[e+1444|0]|y[e+1445|0]<<8)<<2)|0)){break c}Iv(a);w=e,B=Hv(),x[w+68>>2]=B;c=e+68|0;Gv(yh(x[a+4>>2])+32|0,c);or(c);m=x[yh(x[a+4>>2])+32>>2];x[e+1428>>2]=y[e+1446|0]|y[e+1447|0]<<8|(y[e+1448|0]<<16|y[e+1449|0]<<24);w=e,B=Ig(x[b>>2]),x[w+1168>>2]=B;x[e+1136>>2]=214748364;d=e+1168|0;w=e,B=D(x[Cb(d,e+1136|0)>>2],20),x[w+68>>2]=B;sn(m,x[Cb(e+1428|0,c)>>2]);Vb(d,0,256);s=Nb(e+1156|0);while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{j=(y[e+1444|0]|y[e+1445|0]<<8)>>>0<=t>>>0;if(!j){x[23549]=0;c=O(141,b|0,(y[e+1450|0]|y[e+1451|0]<<8|(y[e+1452|0]<<16|y[e+1453|0]<<24))+(t<<2)|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break r}if(!c){break h}c=x[b+8>>2];d=x[b>>2];x[23549]=0;c=U(142,d|0,c|0,4)|0;d=x[23549];x[23549]=0;if((d|0)==1){break r}if(!c){break h}x[23549]=0;c=R(143,b|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break q}x[23549]=0;d=O(141,b|0,c|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break q}if(!d){break h}x[23549]=0;d=O(144,b|0,e+1136|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break p}if(!d){break h}x[23549]=0;d=U(145,b|0,s|0,y[e+1148|0]|y[e+1149|0]<<8)|0;f=x[23549];x[23549]=0;if((f|0)==1){break p}if(!d){break h}f=x[s>>2];g=x[b>>2];x[23549]=0;d=y[e+1148|0]|y[e+1149|0]<<8;g=R(146,g|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break o}i=c+20|0;if(g>>>0<=i+(d<<3)>>>0){break h}c=d?f:0;f=y[e+1148|0]|y[e+1149|0]<<8;g=i+(f<<3)|0;d=0;i=y[e+1150|0]|y[e+1151|0]<<8;if(!(i&1)){while(1){if(d>>>0>=f>>>0){break d}if(!c){break h}f=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);i=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[23549]=0;f=ba(147,i|0,f|0,m|0,x[e+1428>>2])|0;i=x[23549];x[23549]=0;s:{if((i|0)==1){break s}if(!f){break h}x[23549]=0;f=O(141,b|0,g|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break s}if(!f){break h}f=ec(e+1128|0,Db(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)),y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24));i=x[f>>2];f=x[f+4>>2];x[23549]=0;hn(148,e+68|0,b,i,f);f=x[23549];x[23549]=0;if((f|0)==1){break n}if(x[e+72>>2]!=(y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))){break h}d=d+1|0;c=c+8|0;f=y[e+1148|0]|y[e+1149|0]<<8;continue}break}j=N()|0;break a}t:{if(i&4){if(!c){break h}d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[23549]=0;d=ba(147,f|0,d|0,m|0,x[e+1428>>2])|0;f=x[23549];x[23549]=0;if((f|0)==1){break m}if(!d){break h}n=Db(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));l=(y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))&-2;if(!l){break h}x[23549]=0;f=y[e+1154|0]|y[e+1155|0]<<8;d=O(141,b|0,g+(y[e+1152|0]|y[e+1153|0]<<8)|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break l}if(!d){break h}d=x[b+8>>2];g=x[b>>2];x[23549]=0;d=U(142,g|0,d|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-(y[e+1152|0]|y[e+1153|0]<<8)|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break l}if(!d){break h}x[23549]=0;S(149,e+48|0,b|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-(y[e+1152|0]|y[e+1153|0]<<8)|0);d=x[23549];x[23549]=0;if((d|0)==1){break b}d=e+48|0;k=nr(e+68|0,d);ub(d);r=0;i=0;while(1){g=0;u:{while(1){if((i&65535)>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break e}x[23549]=0;d=O(150,k|0,f+1|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break u}h=f&15;o=z[(h<<1)+26048>>1];v:{w:{if(o>>>0<=d>>>0){x[23549]=0;h=y[h+26096|0];q=O(150,k|0,h|0)|0;u=x[23549];x[23549]=0;if((u|0)==1){break u}d=q+(d-o<<h)|0;if((d|0)!=(f|0)){f=d&15;break v}x[23549]=0;d=O(150,k|0,4)|0;h=x[23549];x[23549]=0;if((h|0)==1){break u}if((d|0)==15){x[23549]=0;h=O(150,k|0,1)|0;d=x[23549];x[23549]=0;if((d|0)==1){break u}d=65535;if(!h){break w}break e}d=d+65520|0}if(d>>>0>65535){break v}}d=d&1?0-(d+1>>>1|0)|0:d>>>1|0;q=g+n|0;h=y[e+1150|0]|y[e+1151|0]<<8;x:{if(h&2){r=d+r|0;d=r;break x}d=h&512?d:d^32768}o=d>>>8|0;h=h&1024;v[q+1|0]=h?d:o;v[q|0]=h?o:d;g=g+2|0}if(g>>>0<l>>>0){continue}break}i=i+1|0;if(i>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break e}d=(i<<3)+c|0;g=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);l=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[23549]=0;g=ba(147,g|0,l|0,m|0,x[e+1428>>2])|0;l=x[23549];x[23549]=0;if((l|0)==1){break u}if(!g){break t}l=(y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24))&-2;if(!l){break t}n=Db(x[m>>2],y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));continue}break}j=T(30544)|0;if((eb|0)==($(30544)|0)){Y(j|0)|0;x[23549]=0;X(17);c=x[23549];x[23549]=0;if((c|0)!=1){break e}j=N()|0}ub(k);break a}if(!c){break h}d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[23549]=0;d=ba(147,f|0,d|0,m|0,x[e+1428>>2])|0;f=x[23549];x[23549]=0;if((f|0)==1){break k}if(!d){break h}r=Db(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));if((y[e+1152|0]|y[e+1153|0]<<8)>>>0>256){break h}n=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[e+1154|0]|y[e+1155|0]<<8;x[23549]=0;d=O(141,b|0,g|0)|0;g=x[23549];x[23549]=0;y:{z:{if((g|0)!=1){if(!d){break h}d=ec(e+40|0,e+1168|0,y[e+1152|0]|y[e+1153|0]<<8);g=x[d>>2];d=x[d+4>>2];x[23549]=0;hn(151,e+68|0,b,g,d);d=x[23549];x[23549]=0;if((d|0)==1){break z}d=y[e+1152|0]|y[e+1153|0]<<8;if(d>>>0>A[e+72>>2]){break h}g=x[b+8>>2];i=x[b>>2];x[23549]=0;d=U(142,i|0,g|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-d|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){break y}}j=N()|0;break a}j=N()|0;break a}if(!d){break h}x[23549]=0;S(149,e+48|0,b|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-(y[e+1152|0]|y[e+1153|0]<<8)|0);d=x[23549];x[23549]=0;if((d|0)==1){break f}d=e+48|0;k=nr(e+68|0,d);ub(d);l=0;i=0;while(1){g=0;A:{while(1){if((l&65535)>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break g}x[23549]=0;d=O(150,k|0,f+1|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break A}h=f&7;o=y[h+26080|0];B:{C:{if(o>>>0<=d>>>0){x[23549]=0;h=y[h+26088|0];q=O(150,k|0,h|0)|0;u=x[23549];x[23549]=0;if((u|0)==1){break A}d=q+(d-o<<h)|0;if((d|0)!=(f|0)){f=d&7;break B}x[23549]=0;d=O(150,k|0,3)|0;h=x[23549];x[23549]=0;if((h|0)==1){break A}if((d|0)==7){x[23549]=0;h=O(150,k|0,1)|0;d=x[23549];x[23549]=0;if((d|0)==1){break A}d=255;if(!h){break C}break g}d=d+248|0}if(d>>>0>255){break B}}d=y[(e+1168|0)+d|0];h=d+i|0;q=d;d=(y[e+1150|0]|y[e+1151|0]<<8)&2;v[g+r|0]=d?h:q;i=d?h:i;g=g+1|0}if(g>>>0<n>>>0){continue}break}l=l+1|0;if(l>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break g}d=(l<<3)+c|0;g=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);n=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[23549]=0;g=ba(147,g|0,n|0,m|0,x[e+1428>>2])|0;n=x[23549];x[23549]=0;if((n|0)==1){break A}if(!g){break j}n=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);r=Db(x[m>>2],y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));continue}break}j=T(30544)|0;if((eb|0)==($(30544)|0)){Y(j|0)|0;x[23549]=0;X(17);c=x[23549];x[23549]=0;if((c|0)!=1){break g}j=N()|0}ub(k);break a}ub(k);break h}ge(e+24|0,x[m>>2],x[m+4>>2]);Ng(e+32|0,x[e+24>>2],x[e+28>>2]);b=Xd(e+16|0);x[23549]=0;c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;b=Xf(152,e+68|0,x[e+32>>2],x[e+36>>2],e+8|0);c=x[23549];x[23549]=0;if((c|0)==1){break i}Zc(yh(x[a+4>>2])+12|0,b);ub(b);break h}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}ub(k);break h}j=N()|0;break a}oe(s);break c}ub(k);break d}j=N()|0;break a}ub(k)}t=t+1|0;continue}}db=e+1456|0;return j|0}j=N()|0}oe(s);Q(j|0);p()}function aL(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;k=db-336|0;db=k;n=h;p=i&65535;o=d;m=e&65535;u=(e^i)&-2147483648;s=i>>>16&32767;q=e>>>16&32767;a:{b:{if(s-32767>>>0>4294934529&q-32767>>>0>=4294934530){break b}j=e&2147483647;if(!(!d&(j|0)==2147418112?!(b|c):j>>>0<2147418112)){r=d;u=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){r=h;u=i|32768;b=f;c=g;break a}if(!(b|d|(j^2147418112|c))){if(!(f|h|(e^2147418112|g))){b=0;c=0;u=2147450880;break a}u=u|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){b=0;c=0;break a}if(!(b|d|(c|j))){b=!(f|h|(e|g));r=b?0:r;u=b?2147450880:u;b=0;c=0;break a}if(!(f|h|(e|g))){u=u|2147418112;b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){d=!(m|o);i=d;j=d?b:o;d=d<<6;i=G(i?c:m);d=d+((i|0)==32?G(j)+32|0:i)|0;zf(k+320|0,b,c,o,m,d-15|0);v=16-d|0;o=x[k+328>>2];m=x[k+332>>2];c=x[k+324>>2];b=x[k+320>>2]}if(e>>>0>65535){break b}d=!(n|p);h=d;i=d?f:n;d=d<<6;h=G(h?g:p);d=d+((h|0)==32?G(i)+32|0:h)|0;zf(k+304|0,f,g,n,p,d-15|0);v=(d+v|0)-16|0;n=x[k+312>>2];p=x[k+316>>2];f=x[k+304>>2];g=x[k+308>>2]}e=p|65536;C=e;D=n;d=n;j=e<<15|d>>>17;e=d<<15|g>>>17;d=e;i=0-d|0;h=j;j=1963258675-(j+((d|0)!=0)|0)|0;nf(k+288|0,d,h,0,0,i,j,0,0);d=x[k+296>>2];nf(k+272|0,0-d|0,0-(x[k+300>>2]+((d|0)!=0)|0)|0,0,0,i,j,0,0);d=x[k+280>>2];i=d<<1|x[k+276>>2]>>>31;d=x[k+284>>2]<<1|d>>>31;nf(k+256|0,i,d,0,0,e,h,0,0);j=x[k+264>>2];nf(k+240|0,i,d,0,0,0-j|0,0-(x[k+268>>2]+((j|0)!=0)|0)|0,0,0);i=x[k+248>>2];j=i<<1|x[k+244>>2]>>>31;d=x[k+252>>2]<<1|i>>>31;nf(k+224|0,j,d,0,0,e,h,0,0);i=x[k+232>>2];nf(k+208|0,j,d,0,0,0-i|0,0-(x[k+236>>2]+((i|0)!=0)|0)|0,0,0);d=x[k+216>>2];i=d<<1|x[k+212>>2]>>>31;d=x[k+220>>2]<<1|d>>>31;nf(k+192|0,i,d,0,0,e,h,0,0);j=x[k+200>>2];nf(k+176|0,i,d,0,0,0-j|0,0-(x[k+204>>2]+((j|0)!=0)|0)|0,0,0);i=e;e=x[k+184>>2];d=h;n=e<<1|x[k+180>>2]>>>31;h=n-1|0;e=(x[k+188>>2]<<1|e>>>31)-!n|0;nf(k+160|0,i,d,0,0,h,e,0,0);d=h;nf(k+144|0,f<<15,g<<15|f>>>17,0,0,d,e,0,0);t=k+112|0;z=x[k+168>>2];h=x[k+172>>2];n=x[k+160>>2];i=x[k+152>>2];l=n+i|0;p=x[k+164>>2];j=p+x[k+156>>2]|0;j=i>>>0>l>>>0?j+1|0:j;i=j;j=(p|0)==(j|0)&l>>>0<n>>>0|j>>>0<p>>>0;p=j+z|0;j=j>>>0>p>>>0?h+1|0:h;n=!i&l>>>0>1|(i|0)!=0;h=n+p|0;j=n>>>0>h>>>0?j+1|0:j;nf(t,d,e,0,0,0-h|0,0-(((h|0)!=0)+j|0)|0,0,0);nf(k+128|0,1-l|0,0-((l>>>0>1)+i|0)|0,0,0,d,e,0,0);K=(q-s|0)+v|0;e=x[k+116>>2];t=e;d=x[k+112>>2];j=e<<1|d>>>31;n=d<<1;q=j;d=j;h=x[k+140>>2];B=h;e=x[k+136>>2];j=h<<1|e>>>31;i=e<<1|x[k+132>>2]>>>31;h=i+n|0;d=d+j|0;d=h>>>0<i>>>0?d+1|0:d;e=d;d=d-(h>>>0<13927)|0;y=d;z=d;l=0;j=m|65536;L=j;M=o;d=o;j=j<<1|d>>>31;O=d<<1;P=j;F=j;d=yka(y,l,j,0);j=hb;H=d;w=j;v=b<<1;d=c<<1|b>>>31;s=d;j=0;p=j;i=h-13927|0;y=(e|0)==(y|0)&i>>>0<h>>>0|e>>>0>y>>>0;e=(e|0)==(q|0)&h>>>0<n>>>0|e>>>0<q>>>0;d=x[k+120>>2];h=x[k+124>>2]<<1|d>>>31;d=d<<1|t>>>31;j=h;l=B>>>31|0;d=l+d|0;j=d>>>0<l>>>0?j+1|0:j;h=d;d=d+e|0;l=h>>>0>d>>>0?j+1|0:j;e=d;d=d+y|0;l=e>>>0>d>>>0?l+1|0:l;e=d-1|0;y=l-!d|0;q=0;j=yka(s,p,y,q);d=j+H|0;h=hb+w|0;h=d>>>0<j>>>0?h+1|0:h;t=(w|0)==(h|0)&d>>>0<H>>>0|h>>>0<w>>>0;j=0;B=e;N=c>>>31|0;E=N|o<<1;w=0;e=yka(e,j,E,w);o=e+d|0;j=hb+h|0;l=0;j=e>>>0>o>>>0?j+1|0:j;n=j;d=(j|0)==(h|0)&d>>>0>o>>>0|h>>>0>j>>>0;e=d;d=d+t|0;l=e>>>0>d>>>0?1:l;e=yka(F,p,y,q);d=e+d|0;j=hb+l|0;t=d;d=d>>>0<e>>>0?j+1|0:j;e=yka(F,p,B,w);m=hb;h=e;e=yka(E,w,y,q);l=h+e|0;j=hb+m|0;j=e>>>0>l>>>0?j+1|0:j;e=j;j=(m|0)==(j|0)&h>>>0>l>>>0|j>>>0<m>>>0;m=t+e|0;d=d+j|0;d=m>>>0<e>>>0?d+1|0:d;t=m;m=d;e=0;d=e+o|0;j=l+n|0;j=d>>>0<e>>>0?j+1|0:j;e=j;h=(j|0)==(n|0)&d>>>0<o>>>0|j>>>0<n>>>0;j=m;l=h;h=h+t|0;j=l>>>0>h>>>0?j+1|0:j;I=h;l=j;t=d;m=d;o=e;H=i;d=yka(i,0,E,w);h=hb;e=d;i=yka(z,r,s,r);d=d+i|0;j=hb+h|0;j=d>>>0<i>>>0?j+1|0:j;i=(h|0)==(j|0)&d>>>0<e>>>0|h>>>0>j>>>0;h=j;J=v&-2;e=yka(B,w,J,0);n=e+d|0;j=hb+j|0;j=e>>>0>n>>>0?j+1|0:j;e=j;d=(j|0)==(h|0)&d>>>0>n>>>0|h>>>0>j>>>0;h=0;i=d+i|0;d=(i>>>0<d>>>0?1:h)+o|0;j=l;m=i+m|0;d=m>>>0<i>>>0?d+1|0:d;i=d;d=(d|0)==(o|0)&m>>>0<t>>>0|d>>>0<o>>>0;h=d;d=d+I|0;j=h>>>0>d>>>0?j+1|0:j;Q=d;t=j;d=yka(F,p,H,r);I=hb;F=d;h=yka(y,q,J,r);d=d+h|0;j=hb+I|0;o=d;p=yka(z,r,E,w);l=d+p|0;h=d>>>0<h>>>0?j+1|0:j;d=h+hb|0;d=l>>>0<p>>>0?d+1|0:d;q=l;j=yka(s,r,B,w);p=l+j|0;l=hb+d|0;l=j>>>0>p>>>0?l+1|0:l;B=0;E=(d|0)==(l|0)&p>>>0<q>>>0|d>>>0>l>>>0;j=(h|0)==(I|0)&o>>>0<F>>>0|h>>>0<I>>>0;d=(d|0)==(h|0)&o>>>0>q>>>0|d>>>0<h>>>0;d=d+j|0;d=d+E|0;h=l;q=h+m|0;j=(d|B)+i|0;j=h>>>0>q>>>0?j+1|0:j;o=j;d=(i|0)==(j|0)&m>>>0>q>>>0|i>>>0>j>>>0;j=t;h=d;d=d+Q|0;j=h>>>0>d>>>0?j+1|0:j;B=d;i=j;d=yka(z,r,J,r);z=hb;m=d;h=yka(s,r,H,r);d=d+h|0;j=hb+z|0;j=d>>>0<h>>>0?j+1|0:j;t=0;h=(j|0)==(z|0)&d>>>0<m>>>0|j>>>0<z>>>0;m=j;d=j+n|0;j=(h|t)+e|0;j=d>>>0<m>>>0?j+1|0:j;h=j;m=(e|0)==(j|0)&d>>>0<n>>>0|e>>>0>j>>>0;j=p;p=0;n=p+d|0;l=h+j|0;j=0;l=n>>>0<p>>>0?l+1|0:l;d=(h|0)==(l|0)&d>>>0>n>>>0|h>>>0>l>>>0;e=d;d=d+m|0;j=(e>>>0>d>>>0?1:j)+o|0;l=i;e=d;d=d+q|0;j=e>>>0>d>>>0?j+1|0:j;e=j;h=(o|0)==(j|0)&d>>>0<q>>>0|j>>>0<o>>>0;i=h;h=h+B|0;l=i>>>0>h>>>0?l+1|0:l;i=l;c:{if((l|0)==131071|l>>>0<131071){M=O|N;L=w|P;nf(k+80|0,d,e,h,i,f,g,D,C);l=x[k+84>>2];p=l;j=b<<17;n=0;m=x[k+88>>2];c=n-m|0;b=x[k+80>>2];l=(l|b)!=0;o=c-l|0;m=(j-(x[k+92>>2]+(m>>>0>n>>>0)|0)|0)-(c>>>0<l>>>0)|0;n=0-b|0;p=0-(((b|0)!=0)+p|0)|0;b=K+16382|0;break c}d=(e&1)<<31|d>>>1;e=h<<31|e>>>1;h=(i&1)<<31|h>>>1;i=i>>>1|0;nf(k+96|0,d,e,h,i,f,g,D,C);o=x[k+100>>2];s=o;v=x[k+104>>2];n=0-v|0;l=x[k+96>>2];m=(o|l)!=0;o=n-m|0;m=((b<<16)-(x[k+108>>2]+(p>>>0<v>>>0)|0)|0)-(m>>>0>n>>>0)|0;n=0-l|0;p=0-(((l|0)!=0)+s|0)|0;v=b;s=c;b=K+16383|0}if((b|0)>=32767){u=u|2147418112;b=0;c=0;break a}d:{if((b|0)>0){l=m<<1|o>>>31;o=o<<1|p>>>31;m=l;v=h;s=i&65535|b<<16;l=p<<1|n>>>31;i=n<<1;break d}if((b|0)<=-113){b=0;c=0;break a}em(k- -64|0,d,e,h,i,1-b|0);zf(k+48|0,v,s,M,L,b+112|0);d=x[k+64>>2];e=x[k+68>>2];v=x[k+72>>2];s=x[k+76>>2];nf(k+32|0,f,g,D,C,d,e,v,s);b=x[k+40>>2];c=x[k+56>>2];l=x[k+36>>2];o=b<<1|l>>>31;n=c-o|0;m=x[k+60>>2]-((x[k+44>>2]<<1|b>>>31)+(c>>>0<o>>>0)|0)|0;b=x[k+32>>2];h=l<<1|b>>>31;j=b<<1;i=x[k+52>>2];c=x[k+48>>2];b=(h|0)==(i|0)&j>>>0>c>>>0|h>>>0>i>>>0;o=n-b|0;m=m-(b>>>0>n>>>0)|0;l=i-((c>>>0<j>>>0)+h|0)|0;i=c-j|0}b=i;nf(k+16|0,f,g,D,C,3,0,0,0);nf(k,f,g,D,C,5,0,0,0);c=0;h=l+c|0;j=d&1;b=b+j|0;h=i>>>0>b>>>0?h+1|0:h;i=b;g=(g|0)==(h|0)&b>>>0>f>>>0|g>>>0<h>>>0;l=m;b=(c|0)==(h|0)&b>>>0<j>>>0|c>>>0>h>>>0;f=b+o|0;l=b>>>0>f>>>0?l+1|0:l;j=e;b=(l|0)==(C|0);b=b&(f|0)==(D|0)?g:b&f>>>0>D>>>0|l>>>0>C>>>0;c=b;b=b+d|0;j=c>>>0>b>>>0?j+1|0:j;c=j;d=(e|0)==(j|0)&b>>>0<d>>>0|e>>>0>j>>>0;j=s;e=d;d=d+v|0;j=e>>>0>d>>>0?j+1|0:j;g=d;e=x[k+20>>2];m=(e|0)==(h|0)&A[k+16>>2]<i>>>0|e>>>0<h>>>0;e=x[k+28>>2];d=x[k+24>>2];e=j>>>0<2147418112&((d|0)==(f|0)&(e|0)==(l|0)?m:(e|0)==(l|0)&d>>>0<f>>>0|e>>>0<l>>>0);d=c;m=e;e=b+e|0;d=m>>>0>e>>>0?d+1|0:d;b=(c|0)==(d|0)&b>>>0>e>>>0|c>>>0>d>>>0;c=b;b=b+g|0;j=c>>>0>b>>>0?j+1|0:j;g=b;c=x[k+4>>2];h=(c|0)==(h|0)&A[k>>2]<i>>>0|c>>>0<h>>>0;c=x[k+12>>2];b=x[k+8>>2];b=j>>>0<2147418112&((b|0)==(f|0)&(c|0)==(l|0)?h:(c|0)==(l|0)&b>>>0<f>>>0|c>>>0<l>>>0);c=b;b=b+e|0;l=c>>>0>b>>>0?d+1|0:d;c=l;e=(d|0)==(l|0)&b>>>0<e>>>0|d>>>0>l>>>0;d=j;f=e;e=e+g|0;d=f>>>0>e>>>0?d+1|0:d;r=e|r;u=d|u}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=r;x[a+12>>2]=u;db=k+336|0}function lga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0;d=db-1312|0;db=d;wc(b);e=db-16|0;db=e;mS(e+8|0,d+204|0);h=x[e+12>>2];lc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);i=x[e+4>>2];if((i|0)==(h|0)){Zb(b,x[e+12>>2])}db=e+16|0;a:{if((h|0)!=(i|0)){break a}if(!oS(d+204|0)){break a}if(!Lb(x[b>>2],x[b+8>>2],Qc(nS(y[d+1308|0]|y[d+1309|0]<<8|(y[d+1310|0]<<16|y[d+1311|0]<<24)),hb))){break a}if(!c){m=1;break a}wc(b);b=le(d+204|0,b);x[23549]=0;P(582,d+192|0,b|0);e=x[23549];x[23549]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){ub(b);x[23549]=0;S(583,d+180|0,d+192|0,1196314451);b=x[23549];x[23549]=0;if((b|0)==1){break i}x[23549]=0;S(583,d+168|0,d+192|0,1280331091);b=x[23549];x[23549]=0;if((b|0)==1){break h}if(qc(x[d+180>>2],x[d+184>>2])){break b}if(!qc(x[d+168>>2],x[d+172>>2])){break g}break b}c=N()|0;ub(b);break d}c=N()|0;break e}c=N()|0;break f}x[23549]=0;P(235,a|0,1);b=x[23549];x[23549]=0;j:{k:{l:{m:{if((b|0)!=1){Dg(a);x[a+480188>>2]=4;x[a+480208>>2]=25231360;C=d,E=yb(x[d+168>>2]),x[C+48>>2]=E;k=c&2;f=yb(x[d+172>>2]);n:{o:{while(1){e=x[d+48>>2];if(!Kb(e,f)){break o}b=z[a+480190>>1];if(!Th(b)){break o}b=b+1|0;w[a+480190>>1]=b;x[23549]=0;b=D(b&65535,104)+a|0;h=b+484380|0;P(266,h|0,1);i=x[23549];x[23549]=0;p:{q:{if((i|0)!=1){x[23549]=0;i=O(584,e|0,d+204|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break q}if(!i){break c}if(Tt(d+204|0)){break p}break c}c=N()|0;break j}c=N()|0;break j}x[23549]=0;i=O(54,d+156|0,d+204|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break n}zc(((z[a+480190>>1]<<5)+a|0)+946304|0,i);tb(i);i=y[d+240|0]|y[d+241|0]<<8|(y[d+242|0]<<16|y[d+243|0]<<24);x[h>>2]=i;x[b+484388>>2]=i;x[b+484384>>2]=y[d+236|0]|y[d+237|0]<<8|(y[d+238|0]<<16|y[d+239|0]<<24);i=b+484414|0;w[i>>1]=z[i>>1]|2;w[b+484410>>1]=255;r:{if(k){b=Xc(d+16|0,8,1,0,0);x[23549]=0;U(205,b|0,h|0,e|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break r}}yg(d+48|0);continue}break}c=N()|0;break j}C=d,E=yb(x[d+180>>2]),x[C+152>>2]=E;n=a+484344|0;o=c&1;q=a+484360|0;A=yb(x[d+184>>2]);r=a+484380|0;s=a+946304|0;c=1;m=1;while(1){s:{t:{u:{v:{w:{x:{b=x[d+152>>2];if(!Kb(b,A)){break x}if(!(c&1)){x[23549]=0;c=R(261,q|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break w}if(!c){break x}}Dc(Wb(x[a+484360>>2],y[a+484376|0]));x[23549]=0;c=O(585,b|0,d+204|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break v}if(!(c&!(y[d+1290|0]|y[d+1291|0]<<8))|(y[d+1292|0]|y[d+1293|0]<<8|(y[d+1294|0]<<16|y[d+1295|0]<<24))-5>>>0<4294967292){break c}c=y[a+484376|0];e=x[a+484360>>2];x[23549]=0;S(5,d+48|0,5,d+204|0);h=x[23549];x[23549]=0;if((h|0)==1){break k}x[23549]=0;P(262,Wb(e,c)|0,d+48|0);c=x[23549];x[23549]=0;if((c|0)==1){break l}tb(d+48|0);y:{if(o){x[23549]=0;S(176,d+48|0,b|0,y[d+1300|0]|y[d+1301|0]<<8|(y[d+1302|0]<<16|y[d+1303|0]<<24));b=x[23549];x[23549]=0;if((b|0)!=1){break y}c=N()|0;break j}x[23549]=0;b=R(160,d+112|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break m}SD(d+48|0,b)}b=d+48|0;l=hc(d+132|0,b);ub(b);if(!o){ub(d+112|0)}Vb(d+48|0,0,64);c=1;z:{A:{B:{while(1){if((c|0)==32){break B}b=(D(c,34)+d|0)+170|0;e=b+32|0;Nm(d,e);C:{D:{if(!y[x[d>>2]]){break D}h=y[b- -64|0];if(h>>>0>15){break A}b=y[b+65|0];if(b>>>0>64){break A}if(!Tt(e)){break A}i=b<<2;k=h<<4;h=0;b=1;E:{while(1){f=b&65535;e=z[a+480190>>1];if(f>>>0>e>>>0){break E}x[23549]=0;S(481,d+16|0,x[d>>2],x[d+4>>2]);e=x[23549];x[23549]=0;if((e|0)==1){break C}e=db-32|0;db=e;g=d+16|0;ze(e+24|0,g);kS(e+16|0,((f<<5)+a|0)+946304|0);j=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=j;j=jA(x[e+24>>2],x[e+28>>2],e+8|0);db=e+32|0;tb(g);F:{G:{if(j){break G}C=_b(d+48|0,c),E=b,w[C>>1]=E;e=D(f,104)+a|0;f=e+484410|0;g=z[f>>1];if((g|0)==255){break F}h=b;if(y[e+484417|0]!=(k&255)){break G}if((g|0)==(i|0)){break F}}b=b+1|0;continue}break}v[e+484417|0]=k;w[f>>1]=i;break D}h=h&65535;if(!h){break D}if(!Th(e)){break D}b=e+1|0;w[a+480190>>1]=b;C=_b(d+48|0,c),E=b,w[C>>1]=E;b=D(z[a+480190>>1],104)+r|0;vm(b);e=D(h,104)+r|0;f=ro(b,e);w[b+30>>1]=i;v[b+37|0]=k;eT(f,e);e=(h<<5)+s|0;h=x[e+4>>2];b=(z[a+480190>>1]<<5)+s|0;x[b>>2]=x[e>>2];x[b+4>>2]=h;h=x[e+28>>2];x[b+24>>2]=x[e+24>>2];x[b+28>>2]=h;h=x[e+20>>2];x[b+16>>2]=x[e+16>>2];x[b+20>>2]=h;h=x[e+12>>2];x[b+8>>2]=x[e+8>>2];x[b+12>>2]=h}c=c+1|0;continue}break}break u}k=0;x[d+40>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;e=64;i=65535;B=y[d+1292|0]|y[d+1293|0]<<8;h=0;H:while(1){I:{if(h){break I}b=x[l>>2];x[23549]=0;b=U(142,b|0,x[d+140>>2],1)|0;c=x[23549];x[23549]=0;if((c|0)==1){break z}if(b){break I}c=i;b=e;break t}b=e+1|0;J:{if(e>>>0<63){e=b;break J}x[23549]=0;i=O(351,n|0,64)|0;c=x[23549];x[23549]=0;if((c|0)==1){break z}c=65535;if((i|0)==65535){break t}b=y[a+484376|0];c=x[a+484360>>2];e=0;x[23549]=0;P(479,Wb(c,b)|0,i|0);b=x[23549];x[23549]=0;if((b|0)==1){break z}}b=0;c=Yb(x[n>>2],i&65535);c=$c(x[c>>2],x[x[c+48>>2]+12>>2],e,0);while(1){if((b|0)==(B|0)){continue H}f=(d+16|0)+D(b,7)|0;g=y[f+6|0];K:{if(g){v[f+6|0]=g-1;g=y[f+4|0]|y[f+5|0]<<8;v[c+4|0]=g;v[c+5|0]=g>>>8;f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[c|0]=f;v[c+1|0]=f>>>8;v[c+2|0]=f>>>16;v[c+3|0]=f>>>24;h=h-1|0;break K}g=x[l>>2];x[23549]=0;g=U(142,g|0,x[d+140>>2],1)|0;j=x[23549];x[23549]=0;if((j|0)==1){break u}if(!g){break K}if(x[d+140>>2]==(y[d+1296|0]|y[d+1297|0]<<8|(y[d+1298|0]<<16|y[d+1299|0]<<24))){k=Wb(x[a+484360>>2],y[a+484376|0]);$e(k,GB(x[k>>2],x[k+4>>2]));k=e}x[23549]=0;g=R(192,l|0)|0;j=x[23549];x[23549]=0;L:{if((j|0)!=1){g=g<<24>>24;if((g|0)>=0){break L}g=g&127;v[f+6|0]=g;j=y[f+4|0]|y[f+5|0]<<8;v[c+4|0]=j;v[c+5|0]=j>>>8;f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[c|0]=f;v[c+1|0]=f>>>8;v[c+2|0]=f>>>16;v[c+3|0]=f>>>24;h=g+h|0;break K}break u}if((g-1&255)>>>0<=35){v[c|0]=g+48}x[23549]=0;g=R(192,l|0)|0;j=x[23549];x[23549]=0;M:{N:{if((j|0)!=1){g=g<<24>>24;C=c,E=y[_b(d+48|0,g&31)|0],v[C+1|0]=E;if((g|0)>=0){break N}v[c+3|0]=y[f+3|0];v[c+5|0]=y[f+5|0];break M}break u}x[23549]=0;P(249,d|0,l|0);g=x[23549];x[23549]=0;O:{if((g|0)!=1){g=y[d|0];if(g>>>0>19){break M}t=g<<1;u=y[t+27008|0];v[c+3|0]=u;j=y[fd(d)|0];v[c+5|0]=j;if((u|0)!=16|j>>>0<32){break O}v[c+3|0]=17;break M}break u}if(819137>>>g&1){break M}v[c+5|0]=y[t+27009|0]|j&15}g=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[f|0]=g;v[f+1|0]=g>>>8;v[f+2|0]=g>>>16;v[f+3|0]=g>>>24;g=y[c+4|0]|y[c+5|0]<<8;v[f+4|0]=g;v[f+5|0]=g>>>8}c=c+6|0;b=b+1|0;continue}}}m=0;break s}break u}oj(q,0);x[23549]=0;b=O(1,d+204|0,6408)|0;c=x[23549];x[23549]=0;P:{if((c|0)!=1){zb(a+1298344|0,b);tb(b);x[23549]=0;b=O(1,d+48|0,6710)|0;c=x[23549];x[23549]=0;if((c|0)==1){break P}zb(a+1298356|0,b);tb(b);x[a+1298404>>2]=5;m=1;break b}c=N()|0;break j}c=N()|0;break j}c=N()|0;break j}c=N()|0;break j}c=N()|0;ub(l);break j}c=c&65535;if(!(!((k|0)!=0|b>>>0<63)|(c|0)==65535)){me(Yb(x[n>>2],c),wh(Fe(Be(d,14,k&255),b)))}c=32}ub(l);if(c>>>0<32){break b}yg(d+152|0);c=0;continue}}c=N()|0;break j}c=N()|0;break j}c=N()|0;break j}c=N()|0;tb(d+48|0);break j}c=N()|0}kd(d+168|0)}kd(d+180|0)}_d(d+192|0)}Q(c|0);p()}m=0}kd(d+168|0);kd(d+180|0);_d(d+192|0)}db=d+1312|0;return m|0}function Zja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=db-272|0;db=e;wc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if(!EV(b,e+206|0)){break p}if(!FV(e+206|0)){break p}if(!c){d=1;break p}Bd(a,131072);d=db-16|0;db=d;h=e+112|0;f=Tb(d+4|0,3893);ad(h,f);tb(f);db=d+16|0;x[23549]=0;S(293,e+156|0,h|0,e+210|0);d=x[23549];x[23549]=0;q:{if((d|0)!=1){d=e+156|0;zb(a+1298344|0,d);tb(d);h=e+112|0;Ab(h);f=Tb(d,10990);zb(a+1298356|0,f);tb(f);x[a+1298404>>2]=5;OB(h,3,e+219|0);Bc(d,h);zb(a+1298308|0,d);tb(d);f=e+92|0;nj(f,3,e+249|0);Bc(h,f);x[23549]=0;S(11,d|0,5,h|0);d=x[23549];x[23549]=0;if((d|0)==1){break b}d=e+156|0;zb(a+1298320|0,d);tb(d);tb(e+112|0);d=Eq(d);o=d,q=Vd(y[e+269|0],1,31),x[o+12>>2]=q;o=d,q=Vd(y[e+270|0],1,12)-1|0,x[o+16>>2]=q;x[d+20>>2]=y[e+271|0];h=a+1298408|0;Dc(h);CV(h,d);g=e+120|0;h=Nb(e+144|0);r:{s:{t:{while(1){d=x[b+8>>2];f=x[b>>2];x[23549]=0;d=U(142,f|0,d|0,8)|0;f=x[23549];x[23549]=0;u:{v:{w:{x:{y:{if((f|0)!=1){if(!d){break r}x[23549]=0;P(294,b|0,e+56|0);d=x[23549];x[23549]=0;if((d|0)==1){break y}d=x[e+60>>2];z:{l=y[e+210|0];switch(l-3|0){case 1:break x;case 0:break z;default:break w}}f=2;if(x[e+56>>2]!=1431389523){break v}break u}b=N()|0;break c}b=N()|0;break c}f=4;if(x[e+56>>2]!=1431389523){break v}break u}f=0;if(l>>>0>7){break u}}d=x[e+56>>2]==1146113363?-1:d;f=0}l=x[e+60>>2];x[e+112>>2]=x[e+56>>2];x[e+116>>2]=l;x[23549]=0;S(176,e+92|0,b|0,d|0);d=x[23549];x[23549]=0;if((d|0)==1){break t}hc(g,e+92|0);x[23549]=0;P(295,h|0,e+112|0);d=x[23549];x[23549]=0;if((d|0)==1){break s}Gd(e+112|0);ub(e+92|0);x[23549]=0;O(174,b|0,f|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){continue}break}b=N()|0;break c}b=N()|0;break c}b=N()|0;Gd(e+112|0);ub(e+92|0);break c}x[23549]=0;l=R(160,e+112|0)|0;b=x[23549];x[23549]=0;A:{B:{C:{if((b|0)!=1){x[23549]=0;S(296,e+92|0,h|0,1431389523);b=x[23549];x[23549]=0;if((b|0)==1){break C}d=e+92|0;b=Zc(l,d);ub(d);w[e+90>>1]=0;w[e+88>>1]=65534;if(y[e+210|0]<3){break A}x[23549]=0;d=R(180,b|0)|0;f=x[23549];x[23549]=0;if((f|0)!=1){break B}break e}b=N()|0;break c}b=N()|0;break d}w[e+90>>1]=d;if(y[e+210|0]<4){break A}x[23549]=0;d=R(180,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break e}w[e+88>>1]=y[e+210|0]==4?d?d:-2:d}d=y[a+484376|0];f=x[a+484360>>2];x[23549]=0;g=R(188,b|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break e}x[23549]=0;S(227,Wb(f,d)|0,b|0,g>>>1|0);d=x[23549];x[23549]=0;if((d|0)==1){break e}d=Wb(x[a+484360>>2],y[a+484376|0]);d=GB(x[d>>2],x[d+4>>2]);Wf(e+90|0,d);Wf(e+88|0,d);x[23549]=0;S(296,e+92|0,h|0,1414807888);d=x[23549];x[23549]=0;if((d|0)==1){break h}d=e+92|0;b=Zc(b,d);ub(d);d=x[b>>2];x[23549]=0;d=R(164,d|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break e}if(!(c&1)|d^1){break q}x[23549]=0;P(297,b|0,e|0);d=x[23549];x[23549]=0;if((d|0)==1){break i}o=a,q=Vd(y[e+2|0],1,32)+1|0,w[o+480188>>1]=q;x[23549]=0;d=O(204,e+76|0,z[e>>1])|0;f=x[23549];x[23549]=0;if((f|0)==1){break j}o=e,q=yb(x[d>>2]),x[o+36>>2]=q;g=yb(x[d+4>>2]);D:{E:{while(1){i=x[e+36>>2];if(!Kb(i,g)){f=z[a+480188>>1];x[23549]=0;f=O(298,e+92|0,f|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){g=Wb(x[a+484360>>2],y[a+484376|0]);g=vl(x[g>>2],x[g+4>>2]);x[23549]=0;k=a+484344|0;P(211,k|0,g|0);g=x[23549];x[23549]=0;if((g|0)==1){break g}g=Wb(x[a+484360>>2],y[a+484376|0]);o=e,q=yb(x[g>>2]),x[o+56>>2]=q;i=yb(x[g+4>>2]);F:{while(1){G:{g=x[e+56>>2];if(!Kb(g,i)){g=y[a+484376|0];i=x[a+484360>>2];x[23549]=0;j=Wb(i,g);i=z[e+88>>1];g=O(299,j|0,i|0)|0;j=x[23549];x[23549]=0;if((j|0)!=1){break G}break g}j=x[d>>2];n=Ef(j,x[d+4>>2]);m=z[g>>1];if(n>>>0>m>>>0){x[23549]=0;j=ba(300,Cg(j,m)|0,y[e+210|0],f|0,a|0)|0;m=x[23549];x[23549]=0;if((m|0)==1){break F}w[g>>1]=j}Se(e+56|0);continue}break}H:{if(!g){break H}g=Wb(x[a+484360>>2],y[a+484376|0]);j=z[e+90>>1];if(!j){if(GB(x[g>>2],x[g+4>>2])>>>0<=i>>>0){break H}}g=Yb(x[k>>2],z[_b(x[g>>2],i)>>1]);me(g,Bm(Fe(Be(e+56|0,12,j&255),x[g+12>>2]-1|0)))}ek(f);kd(d);break q}break g}b=N()|0;break f}x[23549]=0;f=y[e+210|0]<3?9:8;O(174,b|0,f-4|0)|0;k=x[23549];x[23549]=0;if((k|0)!=1){x[23549]=0;k=R(143,b|0)|0;j=x[23549];x[23549]=0;if((j|0)==1){break E}ng(b,f);x[23549]=0;S(176,e+56|0,b|0,f+k|0);f=x[23549];x[23549]=0;if((f|0)==1){break D}j=i;f=e+56|0;i=hc(e+92|0,f);Zc(j,i);ub(i);ub(f);yg(e+36|0);continue}break}b=N()|0;break f}b=N()|0;break f}b=N()|0;break f}b=N()|0;Ab(e+112|0);break a}x[23549]=0;S(296,e+56|0,h|0,1196641603);d=x[23549];x[23549]=0;if((d|0)==1){break n}d=e+56|0;b=Zc(b,d);ub(d);d=x[b>>2];x[23549]=0;d=R(164,d|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break e}if(d){x[23549]=0;O(174,b|0,1)|0;d=x[23549];x[23549]=0;if((d|0)==1){break e}x[23549]=0;d=R(188,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break e}x[23549]=0;aa(301,a+1298332|0,b|0,d|0,40,0);d=x[23549];x[23549]=0;if((d|0)==1){break e}}x[23549]=0;S(296,e+56|0,h|0,1146113363);d=x[23549];x[23549]=0;if((d|0)==1){break k}x[23549]=0;S(296,e+36|0,h|0,1229999443);d=x[23549];x[23549]=0;if((d|0)==1){break o}d=e+36|0;b=Zc(b,d);ub(d);x[23549]=0;d=R(192,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break m}w[a+480190>>1]=d;i=!(c&2);f=1;I:{while(1){J:{c=f&65535;if(c>>>0>(d&65535)>>>0){break I}d=30;K:{L:{M:{if(y[e+210|0]>=2){x[23549]=0;d=R(192,b|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break M}}x[23549]=0;S(302,b|0,((c<<5)+a|0)+946304|0,d|0);d=x[23549];x[23549]=0;if((d|0)==1){break M}x[23549]=0;P(303,b|0,e+20|0);d=x[23549];x[23549]=0;if((d|0)==1){break L}x[23549]=0;g=D(c,104)+a|0;k=g+484380|0;P(304,e+20|0,k|0);c=x[23549];x[23549]=0;if((c|0)==1){break L}d=y[e+210|0];if(d>>>0>=8){x[23549]=0;P(305,b|0,g+484423|0);c=x[23549];x[23549]=0;if((c|0)==1){break L}d=y[e+210|0]}x[23549]=0;O(174,b|0,((d&255)>>>0>1?6:2)|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break L}x[23549]=0;c=R(143,e+56|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){x[23549]=0;S(176,e|0,e+56|0,c|0);c=x[23549];x[23549]=0;if((c|0)!=1){break K}}b=N()|0;break l}b=N()|0;break l}b=N()|0;break l}c=hc(e+36|0,e);ub(e);d=x[c>>2];x[23549]=0;d=R(164,d|0)|0;j=x[23549];x[23549]=0;if((j|0)!=1){N:{if(i|d^1){break N}d=Xc(e,w[g+484414>>1]&1?16:8,1,0,(y[e+35|0]&12)==4?7:0);x[23549]=0;U(205,d|0,k|0,c|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){break N}break J}ub(c);f=f+1|0;d=z[a+480190>>1];continue}}break}b=N()|0;ub(c);break l}Dg(a);x[a+480204>>2]=12e5;x[a+480208>>2]=24;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+480228>>2]=48;x[a+480232>>2]=48;x[23549]=0;d=1;U(253,a+1074312|0,114,1)|0;a=x[23549];x[23549]=0;if((a|0)==1){break m}ub(e+56|0);ub(b);_d(h)}db=e+272|0;return d|0}b=N()|0;break l}b=N()|0;break d}b=N()|0}ub(e+56|0);break d}b=N()|0;break d}b=N()|0;break d}b=N()|0;break d}b=N()|0;break d}b=N()|0;ek(f)}kd(d);break d}b=N()|0}ub(l)}_d(h);break a}b=N()|0;tb(e+112|0)}Q(b|0);p()}function Pga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0,R=0,T=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;d=db-320|0;db=d;a:{if(!Vc(b,1080)){break a}if(!zo(b,d+316|0)){break a}m=SS(d+300|0);if(!RS(d+316|0,m)){break a}e=z[m+10>>1];if(!e|e>>>0>127){break a}b:{if(!c){break b}R=1;Bd(a,1);i=z[m+10>>1];w[a+480188>>1]=i;G=y[m+14|0];T=y[m+13|0];g=y[m+12|0];if(!de(d+316|0,26938)){R=de(d+316|0,26943)}if(y[m+15|0]){Jb(a+1074312|0,5,1);i=z[a+480188>>1]}f=d+316|0;r=de(f,16333);e=1;if(!de(f,17079)){e=de(d+316|0,13399)}u=a+480188|0;B=(i&65535)==8&(T|0)!=0;Vc(b,0);bB(b,a+1298308|0,20);w[a+480190>>1]=31;q=(g|0)!=0;i=1;f=0;h=r;c:{while(1){if((i|0)==32){d:{i=0;if(A[m+4>>2]<j>>>0){break a}NS(b,d+170|0);Vc(b,z[m+8>>1]);g=y[d+171|0];e=128;Bu(Wb(x[a+484360>>2],y[a+484376|0]),d+172|0,128);h=!g&h;n=h?n:0;g=y[d+170|0];if(g>>>0<129){break d}j=y[a+484376|0];t=x[a+484360>>2];break c}}else{o=D(i,104)+a|0;g=o+484380|0;H=yA(b,d+170|0,g,((i<<5)+a|0)+946304|0,z[a+480188>>1]==4);s=x[g>>2];e:{if(e){v[o+484417|0]=0-(y[d+194|0]<<3);break e}q=s>>>0<65536&q}o=Hb(y[d+192|0]|y[d+193|0]<<8);f:{if(o){V=!Hb(y[d+198|0]|y[d+199|0]<<8)|V;break f}W=y[d+195|0]==64|W}g=h&1;h=0;g:{if(!g){break g}n=(o<<1)+n|0;g=y[d+194|0];h=!g;if(g|!o){break g}h=y[d+195|0]==64}j=j+H|0;f=f+s|0;i=i+1|0;continue}break}j=y[a+484376|0];t=x[a+484360>>2];if(g){e=g;break c}g=x[Wb(t,j)>>2];i=128;while(1){e=i;if(e>>>0<2){e=1;break c}i=e-1|0;if(!z[_b(g,i)>>1]){continue}break}}s=MS(b,Wb(t,j),e&65535,f,u,n,0);I=1;h:{if(!(h&z[u>>1]==8)){I=(G|0)!=0;break h}x[m>>2]=11121}i:{if(!B){break i}f=Wb(x[a+484360>>2],y[a+484376|0]);_=d,$=yb(x[f>>2]),x[_+156>>2]=$;f=yb(x[f+4>>2]);while(1){g=x[d+156>>2];if(!Kb(g,f)){break i}w[g>>1]=z[g>>1]>>>1;Se(d+156|0);continue}}$e(Wb(x[a+484360>>2],y[a+484376|0]),y[d+171|0]);H=e-1|0;e=y[d+171|0];j:{if((H&65535)>>>0>=e>>>0){i=z[u>>1];if((e|0)!=120|(i|0)!=4){break j}}$e(Wb(x[a+484360>>2],y[a+484376|0]),0);i=z[a+480188>>1]}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;x[a+480208>>2]=0;_=a,$=Ub(256/((i&65535)>>>0)|0,32,128),x[_+480228>>2]=$;vh(a,0);v[d+169|0]=0;J=1;X=1;if(!(q&1)){h=d+161|0;e=0;n=0;q=0;f=r;k:while(1){if(s>>>0>(q&65535)>>>0){g=0;i=0;while(1)if((i|0)==256){q=q+1|0;continue k}else{l=Wh(d+156|0);Au(b,l);o=jB(y[l|0]);l:{m:{n:{o:{l=y[d+159|0];if((l-7&255)>>>0<3){f=0;break o}j=y[d+161|0];if(!((l|0)!=14|j>>>0<=1)){f=0;break n}if(!((l|0)==15&(j&255)>>>0>31)){f=o?f:0;if((l|0)!=13){break o}g=g+1|0;if((g&65535)>>>0<2){break l}}f=0;break l}if((l|0)==8){break m}if((l|0)!=14){break l}j=y[d+161|0]}if((j&240)!=128){break l}v[d+144|0]=j<<4;_=d,$=y[af(d+169|0,d+144|0)|0],v[_+169|0]=$;break l}_=d,$=y[af(d+169|0,h)|0],v[_+169|0]=$;l=v[d+161|0];if((l|0)>=0){e=1;break l}n=(l|0)!=-92&l>>>0>4294967183|n}J=o&J;i=i+1|0;continue}}break}X=f&1;l=(e^-1|n)&1?0:y[d+169|0]>47}Vc(b,z[m+8>>1]);e=z[a+480188>>1];E=a+484344|0;s=s+B&65535;mg(E,s);G=B?4:e;F=a+1074312|0;i=c&1;j=0;n=0;p:{q:{r:{s:{while(1){if((j|0)==(s|0)){break r}t:{if(B){f=(j&65534)>>>1|0;e=j&1;if(!e){if(!$g(E,f,64)){break r}}h=e<<2;e=Yb(x[E>>2],f);break t}if(!$g(E,j&65535,64)){break r}h=0;e=Yb(x[E>>2],j)}g=0;t=$c(x[e>>2],x[x[e+48>>2]+12>>2],0,h);if(!i){K=0;L=0;break q}e=z[u>>1];v[d+84|0]=0;f=d+84|0;M=wu(d+156|0,e,f);e=z[u>>1];x[23549]=0;v[d+84|0]=0;O=U(540,d+144|0,e|0,f|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){q=0;u:while(1){if((q|0)!=64){h=0;f=0;o=0;while(1){if((h|0)==(G|0)){q=q+1|0;K=f&o|K;t=D(z[u>>1],6)+t|0;continue u}x[23549]=0;k=D(h,6)+t|0;P(541,b|0,k|0);e=x[23549];x[23549]=0;v:{w:{if((e|0)!=1){e=y[k+3|0];x:{y:{z:{if(!e){if(y[k+5|0]){break z}break y}if(!T){break z}A:{switch(e-14|0){case 0:v[k+3|0]=0;v[k+5|0]=0;break z;case 1:break A;default:break z}}if(y[k+5|0]<32){break z}v[k+5|0]=31}Qf(k);e=1;B:{C:{D:{g=y[k+3|0];switch(g-14|0){case 2:break x;case 0:break C;case 3:break D;default:break B}}n=y[k+5|0]<100|n;o=1;break y}if(!X){break y}v[k+5|0]=0;break y}if((g|0)==9&l){e=y[k+5|0];if((e|0)==164){v[k+3|0]=20;v[k+5|0]=145;break y}_=k,$=xi(e<<1),v[_+5|0]=$;break y}if((g|0)!=19){break y}e=y[k+5|0];if(e>>>0>15){break y}e=!(e&1);g=(e^Y)&1;Y=g?e:Y;L=g+L|0}e=f}if(y[k|0]){break w}g=y[k+1|0];if(!g|B){break v}f=y[Db(x[M>>2],h)|0];if(!f|(f|0)==(g|0)){break v}f=Db(x[O>>2],h);g=y[f|0]+1|0;v[f|0]=g;if((g&255)>>>0<4){break v}x[23549]=0;U(253,F|0,85,1)|0;f=x[23549];x[23549]=0;if((f|0)!=1){break v}}h=N()|0;bc(O);break s}_=Db(x[O>>2],h),$=0,v[_|0]=$}f=y[k+1|0];if(f){_=Db(x[M>>2],h),$=f,v[_|0]=$}h=h+1|0;f=e;continue}}break}bc(O);bc(M);j=j+1|0;continue}break}h=N()|0}bc(M);break p}g=n}E:{F:{G:{f=J^1;if((f|V)&1){break G}H:{if(de(d+316|0,16333)){break H}if(de(d+316|0,17084)){break H}if(!de(d+316|0,13394)){break G}}x[a+480208>>2]=x[a+480208>>2]|2162688;e=Jb(Jb(Jb(F,85,1),91,1),92,1);I:{if(y[d+169|0]>47){break I}e=Jb(e,84,1);if(y[d+171|0]==127){break I}Jb(e,83,1)}if(!((L|0)>6|I)){break F}break E}if(!(J&1)){if(!(r&(y[d+171|0]==127&(H&65535)>>>0<129))){break E}x[m>>2]=8392;break E}if((L|0)>6|I){break E}}x[a+480208>>2]=x[a+480208>>2]|8388608}if((r|I)==1){Jb(F,89,1)}if(R){Jb(F,84,1)}J:{if(!(c&2)){break J}Vc(b,z[m+8>>1]+(D(s,G)<<8)|0);n=(f|r^1|W)&1;i=1;while(1){if((i|0)==32){break J}l=D(i,104)+a|0;h=l+484380|0;e=x[h>>2];if(e){j=2;if(!R){j=LS(b,13602)?10:0;e=x[h>>2]}f=Xc(d+156|0,8,1,0,j);c=dB(f,e)+x[b+8>>2]|0;if(!n){_=h,$=x[Yc(h,l+484388|0)>>2],x[_>>2]=$}lg(f,h,b);Vc(b,c)}i=i+1|0;continue}}K:{L:{if(!r){if(!((de(d+316|0,17084)&g^-1|K)&1)){break L}break K}if((g^-1|K)&1){break K}}c=KS(d+120|0,0);b=x[c+20>>2];x[d+48>>2]=x[c+16>>2];x[d+52>>2]=b;b=x[c+12>>2];x[d+40>>2]=x[c+8>>2];x[d+44>>2]=b;b=x[c+4>>2];x[d+32>>2]=x[c>>2];x[d+36>>2]=b;b=d+156|0;Wt(b,a,0,d+32|0);Z=C[x[d+156>>2]>>3];vi(b);if(!(Z>=480)){break K}e=Jb(F,5,1);c=JS(d+96|0,Z);b=x[c+20>>2];x[d+24>>2]=x[c+16>>2];x[d+28>>2]=b;b=x[c+12>>2];x[d+16>>2]=x[c+8>>2];x[d+20>>2]=b;b=x[c+4>>2];x[d+8>>2]=x[c>>2];x[d+12>>2]=b;c=d+156|0;Wt(c,a,0,d+8|0);b=y[x[d+156>>2]+26|0];vi(c);if(b){Of(e,5);break K}x[m>>2]=16667}b=d+316|0;e=b;r=gc(b);c=b;while(1){if((e|0)!=(r|0)){f=y[e|0];v[c|0]=f>>>0<=32?32:f;c=c+1|0;e=e+1|0;continue}break}hf(d+84|0,16420);x[23549]=0;c=U(542,d+60|0,b|0,r|0)|0;b=x[23549];x[23549]=0;M:{N:{O:{P:{if((b|0)!=1){x[23549]=0;S(11,d+72|0,1,c|0);b=x[23549];x[23549]=0;if((b|0)==1){break P}x[23549]=0;S(131,d+156|0,d+84|0,d+72|0);b=x[23549];x[23549]=0;if((b|0)==1){break O}b=d+156|0;zb(a+1298344|0,b);tb(b);tb(d+72|0);tb(c);Ab(d+84|0);b=Tb(b,12176);zb(a+1298356|0,b);tb(b);b=x[m>>2];if(b){Wc(a+1298368|0,b)}x[a+1298404>>2]=13;break b}h=N()|0;break M}h=N()|0;break N}h=N()|0;tb(d+72|0)}tb(c)}Ab(d+84|0)}Q(h|0);p()}i=1}db=d+320|0;return i|0}function Qea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;g=db-256|0;db=g;d=db-112|0;db=d;f=le(g+76|0,c);x[23549]=0;n=R(160,f+20|0)|0;c=x[23549];x[23549]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c|0)!=1){x[23549]=0;q=R(160,f+40|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break B}x[23549]=0;r=R(160,f+60|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break A}x[23549]=0;i=R(160,f+80|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break z}x[23549]=0;o=R(160,f+100|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break y}x[23549]=0;k=R(160,f+120|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break x}j=Nb(f+140|0);wc(f);x[f+172>>2]=1873739776;w[f+176>>1]=0;x[23549]=0;e=O(746,f|0,d+100|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break w}if(!e){break n}e=x[d+100>>2];if((e|0)!=1414744396&(e|0)!=1179011410){break n}c=x[d+108>>2];if((c|0)!=1163280727&(c|0)!=1702257015){break n}v[f+176|0]=(e|0)==1414744396;x[23549]=0;S(747,d+88|0,f|0,2);c=x[23549];x[23549]=0;if((c|0)==1){break v}h=x[d+88>>2];C:{if(Fq(h,x[d+92>>2])>>>0<4){break C}c=hy(h,1);e=x[c>>2];c=x[c+4>>2];zi(d+36|0,e,c);if(x[d+36>>2]!=1635017060){break C}zi(d+60|0,e,c);if(!(v[d+64|0]&1)){break C}c=hy(h,2);zi(d+16|0,x[c>>2],x[c+4>>2]);if(y[d+20|0]|y[d+21|0]<<8|(y[d+22|0]<<16|y[d+23|0]<<24)){break C}c=hy(h,3);zi(d+80|0,x[c>>2],x[c+4>>2]);if(x[d+80>>2]){break C}x[23549]=0;O(141,f|0,12)|0;c=x[23549];x[23549]=0;if((c|0)==1){break u}x[23549]=0;S(747,d+36|0,f|0,1);c=x[23549];x[23549]=0;if((c|0)==1){break t}c=d+36|0;Rt(d+88|0,c);_d(c)}x[23549]=0;S(748,d+60|0,d+88|0,544501094);c=x[23549];x[23549]=0;if((c|0)==1){break s}x[23549]=0;e=O(749,d+60|0,f+156|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break k}if(!e){break o}e=z[f+156>>1];if((e|0)!=1){break q}x[23549]=0;e=R(188,d+60|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break r}break k}e=N()|0;break b}e=N()|0;break c}e=N()|0;break d}e=N()|0;break e}e=N()|0;break f}e=N()|0;break g}e=N()|0;break h}e=N()|0;break h}e=N()|0;break i}e=N()|0;break i}e=N()|0;break i}if((e|0)==4){x[23549]=0;h=R(183,d+60|0)|0;c=x[23549];x[23549]=0;D:{if((c|0)!=1){x[23549]=0;e=R(183,d+60|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break D}if((h|0)!=2|(e|0)!=1){break p}v[f+177|0]=1;break p}e=N()|0;break j}e=N()|0;break j}e=z[f+156>>1]}if((e&65535)!=65534){break p}x[23549]=0;e=O(750,d+60|0,d+36|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break l}if(!e){break o}c=y[d+56|0]|y[d+57|0]<<8|(y[d+58|0]<<16|y[d+59|0]<<24);x[d+8>>2]=y[d+52|0]|y[d+53|0]<<8|(y[d+54|0]<<16|y[d+55|0]<<24);x[d+12>>2]=c;c=y[d+48|0]|y[d+49|0]<<8|(y[d+50|0]<<16|y[d+51|0]<<24);x[d>>2]=y[d+44|0]|y[d+45|0]<<8|(y[d+46|0]<<16|y[d+47|0]<<24);x[d+4>>2]=c;c=d+16|0;x[c>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);w[c+4>>1]=y[d+4|0]|y[d+5|0]<<8;w[c+6>>1]=y[d+6|0]|y[d+7|0]<<8;s=c,t=bA(y[d+8|0]|y[d+9|0]<<8|(y[d+10|0]<<16|y[d+11|0]<<24),y[d+12|0]|y[d+13|0]<<8|(y[d+14|0]<<16|y[d+15|0]<<24)),x[s+8>>2]=t;x[c+12>>2]=hb;w[f+172>>1]=x[c>>2]}x[23549]=0;S(748,d+36|0,d+88|0,1635017060);c=x[23549];x[23549]=0;E:{F:{G:{H:{I:{J:{if((c|0)!=1){c=d+36|0;m=Zc(n,c);ub(c);c=x[m>>2];x[23549]=0;e=R(164,c|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break k}if(!e){x[23549]=0;S(748,d+36|0,d+88|0,544039792);c=x[23549];x[23549]=0;if((c|0)==1){break J}c=d+36|0;Zc(m,c);ub(c)}x[23549]=0;S(748,d+36|0,d+88|0,1952670054);c=x[23549];x[23549]=0;if((c|0)==1){break I}x[23549]=0;e=R(143,d+36|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break H}x[f+152>>2]=e;ub(d+36|0);if(x[f+152>>2]?z[f+156>>1]==17:0){break E}h=z[f+158>>1];e=yM(h,z[f+170>>1]);if(!e){break E}c=z[f+168>>1];if((c>>>0)/(h>>>0)>>>0<e<<1>>>0?c:0){break G}c=x[m>>2];x[23549]=0;e=R(146,c|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break k}c=yM(z[f+158>>1],z[f+170>>1]);break F}e=N()|0;break j}e=N()|0;break j}e=N()|0;break j}e=N()|0;ub(d+36|0);break j}c=x[m>>2];x[23549]=0;e=R(146,c|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break k}c=z[f+168>>1]}x[f+152>>2]=(e>>>0)/((c&65535)>>>0)}x[23549]=0;e=O(751,f|0,d+88|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break k}w[f+174>>1]=e;x[23549]=0;P(752,f|0,d+88|0);c=x[23549];x[23549]=0;if((c|0)==1){break k}x[23549]=0;S(748,d+36|0,d+88|0,1886221175);c=x[23549];x[23549]=0;if((c|0)==1){break m}c=d+36|0;Zc(o,c);ub(c)}ub(d+60|0);_d(d+88|0)}db=d+112|0;break a}e=N()|0;break j}e=N()|0;break j}e=N()|0}ub(d+60|0)}_d(d+88|0)}_d(j);ub(k)}ub(o)}ub(i)}ub(r)}ub(q)}ub(n)}ub(f);Q(e|0);p()}c=x[f+20>>2];x[23549]=0;e=R(682,c|0)|0;c=x[23549];x[23549]=0;K:{L:{if((c|0)!=1){M:{if(!e|(z[f+158>>1]-3&65535)>>>0<65534){break M}N:{O:{c=z[f+170>>1];P:{if(!c){if((Vj(f)|0)==85){break P}break M}if(c>>>0>31){break O}}if((Vj(f)|0)!=3){break N}break M}if(c>>>0>64){break M}}e=Vj(f);c=30304;while(1){Q:{R:{if((c|0)!=30328){if((e|0)!=x[c>>2]){break R}}else{c=30328}break Q}c=c+4|0;continue}break}if((c|0)==30328){break M}jt(a,b);x[23549]=0;e=O(54,g- -64|0,21204)|0;c=x[23549];x[23549]=0;S:{T:{U:{V:{W:{if((c|0)!=1){h=zc(((b<<5)+a|0)+946304|0,e);tb(e);x[23549]=0;e=D(b,104)+a|0;i=e+484380|0;P(266,i|0,0);c=x[23549];x[23549]=0;if((c|0)==1){break W}x[i>>2]=x[f+152>>2];x[e+484404>>2]=x[f+160>>2];c=x[a+1298404>>2];x[23549]=0;V(683,f|0,i|0,c|0,h|0);c=x[23549];x[23549]=0;if((c|0)==1){break W}le(g+44|0,f+20|0);e=z[f+158>>1];j=Xc(g+40|0,8,e>>>0>1?2:1,0,0);c=Vj(f);if((c|0)!=17|e>>>0>2){break U}tc(i,268435456);c=D(b,104)+a|0;b=c+484414|0;w[b>>1]=z[b>>1]&65470|((e|0)==2)<<6|1;if(zg(i)){break V}break S}l=N()|0;break K}l=N()|0;break K}j=x[c+484400>>2];h=x[i>>2];k=le(g+20|0,g+44|0);e=z[f+158>>1];c=z[f+168>>1];x[23549]=0;b=x[k+12>>2];x[g+8>>2]=x[k+8>>2];x[g+12>>2]=b;x[g+16>>2]=x[k+16>>2];b=x[k+4>>2];x[g>>2]=x[k>>2];x[g+4>>2]=b;aa(684,j|0,h|0,g|0,c|0,e|0);b=x[23549];x[23549]=0;if((b|0)==1){break L}dj(i,a);break T}if((c|0)==85){x[23549]=0;c=U(518,a|0,b|0,g+44|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break L}if(c){break T}break S}X:{Y:{Z:{if(AQ(z[f+156>>1])){break Z}_:{if(!vd(y[f+177|0])){break _}if((Vj(f)|0)!=1|z[f+170>>1]!=32|z[f+168>>1]!=e<<2){break _}hd(j,32);b=12;break Y}if((Vj(f)|0)!=1|z[f+170>>1]!=24|z[f+168>>1]!=e<<2){break Z}hd(j,32);b=13;break Y}if((Vj(f)&65534)!=6){break X}hd(j,16);b=(Vj(f)|0)==6?17:16}Uf(j,b);x[23549]=0;U(205,j|0,i|0,g+44|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break T}break L}e=z[f+170>>1];c=e-1|0;b=c&-8;h=b&31;hd(j,(c>>>0>=64?8:(b&63)>>>0>=32?1074268168>>>h|0:((1<<h)-1&1074268168)<<32-h|538447880>>>h)&120);if(e>>>0<9){Uf(j,1)}if((Vj(f)|0)==3){Uf(j,3)}x[23549]=0;U(205,j|0,i|0,g+44|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break L}}Fz(i,x[a+480180>>2]);dj(i,a);l=1}ub(g+44|0)}zQ(f);db=g+256|0;return l|0}l=N()|0;break K}l=N()|0;ub(g+44|0)}zQ(f);Q(l|0);p()}function aja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0;e=db-1344|0;db=e;wc(b);d=db-16|0;db=d;i=e+768|0;yU(d+8|0,i);h=x[d+12>>2];lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);j=x[d+4>>2];if((j|0)==(h|0)){Zb(b,x[d+12>>2])}db=d+16|0;d=(h|0)==(j|0);if(!d){xU(i)}a:{if(!d){break a}if(!AU(e+768|0)){break a}if(!Lb(x[b>>2],x[b+8>>2],Qc(zU(y[e+802|0]|y[e+803|0]<<8,y[e+804|0]|y[e+805|0]<<8),hb))){break a}if(!c){f=1;break a}n=xc(e+764|0);b:{while(1){if((f|0)!=32){d=(f<<5)+a|0;h=d+480280|0;Te(h);i=(e+768|0)+(f<<4)|0;w[d+480284>>1]=((y[i+78|0]<<8&65280)>>>0)/255;m=e+496|0;ck(m,1,i- -64|0);j=e+112|0;Bc(j,m);Em(d+480289|0,j);tb(j);c:{d:{switch(y[i+79|0]){case 0:k=g+1|0;break c;case 1:x[h>>2]=1024;k=f+1|0;break c;case 2:break d;default:break b}}x[h>>2]=1024;d=e+112|0;Ll(d,n,f);xm(d)}g=g+1|0;f=f+1|0;continue}break}Bd(a,33554432);w[a+480188>>1]=k&255;g=e+112|0;d=Tb(g,6714);zb(a+1298344|0,d);tb(d);g=Tb(g,10986);zb(a+1298356|0,g);tb(g);x[a+1298404>>2]=5;e:{if(y[e+847|0]){break e}f=1;j=1;while(1){if((f|0)==16){while(1){if((j|0)==16){break e}g=((j<<5)+a|0)+480280|0;x[g>>2]=x[g>>2]&-1025;j=j+1|0;continue}}g=f<<4;f=f+1|0;if(y[(e+g|0)+847|0]==1){continue}break}}g=e+496|0;_e(g,1,e+768|0);d=e+112|0;Bc(d,g);zb(a+1298308|0,d);tb(d);x[a+480208>>2]=x[a+480208>>2]&-17|(y[e+806|0]|y[e+807|0]<<8)<<4&16;x[a+480196>>2]=y[e+816|0];x[a+480204>>2]=D(y[e+817|0],1e4);x[a+480200>>2]=y[e+818|0]<<2;x[a+480228>>2]=y[e+819|0];d=y[e+804|0]|y[e+805|0]<<8;w[a+480190>>1]=0;w[a+480192>>1]=d;_u(b,g);Qq(Wb(x[a+484360>>2],y[a+484376|0]),g,y[e+800|0]|y[e+801|0]<<8,65535,255);r=c&1;if(r){mg(a+484344|0,y[e+802|0]|y[e+803|0]<<8)}o=a+484344|0;f:{while(1){g:{if((y[e+802|0]|y[e+803|0]<<8)>>>0<=l>>>0){m=c&2;g=1;c=0;h:while(1){if(z[a+480192>>1]<=(c&65535)>>>0){f=32;break b}c=c+1|0;f=bC(a,c&65535,0);i=!f;d=db-16|0;db=d;j=e+112|0;dc(d+8|0,j,384);h=x[d+12>>2];lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);k=x[d+4>>2];if((k|0)==(h|0)){Zb(b,x[d+12>>2])}db=d+16|0;d=(h|0)==(k|0);if(!d){Vb(j,0,384)}if(!d|i){continue}j=g&65535;i=db-32|0;db=i;k=i+8|0;h=e+112|0;_e(k,1,h);d=i+20|0;Bc(d,k);zc(f+492|0,d);tb(d);i:{if(!(y[h+378|0]|y[h+379|0]<<8)){break i}k=f+236|0;d=0;while(1){x[i+20>>2]=120;x[i+8>>2]=116;if(A[Cb(i+20|0,i+8|0)>>2]<=d>>>0){break i}l=y[(d+h|0)+32|0];u=_b(k,d+12|0),B=j+l|0,w[u>>1]=B;d=d+1|0;continue}}d=y[h+376|0]|y[h+377|0]<<8;v[f+33|0]=1;x[f>>2]=d;iB(h,f+48|0,0);iB(h,f+68|0,1);iB(h,f+88|0,2);d=y[f+100|0];if(d&1){v[f+100|0]=d|16}if(!(x[f>>2]|v[f+60|0]&1)){x[f>>2]=32767}db=i+32|0;f=0;while(1){d=y[e+490|0]|y[e+491|0]<<8;if(d>>>0<=f>>>0){g=d+g|0;continue h}gV(b,e+48|0);j:{k:{if((y[e+108|0]|y[e+109|0]<<8|(y[e+110|0]<<16|y[e+111|0]<<24))!=808538953){break k}d=f+g|0;j=d&65535;if(j>>>0>3999){break k}w[a+480190>>1]=d;i=db-32|0;db=i;k=D(j,104)+a|0;h=k+484380|0;nd(h,0);l=i+8|0;Xh(l,1,e+48|0);d=i+20|0;Bc(d,l);Ce(h+43|0,d);tb(d);l=y[e+64|0]|y[e+65|0]<<8|(y[e+66|0]<<16|y[e+67|0]<<24);x[h>>2]=l;n=y[e+68|0]|y[e+69|0]<<8|(y[e+70|0]<<16|y[e+71|0]<<24);x[h+4>>2]=n;o=y[e+72|0]|y[e+73|0]<<8|(y[e+74|0]<<16|y[e+75|0]<<24);x[h+8>>2]=o;x[h+24>>2]=y[e+76|0]|y[e+77|0]<<8|(y[e+78|0]<<16|y[e+79|0]<<24);w[h+30>>1]=y[e+80|0]<<2;w[h+28>>1]=y[e+81|0];d=y[e+96|0];if(d&1){w[h+34>>1]=z[h+34>>1]|2;d=y[e+96|0]}if(d&2){w[h+34>>1]=z[h+34>>1]|4;d=y[e+96|0]}if(d&4){x[h+8>>2]=o>>>1;x[h+4>>2]=n>>>1;x[h>>2]=l>>>1;w[h+34>>1]=z[h+34>>1]|1;d=y[e+96|0]}if(d&8){w[h+34>>1]=z[h+34>>1]|32}db=i+32|0;d=db-16|0;db=d;hv(d+8|0,k+484423|0);i=e+28|0;Xq(i,x[d+8>>2],x[d+12>>2]);db=d+16|0;zc(((j<<5)+a|0)+946304|0,i);tb(i);d=y[e+64|0]|y[e+65|0]<<8|(y[e+66|0]<<16|y[e+67|0]<<24);if(!d){break k}i=e+8|0;Wd(i,b,d);d=hc(e+28|0,i);ub(i);if(m){i=Xc(e+8|0,w[k+484414>>1]&1?16:8,1,0,0);x[23549]=0;U(205,i|0,h|0,d|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break j}}ub(d)}f=f+1|0;continue}break}break}a=N()|0;ub(d);break f}d=Fg(b);s=Fg(b);g=e+48|0;Wd(g,b,d-4|0);m=hc(e+112|0,g);ub(g);l:{m:{if(!r){break m}x[23549]=0;g=U(212,o|0,l&65535,s|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break l}if(!g){break m}k=0;i=Wh(e+28|0);while(1){if(k>>>0>=s>>>0){break m}x[23549]=0;h=R(192,m|0)|0;g=x[23549];x[23549]=0;n:{if((g|0)!=1){if(h){break n}k=k+1|0;continue}break g}f=i;q=h&31;if(q>>>0<z[a+480188>>1]){g=Yb(x[o>>2],l);f=$c(x[g>>2],x[x[g+48>>2]+12>>2],k,q)}if(h&32){x[23549]=0;P(249,e+48|0,m|0);g=x[23549];x[23549]=0;if((g|0)==1){break g}g=y[e+48|0];v[f|0]=g;u=f,B=y[fd(e+48|0)|0],v[u+1|0]=B;o:{p:{if((g|0)==160){d=255;break p}if((g|0)==255){d=0;break p}d=0;g=(D(g>>>4|0,12)+(g&15)|0)+13|0;if(wU(g)){break o}}g=d}v[f|0]=g}g=h&192;q:{if(!g){break q}if((g|0)==192){x[23549]=0;P(341,e+48|0,m|0);g=x[23549];x[23549]=0;if((g|0)!=1){g=e+48|0;h=fd(g);j=Ue(g);g=Ai(g);t=y[e+48|0];r:{s:{if((t|0)==12){v[e+8|0]=64;u=f,B=y[Sb(h,e+8|0)|0],v[u+4|0]=B;d=1;break s}d=y[j|0];t:{if((d|0)==12){v[e+8|0]=64;u=f,B=y[Sb(g,e+8|0)|0],v[u+4|0]=B;j=e+48|0;d=1;break t}if((t|0)==10){v[f+4|0]=(y[h|0]<<6>>>0)/255;d=2;break s}if((d|0)!=10){break r}v[f+4|0]=(y[g|0]<<6>>>0)/255;j=e+48|0;d=2}g=h}v[f+2|0]=d;d=y[j|0]}v[f+3|0]=d;v[f+5|0]=y[g|0];break q}break g}x[23549]=0;P(249,e+48|0,m|0);g=x[23549];x[23549]=0;if((g|0)==1){break g}v[f+3|0]=y[e+48|0];u=f,B=y[fd(e+48|0)|0],v[u+5|0]=B}if(y[f+3|0]){g=f+3|0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{h=y[f+3|0];switch(h-14|0){case 19:break A;case 17:break B;case 9:break C;case 8:break D;case 6:case 7:break E;case 1:break F;case 0:break G;default:break z}}g=y[f+5|0];if(!g){g=14;break w}if((g|0)==15){break y}if((g|0)==240){v[f+5|0]=239;break x}if(g>>>0>=16){v[f+5|0]=g|15;break x}v[f+5|0]=g|240;break x}v[f+5|0]=y[f+5|0]^128;break x}g=y[f+5|0];if(g>>>0>=16){v[f+5|0]=g>>>4|240;break x}v[f+5|0]=g|224;break x}v[f+5|0]=((y[f+5|0]^-1)&254)>>>1;break x}v[f+5|0]=y[f+5|0]&15|128;break x}u=f,B=xi(y[f+5|0]<<1),v[u+5|0]=B;break x}d=32;g=0;H:{I:{J:{K:{L:{M:{N:{j=y[f+5|0];switch(j>>>4|0){case 0:break x;case 3:break H;case 5:break I;case 14:break J;case 12:case 13:break K;case 11:break L;case 10:break M;case 8:break N;default:break w}}d=64;break H}d=176;break H}d=224;break H}if(j){break x}break w}O:{switch(j&15){case 0:v[f+5|0]=119;break x;case 1:v[f+5|0]=119;break x;case 2:v[f+5|0]=121;break x;case 3:break O;default:break x}}v[f+5|0]=123;break x}d=48}v[f+5|0]=j&15|d;break x}if(h>>>0<=35){break x}break v}v[f+5|0]=254}g=h}v[f+3|0]=y[g+26672|0];if(y[f+2|0]|(g|0)!=12){break u}v[f+2|0]=1;v[f+3|0]=0;v[f+4|0]=y[f+5|0];g=f+5|0}v[g|0]=0}}Ll(e+48|0,n,q);if(!Ib(x[x[e+48>>2]>>2],x[e+52>>2])){continue}if(!aW(y[f+3|0],y[f+5|0])){continue}v[f+3|0]=0;continue}}ub(m);l=l+1|0;continue}}break}a=N()|0;ub(m)}Q(a|0);p()}f=f>>>0>31}db=e+1344|0;return f|0}function E7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=E(0),g=E(0),h=E(0),i=0,j=E(0),k=E(0),l=0,m=0,n=0,o=E(0),p=0,q=0,r=0,s=0,t=0,u=E(0),w=E(0),z=0,A=0,C=E(0),D=0,F=0,G=E(0),H=0,I=0,J=E(0);a:{if(!y[a+5046|0]){break a}g=B[a+4268>>2];ZK(a);if(g==B[a+4268>>2]){break a}Dx(a)}b:{if(!y[a+5045|0]){break b}if(!Yh(a+44|0)){break b}i=x[a+44>>2];p=Ac(i,0);q=Ac(i,1);i=x[a+56>>2];l=Ac(i,0);m=Ac(i,1);c:{if(!(!y[a+5044|0]|(!d|y[a+4264|0]&2))){B[l>>2]=B[a+5036>>2];B[m>>2]=B[a+5040>>2];v[a+5044|0]=0;q=q+4|0;p=p+4|0;m=m+4|0;l=l+4|0;n=d-1|0;break c}n=d}r=n;s=a+4888|0;t=a+4864|0;D=a+4504|0;F=a+4960|0;d:{while(1){if(!r){break d}g=B[p>>2];g=E(E(E(B[a+5008>>2]-g)*B[a+4276>>2])+g);B[a+5008>>2]=g;I=Fc(x[a+4864>>2],x[a+4868>>2],x[a+4880>>2]),J=g,B[I>>2]=J;g=B[q>>2];g=E(E(E(B[a+5012>>2]-g)*B[a+4276>>2])+g);B[a+5012>>2]=g;I=Fc(x[a+4888>>2],x[a+4892>>2],x[a+4904>>2]),J=g,B[I>>2]=J;g=E(E(E(E(E(Mh(t,x[a+4356>>2])*E(.6800000071525574))+E(Mh(t,x[a+4360>>2])*E(-.5)))-E(Mh(t,x[a+4364>>2])*E(.6200000047683716)))+E(Mh(t,x[a+4368>>2])*E(-.5)))-E(Mh(t,x[a+4372>>2])*E(.6200000047683716)));if(v[a+4264|0]&1){e=g;g=E(B[Fc(x[a+4816>>2],x[a+4820>>2],x[a+4836>>2])>>2]+E(e*E(.6180340051651001)));I=Fc(x[a+4816>>2],x[a+4820>>2],x[a+4832>>2]),J=E(e-E(g*E(.6180340051651001))),B[I>>2]=J}u=B[a+4280>>2];I=a,J=E(Mh(t,x[a+4352>>2])+B[a+5020>>2]),B[I+5020>>2]=J;e=E(Mh(s,x[a+4376>>2])+B[a+5024>>2]);B[a+5024>>2]=e;f=B[a+5020>>2];h=E(E(E(B[a+4980>>2]-B[Fc(x[a+4624>>2],x[a+4628>>2],x[a+4644>>2])>>2])*B[a+4444>>2])+B[Fc(x[a+4624>>2],x[a+4628>>2],x[a+4644>>2])>>2]);B[a+4980>>2]=h;C=E(h*B[a+4440>>2]);k=E(e*E(.7070000171661377));j=E(f*E(-.7070000171661377));f=E(k+j);h=B[a+4272>>2];e=E(C+E(f*h));I=Fc(x[a+4624>>2],x[a+4628>>2],x[a+4640>>2]),J=E(f-E(h*e)),B[I>>2]=J;f=E(E(E(B[a+4976>>2]-B[Fc(x[a+4600>>2],x[a+4604>>2],x[a+4620>>2])>>2])*B[a+4436>>2])+B[Fc(x[a+4600>>2],x[a+4604>>2],x[a+4620>>2])>>2]);B[a+4976>>2]=f;h=B[a+4272>>2];f=E(E(f*B[a+4432>>2])+E(e*h));I=Fc(x[a+4600>>2],x[a+4604>>2],x[a+4616>>2]),J=E(e-E(h*f)),B[I>>2]=J;w=E(E(e*E(-.15000000596046448))+E(f*E(-.20000000298023224)));if(v[a+4264|0]&1){e=E(E(E(B[a+4972>>2]-B[Fc(x[a+4576>>2],x[a+4580>>2],x[a+4596>>2])>>2])*B[a+4428>>2])+B[Fc(x[a+4576>>2],x[a+4580>>2],x[a+4596>>2])>>2]);B[a+4972>>2]=e;h=B[a+4272>>2];e=E(E(e*B[a+4424>>2])+E(f*h));I=Fc(x[a+4576>>2],x[a+4580>>2],x[a+4592>>2]),J=E(f-E(h*e)),B[I>>2]=J;f=E(E(E(B[a+4968>>2]-B[Fc(x[a+4552>>2],x[a+4556>>2],x[a+4572>>2])>>2])*B[a+4420>>2])+B[Fc(x[a+4552>>2],x[a+4556>>2],x[a+4572>>2])>>2]);B[a+4968>>2]=f;h=B[a+4272>>2];f=E(E(f*B[a+4416>>2])+E(e*h));I=Fc(x[a+4552>>2],x[a+4556>>2],x[a+4568>>2]),J=E(e-E(h*f)),B[I>>2]=J;w=E(E(E(e*E(.3499999940395355))+w)+E(f*E(-.3799999952316284)))}I=Fc(x[a+4912>>2],x[a+4916>>2],x[a+4928>>2]),J=f,B[I>>2]=J;e=E(B[Fc(x[a+4912>>2],x[a+4916>>2],x[a+4932>>2])>>2]*B[a+4496>>2]);B[a+5028>>2]=E(E(B[a+5028>>2]-e)*B[a+4500>>2])+e;e=E(E(E(B[a+4964>>2]-B[Fc(x[a+4528>>2],x[a+4532>>2],x[a+4548>>2])>>2])*B[a+4412>>2])+B[Fc(x[a+4528>>2],x[a+4532>>2],x[a+4548>>2])>>2]);B[a+4964>>2]=e;f=B[a+5028>>2];o=B[a+4272>>2];h=E(E(f*o)+E(e*B[a+4408>>2]));I=Fc(x[a+4528>>2],x[a+4532>>2],x[a+4544>>2]),J=E(f-E(o*h)),B[I>>2]=J;e=E(E(E(B[a+4960>>2]-B[Fc(x[a+4504>>2],x[a+4508>>2],x[a+4524>>2])>>2])*B[a+4404>>2])+B[Fc(x[a+4504>>2],x[a+4508>>2],x[a+4524>>2])>>2]);B[a+4960>>2]=e;f=E(e*B[a+4400>>2]);e=B[a+4272>>2];o=E(f+E(h*e));I=Fc(x[a+4504>>2],x[a+4508>>2],x[a+4520>>2]),J=E(h-E(e*o)),B[I>>2]=J;B[a+5020>>2]=o;e=E(E(E(E(E(Mh(s,x[a+4380>>2])*E(.7070000171661377))+E(Mh(s,x[a+4384>>2])*E(-.6000000238418579)))-E(Mh(s,x[a+4388>>2])*E(.5)))+E(Mh(s,x[a+4392>>2])*E(-.6000000238418579)))-E(Mh(s,x[a+4396>>2])*E(.5)));if(v[a+4264|0]&1){f=e;e=E(B[Fc(x[a+4840>>2],x[a+4844>>2],x[a+4860>>2])>>2]+E(e*E(.6180340051651001)));I=Fc(x[a+4840>>2],x[a+4844>>2],x[a+4856>>2]),J=E(f-E(e*E(.6180340051651001))),B[I>>2]=J}G=B[a+4280>>2];f=E(E(E(B[a+5004>>2]-B[Fc(x[a+4768>>2],x[a+4772>>2],x[a+4788>>2])>>2])*B[a+4492>>2])+B[Fc(x[a+4768>>2],x[a+4772>>2],x[a+4788>>2])>>2]);B[a+5004>>2]=f;C=E(f*B[a+4488>>2]);f=E(j-k);j=B[a+4272>>2];k=E(C+E(f*j));I=Fc(x[a+4768>>2],x[a+4772>>2],x[a+4784>>2]),J=E(f-E(j*k)),B[I>>2]=J;f=E(E(E(B[a+5e3>>2]-B[Fc(x[a+4744>>2],x[a+4748>>2],x[a+4764>>2])>>2])*B[a+4484>>2])+B[Fc(x[a+4744>>2],x[a+4748>>2],x[a+4764>>2])>>2]);B[a+5e3>>2]=f;j=B[a+4272>>2];f=E(E(f*B[a+4480>>2])+E(k*j));I=Fc(x[a+4744>>2],x[a+4748>>2],x[a+4760>>2]),J=E(k-E(j*f)),B[I>>2]=J;k=E(E(E(h*E(.3799999952316284))+E(k*E(-.15000000596046448)))+E(f*E(-.20000000298023224)));if(v[a+4264|0]&1){h=E(E(E(B[a+4996>>2]-B[Fc(x[a+4720>>2],x[a+4724>>2],x[a+4740>>2])>>2])*B[a+4476>>2])+B[Fc(x[a+4720>>2],x[a+4724>>2],x[a+4740>>2])>>2]);B[a+4996>>2]=h;j=B[a+4272>>2];h=E(E(h*B[a+4472>>2])+E(f*j));I=Fc(x[a+4720>>2],x[a+4724>>2],x[a+4736>>2]),J=E(f-E(j*h)),B[I>>2]=J;f=E(E(E(B[a+4992>>2]-B[Fc(x[a+4696>>2],x[a+4700>>2],x[a+4716>>2])>>2])*B[a+4468>>2])+B[Fc(x[a+4696>>2],x[a+4700>>2],x[a+4716>>2])>>2]);B[a+4992>>2]=f;j=B[a+4272>>2];f=E(E(f*B[a+4464>>2])+E(h*j));I=Fc(x[a+4696>>2],x[a+4700>>2],x[a+4712>>2]),J=E(h-E(j*f)),B[I>>2]=J;k=E(E(E(h*E(.3499999940395355))+k)+E(f*E(-.3799999952316284)))}H=q+4|0;n=p+4|0;h=E(g*u);w=E(w-E(o*E(.3799999952316284)));o=E(e*G);I=Fc(x[a+4936>>2],x[a+4940>>2],x[a+4952>>2]),J=f,B[I>>2]=J;g=E(B[Fc(x[a+4936>>2],x[a+4940>>2],x[a+4956>>2])>>2]*B[a+4496>>2]);B[a+5032>>2]=E(E(B[a+5032>>2]-g)*B[a+4500>>2])+g;g=E(E(E(B[a+4988>>2]-B[Fc(x[a+4672>>2],x[a+4676>>2],x[a+4692>>2])>>2])*B[a+4460>>2])+B[Fc(x[a+4672>>2],x[a+4676>>2],x[a+4692>>2])>>2]);B[a+4988>>2]=g;e=B[a+5032>>2];f=B[a+4272>>2];g=E(E(e*f)+E(g*B[a+4456>>2]));I=Fc(x[a+4672>>2],x[a+4676>>2],x[a+4688>>2]),J=E(e-E(f*g)),B[I>>2]=J;f=B[a+4284>>2];e=E(E(E(B[a+4984>>2]-B[Fc(x[a+4648>>2],x[a+4652>>2],x[a+4668>>2])>>2])*B[a+4452>>2])+B[Fc(x[a+4648>>2],x[a+4652>>2],x[a+4668>>2])>>2]);B[a+4984>>2]=e;u=B[a+4272>>2];e=E(E(e*B[a+4448>>2])+E(g*u));I=Fc(x[a+4648>>2],x[a+4652>>2],x[a+4664>>2]),J=E(g-E(u*e)),B[I>>2]=J;B[a+5024>>2]=e;e=E(-e);u=B[a+4288>>2];i=D;e:{f:{while(1){if((i|0)==(F|0)){g:{e=E(o+E(E(E(e*E(.3799999952316284))+k)*u));g=E(h+E(E(E(g*E(.3799999952316284))+w)*f));if(!(y[a+4264|0]&2)){break g}p=n;n=H;break f}}else{z=x[i+16>>2];A=z-1|0;x[i+16>>2]=A;if((z|0)<=0){x[i+16>>2]=A+x[i+12>>2]}z=x[i+20>>2];A=z-1|0;x[i+20>>2]=A;if((z|0)<=0){x[i+20>>2]=A+x[i+12>>2]}i=i+24|0;continue}break}B[l>>2]=E(g+B[a+5036>>2])*E(.5);B[m>>2]=E(e+B[a+5040>>2])*E(.5);B[a+5040>>2]=e;B[a+5036>>2]=g;if((r|0)==1){break e}r=r-1|0;p=p+8|0;m=m+4|0;l=l+4|0;n=q+8|0}q=n;B[l>>2]=g;B[m>>2]=e;r=r-1|0;m=m+4|0;l=l+4|0;continue}break}v[a+5044|0]=1}n=a;a=x[a+56>>2];li(n,b,c,Ac(a,0),Ac(a,1),d)}}function _fa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0;d=db-288|0;db=d;wc(b);a:{b:{c:{d:{if(!St(b,d+192|0)){break d}if(!gS(d+192|0)){break d}if(!Lb(x[b>>2],x[b+8>>2],Qc(fS(d+192|0),hb))){break d}if(!c){g=1;break d}if(!Vc(b,y[d+196|0])){break d}Bd(a,268435456);Dg(a);x[a+480208>>2]=4;Jb(a+1074312|0,114,1);h=d+84|0;i=Tb(h,14905);zb(a+1298344|0,i);tb(i);i=Tb(h,10165);zb(a+1298356|0,i);tb(i);x[a+1298404>>2]=5;i=d+16|0;gf(i,d+198|0,48,3);Bc(h,i);zb(a+1298308|0,h);tb(h);h=y[d+246|0];w[a+480188>>1]=h+1;x[a+480228>>2]=y[d+249|0];x[a+480204>>2]=D(y[d+250|0],1e4);x[a+480196>>2]=y[d+251|0];while(1){if((e|0)==(h|0)){e:{w[a+480190>>1]=y[d+284|0];e=y[d+286|0]|y[d+287|0]<<8;i=db-16|0;db=i;h=d+180|0;x[h>>2]=0;x[h+4>>2]=0;xc(h+8|0);Id(i+8|0,x[vb(i+4|0,h)>>2]);f:{g:{if(e){x[23549]=0;P(600,h|0,e|0);f=x[23549];x[23549]=0;if((f|0)==1){break g}TA(h,e)}e=i+8|0;Hd(e);Bg(e);db=i+16|0;break f}a=N()|0;Bg(i+8|0);Q(a|0);p()}x[23549]=0;i=h;S(595,b|0,h|0,y[d+286|0]|y[d+287|0]<<8);h=x[23549];x[23549]=0;if((h|0)==1){break b}u=Nb(d+168|0);r=Nb(d+156|0);x[23549]=0;U(361,b|0,u|0,y[d+285|0])|0;h=x[23549];x[23549]=0;if((h|0)==1){break c}x[23549]=0;U(361,b|0,r|0,y[d+284|0])|0;h=x[23549];x[23549]=0;if((h|0)==1){break c}s=c&2;t=d+122|0;o=d+90|0;h=0;h:{while(1){e=h;if(e>>>0>=y[d+284|0]){g=1;if(!(c&1)){break e}x[d+68>>2]=0;Dc(Wb(x[a+484360>>2],y[a+484376|0]));E=d,F=yb(x[i>>2]),x[E+64>>2]=F;s=a+484344|0;A=yb(x[i+4>>2]);break h}x[23549]=0;h=e+1|0;f=D(h,104)+a|0;j=f+484380|0;P(266,j|0,0);g=x[23549];x[23549]=0;i:{if((g|0)!=1){g=xb(x[r>>2],e);g=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);if(!g){continue}x[23549]=0;g=O(141,b|0,g|0)|0;k=x[23549];x[23549]=0;j:{if((k|0)==1){break j}if(!g){continue}x[23549]=0;g=O(596,b|0,d+84|0)|0;k=x[23549];x[23549]=0;if((k|0)==1){break j}if(!g){continue}g=d+72|0;_e(g,2,o);x[23549]=0;P(208,d+16|0,g|0);g=x[23549];x[23549]=0;if((g|0)==1){break c}g=d+16|0;zc(((h<<5)+a|0)+946304|0,g);tb(g);k=d+72|0;ck(k,2,t);x[23549]=0;P(208,g|0,k|0);g=x[23549];x[23549]=0;if((g|0)==1){break c}g=d+16|0;Ce(f+484423|0,g);tb(g);g=y[d+134|0];if(g>>>0<=15){w[f+484408>>1]=D(g,17);g=f+484414|0;w[g>>1]=z[g>>1]|32}v[d+16|0]=y[d+135|0];v[d+72|0]=64;E=f+484412|0,F=y[Sb(d+16|0,d+72|0)|0],w[E>>1]=F;x[f+484404>>2]=y[d+137|0]|y[d+138|0]<<8;q=f+484384|0;k=y[d+143|0]|y[d+144|0]<<8|(y[d+145|0]<<16|y[d+146|0]<<24);x[q>>2]=k;n=f+484388|0;g=y[d+147|0]|y[d+148|0]<<8|(y[d+149|0]<<16|y[d+150|0]<<24);x[n>>2]=g;l=y[d+151|0]|y[d+152|0]<<8|(y[d+153|0]<<16|y[d+154|0]<<24);x[j>>2]=l;m=y[d+136|0];if(m&1){k=k>>>1|0;x[q>>2]=k;g=g>>>1|0;x[n>>2]=g;x[j>>2]=l>>>1}k:{if(g>>>0<=k>>>0){break k}f=f+484414|0;g=z[f>>1];w[f>>1]=g|2;if(!(m&2)){break k}w[f>>1]=g|6}ok(j);if(!s){continue}e=xb(x[r>>2],e);e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[23549]=0;O(141,b|0,e+y[d+88|0]|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){break i}}break c}break c}e=Xc(d+16|0,v[d+136|0]&1?16:8,1,0,1);x[23549]=0;U(205,e|0,j|0,b|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){continue}break}break c}while(1){k=x[d+64>>2];if(!Kb(k,A)){e=y[a+484376|0];l:{b=x[a+484360>>2];c=x[d+68>>2];h=c&63;m:{if(!h){break m}x[23549]=0;c=c>>>6|0;f=O(299,Wb(b,e)|0,c&65535)|0;b=x[23549];x[23549]=0;if((b|0)==1){break l}e=y[a+484376|0];b=x[a+484360>>2];if(!f){break m}b=z[_b(x[Wb(b,e)>>2],c&65535)>>1];c=x[s>>2];x[23549]=0;P(597,Yb(c,b)|0,h|0);b=x[23549];x[23549]=0;if((b|0)==1){break l}e=y[a+484376|0];b=x[a+484360>>2]}a=Wb(b,e);E=d,F=yb(x[a>>2]),x[E+84>>2]=F;b=yb(x[a+4>>2]);f=65535;while(1){a=x[d+84>>2];if(!Kb(a,b)){break e}if(z[a>>1]==65535){n:{if((f&65535)!=65535){break n}x[23549]=0;f=O(351,s|0,64)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break n}break c}w[a>>1]=f}Se(d+84|0);continue}}break c}o:{c=y[k+3|0];if(y[k+2|0]>y[d+246|0]|c>>>0>=y[d+285|0]){break o}c=xb(x[u>>2],c);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[23549]=0;c=O(141,b|0,c|0)|0;h=x[23549];x[23549]=0;p:{if((h|0)!=1){if(!c){break o}x[23549]=0;P(598,b|0,d+84|0);c=x[23549];x[23549]=0;if((c|0)==1){break c}e=y[d+88|0];if(!e){break o}c=y[k|0]|y[k+1|0]<<8;v[d+16|0]=y[d+89|0];v[d+72|0]=y[d+246|0]-y[k+2|0];t=y[Sb(d+16|0,d+72|0)|0];x[d+60>>2]=c+e;E=d,F=x[Yc(d+68|0,d+60|0)>>2],x[E+68>>2]=F;x[d+40>>2]=0;x[d+44>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;f=c&63;o=c>>>6|0;q=0;while(1){if((e&255)>>>0<=q>>>0){break o}e=Wb(x[a+484360>>2],y[a+484376|0]);j=f>>>0>63;o=j+o|0;c=o&65535;if(Ic(x[e>>2],x[e+4>>2])>>>0<=c>>>0){x[23549]=0;P(315,e|0,o+1&65535);h=x[23549];x[23549]=0;if((h|0)==1){break p}x[23549]=0;h=O(351,s|0,64)|0;e=x[23549];x[23549]=0;if((e|0)==1){break p}e=Wb(x[a+484360>>2],y[a+484376|0]);E=_b(x[e>>2],c),F=h,w[E>>1]=F}l=x[a+484344>>2];h=x[a+484348>>2];n=z[_b(x[e>>2],c)>>1];if(!se(l,h,n)){break o}h=0;c=Yb(l,n);l=j?0:f;e=$c(x[c>>2],x[x[c+48>>2]+12>>2],l,y[k+2|0]);q:{while(1){if((h|0)==(t|0)){c=y[d+89|0];if(c>>>0<=t>>>0){break q}x[23549]=0;O(174,b|0,D(c-t|0,5)|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break q}break c}x[23549]=0;P(599,d+72|0,b|0);c=x[23549];x[23549]=0;if((c|0)!=1){c=d+72|0;j=fd(c);B=Ue(c);m=Ai(c);C=gc(c);f=0;c=y[d+72|0];if((c-1&255)>>>0<=142){f=(D((c&240)>>>4|0,12)+(c&15)|0)+13|0;v[(d+16|0)+h|0]=f}v[e|0]=f;c=y[j|0];v[e+2|0]=1;v[e+1|0]=c;c=y[B|0];r:{if((c|0)!=255){v[e+4|0]=c;break r}v[e+2|0]=0}c=y[m|0];s:{if(c>>>0>22){break s}v[e+3|0]=y[c+27056|0];j=y[C|0];v[e+5|0]=j;c=e+5|0;t:{switch(y[m|0]-4|0){case 3:v[c|0]=j&3|64;break s;case 4:v[c|0]=j&3|48;break s;case 7:f=x[i>>2];if(oc(f,x[i+4>>2])>>>0<=j>>>0){break s}m=c;c=xb(f,j);c=y[c|0]|y[c+1|0]<<8;v[m|0]=c>>>6;f=Yb(x[a+484344>>2],n);f=$c(x[f>>2],x[x[f+48>>2]+12>>2],l,z[a+480188>>1]-1&65535);v[f+5|0]=c&63;v[f+3|0]=14;break s;case 8:m=c;c=x[d+60>>2];v[m|0]=c>>>6;f=Yb(x[a+484344>>2],n);f=$c(x[f>>2],x[x[f+48>>2]+12>>2],l,z[a+480188>>1]-1&65535);v[f+5|0]=c&63;v[f+3|0]=14;break s;case 10:v[c|0]=j&15|128;break s;case 12:v[d+15|0]=15;E=c,F=y[Sb(c,d+15|0)|0]|208,v[E|0]=F;break s;case 13:v[d+15|0]=15;E=c,F=y[Sb(c,d+15|0)|0]|192,v[E|0]=F;break s;case 14:v[d+15|0]=15;E=c,F=y[Sb(c,d+15|0)|0]|224,v[E|0]=F;break s;case 0:case 16:case 17:if(!(j&15)){break s}f=j&240;if(!f|(f|0)==240){break s}v[c|0]=j|15;break s;case 9:case 18:break t;default:break s}}if(f&255){break s}v[e|0]=y[(d+16|0)+h|0]}e=e+6|0;h=h+1|0;continue}break}break c}f=l+1|0;q=q+1|0;e=y[d+88|0];continue}}break c}break c}Ae(d- -64|0);continue}}}else{w[((e<<5)+a|0)+480284>>1]=D(y[(d+e|0)+252|0],17);e=e+1|0;continue}break}sc(r);sc(u);sc(i)}db=d+288|0;return g|0}a=N()|0;sc(r);sc(u);break a}a=N()|0}sc(i);Q(a|0);p()}function lJ(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;i=db-208|0;db=i;a:{b:{if(g){Ye(i+196|0,f,32);x[23549]=0;U(484,i+184|0,f|0,32)|0;h=x[23549];x[23549]=0;if((h|0)!=1){break b}f=N()|0;break a}Gb(i+196|0);Gb(i+184|0)}c:{d:{e:{f:{g:{h:{i:{j:{if(ms(c)){h=x[b+24>>2];j=x[h+484344>>2];if(se(j,x[h+484348>>2],c&65535)){break j}}x[23549]=0;S(1066,a|0,i+196|0,i+184|0);a=x[23549];x[23549]=0;if((a|0)!=1){break i}f=N()|0;break c}c=Yb(j,c);if(!(!((e|0)<0|x[c+12>>2]<=(d|0)|(d|0)<0)&z[h+480188>>1]>e>>>0)){x[23549]=0;S(1066,a|0,i+196|0,i+184|0);a=x[23549];x[23549]=0;if((a|0)!=1){break i}f=N()|0;break c}c=$c(x[c>>2],x[x[c+48>>2]+12>>2],d,e&65535);Ze(i+196|0);Ze(i+184|0);k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{d=y[c|0];if(!Tc(d)){if(!Hp(d)){break A}}e=y[c+1|0];h=x[b+24>>2];x[23549]=0;V(1067,i+160|0,h|0,d|0,e|0);d=x[23549];x[23549]=0;e=1;if((d|0)==1){break y}x[23549]=0;P(989,i+172|0,i+160|0);d=x[23549];x[23549]=0;if((d|0)!=1){break z}f=N()|0;break v}e=0;x[23549]=0;O(54,i+172|0,16353)|0;d=x[23549];x[23549]=0;if((d|0)==1){break x}}x[23549]=0;d=O(777,i+196|0,i+172|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break w}tb(i+172|0);if(e){tb(i+160|0)}e=9851;h=y[c|0];if(!Tc(h)){e=Hp(h)?10161:16353}x[23549]=0;h=O(54,i+172|0,e|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break u}x[23549]=0;e=O(777,i+184|0,h|0)|0;j=x[23549];x[23549]=0;if((j|0)==1){break t}tb(h);if(f-6>>>0>4294967290){break l}x[23549]=0;h=O(54,i+148|0,17394)|0;j=x[23549];x[23549]=0;if((j|0)==1){break s}x[23549]=0;j=O(777,d|0,h|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break r}tb(h);x[23549]=0;h=O(54,i+136|0,17394)|0;l=x[23549];x[23549]=0;if((l|0)==1){break q}x[23549]=0;l=O(777,e|0,h|0)|0;k=x[23549];x[23549]=0;if((k|0)==1){break p}tb(h);h=c+1|0;B:{if(y[c+1|0]){x[23549]=0;P(502,i+124|0,h|0);k=x[23549];x[23549]=0;if((k|0)!=1){break B}break d}x[23549]=0;O(54,i+124|0,16358)|0;k=x[23549];x[23549]=0;if((k|0)==1){break d}}x[23549]=0;k=O(777,j|0,i+124|0)|0;j=x[23549];x[23549]=0;if((j|0)==1){break o}j=i+124|0;tb(j);h=y[h|0];x[23549]=0;h=O(54,j|0,(h?10651:16358)|0)|0;j=x[23549];x[23549]=0;if((j|0)==1){break n}x[23549]=0;l=O(777,l|0,h|0)|0;j=x[23549];x[23549]=0;if((j|0)!=1){break m}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;break c}f=N()|0;tb(i+172|0);if(!e){break c}}tb(i+160|0);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;tb(i+124|0);break c}f=N()|0;break c}tb(h);if(f-9>>>0>4294967287){break l}C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{j=Sg(y[c|0]);O:{if(j){x[23549]=0;m=O(54,i+100|0,17394)|0;h=x[23549];x[23549]=0;if((h|0)==1){break N}h=y[c+4|0];n=y[c+2|0];x[23549]=0;o=i,q=Qj(n,h)&255,x[o+76>>2]=q;P(501,i+88|0,i+76|0);h=x[23549];x[23549]=0;if((h|0)==1){break M}h=0;x[23549]=0;S(946,i+112|0,m|0,i+88|0);m=x[23549];x[23549]=0;if((m|0)!=1){break O}f=N()|0;break G}h=y[c+2|0];if(h){h=qM(x[x[x[b+24>>2]+8>>2]+88>>2],h);x[23549]=0;h=U(484,i+100|0,1,h|0)|0;m=x[23549];x[23549]=0;if((m|0)==1){break E}x[23549]=0;P(502,i+88|0,c+4|0);m=x[23549];x[23549]=0;if((m|0)==1){break L}x[23549]=0;S(946,i+112|0,h|0,i+88|0);m=x[23549];x[23549]=0;h=1;if((m|0)!=1){break O}f=N()|0;break J}h=0;x[23549]=0;O(54,i+112|0,16357)|0;m=x[23549];x[23549]=0;if((m|0)==1){break e}}x[23549]=0;k=O(777,k|0,i+112|0)|0;m=x[23549];x[23549]=0;if((m|0)==1){break K}tb(i+112|0);if(h){tb(i+88|0);tb(i+100|0)}if(j){tb(i+88|0);tb(i+100|0)}h=5429;if(!Sg(y[c|0])){h=y[c+2|0]?5425:16357}x[23549]=0;h=O(54,i+112|0,h|0)|0;j=x[23549];x[23549]=0;if((j|0)==1){break D}x[23549]=0;j=O(777,l|0,h|0)|0;l=x[23549];x[23549]=0;if((l|0)!=1){break C}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;break F}f=N()|0;break I}f=N()|0;tb(i+112|0);if(!h){break H}}tb(i+88|0)}tb(i+100|0)}if(!j){break c}}tb(i+88|0)}tb(i+100|0);break c}f=N()|0;break c}f=N()|0;break c}tb(h);if(f-13>>>0>4294967283){break l}x[23549]=0;h=O(54,i+76|0,17394)|0;l=x[23549];x[23549]=0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((l|0)!=1){x[23549]=0;l=O(777,k|0,h|0)|0;k=x[23549];x[23549]=0;if((k|0)==1){break Z}tb(h);x[23549]=0;h=O(54,i- -64|0,17394)|0;k=x[23549];x[23549]=0;if((k|0)==1){break Y}x[23549]=0;j=O(777,j|0,h|0)|0;k=x[23549];x[23549]=0;if((k|0)==1){break X}tb(h);_:{if(Sg(y[c|0])){h=y[c+5|0];k=y[c+3|0];b=0;x[23549]=0;o=i,q=Qj(k,h)&4095,x[o+16>>2]=q;P(1068,i+52|0,i+16|0);h=x[23549];x[23549]=0;if((h|0)!=1){break _}f=N()|0;break c}h=y[c+3|0];if(h){b=pM(x[x[x[b+24>>2]+8>>2]+84>>2],h);x[23549]=0;b=U(484,i+40|0,1,b|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break W}x[23549]=0;P(502,i+28|0,c+5|0);h=x[23549];x[23549]=0;if((h|0)==1){break V}x[23549]=0;S(946,i+52|0,b|0,i+28|0);h=x[23549];x[23549]=0;b=1;if((h|0)!=1){break _}f=N()|0;break S}b=0;x[23549]=0;O(54,i+52|0,16353)|0;h=x[23549];x[23549]=0;if((h|0)==1){break U}}x[23549]=0;O(777,l|0,i+52|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break T}tb(i+52|0);if(b){tb(i+28|0);tb(i+40|0)}b=11007;if(!Sg(y[c|0])){b=y[c+3|0]?11007:16353}x[23549]=0;b=O(54,i+52|0,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break Q}x[23549]=0;O(777,j|0,b|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break P}f=N()|0;tb(b);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;break R}f=N()|0;break c}f=N()|0;tb(i+52|0);if(!b){break c}}tb(i+28|0)}tb(i+40|0);break c}f=N()|0;break c}tb(b);if(!f){break k}}$:{aa:{ba:{ca:{b=Oc(x[d+4>>2],y[d+11|0]);da:{if(b>>>0>f>>>0){x[23549]=0;V(116,i+16|0,d|0,0,f|0);b=x[23549];x[23549]=0;if((b|0)!=1){b=i+16|0;zb(d,b);tb(b);break da}f=N()|0;break c}if(!g){break da}x[23549]=0;b=U(484,i+16|0,f-b|0,32)|0;c=x[23549];x[23549]=0;if((c|0)==1){break ca}x[23549]=0;O(777,d|0,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break ba}tb(b)}b=Oc(x[e+4>>2],y[e+11|0]);if(b>>>0<=f>>>0){break $}x[23549]=0;V(116,i+4|0,e|0,0,f|0);b=x[23549];x[23549]=0;if((b|0)==1){break aa}b=i+4|0;zb(e,b);tb(b);break k}f=N()|0;break c}f=N()|0;tb(b);break c}f=N()|0;break c}if(!g){break k}x[23549]=0;b=U(484,i+4|0,f-b|0,32)|0;c=x[23549];x[23549]=0;if((c|0)==1){break h}x[23549]=0;O(777,e|0,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break g}tb(b)}x[23549]=0;S(1066,a|0,d|0,e|0);a=x[23549];x[23549]=0;if((a|0)==1){break f}}tb(i+184|0);tb(i+196|0);db=i+208|0;return}f=N()|0;break c}f=N()|0;tb(b);break c}f=N()|0;break c}f=N()|0;break c}f=N()|0}tb(i+184|0)}tb(i+196|0);Q(f|0);p()}function dja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;e=db-256|0;db=e;wc(b);d=db-16|0;db=d;i=e+99|0;EU(d+8|0,i);g=x[d+12>>2];lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(g|0)){Zb(b,x[d+12>>2])}db=d+16|0;d=(g|0)==(h|0);if(!d){DU(i)}a:{if(!d){break a}if(!FU(e+99|0)){break a}if(!c){f=1;break a}Bd(a,x[((y[e+215|0]|y[e+216|0]<<8)<<2)+26464>>2]);x[a+480208>>2]=x[a+480208>>2]|16777216;d=e+36|0;f=Tb(d,12961);zb(a+1298344|0,f);tb(f);f=Tb(d,10196);zb(a+1298356|0,f);tb(f);f=db-16|0;db=f;g=e+4|0;i=Tb(f+4|0,4330);ad(g,i);tb(i);db=f+16|0;x[23549]=0;V(218,d|0,g|0,y[e+178|0],e+175|0);d=x[23549];x[23549]=0;b:{if((d|0)!=1){d=e+36|0;zb(a+1298368|0,d);tb(d);f=e+4|0;Ab(f);Wc(a+1298392|0,((y[e+215|0]|y[e+216|0]<<8)<<2)+26512|0);Wc(a+1298380|0,x[((y[e+215|0]|y[e+216|0]<<8)<<2)+26560>>2]);x[a+1298404>>2]=5;_e(f,2,e+103|0);Bc(d,f);zb(a+1298308|0,d);tb(d);_e(f,2,e+135|0);Bc(d,f);c:{if(lu(d,9633)){x[23549]=0;S(11,e+4|0,5,e+36|0);d=x[23549];x[23549]=0;if((d|0)==1){break c}d=e+4|0;zb(a+1298320|0,d);tb(d)}tb(e+36|0);w[a+480188>>1]=32;d=0;d:{while(1){if((d|0)!=32){g=(d<<5)+a|0;i=g+480280|0;Te(i);f=y[(e+d|0)+180|0];e:{if(f>>>0<=15){x[e+36>>2]=f<<4|8;x[e+4>>2]=256;s=g+480284|0,t=x[qd(e+36|0,e+4|0)>>2],w[s>>1]=t;break e}if((f|0)!=16){if((f|0)!=255){break e}w[a+480188>>1]=d;break d}w[g+480284>>1]=128;x[i>>2]=256}d=d+1|0;continue}break}d=z[a+480188>>1]}f=0;if(!(d&65535)){break a}x[e+36>>2]=y[e+212|0]<<2;x[e+4>>2]=256;s=a,t=x[Cb(e+36|0,e+4|0)>>2],x[s+480200>>2]=t;x[a+480196>>2]=y[e+213|0];x[a+480204>>2]=D(y[e+214|0],1e4);if(Vc(b,y[e+217|0]|y[e+218|0]<<8|(y[e+219|0]<<16|y[e+220|0]<<24))){Ao(Wb(x[a+484360>>2],y[a+484376|0]),b,y[e+221|0]+1|0,255,254)}if(!Vc(b,y[e+227|0]|y[e+228|0]<<8|(y[e+229|0]<<16|y[e+230|0]<<24))){break a}d=y[e+235|0]+1|0;w[a+480190>>1]=d;l=e+68|0;i=1;while(1){f:{g:{j=i&65535;if(j>>>0>(d&65535)>>>0){break g}d=db-16|0;db=d;g=e+36|0;dc(d+8|0,g,62);f=x[d+12>>2];lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(f|0)){Zb(b,x[d+12>>2])}db=d+16|0;d=(f|0)==(h|0);if(!d){Vb(g,0,62)}if(!d){break g}d=0;f=D(j,104)+a|0;k=f+484380|0;nd(k,0);h=e+24|0;_e(h,2,e+36|0);g=e+4|0;Bc(g,h);zc(((j<<5)+a|0)+946304|0,g);tb(g);ck(h,2,l);Bc(g,h);Ce(f+484423|0,g);tb(g);g=y[e+94|0]|y[e+95|0]<<8;x[f+484404>>2]=g;if(!ym(x[a+480180>>2])){break f}while(1){if((d|0)==16){break f}if((g|0)==z[(d<<1)+26608>>1]){v[f+484417|0]=d<<4;break f}else{d=d+1|0;continue}}}h:{if(!(c&2)){break h}if(!Vc(b,y[e+231|0]|y[e+232|0]<<8|(y[e+233|0]<<16|y[e+234|0]<<24))){break h}d=1;while(1){f=d&65535;if(f>>>0>z[a+480190>>1]){break h}f=D(f,104)+a|0;lg(Xc(e+36|0,w[f+484414>>1]&1?16:8,1,0,1),f+484380|0,b);d=d+1|0;continue}}m=a+484344|0;mg(m,y[e+226|0]+1|0);f=tq(a);d=db-16|0;db=d;x[d+12>>2]=0;Xs(d+12|0,f);k=x[d+12>>2];db=d+16|0;Vc(b,y[e+222|0]|y[e+223|0]<<8|(y[e+224|0]<<16|y[e+225|0]<<24));q=c&1;j=0;n=1;i:{j:{k:{while(1){if(y[e+226|0]<j>>>0){if(x[a+480180>>2]==1){break k}c=x[a+480208>>2]&-8454145;break j}l:{d=Fg(b);if(d>>>0>=3){c=e+4|0;Wd(c,b,d-2|0);h=hc(e+36|0,c);ub(c);m:{if(!q){break m}c=x[h>>2];x[23549]=0;c=R(164,c|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break l}if(!c){break m}x[23549]=0;c=U(212,m|0,j&65535,64)|0;d=x[23549];x[23549]=0;if((d|0)==1){break l}l=0;if(!c){break m}while(1){if((l|0)==64){break m}c=Yb(x[m>>2],j);r=sf(x[c>>2],x[x[c+48>>2]+12>>2],l);n:{o:while(1){x[23549]=0;c=R(192,h|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break i}if(!c){break n}d=c&31;if(d>>>0>=z[a+480188>>1]){break n}f=D(d,6)+r|0;if(c&32){x[23549]=0;P(249,e+4|0,h|0);d=x[23549];x[23549]=0;if((d|0)==1){break i}g=fd(e+4|0);d=y[e+4|0];if(d){d=(d&127)-1|0;v[e+4|0]=d;d=(D((d&240)>>>4|0,12)+(d&15)|0)+13|0;v[f|0]=d;n=jB(d)&n}v[f+1|0]=y[g|0]}if(!(c&64)){continue}v[f+2|0]=0;v[f+3|0]=0;g=f+5|0;while(1){c=x[h>>2];x[23549]=0;c=U(142,c|0,x[e+44>>2],2)|0;d=x[23549];x[23549]=0;if((d|0)==1){break i}if(!c){continue o}o=y[f+5|0];c=y[f+3|0];x[23549]=0;P(249,e+4|0,h|0);d=x[23549];x[23549]=0;if((d|0)!=1){i=y[fd(e+4|0)|0];v[g|0]=i;d=y[(y[e+4|0]&31)+26640|0];v[f+3|0]=d;p:{q:{r:{s:{t:{switch(d-2|0){case 0:case 1:if(i>>>0<224){break r}d=223;if(x[a+480180>>2]!=1){break s}break r;case 11:v[e+24|0]=64;s=g,t=y[Sb(g,e+24|0)|0],v[s|0]=t;if(!BU(x[k+88>>2])){break r}v[f+2|0]=1;v[f+4|0]=y[g|0];v[f+3|0]=c;v[g|0]=o;d=c;break q;case 17:u:{switch(((i&240)>>>4|0)-8|0){case 0:v[f+3|0]=2;v[g|0]=i&15|224;break p;case 1:v[f+3|0]=3;v[g|0]=i&15|224;break p;default:break u}}if(ku(x[k+84>>2],19)){break r}Pu(f);break r;case 13:d=x[k+84>>2];if(ku(d,15)){break r}if(!ku(d,19)){break r}v[f+3|0]=19;v[g|0]=i&15|144;break p;case 18:d=145;if((i|0)==1){break s}if((i&240)==128){if(ku(x[k+84>>2],20)){break r}v[f+3|0]=19;break p}v[f+3|0]=0;break p;case 4:case 5:break t;default:break q}}d=i&240;if(!d){break r}}v[g|0]=d}d=y[f+3|0]}if((d&255)!=20){break p}d=y[g|0];if(y[f+2|0]|(d&240)!=128){break p}v[f+2|0]=2;v[f+4|0]=(((d&15)<<6|8)>>>0)/15;v[f+3|0]=c;v[g|0]=o}if(!(y[e+4|0]&32)){continue o}continue}break}break}break i}l=l+1|0;continue}}ub(h)}j=j+1|0;continue}break}break i}c=x[a+480208>>2]&-8454145|(z[a+480188>>1]==4?n&1?8454144:0:0)}x[a+480208>>2]=c;f=1;if(!(y[e+240|0]|y[e+241|0]<<8|(y[e+242|0]<<16|y[e+243|0]<<24))){break a}if(!Vc(b,y[e+236|0]|y[e+237|0]<<8|(y[e+238|0]<<16|y[e+239|0]<<24))){break a}vB(a+1298332|0,b,y[e+240|0]|y[e+241|0]<<8|(y[e+242|0]<<16|y[e+243|0]<<24),4);break a}d=N()|0;ub(h);break b}w[f+484412>>1]=64;g=y[e+81|0]|y[e+82|0]<<8|(y[e+83|0]<<16|y[e+84|0]<<24);x[k>>2]=g;d=y[e+93|0];if(d&2){h=f+484414|0;w[h>>1]=z[h>>1]|1;x[k>>2]=g>>>1}x[f+484384>>2]=y[e+85|0]|y[e+86|0]<<8|(y[e+87|0]<<16|y[e+88|0]<<24);x[f+484388>>2]=(y[e+89|0]|y[e+90|0]<<8|(y[e+91|0]<<16|y[e+92|0]<<24))-1;if(d&1){g=f+484414|0;w[g>>1]=z[g>>1]|2}v:{w:{if(!(d&4)){break w}g=y[e+96|0];if((g|0)==255){break w}v[e+4|0]=g;v[e+24|0]=64;s=f+484410|0,t=y[Sb(e+4|0,e+24|0)|0]<<2,w[s>>1]=t;break v}g=f+484414|0;w[g>>1]=z[g>>1]|32768}x:{if(d&8){d=f+484414|0;g=z[d>>1]|32;w[d>>1]=g;j=f+484408|0;f=y[e+97|0];if(f>>>0<=15){x[e+24>>2]=256;x[e+4>>2]=f<<4|8;h=x[qd(e+4|0,e+24|0)>>2]}else{h=128}w[j>>1]=h;w[d>>1]=g&65279|((f|0)==16)<<8;break x}w[f+484408>>1]=128}i=i+1|0;d=z[a+480190>>1];continue}}d=N()|0;tb(e+36|0);break b}d=N()|0;Ab(e+4|0)}Q(d|0);p()}db=e+256|0;return f|0}function UW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;f=db-192|0;db=f;wc(b);a:{if(!EC(b,f+151|0)){break a}if(!HC(f+151|0)){break a}if(!c){h=1;break a}Bd(a,2048);Dg(a);d=db-16|0;db=d;e=f+8|0;g=Tb(d+4|0,3907);ad(e,g);tb(g);db=d+16|0;x[23549]=0;S(199,f- -64|0,e|0,y[f+154|0]);d=x[23549];x[23549]=0;b:{c:{d:{e:{f:{if((d|0)!=1){d=f- -64|0;zb(a+1298344|0,d);tb(d);e=f+8|0;Ab(e);g=Tb(d,10994);zb(a+1298356|0,g);tb(g);x[a+1298404>>2]=5;w[a+480188>>1]=y[f+191|0];w[a+480190>>1]=y[f+187|0];_e(e,2,f+155|0);Bc(d,e);zb(a+1298308|0,d);tb(d);d=y[f+154|0];g:{if(d>>>0>=9){if(d>>>0>=11){e=(d|0)==11?16:32;d=0;while(1){if((d|0)==(e|0)){break g}g=dv(b);h:{if((g|0)==100){x[((d<<5)+a|0)+480280>>2]=256;break h}x[f+64>>2]=(g<<1)+128;x[f+8>>2]=0;x[f+136>>2]=256;s=((d<<5)+a|0)+480284|0,t=x[sj(f- -64|0,f+8|0,f+136|0)>>2],w[s>>1]=t}d=d+1|0;continue}}e=f- -64|0;d=db-16|0;db=d;i:{if(!Lb(x[b>>2],x[b+8>>2],16)){sC(e);break i}Vu(d+8|0,e);pd(d,b,x[d+8>>2],x[d+12>>2])}db=d+16|0;d=0;while(1){if((d|0)==16){break g}w[((d<<5)+a|0)+480284>>1]=v[(f- -64|0)+d|0]&1?64:192;d=d+1|0;continue}}w[a+480188>>1]=4;ng(b,1);vh(a,1)}j:{if(y[f+154|0]>=13){d=f- -64|0;Yu(d,b);e=fd(d);d=y[f+64|0];if(d>>>0<=31){v[f+64|0]=125;d=125}x[a+480204>>2]=D(d,1e4);x[a+480196>>2]=y[e|0];break j}x[a+480196>>2]=6;x[a+480204>>2]=125e4}Sf(Wb(x[a+484360>>2],y[a+484376|0]),y[f+188|0]);n=Nb(f+136|0);d=x[b+8>>2];e=y[f+154|0]>13;if(!e){break f}x[23549]=0;P(200,n|0,y[f+188|0]);g=x[23549];x[23549]=0;if((g|0)!=1){break f}a=N()|0;break e}a=N()|0;Ab(f+8|0);break d}r=d+(e<<1)|0;d=0;k:{l:{while(1){if(y[f+188|0]<=d>>>0){if(y[f+154|0]!=10){break k}k=x[b+8>>2];d=1;while(1){l=z[a+480190>>1]>=(d&65535)>>>0;if(!l){break l}x[23549]=0;e=O(201,b|0,f- -64|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){if(e){e=0;g=f- -64|0;m:{if(y[g|0]>1|y[f+187|0]<(y[g+46|0]|y[g+47|0]<<8|(y[g+48|0]<<16|y[g+49|0]<<24))>>>0){break m}m=y[g+50|0]|y[g+51|0]<<8|(y[g+52|0]<<16|y[g+53|0]<<24);if(m>>>0>1048576|y[g+56|0]>64|m>>>0<(y[g+57|0]|y[g+58|0]<<8|(y[g+59|0]<<16|y[g+60|0]<<24))>>>0){break m}e=m>>>0>=(y[g+61|0]|y[g+62|0]<<8|(y[g+63|0]<<16|y[g+64|0]<<24))>>>0}if(!e){break l}}d=d+1|0;continue}break}a=N()|0;break e}s=_b(x[Wb(x[a+484360>>2],y[a+484376|0])>>2],d),t=d,w[s>>1]=t;n:{if(y[f+154|0]>=14){x[23549]=0;e=R(180,b|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break n}s=_b(x[n>>2],d),t=e,w[s>>1]=t}e=z[a+480188>>1];x[23549]=0;O(174,b|0,e<<1)|0;e=x[23549];x[23549]=0;if((e|0)==1){break n}d=d+1|0;continue}break}a=N()|0;break e}x[23549]=0;O(141,b|0,k|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){break k}a=N()|0;break e}d=z[a+480190>>1];x[23549]=0;x[f+64>>2]=0;m=U(202,f+52|0,d|0,f- -64|0)|0;d=x[23549];x[23549]=0;o:{p:{q:{r:{if((d|0)!=1){k=l?59:65;g=f+65|0;e=1;s:{while(1){d=e&65535;if(d>>>0>z[a+480190>>1]){g=Nb(f+40|0);x[23549]=0;h=U(203,b|0,g|0,y[f+189|0]|y[f+190|0]<<8)|0;d=x[23549];x[23549]=0;t:{if((d|0)!=1){if(!h){break b}d=0;l=0;e=x[g>>2];if(!qc(e,x[g+4>>2])){e=yb(e);i=yb(x[g+4>>2]);l=db-16|0;db=l;u:{if(!Kb(e,i)){break u}x[l+12>>2]=e;while(1){k=x[Se(l+12|0)>>2];if(!Kb(k,i)){break u}e=Cl(y[e|0]|y[e+1|0]<<8,y[k|0]|y[k+1|0]<<8)?k:e;continue}}db=l+16|0;l=y[e|0]|y[e+1|0]<<8}x[23549]=0;k=O(204,f+28|0,l|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break t}v:{while(1){if((d|0)==(l|0)){if(!(c&2)){break r}j=Xc(f- -64|0,8,1,0,1);e=z[a+480190>>1];i=1;w:{x:while(1){o=i&65535;if(o>>>0>(e&65535)>>>0){break r}d=x[b+8>>2];e=x[b>>2];x[23549]=0;d=U(142,e|0,d|0,1)|0;e=x[23549];x[23549]=0;if((e|0)==1){break w}if(!d){break r}q=x[b+8>>2];d=0;while(1){e=z[a+480190>>1];if(e>>>0<=d>>>0){i=i+1|0;continue x}if((o|0)!=x[xb(x[m>>2],d)>>2]){d=d+1|0;continue}x[23549]=0;O(141,b|0,q|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){x[23549]=0;d=d+1|0;U(205,j|0,(D(d,104)+a|0)+484380|0,b|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){continue}}break}break}a=N()|0;break q}a=N()|0;break q}x[23549]=0;e=R(180,b|0)|0;i=x[23549];x[23549]=0;y:{if((i|0)==1){break y}x[23549]=0;O(174,b|0,1)|0;i=x[23549];x[23549]=0;if((i|0)==1){break y}if(e){x[23549]=0;S(176,f+8|0,b|0,D(e,3)+(y[f+154|0]==1?3:0)|0);e=x[23549];x[23549]=0;if((e|0)==1){break v}i=f+8|0;e=hc(f- -64|0,i);Zc(Cg(x[k>>2],d),e);ub(e);ub(i)}d=d+1|0;continue}break}a=N()|0;break q}a=N()|0;break q}a=N()|0;break p}a=N()|0;break p}z:{A:{if(y[f+154|0]<=9){x[23549]=0;P(206,b|0,f- -64|0);h=x[23549];x[23549]=0;B:{C:{if((h|0)==1){break C}x[23549]=0;P(207,f- -64|0,(D(d,104)+a|0)+484380|0);h=x[23549];x[23549]=0;if((h|0)==1){break C}h=f+40|0;_e(h,2,g);x[23549]=0;P(208,f+8|0,h|0);h=x[23549];x[23549]=0;if((h|0)==1){break B}break A}a=N()|0;break o}a=N()|0;break o}x[23549]=0;S(209,b|0,f- -64|0,k|0);h=x[23549];x[23549]=0;if((h|0)==1){break z}x[23549]=0;S(210,f- -64|0,(D(d,104)+a|0)+484380|0,l|0);h=x[23549];x[23549]=0;if((h|0)==1){break z}h=f+40|0;_e(h,2,g);x[23549]=0;P(208,f+8|0,h|0);h=x[23549];x[23549]=0;if((h|0)==1){break s}}h=f+8|0;zc(((d<<5)+a|0)+946304|0,h);tb(h);s=xb(x[m>>2],d-1|0),t=y[f+110|0]|y[f+111|0]<<8|(y[f+112|0]<<16|y[f+113|0]<<24),x[s>>2]=t;e=e+1|0;continue}break}a=N()|0;break o}a=N()|0;break o}a=N()|0;break e}if(!(c&1)){break c}x[23549]=0;i=a+484344|0;P(211,i|0,y[f+188|0]);c=x[23549];x[23549]=0;D:{if((c|0)!=1){c=0;while(1){E:{if(y[f+188|0]<=c>>>0){break c}d=64;e=x[n>>2];if(Ic(e,x[n+4>>2])>>>0>c>>>0){d=z[_b(e,c)>>1]}x[23549]=0;d=U(212,i|0,c&65535,d&65535)|0;e=x[23549];x[23549]=0;if((e|0)==1){break D}F:{if(d){d=z[a+480188>>1];x[23549]=0;O(141,b|0,D(((y[f+154|0]>13)<<1)+(d<<1)|0,c)+r|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break D}e=Nb(f- -64|0);d=z[a+480188>>1];x[23549]=0;j=U(203,b|0,e|0,d|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break F}d=0;G:{if(!j){break G}while(1){if(z[a+480188>>1]<=d>>>0){break G}H:{j=_b(x[e>>2],d);j=(y[j|0]|y[j+1|0]<<8)-1|0;if((j&65535)>>>0>=(y[f+189|0]|y[f+190|0]<<8)>>>0){break H}j=_b(x[g>>2],j);j=(y[j|0]|y[j+1|0]<<8)-1&65535;if(j>>>0>=l>>>0){break H}o=x[i>>2];q=x[k>>2];x[23549]=0;S(213,Yb(o,c)|0,d&65535,Cg(q,j)|0);j=x[23549];x[23549]=0;if((j|0)!=1){break H}break E}d=d+1|0;continue}}id(e)}c=c+1|0;continue}}break}a=N()|0;id(e);break q}a=N()|0;break q}a=N()|0}kd(k)}id(g)}sc(m)}id(n)}Q(a|0);p()}kd(k)}id(g);sc(m);id(n)}db=f+192|0;return h|0}function x$(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0;l=db-528|0;db=l;x[l+520>>2]=k;x[l+524>>2]=b;a:{b:{if(Jh(a,l+524|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+72>>2]=1136;b=l+72|0;t=pe(l+104|0,l+112|0,b);m=x[t>>2];x[l+100>>2]=m;x[l+96>>2]=m+400;u=Gb(b);q=Gb(l+60|0);n=Gb(l+48|0);o=Gb(l+36|0);s=Gb(l+24|0);b=x[d>>2];x[23549]=0;ha(1146,c|0,b|0,l+92|0,l+88|0,l+84|0,u|0,q|0,n|0,o|0,l+20|0);b=x[23549];x[23549]=0;if((b|0)!=1){x[j>>2]=x[i>>2];A=e&512;w=x[l+20>>2];e=0;while(1){c:{d:{e:{f:{g:{if((e|0)==4){break g}x[23549]=0;b=O(1120,a|0,l+524|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}if(b){break g}h:{i:{j:{k:{l:{switch(v[(l+92|0)+e|0]){case 1:if((e|0)==3){break c}b=x[a>>2];x[23549]=0;b=R(1121,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}x[23549]=0;b=U(1147,h|0,1,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}if(b){x[23549]=0;P(1148,l+12|0,a|0);b=x[23549];x[23549]=0;if((b|0)!=1){x[23549]=0;P(48,s|0,x[l+12>>2]);b=x[23549];x[23549]=0;if((b|0)!=1){break k}}break a}x[f>>2]=x[f>>2]|4;a=0;break d;case 4:break h;case 2:break i;case 3:break j;case 0:break l;default:break c}}if((e|0)==3){break c}}while(1){x[23549]=0;b=O(1120,a|0,l+524|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}if(b){break c}b=x[a>>2];x[23549]=0;b=R(1121,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}x[23549]=0;b=U(1147,h|0,1,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}if(!b){break c}x[23549]=0;P(1148,l+12|0,a|0);b=x[23549];x[23549]=0;if((b|0)!=1){x[23549]=0;P(48,s|0,x[l+12>>2]);b=x[23549];x[23549]=0;if((b|0)!=1){continue}}break}break a}m:{if(!Bb(x[n+4>>2],y[n+11|0])){break m}b=x[a>>2];x[23549]=0;b=R(1121,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}if((b|0)!=x[Mb(n)>>2]){break m}x[23549]=0;R(1123,a|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break a}v[g|0]=0;r=Bb(x[n+4>>2],y[n+11|0])>>>0>1?n:r;break c}n:{o:{k=x[o+4>>2];b=y[o+11|0];if(Bb(k,b)){b=x[a>>2];x[23549]=0;b=R(1121,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}if((b|0)==x[Mb(o)>>2]){break o}k=x[o+4>>2];b=y[o+11|0]}c=Bb(x[n+4>>2],y[n+11|0]);if(!c){break n}if(!Bb(k,b)){break n}x[f>>2]=x[f>>2]|4;a=0;break d}x[23549]=0;R(1123,a|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break a}v[g|0]=1;r=Bb(x[o+4>>2],y[o+11|0])>>>0>1?o:r;break c}b=Bb(k,b);if(!(b|c)){break c}v[g|0]=!b;break c}if(!((e|0)==2&y[l+95|0]!=0|(e>>>0<2|r|A))){r=0;break c}c=vb(l+12|0,od(q));p:{if(!e|y[(e+l|0)+91|0]>1){break p}q:{while(1){b=Hk(q);d=x[c>>2];if(!Kb(d,b)){break q}b=x[d>>2];x[23549]=0;b=U(1147,h|0,1,b|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){if(!b){break q}Ae(c);continue}break}break a}b=od(q);b=bu(x[c>>2],b);if(Bb(x[s+4>>2],y[s+11|0])>>>0>=b>>>0){d=Yj(Hk(s),0-b|0);k=Hk(s);z=od(q);b=db-16|0;db=b;x[b+8>>2]=z;x[b+12>>2]=d;while(1){r:{z=Kb(d,k);if(!z){break r}if(!qc(x[d>>2],x[x[b+8>>2]>>2])){break r}d=Ae(b+12|0);Ae(b+8|0);d=x[d>>2];continue}break}db=b+16|0;if(z^1){break p}}C=c,D=x[vb(l+8|0,od(q))>>2],x[C>>2]=D}x[l+8>>2]=x[c>>2];s:{while(1){b=Hk(q);if(!Kb(x[l+8>>2],b)){break s}x[23549]=0;b=O(1120,a|0,l+524|0)|0;c=x[23549];x[23549]=0;t:{if((c|0)==1){break t}if(b){break s}b=x[a>>2];x[23549]=0;b=R(1121,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break t}if((b|0)!=x[x[l+8>>2]>>2]){break s}x[23549]=0;R(1123,a|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break a}Ae(l+8|0);continue}break}break a}if(!A){break c}b=Hk(q);if(!Kb(x[l+8>>2],b)){break c}x[f>>2]=x[f>>2]|4;a=0;break d}b=0;z=x[l+84>>2];c=m;u:{while(1){v:{x[23549]=0;d=O(1120,a|0,l+524|0)|0;k=x[23549];x[23549]=0;if((k|0)==1){break v}if(d){break u}d=x[a>>2];x[23549]=0;k=R(1121,d|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break a}x[23549]=0;d=U(1147,h|0,64,k|0)|0;B=x[23549];x[23549]=0;if((B|0)==1){break a}w:{if(d){d=x[j>>2];if((d|0)==x[l+520>>2]){x[23549]=0;S(1149,i|0,j|0,l+520|0);d=x[23549];x[23549]=0;if((d|0)==1){break a}d=x[j>>2]}x[j>>2]=d+4;x[d>>2]=k;b=b+1|0;break w}if(!Bb(x[u+4>>2],y[u+11|0])|!b|(k|0)!=(z|0)){break u}if(x[l+96>>2]==(m|0)){x[23549]=0;S(1142,t|0,l+100|0,l+96|0);c=x[23549];x[23549]=0;if((c|0)==1){break a}m=x[l+100>>2]}c=m+4|0;x[l+100>>2]=c;x[m>>2]=b;m=c;b=0}x[23549]=0;R(1123,a|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){continue}}break}break a}if(!b|x[t>>2]==(c|0)){break f}if(x[l+96>>2]==(c|0)){x[23549]=0;S(1142,t|0,l+100|0,l+96|0);c=x[23549];x[23549]=0;if((c|0)==1){break a}c=x[l+100>>2]}m=c+4|0;x[l+100>>2]=m;x[c>>2]=b;break e}x[l+20>>2]=w;x:{if(!r){break x}k=1;while(1){if(Bb(x[r+4>>2],y[r+11|0])>>>0<=k>>>0){break x}x[23549]=0;b=O(1120,a|0,l+524|0)|0;c=x[23549];x[23549]=0;y:{if((c|0)==1){break y}z:{if(!b){b=x[a>>2];x[23549]=0;b=R(1121,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break y}if((b|0)==x[_i(r,k)>>2]){break z}}x[f>>2]=x[f>>2]|4;a=0;break d}x[23549]=0;R(1123,a|0)|0;b=x[23549];x[23549]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}a=1;b=x[t>>2];if((b|0)==(m|0)){break d}a=0;x[l+12>>2]=0;vf(u,b,m,l+12|0);if(x[l+12>>2]){x[f>>2]=x[f>>2]|4;break d}a=1;break d}m=c}A:{if((w|0)<=0){break A}x[23549]=0;b=O(1120,a|0,l+524|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}B:{if(!b){b=x[a>>2];x[23549]=0;b=R(1121,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}if((b|0)==x[l+88>>2]){break B}}x[f>>2]=x[f>>2]|4;a=0;break d}x[23549]=0;b=R(1123,a|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}while(1){if((w|0)<=0){w=0;break A}x[23549]=0;c=O(1120,b|0,l+524|0)|0;d=x[23549];x[23549]=0;C:{if((d|0)==1){break C}D:{if(!c){c=x[b>>2];x[23549]=0;c=R(1121,c|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break C}x[23549]=0;c=U(1147,h|0,64,c|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break C}if(c){break D}}x[f>>2]=x[f>>2]|4;a=0;break d}if(x[j>>2]==x[l+520>>2]){x[23549]=0;S(1149,i|0,j|0,l+520|0);c=x[23549];x[23549]=0;if((c|0)==1){break C}}c=x[b>>2];x[23549]=0;c=R(1121,c|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break C}d=x[j>>2];x[j>>2]=d+4;x[d>>2]=c;x[23549]=0;R(1123,b|0)|0;c=x[23549];x[23549]=0;w=w-1|0;if((c|0)!=1){continue}}break}break a}if(x[j>>2]!=x[i>>2]){break c}x[f>>2]=x[f>>2]|4;a=0}Ec(s);Ec(o);Ec(n);Ec(q);tb(u);Kc(t);break b}e=e+1|0;continue}}break a}db=l+528|0;return a|0}a=N()|0;Ec(s);Ec(o);Ec(n);Ec(q);tb(u);Kc(t);Q(a|0);p()}function gO(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=E(0),s=0,t=0,u=0,C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=E(0),Q=E(0),R=0,S=0,T=E(0),U=0;j=db-48|0;db=j;Ji(b+223848|0,ri(e,oi(e,mo(e),0))+1|0);ge(j+40|0,x[b+223848>>2],x[b+223852>>2]);ec(j+32|0,e,ri(e,oi(e,mo(e),0)));F=x[j+32>>2];G=x[j+36>>2];o=db-16|0;db=o;u=a+1074312|0;g=D(c,872)+b|0;H=g+1415|0;I=g+1304|0;J=g+1392|0;q=g+1368|0;s=g+1364|0;K=g+1336|0;L=g+1308|0;M=g+1300|0;N=g+1280|0;O=g+1402|0;l=g+1466|0;P=E(y[l|0]);Q=E(f>>>0);C=g+616|0;k=x[g+1272>>2];p=1;m=255;while(1){if((n|0)!=(G|0)&A[j+44>>2]>i>>>0){h=y[Db(F,n)|0];e=h-48|0;a:{b:{if((e&255)>>>0<=9){break b}if((h-65&255)>>>0<=5){e=h-55|0;break b}c:{d:{e:{switch(h-97|0){case 2:f:{e=Dl(a,b,c,3,0);if((e-1&255)>>>0>249){break f}e=x[(D(e,160)+a|0)+906140>>2];if(!e){break f}e=Py(e,47664,44764);if(!e){break f}e=ib[x[x[e>>2]+188>>2]](e,C,c)|0;h=(e|0)!=255;e=h?e:0;if(h|!k){break b}break c}if(k){break c}e=0;break b;case 21:g:{if(!Ob(u,28)){e=0;if(!Ob(u,1)){break g}}e=w[J>>1]}h=D(x[q>>2],x[s>>2]);e=D(x[a+1074456>>2],e+x[I>>2]|0);e=Ub((Cc(zka(yka(h,h>>31,e,e>>31),hb,1048576,0),hb)|0)/2|0,1,127);break d;case 20:e=D(x[q>>2],x[s>>2]);h=e;t=e>>31;e=D(x[a+1074456>>2],x[K>>2]);e=Ub((Cc(zka(yka(h,t,e,e>>31),hb,67108864,0),hb)|0)/2|0,1,127);break d;case 23:x[o>>2]=x[L>>2]/2;x[o+12>>2]=127;e=x[qd(o,o+12|0)>>2];break d;case 24:x[o>>2]=x[M>>2]/2;x[o+12>>2]=127;e=x[qd(o,o+12|0)>>2];break d;case 0:e=0;if(!k){break d}h=z[k+28>>1];if(!h){break d}e=h-1>>>7&127;break d;case 1:e=0;if(!k){break d}h=z[k+28>>1];if(!h){break d}e=h-1&127;break d;case 14:e=x[N>>2]>>>8|0;break d;case 7:e=(z[a+480188>>1]<=c>>>0?y[O|0]-1|0:c)&127;break d;case 12:e=y[g+704|0]>>>7|0;break d;case 15:e=0;if(!k){break d}h=y[k+30|0];if(!h){break d}e=h-1&127;break d;case 25:h:{if(!d|v[l|0]<0){break h}i:{if(i>>>0<3){break i}e=x[j+40>>2];if(y[Db(e,i-3|0)|0]!=240){break i}if(y[Db(e,i-2|0)|0]>239){break h}}r=Kp(b,P,Q);j:{if(r<E(4294967296)&r>=E(0)){e=~~r>>>0;break j}e=0}v[l|0]=e;m=128;break d}m=(m&255)==255?f:m;e=f;break d;case 18:k:{if(!i){e=0;break k}h=x[j+40>>2];e=i;while(1){e=e-1|0;t=Db(h,e);if(!e){break k}if(y[t|0]!=240){continue}break}}if(i-e>>>0<5){break a}t=x[j+40>>2];if(y[Db(t,e)|0]!=240){break a}e=e+5|0;h=0;while(1){if((e|0)!=(i|0)){h=y[Db(t,e)|0]+h|0;e=e+1|0;continue}break};e=0-h&127;break d;case 13:break e;default:break a}}e=y[H|0];e=Tc(e)?e-1|0:0}h=p^-1;p=1;i=(h&1)+i|0;R=Db(x[j+40>>2],i),S=e,v[R|0]=S;i=i+1|0;break a}e=z[C+786>>1];h=y[k+31|0];e=(e?e-1|0:c)&15;l:{if((h|0)==17){break l}e=ej(h)?h-1&15:0}}h=Db(x[j+40>>2],i);v[h|0]=(p&1?0:y[h|0]<<4)|e;p=p^1;i=(p&1)+i|0}n=n+1|0;continue}else{if(m<<24>>24>=0){v[l|0]=m}dc(o,x[j+40>>2],((p^-1)&1)+i|0);e=x[o+4>>2];x[j+40>>2]=x[o>>2];x[j+44>>2]=e;db=o+16|0}break}o=x[j+44>>2];i=0;m:while(1){p=0;while(1){e=i;n:{o:{p:{q:{while(1){if(A[j+44>>2]<=e>>>0){break n}f=x[j+40>>2];g=Db(f,e);l=v[g|0];if((l|0)==-16){if(o-e>>>0>=4){i=4;if((y[Db(f,e+1|0)|0]&254)==240){break o}}i=e;r:{while(1){i=i+1|0;if(o>>>0<=i>>>0){break r}if(y[Db(f,i)|0]!=247){continue}break}i=(i-e|0)+1|0;if(i){break o}}R=Db(f,o),S=247,v[R|0]=S;o=o+1|0;i=o-e|0;break p}if((l|0)<0){break q}if(p&255){e=e-1|0;R=Db(f,e),S=p,v[R|0]=S;continue}break}i=i+1|0;continue m}R=j,S=rQ(l&255),x[R+20>>2]=S;x[j+28>>2]=o-e;i=x[Cb(j+20|0,j+28|0)>>2]}if(!i){break n}f=x[j+40>>2];g=Db(f,e)}u=y[g|0];yq(j+20|0,f,x[j+44>>2],e,i);f=ec(j+12|0,x[j+20>>2],x[j+24>>2]);l=x[f+4>>2];x[j>>2]=x[f>>2];x[j+4>>2]=l;l=db-32|0;db=l;k=x[j+4>>2];s:{if(!k){break s}m=vd(y[b+223884|0]);t:{f=x[j>>2];n=Db(f,0);g=y[n|0]-250|0;if(g>>>0>5|!(1<<g&37)){break t}h=z[a+480188>>1];g=0;while(1){if((g|0)==(h|0)){break t}q=(D(g,872)+b|0)+1453|0;v[q|0]=127;v[q+1|0]=0;g=g+1|0;continue}}u:{if((k|0)!=4|y[n|0]!=240){break u}g=y[Db(f,1)|0];if((g&254)!=240){break u}k=(D(c,872)+b|0)+616|0;n=Db(f,2);q=y[Db(f,3)|0];f=q<<24>>24;s=(g|0)!=241&(f|0)>=0;n=y[n|0];if(!(!s|n)){g=D(c,872)+b|0;n=g+1453|0;if(d){f=Ug(Kp(b,E(y[n|0]),E((f&255)>>>0)))}v[n|0]=f;v[g+1412|0]=0;f=Rp(a,k,!(x[g+704>>2]&32768),256);if((f|0)<0|!(y[g+705|0]&2)){break s}g=x[a+1298300>>2];if(m|ud(g)^1){break s}Vp(g,c,f>>>2&255,1);break s}h=n<<24>>24;if(s&(h|0)==1){g=D(c,872)+b|0;m=g+1454|0;if(d){f=Ug(Kp(b,E(y[m|0]),E((f&255)>>>0)))}v[m|0]=f;v[g+1411|0]=0;Rp(a,k,!(x[g+704>>2]&32768),256);break s}if(!((g|0)==241|(h|0)!=2)){if(f>>>0>31){break s}g=D(c,872)+b|0;v[g+1461|0]=(f&240)>>>4;Rp(a,k,!(x[g+704>>2]&32768),256);break s}if(!((g|0)==241|(h|0)!=3)){h=(f|0)<0;f=Dl(a,b,c,3,0)-1|0;if(h|(f&255)>>>0>249){break s}v[l+24|0]=f;g=f&255;f=x[(D(g,160)+a|0)+906300>>2];if(!f){break s}r=E(E(127-q|0)/E(127));if(m){m=0;g=db-16|0;db=g;R=g,S=$j(l+24|0),x[R+4>>2]=S;f=db-16|0;db=f;k=b+223860|0;h=Oy(k,f+12|0,y[l+24|0]);n=x[h>>2];if(!n){m=db-16|0;db=m;n=gc(k);q=rh(f,Hc(24),Ag(m+8|0,n));n=x[q>>2];s=y[x[g+4>>2]];x[n+20>>2]=0;v[n+16|0]=s;R=gc(q),S=1,v[R+4|0]=S;db=m+16|0;Yg(k,x[f+12>>2],h,x[f>>2]);n=Zd(f);ol(f);m=1}Xg(g+8|0,x[vb(f,n)>>2],m);db=f+16|0;f=td(x[g+8>>2]);db=g+16|0;B[f+4>>2]=r;break s}if(!d){bt(x[f+20>>2],r);break s}bt(x[f+20>>2],Kp(b,B[(D(g,160)+a|0)+906444>>2],r));break s}if((g|0)!=241&(h|0)>=0){break s}h=Dl(a,b,c,3,0)-1|0;if((f|0)<0|(h&255)>>>0>249){break s}k=x[(D(h&255,160)+a|0)+906300>>2];if(!k){break s}g=(g|0)!=241?n&127:n+128|0;r=E(E((f&255)>>>0)/E(127));if(m){R=yO(b+223872|0,RN(l+24|0,h,g)),T=r,B[R>>2]=T;break s}f=x[k>>2];if(!d){ib[x[f+44>>2]](k,g,r);break s}S=k,U=g,T=Kp(b,E(ib[x[f+48>>2]](k,g)),r),R=x[x[k>>2]+44>>2],ib[R](S|0,U|0,E(T));break s}if(m){break s}m=z[a+480188>>1];v:{if(m>>>0>c>>>0){g=c+1|0;break v}g=z[(D(c,872)+b|0)+1402>>1];if(!g){break s}}if(y[(D(c,872)+b|0)+707|0]&4|m>>>0<(g&65535)>>>0){break s}g=Dl(a,b,c,3,0);if((g-1&255)>>>0>249){break s}g=x[(D(g,160)+a|0)+906140>>2];if(!g){break s}m=y[n|0];if((m|0)==240){Ng(l+16|0,x[j>>2],x[j+4>>2]);f=x[x[g>>2]+72>>2];k=x[l+20>>2];x[l>>2]=x[l+16>>2];x[l+4>>2]=k;ib[f|0](g,l)|0;break s}R=l,U=rQ(m),x[R+24>>2]=U;x[l+12>>2]=k;k=l+24|0;m=x[Cb(k,l+12|0)>>2];x[l+24>>2]=0;rc(k,f,m);ib[x[x[g>>2]+68>>2]](g,x[l+24>>2])|0}db=l+32|0;p=u>>>0<240?u:p;i=e+i|0;continue}break}break}db=j+48|0}function E$(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;l=db-528|0;db=l;x[l+520>>2]=k;x[l+524>>2]=b;a:{b:{if(Og(a,l+524|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+76>>2]=1136;b=l+76|0;t=pe(l+104|0,l+112|0,b);m=x[t>>2];x[l+100>>2]=m;x[l+96>>2]=m+400;u=Gb(b);q=Gb(l- -64|0);n=Gb(l+52|0);o=Gb(l+40|0);s=Gb(l+28|0);b=x[d>>2];x[23549]=0;ha(1139,c|0,b|0,l+92|0,l+91|0,l+90|0,u|0,q|0,n|0,o|0,l+24|0);b=x[23549];x[23549]=0;if((b|0)!=1){x[j>>2]=x[i>>2];A=e&512;w=x[l+24>>2];B=y[l+95|0];C=y[l+91|0];D=y[l+90|0];d=m;e=0;while(1){c:{d:{e:{f:{if((e|0)==4){break f}x[23549]=0;b=O(1105,a|0,l+524|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}if(b){break f}b=0;g:{h:{i:{j:{k:{switch(v[(l+92|0)+e|0]){case 1:if((e|0)==3){break c}b=x[a>>2];x[23549]=0;b=R(1106,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}if(ih(x[h+8>>2],1,b)){x[23549]=0;P(1140,l+16|0,a|0);b=x[23549];x[23549]=0;if((b|0)!=1){x[23549]=0;P(46,s|0,v[l+16|0]);b=x[23549];x[23549]=0;if((b|0)!=1){break j}}break a}x[f>>2]=x[f>>2]|4;a=0;break d;case 4:break g;case 2:break h;case 3:break i;case 0:break k;default:break c}}if((e|0)==3){break c}}while(1){x[23549]=0;b=O(1105,a|0,l+524|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}if(b){break c}b=x[a>>2];x[23549]=0;b=R(1106,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}if(!ih(x[h+8>>2],1,b)){break c}x[23549]=0;P(1140,l+16|0,a|0);b=x[23549];x[23549]=0;if((b|0)!=1){x[23549]=0;P(46,s|0,v[l+16|0]);b=x[23549];x[23549]=0;if((b|0)!=1){continue}}break}break a}l:{if(!Bb(x[n+4>>2],y[n+11|0])){break l}b=x[a>>2];x[23549]=0;b=R(1106,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}if(y[uc(n,0)|0]!=(b&255)){break l}x[23549]=0;R(1108,a|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break a}v[g|0]=0;r=Bb(x[n+4>>2],y[n+11|0])>>>0>1?n:r;break c}m:{n:{k=x[o+4>>2];b=y[o+11|0];if(Bb(k,b)){b=x[a>>2];x[23549]=0;b=R(1106,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}if(y[uc(o,0)|0]==(b&255)){break n}k=x[o+4>>2];b=y[o+11|0]}c=Bb(x[n+4>>2],y[n+11|0]);if(!c){break m}if(!Bb(k,b)){break m}x[f>>2]=x[f>>2]|4;a=0;break d}x[23549]=0;R(1108,a|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break a}v[g|0]=1;r=Bb(x[o+4>>2],y[o+11|0])>>>0>1?o:r;break c}b=Bb(k,b);if(!(b|c)){break c}v[g|0]=!b;break c}if(!(e>>>0<2|r|((e|0)==2&(B|0)!=0|A))){r=0;break c}c=vb(l+16|0,od(q));o:{if(!e|y[(e+l|0)+91|0]>1){break o}while(1){p:{b=tf(q);k=x[c>>2];if(!Kb(k,b)){break p}if(!ih(x[h+8>>2],1,v[k|0])){break p}Oe(c);continue}break}b=od(q);b=he(x[c>>2],b);if(Bb(x[s+4>>2],y[s+11|0])>>>0>=b>>>0){k=CA(tf(s),b);E=tf(s);z=od(q);b=db-16|0;db=b;x[b+8>>2]=z;x[b+12>>2]=k;while(1){z=Kb(k,E);if(!(!z|y[k|0]!=y[x[b+8>>2]])){k=Oe(b+12|0);Oe(b+8|0);k=x[k>>2];continue}break}db=b+16|0;if(z^1){break o}}F=c,G=x[vb(l+12|0,od(q))>>2],x[F>>2]=G}x[l+12>>2]=x[c>>2];q:{while(1){b=tf(q);if(!Kb(x[l+12>>2],b)){break q}x[23549]=0;b=O(1105,a|0,l+524|0)|0;c=x[23549];x[23549]=0;r:{if((c|0)==1){break r}if(b){break q}b=x[a>>2];x[23549]=0;b=R(1106,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break r}if(y[x[l+12>>2]]!=(b&255)){break q}x[23549]=0;R(1108,a|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break a}Oe(l+12|0);continue}break}break a}if(!A){break c}b=tf(q);if(!Kb(x[l+12>>2],b)){break c}x[f>>2]=x[f>>2]|4;a=0;break d}s:{while(1){t:{x[23549]=0;c=O(1105,a|0,l+524|0)|0;k=x[23549];x[23549]=0;if((k|0)==1){break t}if(c){break s}c=x[a>>2];x[23549]=0;k=R(1106,c|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}u:{if(ih(x[h+8>>2],64,k)){c=x[j>>2];if((c|0)==x[l+520>>2]){x[23549]=0;S(1141,i|0,j|0,l+520|0);c=x[23549];x[23549]=0;if((c|0)==1){break a}c=x[j>>2]}x[j>>2]=c+1;v[c|0]=k;b=b+1|0;break u}if(!Bb(x[u+4>>2],y[u+11|0])|!b|(k&255)!=(D|0)){break s}if(x[l+96>>2]==(d|0)){x[23549]=0;S(1142,t|0,l+100|0,l+96|0);c=x[23549];x[23549]=0;if((c|0)==1){break a}d=x[l+100>>2]}m=d+4|0;x[l+100>>2]=m;x[d>>2]=b;d=m;b=0}x[23549]=0;R(1108,a|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){continue}}break}break a}if(!(!b|x[t>>2]==(m|0))){if(x[l+96>>2]==(m|0)){x[23549]=0;S(1142,t|0,l+100|0,l+96|0);c=x[23549];x[23549]=0;if((c|0)==1){break a}m=x[l+100>>2]}c=m+4|0;x[l+100>>2]=c;x[m>>2]=b;m=c}if((w|0)<=0){break e}x[23549]=0;b=O(1105,a|0,l+524|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}v:{if(!b){b=x[a>>2];x[23549]=0;b=R(1106,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}if((b&255)==(C|0)){break v}}x[f>>2]=x[f>>2]|4;a=0;break d}x[23549]=0;b=R(1108,a|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}while(1){if((w|0)<=0){w=0;break e}x[23549]=0;c=O(1105,b|0,l+524|0)|0;d=x[23549];x[23549]=0;w:{if((d|0)==1){break w}x:{if(!c){c=x[b>>2];x[23549]=0;c=R(1106,c|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break w}if(ih(x[h+8>>2],64,c)){break x}}x[f>>2]=x[f>>2]|4;a=0;break d}if(x[j>>2]==x[l+520>>2]){x[23549]=0;S(1141,i|0,j|0,l+520|0);c=x[23549];x[23549]=0;if((c|0)==1){break w}}c=x[b>>2];x[23549]=0;c=R(1106,c|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break w}d=x[j>>2];x[j>>2]=d+1;v[d|0]=c;x[23549]=0;R(1108,b|0)|0;c=x[23549];x[23549]=0;w=w-1|0;if((c|0)!=1){continue}}break}break a}x[l+24>>2]=w;y:{if(!r){break y}k=1;while(1){if(Bb(x[r+4>>2],y[r+11|0])>>>0<=k>>>0){break y}x[23549]=0;b=O(1105,a|0,l+524|0)|0;c=x[23549];x[23549]=0;z:{if((c|0)==1){break z}A:{if(!b){b=x[a>>2];x[23549]=0;b=R(1106,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break z}if(y[uc(r,k)|0]==(b&255)){break A}}x[f>>2]=x[f>>2]|4;a=0;break d}x[23549]=0;R(1108,a|0)|0;b=x[23549];x[23549]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}a=1;b=x[t>>2];if((b|0)==(m|0)){break d}a=0;x[l+16>>2]=0;vf(u,b,m,l+16|0);if(x[l+16>>2]){x[f>>2]=x[f>>2]|4;break d}a=1;break d}d=m;if(x[j>>2]!=x[i>>2]){break c}x[f>>2]=x[f>>2]|4;a=0}tb(s);tb(o);tb(n);tb(q);tb(u);Kc(t);break b}e=e+1|0;continue}}break a}db=l+528|0;return a|0}a=N()|0;tb(s);tb(o);tb(n);tb(q);tb(u);Kc(t);Q(a|0);p()}function Hfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=db-272|0;db=d;wc(b);e=db-16|0;db=e;f=d+126|0;RR(e+8|0,f);g=x[e+12>>2];lc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);h=x[e+4>>2];if((h|0)==(g|0)){Zb(b,x[e+12>>2])}db=e+16|0;e=(g|0)==(h|0);if(!e){QR(f)}a:{b:{c:{d:{if(!e){break d}if(!SR(d+126|0)){break d}if(!c){i=1;break d}Bd(a,4194304);e=d+40|0;g=Tb(e,16626);zb(a+1298344|0,g);tb(g);g=Tb(e,10020);zb(a+1298356|0,g);tb(g);x[a+1298404>>2]=5;n=a,o=Vd(y[d+204|0]|y[d+205|0]<<8,y[d+206|0]|y[d+207|0]<<8,127),w[n+480188>>1]=o;g=y[d+195|0];x[a+480228>>2]=(g|0)==255?48:g;x[a+480196>>2]=y[d+193|0];x[a+480204>>2]=D(y[d+194|0],1e4);g=d+104|0;gf(g,d+130|0,59,3);Bc(e,g);zb(a+1298308|0,e);tb(e);e=y[d+208|0]|y[d+209|0]<<8|(y[d+210|0]<<16|y[d+211|0]<<24);e:{if(e>>>0<5){break e}if(!Vc(b,e-4|0)){break e}if(!Bi(b,13924)){break e}Ao(Wb(x[a+484360>>2],y[a+484376|0]),b,y[d+198|0]|y[d+199|0]<<8,65535,65535)}f:{e=y[d+212|0]|y[d+213|0]<<8|(y[d+214|0]<<16|y[d+215|0]<<24);if(e>>>0<5){break f}if(!Vc(b,e-4|0)){break f}if(!Bi(b,13561)){break f}e=0;while(1){if((e|0)==32){break f}g=(e<<5)+a|0;Te(g+480280|0);n=g+480284|0,o=((((ee(b)^-1)&15)<<8|8)>>>0)/15|0,w[n>>1]=o;e=e+1|0;continue}}e=y[d+220|0]|y[d+221|0]<<8|(y[d+222|0]<<16|y[d+223|0]<<24);g:{if(e>>>0<5){break g}if(!Vc(b,e-4|0)){break g}if(!Bi(b,13837)){break g}e=d+40|0;Wd(e,b,(y[d+202|0]|y[d+203|0]<<8)<<6);k=c&2;h=a+480190|0;g=hc(d+104|0,e);ub(e);j=d+53|0;e=0;h:{while(1){if((e&65535)>>>0>=(y[d+202|0]|y[d+203|0]<<8)>>>0){break h}x[23549]=0;f=O(627,g|0,d+40|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break b}if(!f){break h}f=y[d+85|0]|y[d+86|0]<<8;w[d+38>>1]=f;i:{j:{if((f-1&65535)>>>0>3998){break j}f=D(f,104)+a|0;i=f+484380|0;if(Sd(x[i>>2],x[f+484400>>2])){break j}n=h,o=z[Ve(h,d+38|0)>>1],w[n>>1]=o;x[23549]=0;P(628,d+40|0,i|0);f=x[23549];x[23549]=0;if((f|0)==1){break i}f=d+12|0;gf(f,j,24,1);x[23549]=0;P(208,d+24|0,f|0);f=x[23549];x[23549]=0;if((f|0)==1){break b}f=d+24|0;zc(((z[d+38>>1]<<5)+a|0)+946304|0,f);tb(f);if(!k){break j}x[23549]=0;O(141,b|0,y[d+77|0]|y[d+78|0]<<8|(y[d+79|0]<<16|y[d+80|0]<<24))|0;f=x[23549];x[23549]=0;if((f|0)==1){break i}i=1;l=d+24|0;f=y[d+87|0];m=Xc(l,f&4?16:8,1,0,0);k:{l:{if(f&8){break l}i=2;if(f&16){break l}if(f&127){break k}}Uf(m,i)}x[23549]=0;U(205,l|0,(D(z[d+38>>1],104)+a|0)+484380|0,b|0)|0;f=x[23549];x[23549]=0;if((f|0)!=1){break j}break b}e=e+1|0;continue}break}break b}ub(g)}i=1;if(!(c&1)){break d}m:{c=y[d+216|0]|y[d+217|0]<<8|(y[d+218|0]<<16|y[d+219|0]<<24);if(c>>>0<5){break m}if(!Vc(b,c-4|0)){break m}if(!Bi(b,13427)){break m}k=a+484344|0;mg(k,y[d+200|0]|y[d+201|0]<<8);f=0;while(1){if((y[d+200|0]|y[d+201|0]<<8)>>>0<=f>>>0){break m}if(!LA(b,d+24|0)){break m}n:{e=z[d+24>>1];if(e>>>0>3){c=d+104|0;Wd(c,b,(e+15&131056)-4|0);g=hc(d+40|0,c);ub(c);x[23549]=0;c=U(212,k|0,f&65535,y[d+26|0])|0;e=x[23549];x[23549]=0;if((e|0)==1){break n}h=0;o:{if(!c){break o}while(1){p:{c=x[g>>2];x[23549]=0;e=U(142,c|0,x[d+48>>2],1)|0;c=x[23549];x[23549]=0;q:{if((c|0)!=1){c=y[d+26|0];if(!(e&c>>>0>(h&255)>>>0)){break p}x[23549]=0;c=R(192,g|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break c}e=c<<24>>24;if(e){break q}h=h+1|0;continue}break c}c=x[a+484344>>2];w[d+104>>1]=e&31;w[d+12>>1]=z[a+480188>>1]-1;c=Yb(c,f);c=$c(x[c>>2],x[x[c+48>>2]+12>>2],h,z[Uc(d+104|0,d+12|0)>>1]);if((e|0)<0){x[23549]=0;P(249,d+104|0,g|0);j=x[23549];x[23549]=0;if((j|0)==1){break c}v[c|0]=y[d+104|0]+36;n=c,o=y[fd(d+104|0)|0],v[n+1|0]=o}e=e&255;if(e&64){v[c+2|0]=1;x[23549]=0;j=R(192,g|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break c}v[d+104|0]=j;v[d+12|0]=64;n=c,o=y[Sb(d+104|0,d+12|0)|0],v[n+4|0]=o}if(!(e&32)){continue}x[23549]=0;P(249,d+104|0,g|0);e=x[23549];x[23549]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{if((e|0)!=1){e=y[fd(d+104|0)|0];v[c+5|0]=e;switch(y[d+104|0]-1|0){case 71:break s;case 70:break t;case 69:break u;case 60:break v;case 59:break w;case 52:break x;case 51:break y;case 50:break z;case 49:break A;case 42:break B;case 41:break C;case 40:break D;case 39:break E;case 30:break F;case 29:break G;case 22:break H;case 21:break I;case 20:break J;case 19:break K;case 16:break L;case 15:break M;case 14:break N;case 13:break O;case 12:break P;case 11:break Q;case 10:break R;case 9:break S;case 3:break T;case 2:break U;case 1:break V;case 0:break W;default:break r}}break c}v[c+3|0]=11;v[c+5|0]=e<<4|15;continue}v[c+3|0]=11;v[c+5|0]=e<<4;continue}v[c+3|0]=11;v[c+5|0]=e|240;continue}v[c+3|0]=11;v[c+5|0]=e&15;continue}v[c+3|0]=2;v[c+5|0]=e|240;continue}v[c+3|0]=2;continue}v[c+3|0]=3;v[c+5|0]=e|240;continue}v[c+3|0]=3;continue}v[c+3|0]=4;continue}v[c+3|0]=20;v[c+5|0]=e|16;continue}v[c+3|0]=6;v[c+5|0]=e<<4;continue}v[c+3|0]=6;v[c+5|0]=e&15;continue}v[c+3|0]=5;continue}v[c+3|0]=20;v[c+5|0]=e|48;continue}v[c+3|0]=7;v[c+5|0]=e<<4;continue}v[c+3|0]=7;v[c+5|0]=e&15;continue}v[c+3|0]=8;continue}v[c+3|0]=20;v[c+5|0]=e|64;continue}v[c+3|0]=10;x[23549]=0;e=R(192,g|0)|0;j=x[23549];x[23549]=0;if((j|0)!=1){v[c+5|0]=e;x[23549]=0;O(174,g|0,1)|0;c=x[23549];x[23549]=0;if((c|0)!=1){continue}}break c}v[c+3|0]=15;v[c+5|0]=e&15;continue}v[c+3|0]=20;v[c+5|0]=e|192;continue}v[c+3|0]=20;v[c+5|0]=e|208;continue}v[c+3|0]=12;continue}v[c+3|0]=14;continue}v[c+3|0]=20;v[c+5|0]=e|176;continue}v[c+3|0]=20;v[c+5|0]=e|224;continue}v[c+3|0]=16;continue}v[c+3|0]=17;continue}v[c+3|0]=1;continue}v[c+3|0]=20;v[c+5|0]=e&15|32;continue}v[c+3|0]=20;v[c+5|0]=e&15|128;continue}v[c+3|0]=0;continue}break}if((c|0)==64){break o}me(Yb(x[k>>2],f),wh(Fe(Be(d+104|0,14,0),c-1|0)))}ub(g)}f=f+1|0;continue}break}break c}c=y[d+224|0]|y[d+225|0]<<8|(y[d+226|0]<<16|y[d+227|0]<<24);if(!c){break d}Vc(b,c);vB(a+1298332|0,b,Fg(b),4)}db=d+272|0;return i|0}a=N()|0;break a}a=N()|0}ub(g);Q(a|0);p()}function cba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=db-48|0;db=i;d=x[b>>2];x[23549]=0;f=R(164,d|0)|0;d=x[23549];x[23549]=0;a:{b:{c:{d:{if((d|0)==1){break d}e:{f:{if(f){j=Nb(i+36|0);x[23549]=0;h=(c|0)!=0;e=U(799,j|0,b|0,h|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break e}f=2;g:{h:{i:{j:{if(e){break j}x[23549]=0;e=U(800,j|0,b|0,h|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break e}f=3;if(e){break j}x[23549]=0;e=U(801,j|0,b|0,h|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break e}f=4;if(e){break j}e=0;x[23549]=0;h=U(802,j|0,b|0,h|0)|0;d=x[23549];x[23549]=0;f=1;if((d|0)==1){break e}if(!h){break i}}if(!c){f=1;d=0;break h}d=x[j>>2];if(!qc(d,x[j+4>>2])){qv(b,d+12|0)}e=f}d=31616;k:{while(1){f=d;if((d|0)!=32132){h=x[f+8>>2];g=(h>>1)+a|0;d=x[f+4>>2];d=h&1?x[x[g>>2]+d>>2]:d;x[23549]=0;h=U(d|0,g|0,b|0,c|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break c}d=f+12|0;if(!h){continue}break k}break}x[a+480180>>2]=0;x[a+480184>>2]=0}if(!c){f=(f|0)!=32132;d=0;break h}if(!(x[a+480184>>2]|!e)){x[a+480184>>2]=e}x[23549]=0;d=1;P(741,a+1298264|0,1);e=x[23549];x[23549]=0;f=1;if((e|0)==1){break g}}gN(j);if(d){break f}break a}break c}x[23549]=0;P(235,a|0,0);d=x[23549];x[23549]=0;if((d|0)==1){break d}x[23549]=0;P(741,a+1298264|0,1);d=x[23549];x[23549]=0;if((d|0)==1){break d}x[a+1074304>>2]=19927555}f=0;while(1){if((f|0)==127){d=1;while(1){f=d&65535;if(f>>>0>z[a+480190>>1]){d=0;f=0;l:{while(1){e=f&65535;if(e>>>0>z[a+480192>>1]){m:{w[a+480192>>1]=d;d=a+480204|0;if(A[a+480204>>2]>=1e4){break m}x[d>>2]=125e4;break l}}else{g=x[((e<<2)+a|0)+900380>>2];if(g){e=x[a+480180>>2];tc(g,65536);tc(g+4|0,64);tc(g+8|0,256);Wf(g+28|0,16384);pf(g+30|0,128);pf(g+31|0,17);if(y[g+16|0]>=4){v[g+16|0]=0}if(y[g+17|0]>=5){v[g+17|0]=0}if(y[g+18|0]>=3){v[g+18|0]=0}pf(g+19|0,64);pf(g+20|0,100);h=224;d=v[g+26|0];n:{if((d|0)>=-32){h=32;if((d|0)<33){break n}}v[g+26|0]=h}pf(g+23|0,64);pf(g+24|0,64);Hz(g+48|0,64);Hz(g+68|0,64);Hz(g+88|0,(e|0)==4096?255:64);d=g+108|0;e=0;while(1){if((e|0)==128){if(!Mo(y[g+14|0])){v[g+14|0]=5}if(y[g+34|0]>=251){v[g+34|0]=0}}else{o:{if(y[Db(d,e)|0]){if(y[Db(d,e)|0]<121){break o}}l=Db(d,e),m=e+1|0,v[l|0]=m}e=e+1|0;continue}break}d=f}f=f+1|0;continue}break}tc(d,65535e4)}if(!x[a+480196>>2]){x[a+480196>>2]=6}f=a+480220|0;d=x[a+480216>>2];if(d>>>0>A[a+480220>>2]){x[f>>2]=d}d=a+480216|0;tc(d,65536);tc(f,65536);tc(a+480200|0,256);p:{if(!qc(x[a+480248>>2],x[a+480252>>2])){d=x[d>>2];x[23549]=0;P(803,a+480248|0,d|0);d=x[23549];x[23549]=0;if((d|0)==1){break p}}x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];d=x[a+480220>>2];f=a+1074408|0;x[f>>2]=x[a+480216>>2];x[f+4>>2]=d;x[a+1074456>>2]=x[a+480200>>2];Uy(a+1074376|0);d=a+1074446|0;w[d>>1]=0;w[d+2>>1]=0;w[d+4>>1]=0;w[d+6>>1]=65535;x[a+1074392>>2]=-2;d=a+1074384|0;x[d>>2]=0;x[d+4>>2]=0;x[a+1074380>>2]=0;d=a+1074424|0;x[d>>2]=0;x[d+4>>2]=0;x[a+1074432>>2]=0;d=a+1074396|0;x[d>>2]=0;x[d+4>>2]=0;if(ym(x[a+480180>>2])){x[23549]=0;O(254,a+1074312|0,7)|0;d=x[23549];x[23549]=0;if((d|0)==1){break p}}w[a+480276>>1]=0;Ip(a);l=i,m=yb(x[a+484360>>2]),x[l+36>>2]=m;f=yb(x[a+484364>>2]);q:{while(1){r:{e=x[i+36>>2];if(!Kb(e,f)){if(x[a+480180>>2]){break r}f=0;break a}x[23549]=0;W(804,e|0);d=x[23549];x[23549]=0;if((d|0)==1){break q}if(Ic(x[e>>2],x[e+4>>2])>>>0<=z[e+28>>1]){$e(e,0)}Wp(i+36|0);continue}break}Xs(a+8|0,tq(a));if(x[a+1074308>>2]){x[23549]=0;W(805,a|0);d=x[23549];x[23549]=0;if((d|0)==1){break p}}j=Nb(i+36|0);s:{t:{if((c&12)!=12){break t}f=0;u:{v:{w:{x:{y:{z:{while(1){if((f|0)==250){break t}A:{h=D(f,160)+a|0;d=h+906316|0;B:{if(!(x[d>>2]|x[h+906320>>2])){break B}x[23549]=0;k=h+906300|0;P(806,k|0,a|0);c=x[23549];x[23549]=0;C:{if((c|0)!=1){e=x[k>>2];if(!e){break C}d=x[h+906448>>2];c=x[x[e>>2]+56>>2];x[23549]=0;P(c|0,e|0,d|0);c=x[23549];x[23549]=0;if((c|0)!=1){break B}}a=N()|0;break s}g=yb(x[j>>2]);c=yb(x[j+4>>2]);h=db-16|0;db=h;x[h+12>>2]=g;while(1){D:{if(!Kb(g,c)){break D}e=x[g>>2];if((y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24))==(y[k+20|0]|y[k+21|0]<<8|(y[k+22|0]<<16|y[k+23|0]<<24))){e=(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))==(y[k+16|0]|y[k+17|0]<<8|(y[k+18|0]<<16|y[k+19|0]<<24))}else{e=0}if(e){break D}g=x[Ae(h+12|0)>>2];continue}break}db=h+16|0;if(Kb(g,yb(x[j+4>>2]))){break B}x[23549]=0;x[i+24>>2]=d;P(807,j|0,i+24|0);c=x[23549];x[23549]=0;if((c|0)==1){break A}x[23549]=0;d=O(1,i+12|0,17279)|0;c=x[23549];x[23549]=0;if((c|0)==1){break z}x[23549]=0;P(808,i|0,k|0);c=x[23549];x[23549]=0;if((c|0)==1){break y}x[23549]=0;S(2,i+24|0,d|0,i|0);c=x[23549];x[23549]=0;if((c|0)==1){break x}c=x[a+1298464>>2];x[23549]=0;S(359,c|0,2,i+24|0);c=x[23549];x[23549]=0;if((c|0)==1){break w}tb(i+24|0);tb(i);tb(d)}f=f+1|0;continue}break}a=N()|0;break s}a=N()|0;break s}a=N()|0;break u}a=N()|0;break v}a=N()|0;tb(i+24|0)}tb(i)}tb(d);break s}c=y[a+1074368|0];x[23549]=0;P(809,a|0,c|0);a=x[23549];x[23549]=0;f=1;if((a|0)!=1){sc(j);break a}a=N()|0}sc(j);break b}a=N()|0;break b}a=N()|0;break b}h=D(f,104)+a|0;g=h+484380|0;E:{if(Sd(x[g>>2],x[h+484400>>2])){dj(g,a);break E}e=h+484414|0;f=z[e>>1];if(f&16384){break E}x[g>>2]=0;x[g+4>>2]=0;x[g+16>>2]=0;x[g+8>>2]=0;x[g+12>>2]=0;w[e>>1]=f&65505}f=h+484412|0;if(z[f>>1]>=65){w[f>>1]=64}F:{G:{if(!(y[h+484415|0]&2)){break G}if(!Sj(x[a+1298300>>2])){break G}x[23549]=0;W(810,a|0);f=x[23549];x[23549]=0;if((f|0)==1){break F}}d=d+1|0;continue}break}a=N()|0;break b}e=(f<<5)+a|0;Wf(e+480286|0,64);d=e+480284|0;if(z[d>>1]>=257){w[d>>1]=128}d=e+480288|0;if(y[d|0]>=251){v[d|0]=0}ko((D(f,872)+a|0)+1074992|0,a,f&65535,134217728);f=f+1|0;continue}}break c}a=N()|0;break b}a=N()|0;gN(j)}ub(b);Q(a|0);p()}ub(b);db=i+48|0;return f|0}function ht(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;n=db-16|0;db=n;x[n+12>>2]=c;a:{if((c|0)<=0){break a}i=x[b+104>>2];b:{c:{d:{e:{f:{g:{h:{i:{j:{j=x[b+656>>2];k:{if(!(!j|x[a+480180>>2]!=16777216)){m=x[j+44>>2]!=0;break k}if(!j){break j}}if((c|0)>128){break i}l=c-1|0;h=z[_b(j+236|0,l)>>1];l:{if((h-1&65535)>>>0<=3998){i=(D(h,104)+a|0)+484380|0;break l}if(!Ob(a+1074312|0,43)){break l}if(!Pj(x[b+656>>2])){break a}}l=y[Db(j+108|0,l)|0];x[n+12>>2]=l;if(l>>>0<=120){break h}c=l;break i}l=c;h=0;if(c>>>0<121){break g}}m:{if(!(x[a+480180>>2]&16777248?(c|0)!=255:0)){$n(a,b);if(d){break m}if(!Ob(a+1074312|0,100)|!(y[a+480208|0]&4)|!y[b+789|0]){break m}x[b+88>>2]=x[b+88>>2]&-6145;break m}if(!z[a+480192>>1]){break m}x[b+88>>2]=x[b+88>>2]|4096}n:{if((c|0)!=254){break n}c=x[b+88>>2];if(!(!(c&512)|x[a+480180>>2]!=2)){x[b+88>>2]=c|2048;break n}x[b+88>>2]=c|2101248;o:{if(x[a+480180>>2]&16777248){if(!z[a+480192>>1]){break o}if(Ob(a+1074312|0,50)){break o}}x[b+688>>2]=0}if(Ob(a+1074312|0,50)){x[b+8>>2]=0;x[b+12>>2]=0}x[b+696>>2]=0}if(!Ob(a+1074312|0,20)){break a}v[b+797|0]=0;v[b+802|0]=0;break a}h=0;if(!m){break g}if(d){h=y[b+797|0];if(h){break f}}x[b+708>>2]=0;h=1}if(d){break e}if(!(!(x[a+480180>>2]&1048588)|!i)){w[b+770>>1]=v[i+36|0];w[b+772>>1]=v[i+37|0];break d}if(i){break d}i=0;p=1;break c}h=D((x[x[j+44>>2]+36>>2]<<16>>16)+1|0,(l<<16>>16)-(h<<16>>16)|0)-x[b+852>>2]|0;x[b+708>>2]=h;x[b+852>>2]=0-h;h=1}p=!i;m=1;if(si(x[b+8>>2],x[b+12>>2])){break b}m=a+1074312|0;if(Ob(m,54)){x[b+700>>2]=0;break a}m=(Ob(m,39)^-1)&d;break b}if(!Ob(a+1074312|0,24)){break c}x[b+704>>2]=x[i+24>>2]}m=0}p:{if(ym(x[a+480180>>2])){x[n+12>>2]=w[b+770>>1]+l;ke(n+12|0,12,131);break p}sS(n+12|0)}k=a+1074312|0;q:{if(Ob(k,34)){d=Am(c);break q}d=x[n+12>>2]}v[b+797|0]=d;v[b+851|0]=y[b+851|0]&183|64;if(!(x[a+480180>>2]&16777250?0:m)){v[b+803|0]=0}o=Rg(a,x[n+12>>2],w[b+772>>1],x[b+704>>2]);v[b+831|0]=0;if(Ob(k,48)){aO(a,b,j,i)}r:{if(!Ob(k,115)|!j){break r}d=y[j+26|0];if(!d){break r}if(!z[b+784>>1]){w[b+784>>1]=z[b+692>>1]+1}$N(b+692|0,c,d,y[j+27|0])}s:{if(m|e^1){break s}x[b+776>>2]=0;x[b+780>>2]=0;if(!j){break s}if(Ob(k,29)){v[b+798|0]=y[j+16|0]}if(!(y[j+60|0]&8)){$i(b+724|0)}if(!(y[j+80|0]&8)){$i(b+732|0)}if(!(y[j+100|0]&8)){$i(b+740|0)}if(y[j+20|0]){c=((D(ft(_n(a)),y[j+20|0])<<16>>16)/64|0)+1<<16>>16;t:{if(Ob(k,28)){d=x[b+752>>2];break t}d=(x[b+688>>2]+1|0)/2|0}w[b+776>>1]=(D(d,c)|0)/199}u:{if(!y[j+19|0]){break u}r=b,s=(D(ft(_n(a)),y[j+19|0])<<16>>16)/32|0,w[r+778>>1]=s;if(Ob(k,28)|z[b+784>>1]){break u}w[b+784>>1]=z[b+692>>1]+1}l=y[j+23|0];if(l){d=ft(_n(a));c=y[b+837|0];v[b+796|0]=c+1;w[b+780>>1]=(D((D(l,d+1|0)<<16>>16)/128<<16>>16,c)+1|0)/128}l=y[j+24|0];if(!l){break s}d=ft(_n(a));c=y[b+838|0];v[b+795|0]=c+1;w[b+782>>1]=(D(c,(D(l,d+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(p){break a}v:{w:{if(!o){d=0;break w}if(!(m&x[b+700>>2]!=0)){x[b+700>>2]=o}x:{y:{if(!h){if(!m){if(Ob(k,69)){break y}if(Ob(k,46)|x[a+480180>>2]==1){break y}}x[b+708>>2]=o;v[b+851|0]=y[b+851|0]&239}if(!m){break y}if(x[b+76>>2]|y[a+480180|0]&2){break x}}x[b+104>>2]=i;c=x[i>>2];x[b+84>>2]=c;x[b+76>>2]=c;x[b+80>>2]=0;x[b>>2]=0;x[b+4>>2]=0;z:{A:{B:{if(!(y[a+480210|0]&32)){if(!Ob(k,96)|y[b+789|0]){break A}q=x[b>>2];c=x[b+76>>2];break B}if(y[b+789|0]){break A}}x[n+8>>2]=c-1;c=x[Cb(b+660|0,n+8|0)>>2];x[b>>2]=q;x[b+4>>2]=c;break z}x[b+660>>2]=0}c=z[i+34>>1];h=c&1023;d=h|x[b+88>>2]&-525056;x[b+88>>2]=d;C:{D:{if(c&8){x[b+80>>2]=x[i+12>>2];c=x[i+16>>2];x[b+88>>2]=(h&16?d|4:d&-524295)|2;x[b+84>>2]=c;if(A[b+76>>2]>c>>>0){break D}break C}if(!(h&2)){break C}x[b+80>>2]=x[i+4>>2];c=x[i+8>>2];x[b+84>>2]=c;if(A[b+76>>2]<=c>>>0){break C}}x[b+76>>2]=c}E:{if(!(r=0,s=Ob(k,83),t=x[b+80>>2],t?r:s)){c=x[b+76>>2];break E}c=x[i>>2];x[b+84>>2]=c;x[b+76>>2]=c}d=x[b+88>>2];if(!(!(d&128)|!c)){x[b+4>>2]=c-1;x[b+88>>2]=d|128}F:{if(y[b+822|0]>3){break F}c=Ob(k,21);h=x[a+480180>>2];G:{H:{if(!(c|!(h&16777248))){d=16;if(y[a+480208|0]&4){break H}break G}d=32;if((h|0)==16){break G}}if(h&67633152){break F}d=0}v[b+819|0]=d}if(Ob(k,21)|y[b+825|0]>3){break x}v[b+820|0]=0}d=x[b>>2];if(A[b+76>>2]<=A[b+4>>2]){c=x[b+80>>2];x[b>>2]=d;x[b+4>>2]=c}d=0;if(!m){break w}d=1;if(!(x[a+480180>>2]&17301536)|(x[b+696>>2]?0:y[b+89|0]&16)){break w}c=1;if(!(y[a+480208|0]&8)){break v}c=1;if(!y[b+789|0]){break v}}if(!(x[b+696>>2]|(!(x[a+480180>>2]&17301536)|!(y[b+89|0]&16)))){hm(b);if(!Ob(k,21)){v[b+818|0]=0;x[b+756>>2]=0}x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}I:{if(!d){i=y[b+789|0];break I}i=y[b+789|0];if(!(y[a+480208|0]&8)){break I}c=1;if(!(i&255)){break v}}if(!(i&255?0:x[a+480180>>2]&1048580)){x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}c=d}d=c;J:{if(!(!d|!Ob(k,40)|(y[b+789|0]?y[a+480208|0]&8:0))){c=x[b+88>>2]&-4194305;break J}c=x[b+88>>2]&-4196353}x[b+88>>2]=c;K:{if(d){break K}w[b+842>>1]=65535;v[b+851|0]=y[b+851|0]|2;x[b+88>>2]=c&-6324225|2097152;L:{if(Ob(k,23)){break L}if(Ob(k,22)){break L}if(Ob(k,52)){break L}if(Ob(k,71)){break L}v[b+839|0]=0;v[b+808|0]=0}if(e){v[b+818|0]=0;x[b+756>>2]=0}x[b+20>>2]=0;x[b+24>>2]=0;if(!(y[b+89|0]&2)){break K}if(!ud(x[a+1298300>>2])|(g|0)==65535){break K}if(Ob(k,111)){Rj(x[a+1298300>>2],g);break K}if(!Ob(k,110)){break K}uz(x[a+1298300>>2],g,0,1,0)}c=x[b+88>>2];M:{N:{O:{if(f){x[b+88>>2]=c&-1025;break O}if(!(c&1024)){break O}if(y[a+24618|0]&16){break N}}a=x[b+104>>2];if(!(!a|!(y[a+35|0]&4)|f)){break N}a=x[b+656>>2];if(!a|(!(y[a+15|0]&2)|f)){break M}}x[b+700>>2]=0}if(d){break a}w[b+136>>1]=0;x[b+132>>2]=4194304;x[b+112>>2]=0;x[b+116>>2]=0}db=n+16|0}function M1(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,E=0;n=db-560|0;db=n;x[n+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){u=1;C=5237;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){u=1;C=5240;break a}u=e&1;C=u?5243:5238;E=!u}b:{if((g&2146435072)==2146435072){g=u+3|0;wf(a,32,c,g,e&-65537);lf(a,C,u);d=f&32;lf(a,b!=b?d?9861:13566:d?10982:13875,3);wf(a,32,c,g,e^8192);p=(c|0)<(g|0)?g:c;break b}z=n+16|0;c:{d:{e:{b=jI(b,n+44|0);b=b+b;if(b!=0){g=x[n+44>>2];x[n+44>>2]=g-1;A=f|32;if((A|0)!=97){break e}break c}A=f|32;if((A|0)==97){break c}l=x[n+44>>2];m=(d|0)<0?6:d;break d}l=g-29|0;x[n+44>>2]=l;b=b*268435456;m=(d|0)<0?6:d}s=(n+48|0)+((l|0)>=0?288:0)|0;h=s;while(1){if(b<4294967296&b>=0){d=~~b>>>0}else{d=0}x[h>>2]=d;h=h+4|0;b=(b-+(d>>>0))*1e9;if(b!=0){continue}break}f:{if((l|0)<=0){d=l;g=h;i=s;break f}i=s;d=l;while(1){q=(d|0)>=29?29:d;g=h-4|0;g:{if(i>>>0>g>>>0){break g}d=0;while(1){k=x[g>>2];B=d;d=q&31;if((q&63)>>>0>=32){p=k<<d;d=0}else{p=(1<<d)-1&k>>>32-d;d=k<<d}B=B+d|0;k=p+r|0;d=Bka(B,d>>>0>B>>>0?k+1|0:k,1e9,0);k=yka(d,hb,-1e9,0)+B|0;x[g>>2]=k;g=g-4|0;if(i>>>0<=g>>>0){continue}break}if(!d){break g}i=i-4|0;x[i>>2]=d}while(1){g=h;if(i>>>0<g>>>0){h=g-4|0;if(!x[h>>2]){continue}}break}d=x[n+44>>2]-q|0;x[n+44>>2]=d;h=g;if((d|0)>0){continue}break}}if((d|0)<0){w=((m+25>>>0)/9|0)+1|0;r=(A|0)==102;while(1){d=0-d|0;p=(d|0)>=9?9:d;h:{if(g>>>0<=i>>>0){h=x[i>>2];break h}q=1e9>>>p|0;k=-1<<p^-1;d=0;h=i;while(1){B=d;d=x[h>>2];x[h>>2]=B+(d>>>p|0);d=D(q,d&k);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=x[i>>2];if(!d){break h}x[g>>2]=d;g=g+4|0}d=p+x[n+44>>2]|0;x[n+44>>2]=d;i=(!h<<2)+i|0;h=r?s:i;g=g-h>>2>(w|0)?h+(w<<2)|0:g;if((d|0)<0){continue}break}}d=0;i:{if(g>>>0<=i>>>0){break i}d=D(s-i>>2,9);h=10;k=x[i>>2];if(k>>>0<10){break i}while(1){d=d+1|0;h=D(h,10);if(k>>>0>=h>>>0){continue}break}}h=(m-((A|0)!=102?d:0)|0)-((A|0)==103&(m|0)!=0)|0;if((h|0)<(D(g-s>>2,9)-9|0)){q=h+9216|0;k=(q|0)/9|0;l=((((l|0)<0?4:292)+n|0)+(k<<2)|0)-4048|0;h=10;p=q+D(k,-9)|0;if((p|0)<=7){while(1){h=D(h,10);p=p+1|0;if((p|0)!=8){continue}break}}q=x[l>>2];w=(q>>>0)/(h>>>0)|0;r=D(w,h);k=l+4|0;j:{if((q|0)==(r|0)&(k|0)==(g|0)){break j}q=q-r|0;k:{if(!(w&1)){b=9007199254740992;if(!(v[l-4|0]&1)|((h|0)!=1e9|i>>>0>=l>>>0)){break k}}b=9007199254740994}t=(g|0)==(k|0)?1:1.5;k=h>>>1|0;t=k>>>0>q>>>0?.5:(k|0)==(q|0)?t:1.5;if(!(y[C|0]!=45|E)){t=-t;b=-b}x[l>>2]=r;if(b+t==b){break j}d=h+r|0;x[l>>2]=d;if(d>>>0>=1e9){while(1){x[l>>2]=0;l=l-4|0;if(l>>>0<i>>>0){i=i-4|0;x[i>>2]=0}d=x[l>>2]+1|0;x[l>>2]=d;if(d>>>0>999999999){continue}break}}d=D(s-i>>2,9);h=10;k=x[i>>2];if(k>>>0<10){break j}while(1){d=d+1|0;h=D(h,10);if(k>>>0>=h>>>0){continue}break}}h=l+4|0;g=g>>>0>h>>>0?h:g}while(1){k=g;q=g>>>0<=i>>>0;if(!q){g=k-4|0;if(!x[g>>2]){continue}}break}l:{if((A|0)!=103){l=e&8;break l}h=m?m:1;g=(h|0)>(d|0)&(d|0)>-5;m=(g?d^-1:-1)+h|0;f=(g?-1:-2)+f|0;l=e&8;if(l){break l}g=-9;m:{if(q){break m}l=x[k-4>>2];if(!l){break m}p=10;g=0;if((l>>>0)%10|0){break m}while(1){h=g;g=g+1|0;p=D(p,10);if(!((l>>>0)%(p>>>0)|0)){continue}break}g=h^-1}h=D(k-s>>2,9);if((f&-33)==70){l=0;g=(g+h|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g;break l}l=0;g=((d+h|0)+g|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g}p=-1;q=l|m;if(((q?2147483645:2147483646)|0)<(m|0)){break b}r=(((q|0)!=0)+m|0)+1|0;h=f&-33;n:{if((h|0)==70){if((r^2147483647)<(d|0)){break b}g=(d|0)>0?d:0;break n}g=d>>31;g=Dn((g^d)-g|0,0,z);if((z-g|0)<=1){while(1){g=g-1|0;v[g|0]=48;if((z-g|0)<2){continue}break}}w=g-2|0;v[w|0]=f;v[g-1|0]=(d|0)<0?45:43;g=z-w|0;if((g|0)>(r^2147483647)){break b}}d=g+r|0;if((d|0)>(u^2147483647)){break b}r=d+u|0;wf(a,32,c,r,e);lf(a,C,u);wf(a,48,c,r,e^65536);o:{p:{q:{if((h|0)==70){f=n+16|0;d=f|8;l=f|9;h=i>>>0>s>>>0?s:i;i=h;while(1){g=Dn(x[i>>2],0,l);r:{if((h|0)!=(i|0)){if(n+16>>>0>=g>>>0){break r}while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(l|0)){break r}v[n+24|0]=48;g=d}lf(a,g,l-g|0);i=i+4|0;if(s>>>0>=i>>>0){continue}break}if(q){lf(a,16359,1)}if((m|0)<=0|i>>>0>=k>>>0){break q}while(1){g=Dn(x[i>>2],0,l);if(g>>>0>n+16>>>0){while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}}lf(a,g,(m|0)>=9?9:m);g=m-9|0;i=i+4|0;if(k>>>0<=i>>>0){break p}d=(m|0)>9;m=g;if(d){continue}break}break p}s:{if((m|0)<0){break s}s=i>>>0<k>>>0?k:i+4|0;f=n+16|0;d=f|8;k=f|9;h=i;while(1){g=Dn(x[h>>2],0,k);if((k|0)==(g|0)){v[n+24|0]=48;g=d}t:{if((h|0)!=(i|0)){if(n+16>>>0>=g>>>0){break t}while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break t}lf(a,g,1);g=g+1|0;if(!(l|m)){break t}lf(a,16359,1)}f=k-g|0;lf(a,g,(f|0)<(m|0)?f:m);m=m-f|0;h=h+4|0;if(s>>>0<=h>>>0){break s}if((m|0)>=0){continue}break}}wf(a,48,m+18|0,18,0);lf(a,w,z-w|0);break o}g=m}wf(a,48,g+9|0,9,0)}wf(a,32,c,r,e^8192);p=(c|0)<(r|0)?r:c;break b}l=(f<<26>>31&9)+C|0;u:{if(d>>>0>11){break u}g=12-d|0;t=16;while(1){t=t*16;g=g-1|0;if(g){continue}break}if(y[l|0]==45){b=-(t+(-b-t));break u}b=b+t-t}s=u|2;i=f&32;h=x[n+44>>2];g=h>>31;g=Dn((g^h)-g|0,0,z);if((z|0)==(g|0)){v[n+15|0]=48;g=n+15|0}m=g-2|0;v[m|0]=f+15;v[g-1|0]=(h|0)<0?45:43;g=e&8;h=n+16|0;while(1){f=h;if(F(b)<2147483648){k=~~b}else{k=-2147483648}v[h|0]=i|y[k+76112|0];b=(b-+(k|0))*16;h=f+1|0;if(!(!(g|(d|0)>0)&b==0|(h-(n+16|0)|0)!=1)){v[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}p=-1;g=z-m|0;f=g+s|0;if((2147483645-f|0)<(d|0)){break b}k=f;f=n+16|0;i=h-f|0;d=d?(i-2|0)<(d|0)?d+2|0:i:i;h=k+d|0;wf(a,32,c,h,e);lf(a,l,s);wf(a,48,c,h,e^65536);lf(a,f,i);wf(a,48,d-i|0,0,0);lf(a,m,g);wf(a,32,c,h,e^8192);p=(c|0)<(h|0)?h:c}db=n+560|0;return p|0}function Pp(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0;h=z[a+480192>>1]>=c>>>0?x[((c<<2)+a|0)+900380>>2]:h;r=x[b+752>>2];a:{j=y[b+802|0];b:{if(!j){if(Ob(a+1074312|0,11)){break b}}c:{d:{if(!h){break d}if(!Tc(j)){break d}e:{g=h+236|0;j=j-1|0;if(z[_b(g,j)>>1]){break e}if(!Ob(a+1074312|0,43)){break e}if(ej(y[h+31|0])){break e}x[b+656>>2]=h;return}if(y[Db(h+108|0,j)|0]>120){break b}j=z[_b(g,j)>>1];n=(j-1&65535)>>>0<3999?(D(j,104)+a|0)+484380|0:0;break c}if(!z[a+480192>>1]){n=(D(c,104)+a|0)+484380|0;break c}if(j>>>0>250){break b}if(!Ob(a+1074312|0,43)){break c}if(h){if(ej(y[h+31|0])){break c}}v[b+803|0]=0;x[b+656>>2]=0;return}j=x[b+104>>2];m=(j|0)!=0&(j|0)!=(n|0);i=x[b+656>>2];p=!h|x[a+480180>>2]!=16777216?p:x[h+44>>2]!=0;o=d^1;g=(h|0)!=(i|0);if((o|g|m)==1){w[b+774>>1]=0}l=!m;if(!(l|(g|!(d&p)))){break b}f:{if(l|o){break f}q=a+1074312|0;if(!(!Ob(q,32)|!(y[a+480208|0]&8))){n=x[b+8>>2]|x[b+12>>2]?x[b+104>>2]:n}j=x[a+480180>>2];g:{h:{i:{j:{if(!g){if((h|0)!=0&(j&1048580)!=0|(j|0)==268435456){break h}if((j|0)!=1){break i}break j}if((j|0)==1){break j}if((j|0)==268435456){break h}break i}if(si(x[b+8>>2],x[b+12>>2])){break h}}if(!Ob(q,79)){break g}if(!si(x[b+8>>2],x[b+12>>2])){break g}}k=1}if(!Ob(q,119)|z[a+480192>>1]){break f}v[b+851|0]=y[b+851|0]|2}k:{if(!x[b+16>>2]|(g|!z[a+480192>>1]|l)){break k}if(!Ob(a+1074312|0,87)){break k}k=Tc(y[b+788|0])^1|k}l=(h|0)!=(i|0);l:{if(si(x[b+8>>2],x[b+12>>2])|!(x[a+480180>>2]&16777248)){break l}if(h){if(ej(y[h+31|0])){break l}}l=1}m:{n:{if(!(m|l)|!d){break n}if(!Ob(a+1074312|0,61)){break n}i=x[b+656>>2];g=x[b+104>>2];j=0;if(i|g){break m}}x[b+656>>2]=h;g=n;i=h;j=l}o:{p:{q:{if(!e){break q}r:{if(y[a+480180|0]&3){if(g){if(Sd(x[g>>2],x[g+20>>2])){break r}}if(!Pj(i)){break q}}if(!g){break p}}if(w[g+34>>1]<0){break q}x[b+688>>2]=z[g+30>>1]}h=(g|0)!=0;if(!(k&m)|!g){break o}if(Ob(a+1074312|0,85)){w[b+772>>1]=v[g+37|0]}h=1;if(x[a+480180>>2]!=2){break o}if(!Sd(x[g>>2],x[g+20>>2])){break o}x[b+704>>2]=x[g+24>>2];break o}if(!(!i|!y[i+34|0])){h=x[b+688>>2];if(i){h=x[i+4>>2]<<2}x[b+688>>2]=h;h=0;break o}h=0;x[b+688>>2]=0}if(k){break b}v[b+803|0]=0;s:{if(!i){break s}if(s=(B=Ob(a+1074312|0,29),C=1,E=g,E?B:C),t=0,u=!y[i+34|0]&(j^-1),u?s:t){break s}v[b+798|0]=y[i+16|0]}k=64;x[b+752>>2]=64;if(g){k=z[g+32>>1];x[b+752>>2]=k}if(i){x[b+752>>2]=D(x[i+4>>2],k)>>>6}t:{if(!(x[a+480180>>2]&1048580?e:1)){break t}if(Ob(a+1074312|0,48)){break t}aO(a,b,i,g)}u:{v:{w:{if(!f){break w}x:{y:{z:{A:{B:{C:{D:{E:{f=a+1074312|0;if(Ob(f,19)){if(!x[b+76>>2]){e=1;break D}if(!(!c|o)){e=(y[a+480208|0]&8)>>>3|0;if(e){break D}break E}e=0;if(c){break E}break D}F:{c=x[a+480180>>2]&17301536;e=1;G:{if(!d|!c){break G}c=1;e=1;if(y[a+480208|0]&8){break G}e=1;if(!x[b+76>>2]){break G}if(!(y[b+89|0]&16)){break F}e=!x[b+696>>2]}if(j|(!i|!c)){break B}if(!e){break x}c=x[b+88>>2];x[b+88>>2]=c|2097152;if(c&6144){break A}break C}if((j|!i)!=1){break x}break y}if(d){break D}if(!(y[b+89|0]&24)){e=0;break D}e=(y[a+480208|0]&4)>>>2|0}if(j|!x[b+696>>2]){break B}if(!e){break y}c=x[b+88>>2];x[b+88>>2]=c|2097152;if(!i){break z}if(c&2048){break A}}if(!(y[i+60|0]&8)){$i(b+724|0)}if(!(y[i+80|0]&8)){$i(b+732|0)}if(y[i+100|0]&8){break z}$i(b+740|0);break z}if(!e){break y}x[b+88>>2]=x[b+88>>2]|2097152;if(!i){break z}}hm(b)}if(Ob(f,21)){break w}v[b+818|0]=0;x[b+756>>2]=0;break w}if(!i){break v}}if(v[i+60|0]&1){break w}if(Ob(f,32)){$i(b+724|0);break w}hm(b)}c=0;if(g){break u}if(!i){break a}c=1;if(ej(y[i+31|0])){break u}break a}c=0;if(!g){break a}}H:{if(!(!d|(h^1|x[b+104>>2]!=(g|0)))){e=x[a+480180>>2];if(x[b+76>>2]?e&16777250:0){break b}I:{J:{if((e|0)!=4){break J}if(!Ob(a+1074312|0,40)|y[b+789|0]){break J}e=x[b+88>>2];break I}e=x[b+88>>2]&-6145}x[b+88>>2]=e&-640;break H}x[b+88>>2]=x[b+88>>2]&-6145;e=a+1074312|0;K:{L:{if(!Ob(e,18)){h=-640;if(j|(x[a+480180>>2]&16777248|x[b+104>>2]!=(g|0))){break L}break K}h=-640;if((j^-1)&x[b+104>>2]==(g|0)){break K}}h=-768}x[b+88>>2]=x[b+88>>2]&h;if(!i){break H}v[b+730|0]=y[i+60|0];v[b+738|0]=y[i+80|0];v[b+746|0]=y[i+100|0];M:{if((y[i+100|0]&17)!=17){break M}if(Ob(e,36)|y[b+837|0]){break M}v[b+837|0]=127}e=y[i+21|0];if(ue(e)){s=b,t=rj(e),v[s+837|0]=t}e=y[i+22|0];if(!ue(e)){break H}s=b,t=rj(e),v[s+838|0]=t}if(c){x[b+76>>2]=0;x[b+104>>2]=0;return}N:{if(x[b+76>>2]|!d){break N}c=a+1074312|0;if(!Ob(c,54)){if(!Ob(c,39)){break N}}x[b+8>>2]=0;x[b+12>>2]=0}O:{if(y[b+788|0]!=255){break O}if(!Ob(a+1074312|0,100)|!(y[a+480208|0]>>>2&m)){break O}c=x[b+104>>2];if(c){x[b+88>>2]=x[b+88>>2]|z[c+34>>1]&1023}x[b+752>>2]=r;x[b+688>>2]=z[g+30>>1];if(!(y[g+34|0]&32)){break b}Yp(b,z[g+28>>1],a);return}x[b+104>>2]=g;x[b+76>>2]=x[g>>2];x[b+80>>2]=x[g+4>>2];x[b+84>>2]=x[g+8>>2];c=a+1074312|0;if(!(!Ob(c,83)|x[b+80>>2])){x[b+84>>2]=x[g>>2]}x[b+88>>2]=x[b+88>>2]|z[g+34>>1]&1023;if(Ob(c,21)){v[b+818|0]=0;x[b+756>>2]=0}P:{Q:{if(p){x[b+704>>2]=x[g+24>>2];v[b+851|0]=y[b+851|0]|64;d=0;break Q}if(!(m|o)){d=x[a+480180>>2];if(d&5){break P}}x[b+704>>2]=x[g+24>>2];d=v[g+37|0]}w[b+772>>1]=d;d=x[a+480180>>2]}if(ym(d)){d=v[g+36|0]}else{d=0}w[b+770>>1]=d;if(!(Ob(c,69)|x[a+480180>>2]==1)){x[b+708>>2]=0}x[b+852>>2]=0;h=x[b+88>>2];if(h&8){x[b+80>>2]=x[g+12>>2];x[b+84>>2]=x[g+16>>2];h=h>>>2&4|h|2;x[b+88>>2]=h}c=x[b+76>>2];R:{if(!(h&2)){break R}d=x[b+84>>2];if(d>>>0>=c>>>0){break R}x[b+76>>2]=d;c=d}if(!(x[a+480180>>2]&16777248)|A[b+4>>2]<c>>>0){break b}x[b>>2]=0;x[b+4>>2]=0}return}x[b+752>>2]=0;x[b+104>>2]=0}function Pea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;d=db-176|0;db=d;wc(c);a:{if(!Bo(c,d+164|0)|(y[d+164|0]|y[d+165|0]<<8|(y[d+166|0]<<16|y[d+167|0]<<24))!=1297239878){break a}f=y[d+172|0]|y[d+173|0]<<8|(y[d+174|0]<<16|y[d+175|0]<<24);if((f|0)!=1179011393&(f|0)!=1128679745){break a}e=db-32|0;db=e;g=d+152|0;f=Nb(g);b:{c:{d:{e:{f:{while(1){h=x[c+8>>2];i=x[c>>2];x[23549]=0;h=U(142,i|0,h|0,8)|0;i=x[23549];x[23549]=0;if((i|0)==1){break d}if(!h){break e}x[23549]=0;P(764,e+4|0,c|0);h=x[23549];x[23549]=0;if((h|0)!=1){x[23549]=0;P(765,f|0,e+4|0);h=x[23549];x[23549]=0;if((h|0)==1){break f}Gd(e+4|0);continue}break}a=N()|0;break c}a=N()|0;Gd(e+4|0);break c}db=e+32|0;break b}a=N()|0}_d(f);Q(a|0);p()}x[23549]=0;S(685,d+132|0,g|0,1129270605);c=x[23549];x[23549]=0;g:{h:{i:{j:{k:{l:{m:{if((c|0)!=1){x[23549]=0;c=O(686,d+132|0,d+114|0)|0;e=x[23549];x[23549]=0;n:{o:{if((e|0)!=1){if(!c){break g}if(!$b(z[d+116>>1]|z[d+118>>1]<<16)){break g}if((Hb(z[d+114>>1])-3&65535)>>>0<65534){break g}if((Hb(z[d+120>>1])-65&65535)>>>0<65472){break g}x[d+108>>2]=1162760014;c=1;if((y[d+172|0]|y[d+173|0]<<8|(y[d+174|0]<<16|y[d+175|0]<<24))==1128679745){x[23549]=0;c=O(569,d+132|0,d+108|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break o}if(!c){break g}c=x[d+108>>2]!=1936684916}x[23549]=0;S(685,d+88|0,d+152|0,1397968452);e=x[23549];x[23549]=0;p:{q:{if((e|0)!=1){x[23549]=0;k=O(687,d+88|0,d+80|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break p}if(k){break q}break h}c=N()|0;break j}e=(Hb(z[d+120>>1])-1|0)/8|0;g=e<<3;f=g&31;g=Xc(d+76|0,(e>>>0>=8?8:(g&63)>>>0>=32?1074268168>>>f|0:((1<<f)-1&1074268168)<<32-f|538447880>>>f)&120,(Hb(z[d+114>>1])|0)==2?2:1,c,0);c=x[d+108>>2];r:{if((c|0)!=544694642){s:{t:{if(!((c|0)==842222662|(c|0)==842230886|(c|0)==875973702)){if((c|0)==2002873461){break s}if((c|0)==1463897153){break t}if((c|0)==1463897173){break s}if((c|0)==2002873441){break t}if((c|0)!=875981926){break r}}Uf(g,3);break r}Uf(g,17);hd(g,16);break r}Uf(g,16);hd(g,16);break r}Uf(g,1)}c=x[d+80>>2];x[23549]=0;c=U(142,x[d+88>>2],x[d+96>>2],$b(c)|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break l}if(c){c=x[d+80>>2];x[23549]=0;O(174,d+88|0,$b(c)|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break l}}jt(a,b);x[23549]=0;c=D(b,104)+a|0;h=c+484380|0;P(266,h|0,0);e=x[23549];x[23549]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((e|0)==1){break D}s=h,t=$b(z[d+116>>1]|z[d+118>>1]<<16),x[s>>2]=t;j=c+484404|0;c=y[d+124|0]|y[d+125|0]<<8|(y[d+126|0]<<16|y[d+127|0]<<24);f=c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24);i=30-y[d+123|0]|0;e=0;while(1){c=f;if(i&255){f=c>>>1|0;i=i-1|0;e=c;continue}break}x[j>>2]=c+(e&1);x[23549]=0;U(205,g|0,h|0,d+88|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break D}x[23549]=0;S(685,d+56|0,d+152|0,1296126539);c=x[23549];x[23549]=0;if((c|0)==1){break C}x[23549]=0;c=R(164,x[d+56>>2])|0;e=x[23549];x[23549]=0;if((e|0)==1){break B}if(!c){break u}x[23549]=0;S(685,d+16|0,d+152|0,1229869908);c=x[23549];x[23549]=0;if((c|0)==1){break A}x[23549]=0;c=O(688,d+16|0,d+36|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break z}ub(d+16|0);if(!c){break u}x[23549]=0;f=R(260,d+56|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break y}e=Nb(d+16|0);x[23549]=0;P(689,e|0,f|0);c=x[23549];x[23549]=0;if((c|0)==1){break w}c=0;while(1){if((c|0)==(f|0)){break x}x[23549]=0;g=O(690,d+56|0,d+4|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break w}if(!g){break x}x[23549]=0;P(691,e|0,d+4|0);g=x[23549];x[23549]=0;if((g|0)==1){break w}x[23549]=0;g=y[d+10|0];O(174,d+56|0,!(g&1)+g|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break w}c=c+1|0;continue}}c=N()|0;break k}c=N()|0;break k}c=N()|0;break m}c=N()|0;break m}c=N()|0;ub(d+16|0);break m}c=N()|0;break m}c=Hb(y[d+44|0]|y[d+45|0]<<8);if(c){f=(D(b,104)+a|0)+484414|0;w[f>>1]=z[f>>1]&65511|((c|0)==2)<<4|8}c=Hb(y[d+50|0]|y[d+51|0]<<8);if(c){f=(D(b,104)+a|0)+484414|0;w[f>>1]=z[f>>1]&65529|((c|0)==2?4:2)|2}s=d,t=yb(x[e>>2]),x[s+4>>2]=t;c=D(b,104)+a|0;g=c+484388|0;i=c+484384|0;j=c+484396|0;l=c+484392|0;m=yb(x[e+4>>2]);n=y[d+46|0]|y[d+47|0]<<8;o=y[d+48|0]|y[d+49|0]<<8;q=y[d+52|0]|y[d+53|0]<<8;r=y[d+54|0]|y[d+55|0]<<8;while(1){c=x[d+4>>2];if(!Kb(c,m)){break v}f=Hb(y[c|0]|y[c+1|0]<<8);if((f|0)==(Hb(n)|0)){s=l,t=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Hb(y[c|0]|y[c+1|0]<<8)}if((Hb(o)|0)==(f|0)){s=j,t=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Hb(y[c|0]|y[c+1|0]<<8)}if((Hb(q)|0)==(f|0)){s=i,t=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Hb(y[c|0]|y[c+1|0]<<8)}if((f|0)==(Hb(r)|0)){s=g,t=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t}x[d+4>>2]=x[d+4>>2]+7;continue}}c=N()|0;OO(e);break m}ok(h);OO(e)}x[23549]=0;S(685,d+16|0,d+152|0,1312902469);c=x[23549];x[23549]=0;if((c|0)==1){break n}x[23549]=0;c=R(164,x[d+16>>2])|0;e=x[23549];x[23549]=0;E:{if((e|0)==1){break E}F:{if(c){x[23549]=0;c=R(146,x[d+16>>2])|0;e=x[23549];x[23549]=0;if((e|0)==1){break E}x[23549]=0;S(302,d+16|0,((b<<5)+a|0)+946304|0,c|0);b=x[23549];x[23549]=0;if((b|0)!=1){break F}break E}x[23549]=0;c=O(54,d+4|0,21204)|0;e=x[23549];x[23549]=0;if((e|0)==1){break E}zc(((b<<5)+a|0)+946304|0,c);tb(c)}Fz(h,x[a+480180>>2]);dj(h,a);ub(d+16|0);ub(d+56|0);break h}c=N()|0;ub(d+16|0);break m}c=N()|0;break k}c=N()|0;break j}c=N()|0;break j}c=N()|0;break m}c=N()|0;break i}ub(d+56|0);break k}c=N()|0}ub(d+88|0)}ub(d+132|0)}_d(d+152|0);Q(c|0);p()}ub(d+88|0)}ub(d+132|0);_d(d+152|0)}db=d+176|0;return k|0}function qfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0;d=db-208|0;db=d;wc(b);a:{if(!Vt(b,d+144|0)){break a}if(!sR(d+144|0)){break a}if(!Lb(x[b>>2],x[b+8>>2],Qc(rR(d+144|0),hb))){break a}if(!c){e=1;break a}Bd(a,256);f=d+132|0;nj(f,2,d+144|0);e=d+40|0;Bc(e,f);zb(a+1298308|0,e);tb(e);f=y[d+194|0]|y[d+195|0]<<8;x[a+480260>>2]=64;x[a+480264>>2]=32767;w[a+480188>>1]=4;w[a+480190>>1]=f;Jb(a+1074312|0,107,1);f=y[d+187|0];f=f?f:96;k=$z(f);x[a+480196>>2]=f>>>4;x[a+480204>>2]=k;v[d+40|0]=64;E=a,F=y[Sb(d+186|0,e)|0]<<2,x[E+480200>>2]=F;e=0;b:{c:{d:{e:{f:{g:{while(1){if((e|0)==4){h:{k=Nb(d+132|0);m=Nb(d+120|0);x[23549]=0;O(141,b|0,(y[d+176|0]|y[d+177|0]<<8)<<4)|0;e=x[23549];x[23549]=0;i:{if((e|0)==1){break i}x[23549]=0;U(203,b|0,k|0,y[d+192|0]|y[d+193|0]<<8)|0;e=x[23549];x[23549]=0;if((e|0)==1){break i}x[23549]=0;O(141,b|0,(y[d+178|0]|y[d+179|0]<<8)<<4)|0;e=x[23549];x[23549]=0;if((e|0)==1){break i}x[23549]=0;U(203,b|0,m|0,y[d+194|0]|y[d+195|0]<<8)|0;e=x[23549];x[23549]=0;if((e|0)==1){break i}x[23549]=0;O(141,b|0,((y[d+180|0]|y[d+181|0]<<8)<<4)+32|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break i}e=y[a+484376|0];f=x[a+484360>>2];x[23549]=0;P(315,Wb(f,e)|0,y[d+196|0]|y[d+197|0]<<8);e=x[23549];x[23549]=0;if((e|0)==1){break i}e=Wb(x[a+484360>>2],y[a+484376|0]);E=d,F=yb(x[e>>2]),x[E+40>>2]=F;e=yb(x[e+4>>2]);j:{while(1){f=x[d+40>>2];if(!Kb(f,e)){e=0;if(!uR(Wb(x[a+484360>>2],y[a+484376|0]))){break b}h=c&2;j=d+41|0;e=1;break j}x[23549]=0;h=R(192,b|0)|0;j=x[23549];x[23549]=0;k:{if((j|0)==1){break k}w[f>>1]=h;x[23549]=0;O(174,b|0,4)|0;f=x[23549];x[23549]=0;if((f|0)==1){break k}Se(d+40|0);continue}break}b=N()|0;break c}l:{m:{n:{o:{while(1){f=e&65535;if(f>>>0>(y[d+194|0]|y[d+195|0]<<8)>>>0){break l}i=_b(x[m>>2],f-1|0);i=y[i|0]|y[i+1|0]<<8;x[23549]=0;i=O(141,b|0,i<<4)|0;g=x[23549];x[23549]=0;p:{if((g|0)!=1){if(i){break p}e=0;break b}b=N()|0;break c}x[23549]=0;O(636,b|0,d+40|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break o}x[23549]=0;i=(D(f,104)+a|0)+484380|0;S(637,d+40|0,i|0,0);g=x[23549];x[23549]=0;if((g|0)==1){break o}g=d+16|0;ck(g,2,j);x[23549]=0;P(208,d+28|0,g|0);g=x[23549];x[23549]=0;if((g|0)==1){break n}g=((f<<5)+a|0)+946304|0;f=d+28|0;zc(g,f);tb(f);q:{r:{if(!h|!(y[d+56|0]|y[d+57|0]<<8|(y[d+58|0]<<16|y[d+59|0]<<24))){break r}f=IR(d+40|0);x[23549]=0;f=O(141,b|0,f|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break m}if(!f){break r}f=d+28|0;GR(f,y[d+70|0],y[d+71|0],1);x[23549]=0;U(205,f|0,i|0,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break q}}e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}v[d+15|0]=1;e=x[k>>2];s:{if(qc(e,x[k+4>>2])|(y[d+172|0]|y[d+173|0]<<8)==26){break s}f=y[e|0]|y[e+1|0]<<8;e=0;x[23549]=0;f=O(141,b|0,f<<4)|0;h=x[23549];x[23549]=0;if((h|0)==1){break h}if(!f){break b}x[23549]=0;e=R(180,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break h}if((e|0)!=(y[d+172|0]|y[d+173|0]<<8)){break s}v[d+15|0]=0}n=c&1;if(n){x[23549]=0;P(211,a+484344|0,y[d+192|0]|y[d+193|0]<<8);c=x[23549];x[23549]=0;if((c|0)==1){break h}}i=a+484344|0;q=d+45|0;r=d+43|0;s=d+44|0;t=d+42|0;u=d+41|0;A=y[d+15|0];f=0;while(1){t:{if(!n|(y[d+192|0]|y[d+193|0]<<8)>>>0<=f>>>0){break t}x[23549]=0;c=U(212,i|0,f&65535,64)|0;e=x[23549];x[23549]=0;if((e|0)==1){break g}if(!c){break t}c=_b(x[k>>2],f);c=y[c|0]|y[c+1|0]<<8;x[23549]=0;c=O(141,b|0,c<<4)|0;e=x[23549];x[23549]=0;if((e|0)==1){break g}e=0;if(!c){break b}if(!A){x[23549]=0;c=R(180,b|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break g}if(c>>>0>2112){break b}}w[d+16>>1]=65535;x[d+28>>2]=63;u:while(1){c=Yb(x[i>>2],f);B=sf(x[c>>2],x[x[c+48>>2]+12>>2],e);v:while(1){c=e;while(1){if(c>>>0<=63){x[23549]=0;e=R(192,b|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break f}g=e<<24>>24;if(!g){e=64;if(c>>>0>62){continue v}e=c+1|0;continue u}e=g&31;h=D(e,6)+B|0;l=Wh(d+40|0);j=e>>>0<z[a+480188>>1];o=j?h:l;l=g&255;if(l&32){x[23549]=0;P(249,d|0,b|0);e=x[23549];x[23549]=0;w:{x:{y:{if((e|0)!=1){C=fd(d);e=y[d|0];if(e>>>0>239){break y}e=FR((D(e>>>4|0,12)+(e&15)|0)+37|0);break x}b=N()|0;break c}z:{switch(e-254|0){case 0:break x;case 1:break z;default:break w}}e=0}v[o|0]=e}v[(j?h+1|0:u)|0]=y[C|0]}if(l&64){x[23549]=0;e=R(192,b|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break e}v[d|0]=e;v[(j?h+2|0:t)|0]=1;v[d+14|0]=64;E=j?h+4|0:s,F=y[Sb(d,d+14|0)|0],v[E|0]=F}if((g|0)>=0){continue}x[23549]=0;P(249,d|0,b|0);e=x[23549];x[23549]=0;if((e|0)==1){break d}v[(j?h+3|0:r)|0]=y[d|0];E=j?h+5|0:q,F=y[fd(d)|0],v[E|0]=F;tR(o,c,255,d+16|0,d+28|0);continue}break}break}break}c=z[d+16>>1];if((c|0)!=65535){me(Yb(x[i>>2],f),Bm(Fe(Be(d+40|0,12,c&255),x[d+28>>2])))}f=f+1|0;continue}break}x[23549]=0;b=O(1,d+40|0,6029)|0;c=x[23549];x[23549]=0;A:{B:{C:{if((c|0)!=1){zb(a+1298344|0,b);tb(b);x[23549]=0;b=O(1,d+28|0,5215)|0;c=x[23549];x[23549]=0;if((c|0)==1){break C}zb(a+1298356|0,b);tb(b);x[a+1298404>>2]=5;x[23549]=0;P(639,d|0,4346);b=x[23549];x[23549]=0;if((b|0)==1){break B}x[23549]=0;S(293,d+16|0,d|0,d+15|0);b=x[23549];x[23549]=0;if((b|0)==1){break A}b=a+1298368|0;a=d+16|0;zb(b,a);tb(a);Ab(d);e=1;break b}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;Ab(d);break c}b=N()|0;break c}}else{f=(e<<5)+a|0;Te(f+480280|0);w[f+480284>>1]=e&1?64:192;e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0}id(m);id(k);Q(b|0);p()}id(m);id(k)}db=d+208|0;return e|0}function Lga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=db-1808|0;db=d;wc(b);f=db-16|0;db=f;i=d+1208|0;ES(f+8|0,i);h=x[f+12>>2];j=b;lc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(h|0)){Zb(j,x[f+12>>2])}db=f+16|0;b=(b|0)==(h|0);if(!b){DS(i)}a:{if(!b){break a}if(!FS(d+1208|0)){break a}if(!xA(j,16,0)){break a}b=d+1224|0;x[d+1200>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);b=y[d+1212|0]|y[d+1213|0]<<8|(y[d+1214|0]<<16|y[d+1215|0]<<24);x[d+1184>>2]=y[d+1208|0]|y[d+1209|0]<<8|(y[d+1210|0]<<16|y[d+1211|0]<<24);x[d+1188>>2]=b;b=d+1216|0;f=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);b=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[d+1192>>2]=f;x[d+1196>>2]=b;Bd(a,1);Jb(Jb(Of(a+1074312|0,83),84,1),85,1);w[a+480188>>1]=4;x[d+1180>>2]=0;w[a+480190>>1]=15;Vc(j,20);l=a+480188|0;e=1;i=1;b:{while(1){c:{if((e|0)==16){NS(j,d+1048|0);b=a+484376|0;Bu(Wb(x[a+484360>>2],y[b|0]),d+1050|0,128);n=MS(j,Wb(x[a+484360>>2],y[b|0]),y[d+1048|0],g,l,0,1);if(!(y[d+1049|0]|n>>>0>1)){e=0;if(!y[d+1048|0]){break a}}b=(n<<10)+g|0;x[d+1044>>2]=b;x[d+8>>2]=65536;e=0;if(!Lb(x[j>>2],x[j+8>>2],b-x[Cb(d+1044|0,d+8|0)>>2]|0)){break a}if(c){break c}break b}f=D(e,104)+a|0;h=f+484380|0;b=((e<<5)+a|0)+946304|0;yA(j,d+8|0,h,b,1);m=x[h>>2];d:{if(!y[Db(b,0)|0]){break d}e:{if(cd(b,16361,3)){if(cd(b,16365,3)){break e}}if(y[Db(b,5)|0]==58){break d}}i=0}b=Hb(y[d+36|0]|y[d+37|0]<<8);if(b>>>0>=2){k=b<<1;b=Hb(y[d+34|0]|y[d+35|0]<<8);x[f+484388>>2]=k+b;x[f+484384>>2]=b;ok(h)}f:{if(Hb(y[d+30|0]|y[d+31|0]<<8)>>>0<=4999){if(Hb(y[d+34|0]|y[d+35|0]<<8)>>>0<1e4){break f}}x[d+1048>>2]=5;s=d,t=x[Re(d+1180|0,d+1048|0)>>2],x[s+1180>>2]=t}g=g+m|0;e=e+1|0;continue}break}e=y[d+1049|0];if(!e){v[d+1049|0]=120;e=120}g:{if(!cd(d+1184|0,14596,6)){v[d+1049|0]=120;x[a+480204>>2]=125e4;break g}x[a+480204>>2]=125e4;if((e|0)==120){break g}s=a,t=Le(1773447.5/(+(240-e|0)*122)*1e4),x[s+480204>>2]=t;if(x[d+1180>>2]>=2){x[d+8>>2]=i&1?4:5;s=d,t=x[Re(d+1180|0,d+8|0)>>2],x[s+1180>>2]=t;break g}x[d+8>>2]=i&1?1:2;s=d,t=x[Re(d+1180|0,d+8|0)>>2],x[s+1180>>2]=t}x[a+480228>>2]=64;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480208>>2]=x[a+480208>>2]|2097152;g=d+1032|0;nj(g,3,d+1184|0);b=d+8|0;Bc(b,g);zb(a+1298308|0,b);tb(b);vh(a,0);f=i&1;r=x[j+8>>2];l=0;while(1){h:{if(n>>>0>(l&65535)>>>0){b=Wb(x[a+484360>>2],y[a+484376|0]);b=Kb(rA(yb(x[b>>2]),yb(x[b+4>>2]),l),yb(x[b+4>>2]));CS(j,d+8|0);i:{if(b){q=vA(d+8|0,0)+q|0;if(q>>>0>512){break i}}m=0;b=x[d+1180>>2];g=0;i=0;j:while(1){if((i|0)==64){break h}e=0;while(1)if((e|0)==4){i=i+1|0;continue j}else{k=xb(_c(d+8|0,i),e);o=y[Db(k,2)|0]&15;h=y[Db(k,3)|0];k:{if(!(!(g&255)|(y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24)))){g=g+1|0;if((g&255)>>>0<33){break k}b=6;x[d+1180>>2]=6;break k}g=0}l:{m:{n:{o:{switch(o-1|0){case 0:case 1:if((b|0)==1&h>>>0>=32){break m}k=(o|0)!=1;if(!(k|!h|h>>>0>2)){x[d+1032>>2]=2;b=x[Re(d+1180|0,d+1032|0)>>2];break n}if(k|(h|0)!=55&(h|0)!=71){break l}if((b|0)<=2){break m}break l;case 10:b=6;break n;case 11:case 12:case 13:x[d+1032>>2]=2;b=x[Re(d+1180|0,d+1032|0)>>2];x[d+1180>>2]=b;if((o|0)!=13){break l}m=((h|i)!=0)+m|0;g=1;break l;case 14:break o;default:break l}}x[d+1032>>2]=3;b=x[Re(d+1180|0,d+1032|0)>>2]}x[d+1180>>2]=b;break l}x[d+1180>>2]=f;b=f}e=e+1|0;continue}}}e=0;break a}if(!(x[d+1180>>2]!=6|n+32>>>0>=p>>>0)){x[d+1180>>2]=5}Vc(j,r);o=c&1;if(o){mg(a+484344|0,n)}k=a+484344|0;l=0;while(1)if((l|0)==(n|0)){e=21204;b=x[d+1180>>2];if(b>>>0<7){e=x[(b<<2)+26956>>2]}b=d+8|0;g=Tb(b,8202);zb(a+1298344|0,g);tb(g);b=Tb(b,10639);zb(a+1298356|0,b);tb(b);Wc(a+1298368|0,e);x[a+1298404>>2]=13;e=1;if(!(c&2)){break a}while(1){if((e|0)==16){break b}b=D(e,104)+a|0;c=b+484384|0;Zb(j,x[c>>2]);g=x[c>>2];x[c>>2]=0;c=b+484380|0;x[c>>2]=x[c>>2]-g;b=b+484388|0;x[b>>2]=x[b>>2]-g;b=d+8|0;Xc(b,8,1,1,0);lg(b,c,j);e=e+1|0;continue}}else{CS(j,d+8|0);p:{if(!o){break p}if(!$g(k,l&65535,64)){break p}m=0;x[d+1032>>2]=0;q:while(1){if((m|0)==64){break p}e=0;b=Yb(x[k>>2],l);p=$c(x[b>>2],x[x[b+48>>2]+12>>2],m,0);while(1)if((e|0)==4){m=m+1|0;continue q}else{b=xb(_c(d+8|0,m),e);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[d>>2]=b;x[d+4>>2]=b;f=p+D(e,6)|0;nu(d,f);b=y[f+3|0];h=b;r:{s:{t:{g=y[f+5|0];if(g){h=14;if((b&255)!=14){break t}}v[(d+1032|0)+e|0]=0;if((g|h)&255){break s}break r}h=b;i=y[(d+1032|0)+e|0];if(!i){break s}u:{if(i>>>0>=16){v[f+2|0]=3;i=i>>>4|0;break u}v[f+2|0]=4}v[f+4|0]=i}v:{w:{x:{y:{z:{A:{switch((h&255)-12|0){case 1:h=x[d+1180>>2];if((h|0)==6){break w}b=10;v[f+3|0]=10;break x;case 0:g=g&127;break z;case 2:if(g>>>0<=1&x[d+1180>>2]>3){break v}b=10;v[f+3|0]=10;v[(d+1032|0)+e|0]=g;break y;case 3:break A;default:break y}}g=g&15}v[f+5|0]=g}h=x[d+1180>>2]}if((h|0)>1){break v}B:{C:{D:{switch(b&255){case 0:if(g>>>0>2){break C}break;case 2:break B;case 1:break C;default:break D}}v[f+3|0]=0;break r}v[f+3|0]=1;break r}b=g&15;if(b){v[f+3|0]=2;v[f+5|0]=b;break r}if(g>>>0<16){break r}v[f+3|0]=3;v[f+5|0]=g>>>4;break r}v[f+5|0]=0}Qf(f)}e=e+1|0;continue}}}l=l+1|0;continue}}if((m-1&255)>>>0<2){x[d+1180>>2]=6}l=l+1|0;p=(m&255)+p|0;continue}}e=1}db=d+1808|0;return e|0}function hI(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,B=0,E=0,F=0,G=0;j=db-80|0;db=j;x[j+76>>2]=b;E=j+55|0;s=j+56|0;a:{b:{c:{d:{e:while(1){k=b;if((p^2147483647)<(h|0)){break d}p=h+p|0;f:{g:{h:{h=k;i=y[h|0];if(i){while(1){i:{b=i&255;j:{if(!b){b=h;break j}if((b|0)!=37){break i}i=h;while(1){if(y[i+1|0]!=37){b=i;break j}h=h+1|0;m=y[i+2|0];b=i+2|0;i=b;if((m|0)==37){continue}break}}h=h-k|0;B=p^2147483647;if((h|0)>(B|0)){break d}if(a){lf(a,k,h)}if(h){continue e}x[j+76>>2]=b;h=b+1|0;q=-1;i=v[b+1|0];if(!(!Kj(i)|y[b+2|0]!=36)){q=i-48|0;u=1;h=b+3|0}x[j+76>>2]=h;n=0;i=v[h|0];b=i-32|0;k:{if(b>>>0>31){o=h;break k}o=h;b=1<<b;if(!(b&75913)){break k}while(1){o=h+1|0;x[j+76>>2]=o;n=b|n;i=v[h+1|0];b=i-32|0;if(b>>>0>=32){break k}h=o;b=1<<b;if(b&75913){continue}break}}l:{if((i|0)==42){b=v[o+1|0];m:{if(!(!Kj(b)|y[o+2|0]!=36)){x[((b<<2)+e|0)-192>>2]=10;i=o+3|0;u=1;b=x[((v[o+1|0]<<3)+d|0)-384>>2];break m}if(u){break h}i=o+1|0;if(!a){x[j+76>>2]=i;u=0;r=0;break l}b=x[c>>2];x[c>>2]=b+4;u=0;b=x[b>>2]}x[j+76>>2]=i;r=b;if((b|0)>=0){break l}r=0-r|0;n=n|8192;break l}r=gI(j+76|0);if((r|0)<0){break d}i=x[j+76>>2]}h=0;l=-1;n:{if(y[i|0]!=46){b=i;A=0;break n}if(y[i+1|0]==42){b=v[i+2|0];o:{if(!(!Kj(b)|y[i+3|0]!=36)){x[((b<<2)+e|0)-192>>2]=10;b=i+4|0;l=x[((v[i+2|0]<<3)+d|0)-384>>2];break o}if(u){break h}b=i+2|0;l=0;if(!a){break o}i=x[c>>2];x[c>>2]=i+4;l=x[i>>2]}x[j+76>>2]=b;A=(l^-1)>>>31|0;break n}x[j+76>>2]=i+1;l=gI(j+76|0);b=x[j+76>>2];A=1}while(1){t=h;o=28;m=b;h=v[b|0];if(h-123>>>0<4294967238){break c}b=m+1|0;h=y[(h+D(t,58)|0)+75583|0];if(h-1>>>0<8){continue}break}x[j+76>>2]=b;p:{q:{if((h|0)!=27){if(!h){break c}if((q|0)>=0){x[(q<<2)+e>>2]=h;i=(q<<3)+d|0;h=x[i+4>>2];x[j+64>>2]=x[i>>2];x[j+68>>2]=h;break q}if(!a){break f}fI(j- -64|0,h,c,g);break p}if((q|0)>=0){break c}}h=0;if(!a){continue e}}i=n&-65537;n=n&8192?i:n;q=0;z=5227;o=s;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{h=v[m|0];h=t?(h&15)==3?h&-33:h:h;switch(h-88|0){case 11:break r;case 9:case 13:case 14:case 15:break s;case 27:break x;case 12:case 17:break A;case 23:break B;case 0:case 32:break C;case 24:break D;case 22:break E;case 29:break F;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break g;default:break G}}H:{switch(h-65|0){case 0:case 4:case 5:case 6:break s;case 2:break v;case 1:case 3:break g;default:break H}}if((h|0)==83){break w}break g}i=x[j+64>>2];m=x[j+68>>2];z=5227;break z}h=0;I:{switch(t&255){case 0:x[x[j+64>>2]>>2]=p;continue e;case 1:x[x[j+64>>2]>>2]=p;continue e;case 2:k=x[j+64>>2];x[k>>2]=p;x[k+4>>2]=p>>31;continue e;case 3:w[x[j+64>>2]>>1]=p;continue e;case 4:v[x[j+64>>2]]=p;continue e;case 6:x[x[j+64>>2]>>2]=p;continue e;case 7:break I;default:continue e}}k=x[j+64>>2];x[k>>2]=p;x[k+4>>2]=p>>31;continue e}l=l>>>0<=8?8:l;n=n|8;h=120}k=s;F=h&32;i=x[j+64>>2];m=x[j+68>>2];if(i|m){while(1){k=k-1|0;v[k|0]=F|y[(i&15)+76112|0];G=!m&i>>>0>15|(m|0)!=0;t=m;m=m>>>4|0;i=(t&15)<<28|i>>>4;if(G){continue}break}}if(!(n&8)|!(x[j+64>>2]|x[j+68>>2])){break y}z=(h>>>4|0)+5227|0;q=2;break y}h=s;k=x[j+68>>2];m=k;i=x[j+64>>2];if(k|i){while(1){h=h-1|0;v[h|0]=i&7|48;t=!m&i>>>0>7|(m|0)!=0;k=m;m=k>>>3|0;i=(k&7)<<29|i>>>3;if(t){continue}break}}k=h;if(!(n&8)){break y}h=s-k|0;l=(h|0)<(l|0)?l:h+1|0;break y}i=x[j+64>>2];h=x[j+68>>2];m=h;if((h|0)<0){k=0-(m+((i|0)!=0)|0)|0;m=k;i=0-i|0;x[j+64>>2]=i;x[j+68>>2]=k;q=1;z=5227;break z}if(n&2048){q=1;z=5228;break z}q=n&1;z=q?5229:5227}k=Dn(i,m,s)}if((l|0)<0?A:0){break d}n=A?n&-65537:n;h=x[j+64>>2];i=x[j+68>>2];if(!((h|i)!=0|l)){k=s;l=0;break g}h=!(h|i)+(s-k|0)|0;l=(h|0)<(l|0)?l:h;break g}h=x[j+64>>2];k=h?h:16660;m=l>>>0>=2147483647?2147483647:l;h=EA(k,0,m);h=h?h-k|0:m;o=h+k|0;if((l|0)>=0){n=i;l=h;break g}n=i;l=h;if(y[o|0]){break d}break g}if(l){i=x[j+64>>2];break u}h=0;wf(a,32,r,0,n);break t}x[j+12>>2]=0;x[j+8>>2]=x[j+64>>2];i=j+8|0;x[j+64>>2]=i;l=-1}h=0;J:{while(1){k=x[i>>2];if(!k){break J}m=eI(j+4|0,k);k=(m|0)<0;if(!(k|m>>>0>l-h>>>0)){i=i+4|0;h=h+m|0;if(l>>>0>h>>>0){continue}break J}break}if(k){break b}}o=61;if((h|0)<0){break c}wf(a,32,r,h,n);if(!h){h=0;break t}o=0;i=x[j+64>>2];while(1){k=x[i>>2];if(!k){break t}k=eI(j+4|0,k);o=k+o|0;if(o>>>0>h>>>0){break t}lf(a,j+4|0,k);i=i+4|0;if(h>>>0>o>>>0){continue}break}}wf(a,32,r,h,n^8192);h=(h|0)<(r|0)?r:h;continue e}if((l|0)<0?A:0){break d}o=61;h=ib[f|0](a,C[j+64>>3],r,l,n,h)|0;if((h|0)>=0){continue e}break c}v[j+55|0]=x[j+64>>2];l=1;k=E;n=i;break g}i=y[h+1|0];h=h+1|0;continue}}if(a){break a}if(!u){break f}h=1;while(1){a=x[(h<<2)+e>>2];if(a){fI((h<<3)+d|0,a,c,g);p=1;h=h+1|0;if((h|0)!=10){continue}break a}break}p=1;if(h>>>0>=10){break a}while(1){if(x[(h<<2)+e>>2]){break h}h=h+1|0;if((h|0)!=10){continue}break}break a}o=28;break c}m=o-k|0;i=(l|0)>(m|0)?l:m;if((i|0)>(q^2147483647)){break d}o=61;l=i+q|0;h=(l|0)<(r|0)?r:l;if((B|0)<(h|0)){break c}wf(a,32,h,l,n);lf(a,z,q);wf(a,48,h,l,n^65536);wf(a,48,i,m,0);lf(a,k,m);wf(a,32,h,l,n^8192);continue}break}p=0;break a}o=61}x[23424]=o}p=-1}db=j+80|0;return p}function Hia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0;f=db-192|0;db=f;if(Bi(b,13592)){if(d){v[d|0]=1}k=a+480204|0;n=a+480216|0;o=a+480220|0;q=a+480224|0;l=a+1074368|0;t=a+480228|0;u=a+480232|0;r=a+480200|0;m=a+480268|0;B=a+1298320|0;C=a+480248|0;E=iu(a+1074312|0);a:{b:{c:{d:{e:{f:{g:{h:{while(1){if(!Lb(x[b>>2],x[b+8>>2],7)){break a}e=pg(b);g=Fg(b);if((e|0)==70791730){ng(b,6);break a}if(!(e&1616928864)|e&-2139062144){break a}if(!Lb(x[b>>2],x[b+8>>2],g)){break a}d=f+152|0;Wd(d,b,g);h=hc(f+172|0,d);ub(d);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{if((e|0)!=1127099950){if((e|0)==1129797166){break v}if((e|0)==1130917459){break o}if((e|0)==1145525806){break t}d=u;if((e|0)==1448301654){break s}if((e|0)==1196316499){break m}if((e|0)==1213486401){break p}if((e|0)==1280530262){break u}if((e|0)==1297303086){break l}if((e|0)==1347243310){break w}if((e|0)==1347244882){break q}if((e|0)!=1380340804){if((e|0)==1380986414){break r}d=n;if((e|0)==1380991534){break s}d=o;if((e|0)==1380994350){break s}if((e|0)==1397052739){break n}d=t;if((e|0)==1397768494){break s}if((e|0)==1414344238){break k}if((e|0)!=1146367534){break j}x[23549]=0;S(393,h|0,g|0,f+152|0);d=x[23549];x[23549]=0;if((d|0)==1){break i}x[k>>2]=D(x[f+152>>2],1e4)+(A[k>>2]%1e4|0);break j}x[23549]=0;S(393,h|0,g|0,f+152|0);d=x[23549];x[23549]=0;if((d|0)!=1){d=x[k>>2];x[k>>2]=d-((d>>>0)%1e4|0)+A[f+152>>2]%1e4;break j}e=N()|0;break b}if(c){break j}x[23549]=0;w[f+152>>1]=0;S(394,h|0,g|0,f+152|0);d=x[23549];x[23549]=0;if((d|0)!=1){F=a,G=Vd(z[f+152>>1],z[a+480188>>1],127),w[F+480188>>1]=G;break j}e=N()|0;break b}x[23549]=0;S(395,h|0,g|0,l|0);d=x[23549];x[23549]=0;if((d|0)!=1){break j}break c}x[23549]=0;x[f+152>>2]=0;S(393,h|0,g|0,f+152|0);d=x[23549];x[23549]=0;if((d|0)!=1){x[a+1074304>>2]=x[f+152>>2];break j}e=N()|0;break b}x[23549]=0;x[f+152>>2]=0;S(393,h|0,g|0,f+152|0);d=x[23549];x[23549]=0;if((d|0)==1){break h}d=x[f+152>>2];if(!d){break j}x[a+1074308>>2]=d;break j}d=r}x[23549]=0;S(393,h|0,g|0,d|0);d=x[23549];x[23549]=0;if((d|0)==1){break c}break j}if(x[a+480180>>2]==4){break j}x[23549]=0;S(394,h|0,g|0,f+152|0);d=x[23549];x[23549]=0;if((d|0)!=1){$e(Wb(x[a+484360>>2],y[a+484376|0]),z[f+152>>1]);break j}e=N()|0;break b}x[23549]=0;S(396,h|0,g|0,m|0);d=x[23549];x[23549]=0;if((d|0)==1){break c}if(Mo(y[m|0])){break j}v[m|0]=5;break j}d=Gb(f+152|0);e=x[h>>2];x[23549]=0;e=R(146,e|0)|0;g=x[23549];x[23549]=0;x:{if((g|0)==1){break x}x[23549]=0;S(397,h|0,d|0,e|0);e=x[23549];x[23549]=0;if((e|0)==1){break x}x[23549]=0;S(11,f+140|0,0,d|0);e=x[23549];x[23549]=0;if((e|0)==1){break x}e=f+140|0;zb(B,e);tb(e);tb(d);break j}e=N()|0;tb(d);break b}if(g&1|g>>>0>126){break j}d=64;w[f+152>>1]=(g>>>1|0)- -64;w[f+140>>1]=127;e=z[Uc(f+152|0,f+140|0)>>1];i=e>>>0<=64?64:e;while(1){if((d|0)==(i|0)){break j}x[23549]=0;P(249,f+152|0,h|0);e=x[23549];x[23549]=0;if((e|0)==1){break g}e=y[f+152|0];y:{if((e|0)==255){break y}j=y[fd(f+152|0)|0];g=(d<<5)+a|0;s=g+480284|0;w[s>>1]=128;w[g+480286>>1]=j;g=g+480280|0;j=(e&128)<<3;x[g>>2]=j;e=e&127;if(e>>>0<65){w[s>>1]=e<<2;break y}if((e|0)!=100){break y}x[g>>2]=j|256}d=d+1|0;continue}}if(g>>>0<3){break j}x[23549]=0;d=R(180,h|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break f}if(z[a+480190>>1]<=(d-1&65535)>>>0){break j}d=(D(d,104)+a|0)+484448|0;g=oU(d);while(1){if((d|0)==(g|0)){break j}e=x[h>>2];x[23549]=0;i=U(142,e|0,x[f+180>>2],4)|0;e=x[23549];x[23549]=0;z:{if((e|0)!=1){e=268435456;if(!i){break z}x[23549]=0;e=R(143,h|0)|0;i=x[23549];x[23549]=0;if((i|0)!=1){break z}}e=N()|0;break b}x[d>>2]=e;d=d+4|0;continue}}if(g>>>0<3){break j}x[23549]=0;P(398,f+140|0,h|0);d=x[23549];x[23549]=0;A:{B:{C:{D:{if((d|0)!=1){x[23549]=0;S(399,f+152|0,x[f+140>>2],x[f+144>>2]);d=x[23549];x[23549]=0;if((d|0)==1){break D}x[23549]=0;d=O(78,f|0,f+152|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break C}tb(f+152|0);bc(f+140|0);e=x[h>>2];x[23549]=0;R(146,e|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break A}x[23549]=0;S(400,d|0,C|0,d|0);e=x[23549];x[23549]=0;if((e|0)==1){break A}mf(d);break j}e=N()|0;break b}e=N()|0;break B}e=N()|0;tb(f+152|0)}bc(f+140|0);break b}e=N()|0;mf(d);break b}e=0;g=iu(E);E:while(1){d=x[h>>2];x[23549]=0;d=U(142,d|0,x[f+180>>2],1)|0;i=x[23549];x[23549]=0;if((i|0)==1){break d}if(!(d&e>>>0<120)){break j}x[23549]=0;i=R(192,h|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break e}d=0;while(1){if((d|0)==8){continue E}F:{if(!(i>>>d&1)|e>>>0>119){break F}x[23549]=0;U(253,g|0,e|0,1)|0;j=x[23549];x[23549]=0;if((j|0)!=1){break F}e=N()|0;break b}e=e+1|0;d=d+1|0;continue}}}x[23549]=0;S(401,h|0,g|0,q|0);d=x[23549];x[23549]=0;if((d|0)==1){break c}}ub(h);continue}break}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0}ub(h);Q(e|0);p()}b=x[a+8>>2];To(k,D(x[b+20>>2],1e4),D(x[b+24>>2],1e4));if(y[a+480224|0]>=3){v[q|0]=0}if(y[l|0]>=6){v[l|0]=0}tc(r,256);tc(n,65536);tc(o,65536)}db=f+192|0}function vfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=db-352|0;db=d;a:{b:{c:{if(!Vc(b,60)){break c}if(!bp(b,d+332|0)){break c}h=15;if(Lt(d+332|0,15)){break b}}if(!Vc(b,124)){break a}if(!bp(b,d+332|0)){break a}h=31;if(!Lt(d+332|0,31)){break a}}Bd(a,536870912);w[a+480190>>1]=h;wc(b);d:{while(1){if(z[a+480190>>1]>f>>>0){e=Io(b);x[(d+208|0)+(f<<2)>>2]=e;f=f+1|0;if(e>>>0<=131072){continue}break d}break}Zb(b,20);h=0;w[a+480192>>1]=0;w[a+480188>>1]=4;f=y[d+336|0]|y[d+337|0]<<8;x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480196>>2]=6;q=a,r=Le(1776930/+(Hb(f)>>>0)*1e4),x[q+480204>>2]=r;x[a+480228>>2]=64;vh(a,1);k=1;e:while(1){n=k&65535;if(n>>>0<=z[a+480190>>1]){IS(b,d+52|0);e=x[((n<<2)+d|0)+204>>2];l=db-16|0;db=l;g=(D(n,104)+a|0)+484380|0;nd(g,1);x[g>>2]=e;v[g+37|0]=y[d+76|0]<<4;v[l+15|0]=y[d+77|0];v[l+14|0]=64;q=g,r=y[Sb(l+15|0,l+14|0)|0]<<2,w[q+30>>1]=r;f:{if(!e){break f}f=Hb(y[d+80|0]|y[d+81|0]<<8);j=Hb(y[d+78|0]|y[d+79|0]<<8);x[g+4>>2]=j;f=(f<<1)+j|0;x[g+8>>2]=f;if(e>>>0<=j>>>0){j=e-1|0;x[g+4>>2]=j}if(e>>>0<f>>>0){x[g+8>>2]=e;f=e}if(!(!(f>>>0<4|f>>>0<j>>>0)&f-j>>>0>3)){x[g+4>>2]=0;x[g+8>>2]=0;break f}if(f>>>0<=j>>>0){break f}w[g+34>>1]=z[g+34>>1]|2}db=l+16|0;f=0;while(1)if((f|0)==22){if(h>>>0>=128){break d}e=d+184|0;zl(e,3,d+52|0);f=d+196|0;Bc(f,e);zc(((n<<5)+a|0)+946304|0,f);k=k+1|0;tb(f);continue e}else{e=(d+52|0)+f|0;if((y[e|0]-1&255)>>>0<=30){v[e|0]=32;h=h+1|0}f=f+1|0;continue}}break}j=1;g:{h:{i:{h=a+946336|0;f=Tb(d+52|0,13745);if(!AR(h,f)){x[23549]=0;e=O(54,d+196|0,13756)|0;g=x[23549];x[23549]=0;if((g|0)==1){break i}j=AR(h,e);tb(e)}tb(f);f=0;e=d+52|0;h=HS(b,e);if(!h){tA(e)}if(!h){break a}e=y[d+52|0];if(!DR(e)){break a}if(!c){break g}w[d+50>>1]=0;while(1)if((e|0)==(f|0)){f=a+484376|0;g=Wb(x[a+484360>>2],y[f|0]);h=y[d+53|0];$e(g,e>>>0>h>>>0?h:0);av(Wb(x[a+484360>>2],y[f|0]),d+54|0,y[d+52|0],65535,65535);if(z[a+480190>>1]==31){Zb(b,4)}x[d+44>>2]=0;x[d+40>>2]=0;x[d+36>>2]=0;v[d+35|0]=0;n=c&1;if(n){mg(a+484344|0,z[d+50>>1])}l=a+484344|0;k=0;while(1){j:{k:{l:{if(z[d+50>>1]<=k>>>0){if(!(c&2)){break l}f=1;while(1){h=z[a+480190>>1];c=f&65535;if(h>>>0<c>>>0){break k}c=(D(c,104)+a|0)+484380|0;if(x[c>>2]){lg(Xc(d+184|0,8,1,0,0),c,b)}f=f+1|0;continue}}m:{if(n){h=0;if($g(l,k&65535,64)){break m}}Zb(b,1024);break j}n:while(1){if((h|0)==64){break j}f=0;e=Yb(x[l>>2],k);o=$c(x[e>>2],x[x[e+48>>2]+12>>2],h,0);while(1)if((f|0)==4){h=h+1|0;continue n}else{g=d+184|0;Im(g,b);e=D(f,6)+o|0;o:{p:{q:{r:{if(y[Db(g,0)|0]!=255){break r}v[(d+44|0)+f|0]=0;v[(d+36|0)+f|0]=0;g=Db(d+184|0,1);i=y[g|0];if((i|0)==252&j){v[g|0]=254;break p}switch(i-252|0){case 1:break o;case 2:break p;case 0:break q;default:break r}}g=x[d+184>>2];x[d+28>>2]=g;x[d+8>>2]=g;nu(d+8|0,e);g=y[e|0];s:{if(!g){break s}v[(d+36|0)+f|0]=0;v[(d+44|0)+f|0]=g;if(g>>>0>48){break s}v[d+12|0]=8;q=d,r=y[af(d+35|0,d+12|0)|0],v[q+35|0]=r}t:{u:{v:{w:{x:{y:{switch(y[e+3|0]){case 1:v[e+3|0]=1;break o;case 2:g=y[e+5|0];if(g>>>0>=16){v[e+3|0]=3;v[e+5|0]=g>>>4;break o}if(g){v[e+3|0]=2;v[e+5|0]=g;break o}v[e+5|0]=0;break u;case 3:if(y[(d+36|0)+f|0]){break v}v[e+3|0]=19;v[e+5|0]=0;break o;case 4:if(y[(d+36|0)+f|0]){break v}v[e+3|0]=19;v[e+5|0]=1;break o;case 5:if(!y[e+1|0]){break v}v[e+3|0]=13;v[d+12|0]=63;v[d+27|0]=y[e+5|0]+(z[(D(y[e+1|0],104)+a|0)+484410>>1]>>>2|0);q=e,r=y[Sb(d+12|0,d+27|0)|0],v[q+5|0]=r;if(!y[(d+36|0)+f|0]){break x}v[e+2|0]=1;v[e+4|0]=y[e+5|0];v[e+5|0]=0;break u;case 6:g=y[e+1|0];if(!g){break v}v[e+3|0]=13;g=z[(D(g,104)+a|0)+484410>>1]>>>2|0;i=y[e+5|0];g=g>>>0>=i>>>0?g-i|0:0;v[e+5|0]=g;if(!y[(d+36|0)+f|0]){break o}v[e+4|0]=g;v[e+2|0]=1;v[e+5|0]=0;break u;case 7:g=y[(d+44|0)+f|0];i=y[e+5|0];m=g-(i>>>4|0)|0;v[(d+40|0)+f|0]=m;v[e+3|0]=3;i=i&15;v[(d+36|0)+f|0]=i;q=e,r=zR(i,m&255,g),v[q+5|0]=r;break o;case 8:i=y[(d+44|0)+f|0];g=y[e+5|0];m=i+(g>>>4|0)|0;v[(d+40|0)+f|0]=m;v[e+3|0]=2;g=g&15;v[(d+36|0)+f|0]=g;q=e,r=zR(g,i,m&255),v[q+5|0]=r;break o;case 0:break w;case 9:break y;default:break u}}v[d+12|0]=8;q=d,r=y[af(d+35|0,d+12|0)|0],v[q+35|0]=r;break u}if(!y[e+3|0]){break t}break o}if(!y[e+5|0]){break t}break u}v[e+5|0]=0}v[e+3|0]=0}i=y[(d+36|0)+f|0];if(!i){break o}m=(d+40|0)+f|0;g=y[m|0];if(g){v[(d+44|0)+f|0]=g;v[e|0]=g;v[e+5|0]=i;v[m|0]=0}v[e+3|0]=4;break o}v[e+3|0]=14;v[d+35|0]=9;break o}v[e+3|0]=13}f=f+1|0;continue}}}h=z[a+480190>>1]}z:{A:{if((h&65535)==15){b=d+12|0;hf(b,4359);x[23549]=0;S(293,d+184|0,b|0,d+35|0);b=x[23549];x[23549]=0;if((b|0)!=1){break A}h=N()|0;Ab(d+12|0);break h}x[23549]=0;O(1,d+184|0,12180)|0;b=x[23549];x[23549]=0;if((b|0)==1){break z}}b=d+184|0;zb(a+1298344|0,b);tb(b);if((h&65535)==15){Ab(d+12|0)}Wc(a+1298356|0,z[a+480190>>1]==15?5223:14773);x[a+1298404>>2]=13;break g}h=N()|0;break h}k=k+1|0;continue}}else{w[d+184>>1]=y[(d+f|0)+54|0]+1;q=d,r=z[Ve(d+50|0,d+184|0)>>1],w[q+50>>1]=r;f=f+1|0;continue}}h=N()|0;tb(f)}Q(h|0);p()}f=1;break a}f=0}db=d+352|0;return f|0}function nga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0;f=db-256|0;db=f;wc(b);a:{if(!EV(b,f+190|0)){break a}if(!qS(f+190|0)){break a}if(!Lb(x[b>>2],x[b+8>>2],Qc(pS(f+190|0),hb))){break a}b:{if(!c){break b}Bd(a,16);e=f+28|0;nj(e,2,f+194|0);d=f+48|0;Bc(d,e);zb(a+1298308|0,d);tb(d);w[a+480190>>1]=y[f+220|0];w[a+480188>>1]=y[f+223|0];g=Tb(d,8263);zb(a+1298344|0,g);tb(g);g=Tb(d,10012);zb(a+1298356|0,g);tb(g);hf(e,4152);g=y[f+193|0];x[f+8>>2]=g>>>4;x[23549]=0;x[f+184>>2]=g&15;V(290,d|0,e|0,f+8|0,f+184|0);d=x[23549];x[23549]=0;c:{d:{if((d|0)!=1){d=f+48|0;zb(a+1298368|0,d);tb(d);Ab(f+28|0);x[a+1298404>>2]=5;h=1;while(1){k=h&65535;if(k>>>0>z[a+480190>>1]){h=0;while(1)if(z[a+480188>>1]<=h>>>0){e=f+48|0;d=db-16|0;db=d;k=b;e:{if(!Lb(x[b>>2],x[b+8>>2],128)){b=0;while(1){if((b|0)!=128){tg(b+e|0);b=b+1|0;continue}break}break e}MT(d+8|0,e);pd(d,k,x[d+8>>2],x[d+12>>2])}db=d+16|0;av(Wb(x[a+484360>>2],y[a+484376|0]),e,y[f+217|0]+1|0,255,254);b=y[f+222|0];d=f+8|0;Wd(d,k,D(y[f+214|0]|y[f+215|0]<<8,192));n=hc(f+28|0,d);ub(d);f:{r=c&1;if(!r){break f}x[23549]=0;P(211,a+484344|0,y[f+216|0]+1|0);d=x[23549];x[23549]=0;if((d|0)!=1){break f}break d}o=b?b:64;q=a+484344|0;b=0;while(1){g:{h:{i:{if(y[f+216|0]<l>>>0){if(!(b&t)){break h}u=f,B=yb(x[a+484344>>2]),x[u+8>>2]=B;j=yb(x[a+484348>>2]);i=z[a+480188>>1];break i}j:{if(r){x[23549]=0;d=U(212,q|0,l&65535,o|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break d}m=0;if(d){break j}}x[23549]=0;O(174,k|0,64)|0;d=x[23549];x[23549]=0;if((d|0)!=1){break g}break d}while(1){e=m&65535;if(e>>>0>31){break g}x[23549]=0;d=R(180,k|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}k:{if((d-1&65535)>>>0>=(y[f+214|0]|y[f+215|0]<<8)>>>0|e>>>0>=z[a+480188>>1]){break k}x[23549]=0;O(141,n|0,D(d,192)-192|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break d}d=0;g=Yb(x[q>>2],l);h=$c(x[g>>2],x[x[g+48>>2]+12>>2],0,e);while(1){if((d|0)==(o|0)){break k}j=b;x[23549]=0;P(491,f+8|0,n|0);b=x[23549];x[23549]=0;l:{m:{n:{o:{p:{if((b|0)!=1){b=f+8|0;i=fd(b);e=Ue(b);b=y[f+8|0];if(b>>>0>=4){v[h|0]=(b>>>2|0)+37;b=y[f+8|0]}v[h+1|0]=b<<4&48|y[i|0]>>>4;b=y[e|0];g=0;e=0;q:{r:{i=y[i|0]&15;switch(i-8|0){case 0:break o;case 2:break q;case 6:break r;default:break p}}i=14;s=(b&240)<<24>>24;if((s|0)<=-17|!(435>>>((s+16&240)>>>4)&1)){break n}break o}b=(b&240?-16:15)&b;i=10;break n}break d}g=i;e=b}i=g;b=e;if(!((g|b)&255)){break m}}v[h+5|0]=b;v[h+3|0]=i;Qf(h);b=1;s:{switch(y[h+3|0]-16|0){case 0:break l;case 1:break s;default:break m}}t=1}b=j}d=d+1|0;h=D(z[a+480188>>1],6)+h|0;continue}}m=m+1|0;continue}}while(1){t:{b=x[f+8>>2];if(Kb(b,j)){l=x[b+48>>2];m=x[b>>2];o=x[b+12>>2];e=0;u:while(1){if((e|0)==(o|0)){break t}h=0;q=sf(m,x[l+12>>2],e);d=0;g=0;while(1)if((h|0)==(i|0)){e=e+1|0;if(!(d&g&1)){continue u}break h}else{b=1;v:{switch(y[(q+D(h,6)|0)+3|0]-16|0){case 1:g=1;default:b=d;break;case 0:break v}}h=h+1|0;d=b;continue}}}u=f,B=yb(x[a+484344>>2]),x[u+184>>2]=B;d=yb(x[a+484348>>2]);w:while(1){b=x[f+184>>2];if(!Kb(b,d)){break h}e=0;while(1)if(A[b+12>>2]<=e>>>0){so(f+184|0);continue w}else{g=sf(x[b>>2],x[x[b+48>>2]+12>>2],e);j=z[a+480188>>1];h=0;x:{while(1){if((h|0)==(j|0)){break x}i=D(h,6);h=h+1|0;i=y[(g+i|0)+3|0];if((i&254)!=16){continue}break}g=(i|0)==16;me(b,Fe(Be(f+8|0,g?17:16,g?125:6),e))}e=e+1|0;continue}}}so(f+8|0);continue}}y:{b=y[f+218|0]|y[f+219|0]<<8;if(!b){break y}x[23549]=0;aa(301,a+1298332|0,k|0,b|0,39,1);b=x[23549];x[23549]=0;if((b|0)!=1){break y}break d}z:{if(!(c&2)){break z}h=1;while(1){b=h&65535;if(b>>>0>z[a+480190>>1]){break z}b=D(b,104)+a|0;c=Xc(f+8|0,w[b+484414>>1]&1?16:8,1,0,1);x[23549]=0;U(205,c|0,b+484380|0,k|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){h=h+1|0;continue}break}break d}x[a+480260>>2]=64;x[a+480264>>2]=32767;ub(n);break b}l=l+1|0;continue}}else{d=(h<<5)+a|0;Te(d+480280|0);w[d+480284>>1]=(y[(f+h|0)+224|0]<<4|8)&248;h=h+1|0;continue}}else{e=f+48|0;IC(b,e);j=db-16|0;db=j;d=(D(k,104)+a|0)+484380|0;nd(d,0);w[j+14>>1]=y[e+35|0]<<2;w[j+12>>1]=256;u=d,B=z[Uc(j+14|0,j+12|0)>>1],w[u+30>>1]=B;g=y[e+22|0]|y[e+23|0]<<8|(y[e+24|0]<<16|y[e+25|0]<<24);A:{if(g>>>0<3){break A}x[d>>2]=g;x[d+4>>2]=y[e+26|0]|y[e+27|0]<<8|(y[e+28|0]<<16|y[e+29|0]<<24);x[j+8>>2]=y[e+30|0]|y[e+31|0]<<8|(y[e+32|0]<<16|y[e+33|0]<<24);x[j+4>>2]=1;u=d,B=x[Yc(j+8|0,j+4|0)>>2]-1|0,x[u+8>>2]=B;tc(d+8|0,g);g=x[d+8>>2];i=x[d+4>>2];B:{if(g>>>0<=i+4>>>0){x[d+4>>2]=0;x[d+8>>2]=0;g=0;i=0;break B}if(g>>>0<3){break B}w[d+34>>1]=z[d+34>>1]|2}v[d+37|0]=y[e+34|0];u=d,B=Ru(0,v[e+34|0]<<4),x[u+24>>2]=B;if(!(v[e+36|0]&1)){break A}x[d+8>>2]=g>>>1;x[d+4>>2]=i>>>1;w[d+34>>1]=z[d+34>>1]|1;x[d>>2]=x[d>>2]>>>1}db=j+16|0;g=f+8|0;zl(g,2,e);d=f+28|0;Bc(d,g);zc(((k<<5)+a|0)+946304|0,d);h=h+1|0;tb(d);continue}}}h=N()|0;Ab(f+28|0);break c}h=N()|0;ub(n)}Q(h|0);p()}h=1}db=f+256|0;return h|0}function KI(a,b,c,d,e,f){var g=0,h=E(0),i=0,j=0,k=E(0),l=E(0),m=E(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=0,z=E(0),A=E(0),C=0,F=0,G=0,H=E(0),I=E(0),J=E(0),K=E(0),L=E(0),M=E(0),N=E(0),O=E(0),P=0,Q=0;F=(d|0)>0?d:0;while(1){if((s|0)!=(F|0)){G=D(s,2304)+b|0;u=0;q=(c|0)>0?c:0;n=db-128|0;x=n+96|0;y=n- -64|0;C=n+32|0;while(1){if((q|0)!=(u|0)){o=G+(u<<2)|0;v=0;i=n;p=i;j=0;while(1){if((j|0)!=8){k=B[D(15-j|0,72)+o>>2];g=D(j,72)+o|0;h=B[g+1152>>2];l=E(k+h);m=B[g>>2];z=B[D(31-j|0,72)+o>>2];A=E(m+z);B[p>>2]=l+A;g=D(j,12);k=E(E(k-h)*B[g+70336>>2]);h=E(E(m-z)*B[g+70340>>2]);B[p+64>>2]=k+h;m=E(A-l);l=B[g+70344>>2];B[p+32>>2]=m*l;B[p+96>>2]=l*E(h-k);p=p+4|0;j=j+1|0;continue}break}while(1){if((v|0)!=4){l=B[i+8>>2];m=B[i+20>>2];h=E(l+m);z=B[i+4>>2];A=B[i+24>>2];H=E(z+A);k=E(h+H);I=B[i+12>>2];J=B[i+16>>2];K=E(I+J);L=B[i>>2];M=B[i+28>>2];N=E(L+M);O=E(K+N);B[i>>2]=k+O;B[i+16>>2]=E(O-k)*E(.7071067690849304);k=E(N-K);h=E(E(k+E(H-h))*E(.7071067690849304));B[i+24>>2]=E(k-h)*E(1.3065630197525024);B[i+8>>2]=E(k+h)*E(.5411961078643799);k=E(L-M);h=E(l-m);l=E(z-A);m=E(E(h+l)*E(.7071067690849304));z=E(k+m);A=E(E(I-J)+h);h=E(l+k);l=E(A-E(h*E(.1989123672246933)));h=E(E(l*E(.3826834261417389))+h);B[i+28>>2]=E(z-h)*E(2.562915563583374);B[i+4>>2]=E(z+h)*E(.509795606136322);k=E(k-m);h=E(l-E(h*E(.1989123672246933)));B[i+20>>2]=E(k+h)*E(.8999761939048767);B[i+12>>2]=E(k-h)*E(.601344883441925);i=i+32|0;v=v+1|0;continue}break}i=0;while(1){if((i|0)!=7){p=i<<2;B[o>>2]=B[p+n>>2];k=B[p+x>>2];i=i+1|0;j=i<<2;h=B[j+x>>2];B[o+72>>2]=E(B[p+y>>2]+k)+h;B[o+144>>2]=B[p+C>>2]+B[j+C>>2];B[o+216>>2]=h+E(k+B[j+y>>2]);o=o+288|0;continue}break}B[o>>2]=B[n+28>>2];k=B[n+124>>2];B[o+72>>2]=B[n+92>>2]+k;h=B[n+60>>2];B[o+216>>2]=k;B[o+144>>2]=h;u=u+1|0;continue}break}s=s+1|0;continue}break}C=rc(f,a,3840);G=d<<5;s=0;while(1){if((c|0)>(s|0)){i=db-32|0;db=i;o=C+(s<<8)|0;u=(s<<2)+b|0;B[o+4080>>2]=B[u+1152>>2];f=d-1|0;v=u+D(f,2304)|0;B[o+4084>>2]=B[v+1152>>2];B[o+4088>>2]=B[u>>2];B[o+4092>>2]=B[v>>2];B[o+4336>>2]=B[u+1156>>2];B[o+4340>>2]=B[v+1156>>2];B[o+4344>>2]=B[u+4>>2];B[o+4348>>2]=B[v+4>>2];x=(D(s,G)<<1)+e|0;y=x+(f<<1)|0;ks(y,d,o+244|0);f=d<<6;ks(f+y|0,d,o+500|0);ks(x,d,o+240|0);ks(f+x|0,d,o+496|0);F=o+3840|0;p=14;n=70432;while(1){if((p|0)>=0){g=p<<4;j=g+F|0;f=D(31-p|0,72);B[j>>2]=B[f+u>>2];B[j+4>>2]=B[f+v>>2];f=f|4;B[j+8>>2]=B[f+u>>2];B[j+12>>2]=B[f+v>>2];f=D(p,72);q=f+76|0;B[j+256>>2]=B[q+u>>2];B[j+260>>2]=B[q+v>>2];f=f+72|0;B[j-248>>2]=B[f+u>>2];B[j-244>>2]=B[f+v>>2];q=p<<2;t=g+o|0;k=B[n+4>>2];h=B[n>>2];f=0;while(1){if((f|0)!=4){g=f<<2;l=B[g+j>>2];m=B[g+t>>2];B[g+(i+16|0)>>2]=E(l*h)-E(k*m);B[i+g>>2]=E(l*k)+E(h*m);f=f+1|0;continue}break}j=F+(q<<2)|0;q=j-3584|0;t=j-256|0;k=B[n+12>>2];h=B[n+8>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-3328|0;t=j-512|0;k=B[n+20>>2];h=B[n+16>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}q=j-3072|0;t=j-768|0;k=B[n+28>>2];h=B[n+24>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-2816|0;t=j-1024|0;k=B[n+36>>2];h=B[n+32>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}q=j-2560|0;t=j-1280|0;k=B[n+44>>2];h=B[n+40>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-2304|0;t=j-1536|0;k=B[n+52>>2];h=B[n+48>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}g=j-2048|0;q=j-1792|0;k=B[n+60>>2];h=B[n+56>>2];f=0;while(1){if((f|0)!=4){j=f<<2;t=j+i|0;l=B[j+q>>2];m=B[g+j>>2];B[t>>2]=B[t>>2]+E(E(l*k)+E(h*m));j=j+(i+16|0)|0;B[j>>2]=E(E(m*k)-E(h*l))+B[j>>2];f=f+1|0;continue}break}f=D(15-p|0,d)<<1;P=f+y|0,Q=Vi(B[i+20>>2]),w[P>>1]=Q;j=D(p+17|0,d)<<1;P=j+y|0,Q=Vi(B[i+4>>2]),w[P>>1]=Q;P=f+x|0,Q=Vi(B[i+16>>2]),w[P>>1]=Q;P=j+x|0,Q=Vi(B[i>>2]),w[P>>1]=Q;f=D(47-p|0,d)<<1;P=f+y|0,Q=Vi(B[i+28>>2]),w[P>>1]=Q;j=D(p+49|0,d)<<1;P=j+y|0,Q=Vi(B[i+12>>2]),w[P>>1]=Q;P=f+x|0,Q=Vi(B[i+24>>2]),w[P>>1]=Q;P=j+x|0,Q=Vi(B[i+8>>2]),w[P>>1]=Q;p=p-1|0;n=n- -64|0;continue}break}db=i+32|0;s=s+2|0;continue}break}b=c<<6;a:{if((d|0)==1){s=0;while(1){if(s>>>0>959){break a}B[(s<<2)+a>>2]=B[C+(b+s<<2)>>2];s=s+2|0;continue}}rc(a,C+(b<<2)|0,3840)}}function Rea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=db-112|0;db=d;wc(c);a:{b:{c:{d:{if(!Bo(c,d+100|0)|(y[d+100|0]|y[d+101|0]<<8|(y[d+102|0]<<16|y[d+103|0]<<24))!=1297239878){break d}e=y[d+108|0]|y[d+109|0]<<8|(y[d+110|0]<<16|y[d+111|0]<<24);if(!((e|0)==1482052408|(e|0)==1448293937)&(y[d+108|0]|y[d+109|0]<<8|(y[d+110|0]<<16|y[d+111|0]<<24))!=1146437965){break d}e=db-32|0;db=e;i=Nb(d+88|0);e:{f:{g:{h:{i:{while(1){h=x[c+8>>2];j=x[c>>2];x[23549]=0;h=U(142,j|0,h|0,8)|0;j=x[23549];x[23549]=0;if((j|0)==1){break g}if(!h){break h}x[23549]=0;P(768,e+4|0,c|0);h=x[23549];x[23549]=0;if((h|0)!=1){x[23549]=0;P(769,i|0,e+4|0);h=x[23549];x[23549]=0;if((h|0)==1){break i}Gd(e+4|0);continue}break}a=N()|0;break f}a=N()|0;Gd(e+4|0);break f}db=e+32|0;break e}a=N()|0}_d(i);Q(a|0);p()}x[23549]=0;h=R(160,d+68|0)|0;c=x[23549];x[23549]=0;j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if((c|0)!=1){i=Xc(d- -64|0,8,1,1,0);if((y[d+108|0]|y[d+109|0]<<8|(y[d+110|0]<<16|y[d+111|0]<<24))!=1146437965){break q}x[23549]=0;S(679,d+44|0,d+88|0,1296581714);c=x[23549];x[23549]=0;if((c|0)==1){break n}x[23549]=0;S(679,d+24|0,d+88|0,1296318804);c=x[23549];x[23549]=0;if((c|0)==1){break c}c=d+24|0;e=Zc(h,c);ub(c);x[23549]=0;c=R(680,d+44|0)|0;g=x[23549];x[23549]=0;f=1;if((g|0)==1){break c}if(!c){break r}c=x[e>>2];x[23549]=0;c=R(164,c|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break c}if(!c){break r}x[23549]=0;k=R(268,d+44|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break c}x[23549]=0;c=R(260,d+44|0)|0;e=x[23549];x[23549]=0;t:{if((e|0)==1){break t}x[23549]=0;O(174,d+44|0,2)|0;e=x[23549];x[23549]=0;if((e|0)==1){break t}x[23549]=0;l=R(268,d+44|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){break s}}break c}f=N()|0;break a}x[23549]=0;P(591,d+24|0,d+44|0);e=x[23549];x[23549]=0;if((e|0)==1){break c}e=Hb(z[d+24>>1]);if(!e){break r}l=(l>>>0)/(e>>>0)|0;g=d+24|0;e=gc(g);g=Ue(g);e=Hb(y[e|0]|y[e+1|0]<<8);if((e|0)!=(Hb(y[g|0]|y[g+1|0]<<8)+1|0)){break r}if((e|0)==2){Oo(i,2)}u:{if((c|0)!=16){if((c|0)!=8){break r}v:{switch(Hb(y[d+30|0]|y[d+31|0]<<8)|0){case 0:Uf(i,1);break u;case 2:Uf(i,17);break u;case 3:break v;default:break r}}Uf(i,16);break u}if(Hb(y[d+30|0]|y[d+31|0]<<8)){break r}hd(i,16)}f=0}ub(d+44|0);g=0;if(!f){break p}f=0;break j}x[23549]=0;S(679,d+44|0,d+88|0,1447576658);c=x[23549];x[23549]=0;w:{x:{y:{if((c|0)!=1){x[23549]=0;S(679,d+24|0,d+88|0,1128808782);c=x[23549];x[23549]=0;if((c|0)==1){break y}x[23549]=0;S(679,d+4|0,d+88|0,1112491097);c=x[23549];x[23549]=0;if((c|0)==1){break x}c=d+4|0;j=Zc(h,c);ub(c);c=x[j>>2];x[23549]=0;e=R(164,c|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break x}c=0;z:{if(!e){break z}x[23549]=0;e=R(164,x[d+44>>2])|0;c=x[23549];x[23549]=0;if((c|0)==1){break x}c=0;if(!e){break z}x[23549]=0;e=O(681,d+44|0,d+4|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break x}c=0;if(!e){break z}c=y[d+108|0]|y[d+109|0]<<8|(y[d+110|0]<<16|y[d+111|0]<<24);x[23549]=0;l=R(268,d+24|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break x}g=(c|0)!=1482052408;if(g){hd(i,16)}if((l|0)==6){Oo(i,3)}m=$b(x[d+4>>2]);e=x[d+8>>2];c=x[d+12>>2];k=$b(c);A:{B:{if(k>>>0<33){break B}n=$b(e);if(n>>>0<=k>>>0){break B}if(!((n>>>0)%(k>>>0)|0)){break A}}c=e}e=x[j>>2];x[23549]=0;j=x[d+20>>2];n=z[d+16>>1];k=R(146,e|0)|0;e=x[23549];x[23549]=0;o=1;if((e|0)==1){break x}e=g+((l|0)==6)|0;m=m>>>e|0;k=k>>>e|0;g=$b(j);l=Hb(n);c=$b(c)>>>e|0}ub(d+24|0);ub(d+44|0);if(o){break o}break j}f=N()|0;break b}f=N()|0;break w}f=N()|0;ub(d+24|0)}ub(d+44|0);break b}c=0}jt(a,b);x[23549]=0;f=D(b,104)+a|0;e=f+484380|0;P(266,e|0,0);j=x[23549];x[23549]=0;if((j|0)==1){break m}x[e>>2]=k;c=c+m|0;x[f+484388>>2]=c;x[f+484384>>2]=m;if(!(c>>>0<=m+4>>>0|c>>>0>k>>>0)){c=(D(b,104)+a|0)+484414|0;w[c>>1]=z[c>>1]|2}c=D(b,104)+a|0;x[c+484404>>2]=l>>>0<2?22050:l;f=c+484410|0;c=g>>>8|0;w[f>>1]=(g&16776960)>>>0>65536?256:c&65535?c:256;Fz(e,x[a+480180>>2]);x[23549]=0;S(679,d+44|0,d+88|0,1312902469);c=x[23549];x[23549]=0;if((c|0)==1){break l}x[23549]=0;c=R(164,x[d+44>>2])|0;f=x[23549];x[23549]=0;if((f|0)==1){break k}C:{D:{if(c){x[23549]=0;c=R(146,x[d+44>>2])|0;f=x[23549];x[23549]=0;if((f|0)==1){break k}x[23549]=0;S(316,d+44|0,((b<<5)+a|0)+946304|0,c|0);b=x[23549];x[23549]=0;if((b|0)!=1){break D}break k}x[23549]=0;c=O(54,d+24|0,21204)|0;f=x[23549];x[23549]=0;if((f|0)==1){break C}zc(((b<<5)+a|0)+946304|0,c);tb(c)}x[23549]=0;U(205,i|0,e|0,h|0)|0;b=x[23549];x[23549]=0;f=1;if((b|0)==1){break k}dj(e,a);ub(d+44|0);break j}break k}f=N()|0;break b}f=N()|0;break b}f=N()|0;break b}f=N()|0;ub(d+44|0);break b}ub(h);_d(d+88|0)}db=d+112|0;return f|0}f=N()|0;ub(d+44|0)}ub(h)}_d(d+88|0);Q(f|0);p()}function Eea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;i=db-192|0;db=i;wc(b);a:{if(!mB(b,i+144|0)){break a}if(!FQ(i+144|0)){break a}b:{if(!c){break b}if(!Lb(x[b>>2],x[b+8>>2],Qc(EQ(y[i+191|0]),hb))){break a}Bd(a,128);d=i+132|0;_e(d,2,i+159|0);e=i- -64|0;Bc(e,d);zb(a+1298308|0,e);tb(e);h=Tb(e,8351);zb(a+1298344|0,h);tb(h);h=Tb(e,5997);zb(a+1298356|0,h);tb(h);d=Tb(d,17128);x[23549]=0;S(694,e|0,d|0,x[(y[i+158|0]<<2)+26924>>2]);e=x[23549];x[23549]=0;c:{if((e|0)!=1){e=i- -64|0;zb(a+1298368|0,e);tb(e);tb(d);x[a+480208>>2]=12;x[a+1298404>>2]=5;EB(a+1298332|0,b,y[i+191|0]<<5,32,0);e=ee(b);w[a+480190>>1]=e;h=1;while(1){m=h&65535;if(m>>>0>(e&65535)>>>0){Ao(Wb(x[a+484360>>2],y[a+484376|0]),b,256,255,254);h=0;e=ee(b);if(e>>>0>=127){break a}w[a+480188>>1]=e+1;d=ee(b);while(1)if(z[a+480188>>1]<=h>>>0){l=a+484344|0;r=d+1|0;mg(l,r);e=0;while(1){d:{f=e&65535;if(f>>>0>d>>>0){e:while(1){n=s&65535;d=z[a+480188>>1];if(n>>>0>=d>>>0){e=oo(i+12|0);v[e+16|0]=0;w[e+14>>1]=0;w[e+12>>1]=d;x[23549]=0;P(696,e|0,d|0);d=x[23549];x[23549]=0;if((d|0)==1){a=N()|0;He(e);Q(a|0);p()}x[23549]=0;d=e;S(695,i+32|0,l|0,d|0);e=x[23549];x[23549]=0;h=1;if((e|0)==1){break d}He(i+32|0);He(d);if(!(c&2)){break a}while(1){c=h&65535;if(c>>>0>z[a+480190>>1]){break b}c=D(c,104)+a|0;lg(Xc(i- -64|0,w[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);h=h+1|0;continue}}m=0;f=Wh(i- -64|0);f:while(1){g:{if((m|0)!=(r|0)){if(Lb(x[b>>2],x[b+8>>2],5)){break g}}s=s+1|0;continue e}e=0;d=Yb(x[l>>2],m);h=$c(x[d>>2],x[x[d+48>>2]+12>>2],0,n);while(1){h:{i:{if(e>>>0>63){break i}j=y[i+158|0];d=db-16|0;db=d;o=1;g=ee(b);if((g|0)==252){o=ee(b);g=ee(b)}v[f|0]=(g-1&255)>>>0<60?g+36|0:0;g=d+12|0;Im(g,b);v[f+1|0]=y[d+12|0];k=y[fd(g)|0];v[d+11|0]=k&15;v[d+10|0]=k>>>4;t=d,u=y[Ue(g)|0],v[t+9|0]=u;t=d,u=y[Ai(g)|0],v[t+8|0]=u;CQ(d+11|0,d+9|0,j);CQ(d+10|0,d+8|0,j);j=y[d+11|0];k=(j|0)!=10;g=y[d+10|0];j:{if(!(k|(g|0)!=10)){j=y[d+9|0];g=y[d+8|0];v[f+3|0]=10;j=j|g<<8;v[f+5|0]=j>>>6;if(j>>>0<16384){break j}v[f+2|0]=15;v[f+4|0]=g>>>6;break j}k:{l:{m:{n:{if(!k){k=y[d+9|0];q=k<<2;t=d,u=Km(q),v[t+9|0]=u;if(k>>>0<64){break n}if(th(g)>>>0>=th(10)>>>0){break n}v[f+5|0]=q;v[f+2|0]=15;v[f+3|0]=10;v[f+4|0]=k>>>6;break j}if((g|0)==10){g=y[d+8|0];k=g<<2;t=d,u=Km(k),v[t+8|0]=u;if(g>>>0<64){break k}if(th(j)>>>0>=th(10)>>>0){break k}v[f+5|0]=k;v[f+2|0]=15;v[f+3|0]=10;v[f+4|0]=g>>>6;break j}if((g|0)!=(j|0)){break n}g=0;v[d+10|0]=0;break m}if((g|0)==13){break l}}if((j|0)==13|g){break k}}sh(d+11|0,d+10|0);sh(d+9|0,d+8|0)}g=d+10|0;j=d+8|0;k=d+11|0;q=d+9|0;Ou(g,j,k,q);Gq(d+6|0,k,q,g,j);v[f+2|0]=y[d+11|0];v[f+4|0]=y[d+9|0];v[f+3|0]=y[d+10|0];v[f+5|0]=y[d+8|0]}db=d+16|0;g=e+o|0;e=g>>>0>64?64-e|0:o;if(!e){break i}while(1){if(!e){break h}d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[h|0]=d;v[h+1|0]=d>>>8;v[h+2|0]=d>>>16;v[h+3|0]=d>>>24;d=y[f+4|0]|y[f+5|0]<<8;v[h+4|0]=d;v[h+5|0]=d>>>8;e=e-1|0;h=D(z[a+480188>>1],6)+h|0;continue}}m=m+1|0;continue f}e=g>>>0>=64?64:g;continue}}}}e=e+1|0;h=0;if($g(l,f,64)){continue}break a}break}e=N()|0;He(d);break c}else{e=(h<<5)+a|0;Te(e+480280|0);e=e+480284|0;o:{if(y[i+158|0]>=51){n=(ee(b)<<4|8)&248;break o}n=h&1?192:64}w[e>>1]=n;h=h+1|0;continue}}else{p:{if(y[i+158|0]>=52){e=i- -64|0;if(!kV(b,e)){HB(e)}break p}f=i- -64|0;d=db-32|0;db=d;x[d+28>>2]=64;x[d+8>>2]=66;r=x[b>>2];n=x[b+8>>2];e=x[Cb(d+28|0,d+8|0)>>2];if(!Lb(r,n,e)){e=rf(b)}g=d+8|0;yu(g,f);l=ec(d+16|0,x[d+8>>2],e);o=x[l>>2];lc(d,x[b>>2],x[b+8>>2],o,x[l+4>>2]);yu(g,f);Vb(x[d+8>>2]+e|0,0,66-e|0);Zb(b,x[d+28>>2]);db=d+32|0;e=y[i+126|0]|y[i+127|0]<<8;v[i+128|0]=e;v[i+129|0]=e>>>8;v[i+126|0]=171;v[i+127|0]=32}g=db-32|0;db=g;f=(D(m,104)+a|0)+484380|0;nd(f,0);wB(f);l=g+8|0;d=i- -64|0;ck(l,2,d+32|0);e=g+20|0;Bc(e,l);Ce(f+43|0,e);tb(e);e=y[d+56|0]|y[d+57|0]<<8|(y[d+58|0]<<16|y[d+59|0]<<24);l=y[d+52|0]|y[d+53|0]<<8|(y[d+54|0]<<16|y[d+55|0]<<24);q:{if(e>>>0<=l>>>0){break q}x[f>>2]=e-l;x[f+12>>2]=y[d+44|0]|y[d+45|0]<<8|(y[d+46|0]<<16|y[d+47|0]<<24);x[g+20>>2]=y[d+48|0]|y[d+49|0]<<8|(y[d+50|0]<<16|y[d+51|0]<<24);t=f,u=x[Cb(g+20|0,f)>>2],x[t+16>>2]=u;w[f+30>>1]=y[d+60|0];x[f+24>>2]=y[d+62|0]|y[d+63|0]<<8;e=y[d+64|0]|y[d+65|0]<<8;if(e){vq(f,+(e<<16>>16)/393216)}e=y[d+61|0];if(e&8){w[f+34>>1]=z[f+34>>1]|8;e=y[d+61|0]}if(e&16){w[f+34>>1]=z[f+34>>1]|16;e=y[d+61|0]}if(!(e&4)){break q}w[f+34>>1]=z[f+34>>1]|1;x[f+12>>2]=x[f+12>>2]>>>1;x[f+16>>2]=x[f+16>>2]>>>1}db=g+32|0;f=i+52|0;_e(f,2,d);e=i+132|0;Bc(e,f);zc(((m<<5)+a|0)+946304|0,e);h=h+1|0;tb(e);e=z[a+480190>>1];continue}}}e=N()|0;tb(d)}Q(e|0);p()}h=1}db=i+192|0;return h|0}function KN(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=db-16|0;db=g;a:{if(!Tc(d&255)){break a}n=a+1074376|0;j=(n+D(b,872)|0)+616|0;b:{h=z[a+480192>>1];if(!(!(x[a+480180>>2]&17825824)|!h|e)){break b}if(Pj(x[j+656>>2])){break b}c=D(b,872)+a|0;d=c+1075068|0;if(!x[d>>2]){break a}c=x[c+1075080>>2];if(c&1024){break a}e=D(b,872)+a|0;h=e+1075012|0;e=e+1075016|0;if(!(x[h>>2]|x[e>>2])){break a}c:{if(!(c&512)){break c}c=x[a+1298300>>2];if(!ud(c)){break c}aj(c,b,0);break a}c=Ly(a,b);if((c|0)==65535){break a}i=D(c,872);c=a+1074992|0;a=i+c|0;Mp(a,j);v[a+831|0]=0;v[a+805|0]=0;w[a+786>>1]=b+1;x[a+88>>2]=x[a+88>>2]&-918529;qo(a+788|0);x[a+696>>2]=0;x[a+88>>2]=x[a+88>>2]|2101248;x[d>>2]=0;x[j>>2]=0;x[j+4>>2]=0;a=c+D(b,872)|0;x[a+92>>2]=0;x[a+96>>2]=0;x[h>>2]=0;x[e>>2]=0;break a}e=D(b,872)+a|0;m=x[e+1075096>>2];c=c>>>0<=h>>>0?c:0;h=x[(c?((c<<2)+a|0)+900380|0:e+1075648|0)>>2];d:{if(!h){break d}k=d-1|0;c=z[_b(h+236|0,k)>>1];f=a+1074312|0;Fb(g+8|0,f,104);e:{if(Ib(x[x[g+8>>2]>>2],x[g+12>>2])){Fb(g,f,34);if(Ib(x[x[g>>2]>>2],x[g+4>>2])){break e}}d=y[Db(h+108|0,k)|0]}if((c-1&65535)>>>0<=3998){m=(D(c,104)+a|0)+484380|0;break d}Fb(g+8|0,f,43);if(!Ib(x[x[g+8>>2]>>2],x[g+12>>2])){break d}if(!ej(y[h+31|0])){break a}}if(y[e+1075081|0]&4){break a}p=b>>>0<=256?256:b;k=a+1074312|0;q=b+1|0;c=b;f:{while(1){if((c|0)==(p|0)){g:{e=0;c=0;if(!Pj(x[j+656>>2])){break f}c=0;if(!Tc(y[(D(b,872)+a|0)+1075789|0])){break f}d=Dl(a,n,b,2,1);c=0;if((d-1&255)>>>0>249){break f}e=x[(D(d,160)+a|0)+906140>>2];if(e){break g}e=0;c=0;break f}}else{f=(b|0)==(c|0);h:{if(!f&z[a+480188>>1]>c>>>0){break h}e=D(c,872)+a|0;if(!f&z[e+1075778>>1]!=(q|0)){break h}o=e+1075648|0;f=x[o>>2];if(!f){break h}l=e+1074992|0;i:{j:{k:{l:{m:{n:{o:{switch(y[f+17|0]-1|0){case 0:if(!d){break h}i=(f|0)==(h|0)&y[e+1075789|0]==(d|0);if(!h){break n}if(i){break k}break h;case 1:if(!m|x[e+1075096>>2]!=(m|0)){break h}if((f|0)==(h|0)){break i}Fb(g+8|0,k,104);if(!Ib(x[x[g+8>>2]>>2],x[g+12>>2])){break i}break h;case 3:break m;case 2:break o;default:break h}}if(h){break l}i=(f|0)==(h|0)}if(i){break i}break h}if(!h){break h}i=y[h+34|0];if(!i){break h}if((i|0)==y[f+34|0]){break j}break h}if((f|0)!=(h|0)){break h}}if(!y[h+34|0]){break i}}i=e+1075789|0;if(!y[i|0]|y[f+18|0]>2){break i}Fb(g+8|0,k,34);f=jQ(l,Ib(x[x[g+8>>2]>>2],x[g+12>>2]));if(!f){break i}fm(a,c&65535,f+255|0,0);v[e+1075792|0]=0;v[i|0]=0}p:{q:{switch(y[x[o>>2]+18|0]){case 0:$n(a,l);x[e+1075680>>2]=0;if(!(y[e+1075081|0]&2)){break p}f=x[a+1298300>>2];if(!ud(f)){break p}aj(f,c&65535,1);break p;case 1:$n(a,l);if(!(y[e+1075081|0]&2)){break p}f=x[a+1298300>>2];if(!ud(f)){break p}Rj(f,c&65535);break p;case 2:break q;default:break p}}l=e+1075080|0;f=x[l>>2];x[l>>2]=f|4096;if(!(f&512)){break p}if(!ud(x[a+1298300>>2])){break p}Fb(g+8|0,k,105);if(Ib(x[x[g+8>>2]>>2],x[g+12>>2])){break p}Rj(x[a+1298300>>2],c&65535)}if(x[e+1075680>>2]){break h}x[e+1075688>>2]=0;e=e+1075080|0;x[e>>2]=x[e>>2]|2101248}c=c+1|0;continue}break}Fb(g+8|0,k,34);d=jQ(j,Ib(x[x[g+8>>2]>>2],x[g+12>>2]));c=0;if(!d){break f}c=ib[x[x[e>>2]+100>>2]](e,d,b)|0}if(!(si(x[j+8>>2],x[j+12>>2])|c)){break a}r:{if(!e|c^1){break r}c=y[(D(b,872)+a|0)+1075790|0];if(c>>>0>3|(c|0)==1){break r}fm(a,b,255,0);v[(D(b,872)+a|0)+1075792|0]=0}c=Ly(a,b);if((c|0)==65535){break a}f=D(c,872);e=f+a|0;d=e+1075080|0;h=e+1074992|0;s:{if(!(y[e+1075081|0]&2)){break s}e=x[a+1298300>>2];if(!ud(e)){break s}aj(e,c,1)}m=Mp(h,j);e=x[d>>2];h=e&-917505;x[d>>2]=h;l=a+1074992|0;f=l+f|0;v[f+831|0]=0;i=z[a+480188>>1];v[f+805|0]=0;w[f+786>>1]=b>>>0<i>>>0?b+1|0:0;t:{u:{switch(y[(l+D(b,872)|0)+798|0]){case 2:$n(a,m);if(!(y[d+1|0]&2)){break t}e=x[a+1298300>>2];if(!ud(e)){break t}Rj(e,b);Fb(g+8|0,k,105);if(!Ib(x[x[g+8>>2]>>2],x[g+12>>2])){break t}vz(x[a+1298300>>2],b,c);break t;case 0:x[(D(c,872)+a|0)+1075688>>2]=0;x[d>>2]=h|4096;if(!(e&512)){break t}e=x[a+1298300>>2];if(!ud(e)){break t}aj(e,b,1);break t;case 3:x[d>>2]=h|4096;if(!(e&512)){break t}if(!ud(x[a+1298300>>2])){break t}Fb(g+8|0,k,105);e=x[a+1298300>>2];if(Ib(x[x[g+8>>2]>>2],x[g+12>>2])){vz(e,b,c);break t}Rj(e,b);break t;case 1:break u;default:break t}}if(!(e&512)){break t}e=x[a+1298300>>2];if(!ud(e)){break t}vz(e,b,c)}c=D(c,872)+a|0;if(!x[c+1075680>>2]){x[c+1075688>>2]=0;x[d>>2]=x[d>>2]|2101248}a=D(b,872)+a|0;x[a+1075068>>2]=0;x[j>>2]=0;x[j+4>>2]=0;a=a+1075084|0;x[a>>2]=0;x[a+4>>2]=0}db=g+16|0}function Ed(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;k=db-96|0;db=k;u=i&65535;o=(e^i)&-2147483648;r=e&65535;A=r;R=i>>>16&32767;S=e>>>16&32767;a:{b:{if(R-32767>>>0>4294934529&S-32767>>>0>=4294934530){break b}s=e&2147483647;q=s;j=d;if(!(!d&(q|0)==2147418112?!(b|c):q>>>0<2147418112)){m=d;o=e|32768;break a}s=i&2147483647;p=s;e=h;if(!(!e&(p|0)==2147418112?!(f|g):p>>>0<2147418112)){m=h;o=i|32768;b=f;c=g;break a}if(!(b|j|(q^2147418112|c))){if(!(e|f|(g|p))){o=2147450880;b=0;c=0;break a}o=o|2147418112;b=0;c=0;break a}if(!(e|f|(p^2147418112|g))){e=b|j;d=c|q;b=0;c=0;if(!(d|e)){o=2147450880;break a}o=o|2147418112;break a}if(!(b|j|(c|q))){b=0;c=0;break a}if(!(e|f|(g|p))){b=0;c=0;break a}if((q|0)==65535|q>>>0<65535){j=!(d|r);i=j?b:d;s=j<<6;e=G(i)+32|0;i=G(j?c:r);i=s+((i|0)==32?e:i)|0;zf(k+80|0,b,c,d,r,i-15|0);t=16-i|0;d=x[k+88>>2];A=x[k+92>>2];c=x[k+84>>2];b=x[k+80>>2]}if(p>>>0>65535){break b}i=!(h|u);e=i?f:h;r=i<<6;j=G(e)+32|0;e=G(i?g:u);e=r+((e|0)==32?j:e)|0;zf(k- -64|0,f,g,h,u,e-15|0);t=(t-e|0)+16|0;h=x[k+72>>2];u=x[k+76>>2];f=x[k+64>>2];g=x[k+68>>2]}e=f;f=g<<15|f>>>17;i=e<<15;e=0;v=i&-32768;L=c;s=yka(v,e,c,0);e=hb;z=e;M=f;q=b;b=yka(f,0,b,0);i=b+s|0;f=hb+e|0;c=b>>>0>i>>>0?f+1|0:f;j=0;b=yka(q,l,v,l);p=j+b|0;f=i;e=f+hb|0;e=b>>>0>p>>>0?e+1|0:e;r=e;N=(f|0)==(e|0)&j>>>0>p>>>0|e>>>0<f>>>0;O=d;w=yka(v,l,d,0);P=hb;b=yka(L,l,M,l);y=b+w|0;j=hb+P|0;j=b>>>0>y>>>0?j+1|0:j;b=u<<15|h>>>17;B=h<<15|g>>>17;d=yka(B,0,q,l);C=d+y|0;f=hb+j|0;f=d>>>0>C>>>0?f+1|0:f;D=f;d=(c|0)==(z|0)&i>>>0<s>>>0|c>>>0<z>>>0;E=c+C|0;f=d+f|0;f=c>>>0>E>>>0?f+1|0:f;u=f;g=E;c=f;F=A|65536;A=yka(v,l,F,n);Q=hb;d=yka(O,m,M,l);H=d+A|0;e=hb+Q|0;e=d>>>0>H>>>0?e+1|0:e;i=e;I=b|-2147483648;b=yka(I,0,q,l);J=b+H|0;f=hb+e|0;f=b>>>0>J>>>0?f+1|0:f;b=yka(B,m,L,l);z=b+J|0;K=f;f=f+hb|0;s=b>>>0>z>>>0?f+1|0:f;b=0;q=b+g|0;e=c+z|0;v=b>>>0>q>>>0?e+1|0:e;f=v;b=q+N|0;c=b>>>0<q>>>0?f+1|0:f;t=((S+R|0)+t|0)-16383|0;d=yka(I,m,L,l);h=hb;e=yka(F,m,M,l);g=e+d|0;f=hb+h|0;f=e>>>0>g>>>0?f+1|0:f;n=(h|0)==(f|0)&d>>>0>g>>>0|f>>>0<h>>>0;h=f;e=yka(B,m,O,m);d=e+g|0;f=hb+f|0;f=d>>>0<e>>>0?f+1|0:f;e=f;g=(f|0)==(h|0)&d>>>0<g>>>0|f>>>0<h>>>0;f=0;h=g;g=g+n|0;f=h>>>0>g>>>0?1:f;h=g;g=yka(I,m,F,m);h=h+g|0;f=hb+f|0;N=h;g=g>>>0>h>>>0?f+1|0:f;h=d;l=e;e=(j|0)==(P|0)&w>>>0>y>>>0|j>>>0<P>>>0;f=0;j=(j|0)==(D|0)&y>>>0>C>>>0|j>>>0>D>>>0;n=j;j=e+j|0;e=(n>>>0>j>>>0?1:f)+l|0;f=g;d=d+j|0;e=d>>>0<j>>>0?e+1|0:e;n=e;w=d;d=(e|0)==(l|0)&d>>>0<h>>>0|e>>>0<l>>>0;e=d;d=d+N|0;f=e>>>0>d>>>0?f+1|0:f;j=d;g=f;e=yka(B,m,F,m);l=hb;d=yka(I,m,O,m);h=d+e|0;f=hb+l|0;f=d>>>0>h>>>0?f+1|0:f;d=f;f=(l|0)==(f|0)&e>>>0>h>>>0|f>>>0<l>>>0;y=d+j|0;e=f+g|0;e=d>>>0>y>>>0?e+1|0:e;l=y;g=e;e=0;d=e+w|0;f=h+n|0;f=d>>>0<e>>>0?f+1|0:f;e=f;h=(n|0)==(f|0)&d>>>0<w>>>0|f>>>0<n>>>0;f=g;g=h+l|0;f=g>>>0<h>>>0?f+1|0:f;w=g;g=f;h=d;j=e;e=(s|0)==(K|0)&z>>>0<J>>>0|s>>>0<K>>>0;d=(i|0)==(Q|0)&A>>>0>H>>>0|i>>>0<Q>>>0;i=(i|0)==(K|0)&H>>>0>J>>>0|i>>>0>K>>>0;d=d+i|0;d=d+e|0;n=s;i=n+h|0;e=d+j|0;f=g;d=i;e=d>>>0<n>>>0?e+1|0:e;h=(e|0)==(j|0)&h>>>0>d>>>0|e>>>0<j>>>0;g=h+w|0;f=h>>>0>g>>>0?f+1|0:f;j=g;g=f;h=d;f=0;i=e;n=(u|0)==(v|0)&q>>>0<E>>>0|u>>>0>v>>>0;l=n;n=n+((u|0)==(D|0)&C>>>0>E>>>0|u>>>0<D>>>0)|0;e=e+(l>>>0>n>>>0?1:f)|0;f=g;d=d+n|0;e=d>>>0<n>>>0?e+1|0:e;h=(e|0)==(i|0)&d>>>0<h>>>0|e>>>0<i>>>0;g=h;h=h+j|0;f=g>>>0>h>>>0?f+1|0:f;i=f;c:{if(f&65536){t=t+1|0;break c}j=r>>>31|0;g=0;f=i<<1|h>>>31;h=h<<1|e>>>31;i=f;f=e<<1|d>>>31;d=d<<1|c>>>31;e=f;f=r<<1|p>>>31;p=p<<1;r=f;f=c<<1|b>>>31;b=b<<1|j;c=f|g}if((t|0)>=32767){o=o|2147418112;b=0;c=0;break a}d:{if((t|0)<=0){g=1-t|0;if(g>>>0<=127){f=t+127|0;zf(k+48|0,p,r,b,c,f);zf(k+32|0,d,e,h,i,f);em(k+16|0,p,r,b,c,g);em(k,d,e,h,i,g);p=x[k+32>>2]|x[k+16>>2]|(x[k+48>>2]|x[k+56>>2]|(x[k+52>>2]|x[k+60>>2]))!=0;r=x[k+36>>2]|x[k+20>>2];b=x[k+40>>2]|x[k+24>>2];c=x[k+44>>2]|x[k+28>>2];d=x[k>>2];e=x[k+4>>2];g=x[k+8>>2];f=x[k+12>>2];break d}b=0;c=0;break a}g=h;f=i&65535|t<<16}m=g|m;o=f|o;if(!(!b&(c|0)==-2147483648?!(p|r):(c|0)>0|(c|0)>=0)){b=d+1|0;j=b?e:e+1|0;e=o;c=j;d=!(j|b);m=d+m|0;o=d>>>0>m>>>0?e+1|0:e;break a}if(b|p|(c^-2147483648|r)){b=d;c=e;break a}f=e;b=d&1;c=b;b=b+d|0;f=c>>>0>b>>>0?f+1|0:f;c=f;d=(e|0)==(f|0)&b>>>0<d>>>0|e>>>0>f>>>0;f=o;m=d+m|0;o=m>>>0<d>>>0?f+1|0:f}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=m;x[a+12>>2]=o;db=k+96|0}function fga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=db-128|0;db=g;wc(b);a:{b:{c:{d:{e:{if(!jS(b,13856)){break e}k=Nb(g+116|0);j=Nb(g+104|0);x[23549]=0;x[g+96>>2]=0;x[g+100>>2]=0;P(235,a|0,32768);d=x[23549];x[23549]=0;if((d|0)==1){break b}x[23549]=0;d=O(1,g+84|0,8067)|0;i=x[23549];x[23549]=0;if((i|0)==1){break c}zb(a+1298344|0,d);tb(d);x[23549]=0;d=O(1,g+72|0,6001)|0;i=x[23549];x[23549]=0;if((i|0)==1){break d}zb(a+1298356|0,d);tb(d);x[a+1298404>>2]=13;i=a+480280|0;while(1){d=x[b+8>>2];f=x[b>>2];x[23549]=0;d=U(142,f|0,d|0,8)|0;f=x[23549];x[23549]=0;f:{g:{h:{if((f|0)!=1){i:{j:{k:{l:{m:{n:{if(!d){break n}x[23549]=0;d=O(590,b|0,g- -64|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break m}if(!d){break n}d=x[g+68>>2];x[23549]=0;S(176,g+24|0,b|0,$b(d)|0);d=x[23549];x[23549]=0;if((d|0)==1){break l}d=g+24|0;f=hc(g+44|0,d);ub(d);d=x[f>>2];x[23549]=0;d=R(164,d|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break j}if(d){break k}ub(f)}if(z[a+480188>>1]){break i}i=0;break g}a=N()|0;break a}a=N()|0;break a}o:{p:{q:{r:{s:{t:{u:{d=$b(x[g+64>>2]);if((d|0)!=1397769541){if((d|0)==1346458708){break t}if((d|0)==1346522948){break s}if((d|0)==1347175758){break u}if((d|0)!=1396788560){if((d|0)==1396854596){break r}if((d|0)==1397507406){break f}if((d|0)!=1129140036){break p}if(z[a+480188>>1]){break f}d=x[f>>2];x[23549]=0;d=R(146,d|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break j}if(d>>>0<8){break f}d=0;x[23549]=0;P(591,g+24|0,f|0);e=x[23549];x[23549]=0;if((e|0)==1){break j}while(1)if((d|0)==4){if(c){break f}i=1;break o}else{h=_b(g+24|0,d);e=z[a+480188>>1];v:{if(!Hb(y[h|0]|y[h+1|0]<<8)){h=(d&3)-1|0;break v}h=g+96|0;n=Db(h,e),o=1,v[n|0]=o;n=Db(h,z[a+480188>>1]+1|0),o=255,v[n|0]=o;Te(i+(z[a+480188>>1]<<5)|0);h=z[a+480188>>1];e=h+1|0;w[a+480188>>1]=e;l=i+(h<<5)|0;h=(d&3)-1|0;w[l+4>>1]=h>>>0<2?192:64}Te(i+((e&65535)<<5)|0);e=z[a+480188>>1];w[a+480188>>1]=e+1;w[(i+(e<<5)|0)+4>>1]=h>>>0<2?192:64;d=d+1|0;continue}}if(z[a+480190>>1]){break f}x[23549]=0;P(592,f|0,a|0);d=x[23549];x[23549]=0;if((d|0)!=1){break f}break j}d=x[f>>2];x[23549]=0;d=R(146,d|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break j}if(d>>>0<2){break f}x[23549]=0;d=R(260,f|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break j}n=a,o=Vd(d,1,255),x[n+480196>>2]=o;break f}d=x[f>>2];x[23549]=0;d=R(146,d|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break j}if(d>>>0<2){break f}x[23549]=0;m=R(260,f|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){break f}break j}d=y[a+484376|0];e=x[a+484360>>2];h=x[f>>2];x[23549]=0;h=R(146,h|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break j}x[23549]=0;aa(332,Wb(e,d)|0,f|0,h|0,255,254);d=x[23549];x[23549]=0;if((d|0)==1){break j}break f}d=k;if(Ef(x[d>>2],x[d+4>>2])>>>0>=256){break f}break q}if(Ef(x[j>>2],x[j+4>>2])>>>0>3998){break f}d=x[f>>2];x[23549]=0;e=R(146,d|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break j}d=j;if(!e){break f}}x[23549]=0;P(593,d|0,f|0);d=x[23549];x[23549]=0;if((d|0)!=1){break f}break j}if(!(d&-2139062144)){break f}i=0}ub(f);break g}a=N()|0;ub(f);break a}x[a+480200>>2]=256;x[a+480204>>2]=125e4;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480228>>2]=48;x[a+480232>>2]=48;b=x[a+484360>>2];d=y[a+484376|0];x[23549]=0;P(315,Wb(b,d)|0,m&65535);b=x[23549];x[23549]=0;if((b|0)==1){break b}w:{if(!(c&1)){break w}b=x[k+4>>2];i=x[k>>2];d=0;x[23549]=0;P(211,a+484344|0,Ef(i,b)&65535);b=x[23549];x[23549]=0;if((b|0)==1){break b}while(1){e=x[k>>2];b=d&65535;if(Ef(e,x[k+4>>2])>>>0<=b>>>0){break w}x[23549]=0;i=x[g+100>>2];f=x[g+96>>2];x[g+16>>2]=f;x[g+20>>2]=i;x[g+8>>2]=f;x[g+12>>2]=i;V(594,Cg(e,b)|0,b|0,a|0,g+8|0);b=x[23549];x[23549]=0;if((b|0)!=1){d=d+1|0;continue}break}a=N()|0;break a}f=c&2;i=1;d=1;b=0;while(1){if(z[a+480190>>1]<=d>>>0){break g}if(!f|Ef(x[j>>2],x[j+4>>2])>>>0<=b>>>0){break g}c=(D(d,104)+a|0)+484380|0;Po(c);x:{if(x[c>>2]){e=x[Cg(x[j>>2],b)>>2];x[23549]=0;e=R(146,e|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break h}tc(c,e);e=Xc(g+44|0,8,1,1,0);h=x[j>>2];x[23549]=0;U(205,e|0,c|0,Cg(h,b)|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break x}b=b+1|0}d=d+1|0;continue}break}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}kd(j);kd(k);break e}ub(f);continue}}db=g+128|0;return i|0}a=N()|0;break a}a=N()|0;break a}a=N()|0}kd(j);kd(k);Q(a|0);p()}function T9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,q=0;d=db-112|0;db=d;g=-1;a:{b:{c:{d:{if(x[(x[x[b>>2]-12>>2]+b|0)+16>>2]){break d}ae(d+96|0,b);e=x[d+104>>2];f=x[d+108>>2];k=d+88|0;El(k);b=Lk(b,k,8);if((y[d+88|0]|y[d+89|0]<<8|(y[d+90|0]<<16|y[d+91|0]<<24))!=1414681667|(y[d+92|0]|y[d+93|0]<<8|(y[d+94|0]<<16|y[d+95|0]<<24))!=776101705){a=gh(d+72|0,e,f);c=x[a+12>>2];x[d+8>>2]=x[a+8>>2];x[d+12>>2]=c;c=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=c;Gj(b,d);break d}w[d+70>>1]=0;Mf(b,d+70|0);k=w[d+70>>1];if((k-4&65535)>>>0<65534){break d}e=d+62|0;El(e);e=Lk(b,e,8);if((y[d+62|0]|y[d+63|0]<<8|(y[d+64|0]<<16|y[d+65|0]<<24))!=1933333571|(y[d+66|0]|y[d+67|0]<<8|(y[d+68|0]<<16|y[d+69|0]<<24))!=1111389030){break d}w[d+60>>1]=0;Mf(e,d+60|0);f=w[d+60>>1];if((f-5&65535)>>>0<65534){break d}e:{f:{g:{h:{i:{j:{if(f>>>0<=3){b=Gb(d+96|0);x[23549]=0;h=U(437,e|0,b|0,65535)|0;l=x[23549];x[23549]=0;if((l|0)==1){break b}if(!h){break i}x[23549]=0;S(11,d+48|0,c|0,b|0);h=x[23549];x[23549]=0;if((h|0)!=1){break j}break b}b=Gb(d+96|0);x[23549]=0;h=O(439,e|0,b|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break c}if(!h){break h}x[23549]=0;S(11,d+48|0,c|0,b|0);h=x[23549];x[23549]=0;if((h|0)==1){break c}}h=d+48|0;zb(a+40|0,h);tb(h);tb(b);w[d+46>>1]=0;Mf(e,d+46|0);w[d+44>>1]=0;Mf(e,d+44|0);w[a>>1]=z[d+44>>1];w[d+42>>1]=0;k:{if((f|0)<=3){x[d+96>>2]=0;ak(e,d+96|0);b=x[d+96>>2];if(b>>>0>65535){break d}b=xu(b);w[d+42>>1]=b;break k}Mf(e,d+42|0);b=z[d+42>>1]}h=a+52|0;l=b&65535;n=(f|0)>3;b=0;l:{m:{while(1){if(l>>>0<=(b&65535)>>>0){break l}f=Gb(d+96|0);x[23549]=0;w[d+24>>1]=0;P(871,e|0,d+24|0);i=x[23549];x[23549]=0;if((i|0)==1){break g}n:{if(!n){x[23549]=0;i=U(437,e|0,f|0,65535)|0;j=x[23549];x[23549]=0;if((j|0)==1){break g}if(i){break n}break e}x[23549]=0;i=O(439,e|0,f|0)|0;j=x[23549];x[23549]=0;if((j|0)==1){break g}if(!i){break e}}x[23549]=0;S(11,d+48|0,c|0,f|0);i=x[23549];x[23549]=0;if((i|0)!=1){x[23549]=0;i=O(868,h|0,d+24|0)|0;j=x[23549];x[23549]=0;if((j|0)==1){break m}j=i;i=d+48|0;zb(j,i);tb(i);tb(f);b=b+1|0;continue}break}g=N()|0;break f}g=N()|0;tb(d+48|0);break f}b=d+48|0;El(b);b=Lk(e,b,8);if((y[d+48|0]|y[d+49|0]<<8|(y[d+50|0]<<16|y[d+51|0]<<24))!=1933333571|(y[d+52|0]|y[d+53|0]<<8|(y[d+54|0]<<16|y[d+55|0]<<24))!=1161720678){break d}c=z[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;o:{if((k|0)<=2){if(WL(b,c)){break o}break d}if(!VL(b,c)){break d}}o=d,q=yb(x[a+4>>2]),x[o+96>>2]=q;c=yb(x[a+8>>2]);while(1){e=x[d+96>>2];if(Kb(e,c)){if(!bm(B[e>>2])){break d}Ae(d+96|0);continue}break}c=a+16|0;p:{if((k|0)<=2){if(WL(b,c)){break p}break d}if(!VL(b,c)){break d}}o=d,q=yb(x[a+16>>2]),x[o+96>>2]=q;c=yb(x[a+20>>2]);while(1){e=x[d+96>>2];if(Kb(e,c)){if(!bm(B[e>>2])){break d}Ae(d+96|0);continue}break}o=a,q=oc(x[a+16>>2],x[a+20>>2]),x[o+36>>2]=q;w[d+40>>1]=0;Mf(b,d+40|0);c=z[d+40>>1];w[a+28>>1]=c;if((c-201&65535)>>>0<65135){break d}w[d+38>>1]=0;Mf(b,d+38|0);c=w[d+38>>1];w[a+30>>1]=c;if((c|0)<0){break d}x[d+32>>2]=0;Bp(b,d+32|0);m=YL(B[d+32>>2]);B[a+32>>2]=m;if(!bm(m)){break d}c=d+24|0;El(c);Lk(b,c,8);if((y[d+24|0]|y[d+25|0]<<8|(y[d+26|0]<<16|y[d+27|0]<<24))!=1414681667|(y[d+28|0]|y[d+29|0]<<8|(y[d+30|0]<<16|y[d+31|0]<<24))!=776298313){break d}b=oc(x[a+4>>2],x[a+8>>2]);if(b>>>0>32767){break d}c=w[a+30>>1];e=z[a>>1];if(!(e?!(B[a+32>>2]<=E(0))&(c|0)>0:1)){break d}q:{switch(e-1|0){case 0:case 2:if(b>>>0<c>>>0){break d}break;default:break q}}b=0;c=x[a+36>>2];if(c){b=c-1|0;x[a+36>>2]=b}o=d,q=Hh(b),x[o+96>>2]=q;x[d+20>>2]=0;o=a,q=x[sj(d+96|0,d+20|0,44048)>>2],x[o+36>>2]=q;Cp(a);g=1;if(z[a>>1]!=3){break d}c=w[a+30>>1];if((c-w[a+28>>1]|0)>(dM(oc(x[a+4>>2],x[a+8>>2]))|0)){break d}g=a+32|0;e=Nb(d+96|0);b=0;while(1){r:{if(c<<16>>16<=(b|0)){b=z[a+28>>1];w[d+20>>1]=b;o=d,q=(oc(x[a+4>>2],x[a+8>>2])+b|0)-1|0,w[o+22>>1]=q;x[23549]=0;w[d+18>>1]=0;fa(866,a|0,e|0,g|0,d+20|0,d+18|0)|0;a=x[23549];x[23549]=0;g=1;if((a|0)==1){break r}sc(e);break d}c=w[a+28>>1];f=x[a+4>>2];x[23549]=0;P(872,e|0,xb(f,b-c|0)|0);c=x[23549];x[23549]=0;if((c|0)!=1){b=b+1|0;c=z[a+30>>1];continue}}break}g=N()|0;sc(e);break a}tb(b);break d}tb(b);break d}g=N()|0}tb(f);break a}tb(f)}db=d+112|0;return g|0}g=N()|0;tb(b);break a}g=N()|0;tb(b)}Q(g|0);p()}function HW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=db-80|0;db=e;wc(b);a:{if(!Oq(b,11632)){break a}if(!Tu(b,e+69|0)){break a}if(!qC(y[e+70|0])){break a}if(!Lb(x[b>>2],x[b+8>>2],Qc(pC(e+69|0),hb))){break a}if(!Zb(b,y[e+78|0]|y[e+79|0]<<8)){break a}b:{if(!c){break b}Bd(a,4096);x[a+480208>>2]=12;w[a+480188>>1]=(y[e+71|0]&31)+1;w[a+480190>>1]=y[e+72|0];vh(a,1);d=e+20|0;i=Tb(d,8374);zb(a+1298344|0,i);tb(i);i=Tb(d,6991);zb(a+1298356|0,i);tb(i);i=db-16|0;db=i;f=Tb(i+4|0,4188);ad(e,f);tb(f);db=i+16|0;x[23549]=0;V(218,d|0,e|0,y[e+70|0],e+69|0);d=x[23549];x[23549]=0;c:{if((d|0)!=1){d=e+20|0;zb(a+1298368|0,d);tb(d);Ab(e);x[a+1298404>>2]=5;d=y[e+72|0];i=e+56|0;x[i>>2]=0;x[i+4>>2]=0;Xj(i+8|0,0);if(d){Wq(i,d);eD(i,d,0)}d=1;d:{while(1){f=d&65535;if(f>>>0>z[a+480190>>1]){x[23549]=0;O(219,b|0,a+1298308|0)|0;f=x[23549];x[23549]=0;d=1;e:{if((f|0)==1){break e}while(1){f=d&65535;if(f>>>0>z[a+480190>>1]){d=0;f:{while(1){if(z[a+480188>>1]<=d>>>0){d=0;x[23549]=0;f=a+484344|0;P(211,f|0,y[e+73|0]|y[e+74|0]<<8);g=x[23549];x[23549]=0;if((g|0)==1){break e}break f}f=(d<<5)+a|0;Te(f+480280|0);x[23549]=0;P(220,b|0,f+480289|0);f=x[23549];x[23549]=0;if((f|0)!=1){d=d+1|0;continue}break}b=N()|0;break d}g:{h:{i:{j:{while(1){if((y[e+73|0]|y[e+74|0]<<8)>>>0<=d>>>0){x[23549]=0;g=R(180,b|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break h}if(!g){break i}d=x[b+8>>2];f=x[b>>2];x[23549]=0;d=U(142,f|0,d|0,g|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break h}if(d){break j}break i}x[23549]=0;g=O(221,b|0,e+20|0)|0;h=x[23549];x[23549]=0;k:{if((h|0)==1){break k}x[23549]=0;h=U(212,f|0,d&65535,64)|0;j=x[23549];x[23549]=0;if((j|0)==1){break k}if((g&h)==1){g=x[f>>2];x[23549]=0;P(222,Yb(g,d)|0,e+20|0);g=x[23549];x[23549]=0;if((g|0)==1){break k}}d=d+1|0;continue}break}b=N()|0;break d}f=Nb(e+20|0);x[23549]=0;S(223,b|0,f|0,g|0);d=x[23549];x[23549]=0;l:{if((d|0)!=1){d=Gb(e);x[23549]=0;P(45,d|0,g|0);g=x[23549];x[23549]=0;m:{if((g|0)==1){break m}l=e,m=yb(x[f>>2]),x[l+40>>2]=m;h=yb(x[f+4>>2]);while(1){n:{g=x[e+40>>2];if(!Kb(g,h)){x[23549]=0;V(224,e+40|0,5,6,d|0);g=x[23549];x[23549]=0;if((g|0)==1){break n}h=e+40|0;g=zb(d,h);tb(h);h=Mb(g);j=y[g+11|0];k=x[g+4>>2];x[23549]=0;aa(225,a+1298332|0,h|0,Oc(k,j)|0,76,0);h=x[23549];x[23549]=0;if((h|0)==1){break m}tb(g);bc(f);break i}o:{g=v[g|0];if((g|0)<0){j=x[vb(e+52|0,tf(d))>>2];x[23549]=0;V(226,d|0,j|0,g&127,32);g=x[23549];x[23549]=0;if((g|0)!=1){break o}break m}x[23549]=0;P(46,d|0,g|0);g=x[23549];x[23549]=0;if((g|0)!=1){break o}break m}Oe(e+40|0);continue}break}}b=N()|0;tb(d);break l}b=N()|0}bc(f);break d}d=y[a+484376|0];f=x[a+484360>>2];x[23549]=0;S(227,Wb(f,d)|0,b|0,y[e+75|0]|y[e+76|0]<<8);d=x[23549];x[23549]=0;if((d|0)==1){break h}g=c&1;d=0;while(1){p:{q:{if((y[e+73|0]|y[e+74|0]<<8)>>>0>d>>>0){f=x[b+8>>2];h=x[b>>2];x[23549]=0;f=U(142,h|0,f|0,4)|0;h=x[23549];x[23549]=0;if((h|0)==1){break p}if(f){break q}}if(!(c&2)){break g}d=1;while(1){c=d&65535;if(c>>>0>z[a+480190>>1]){break g}f=D(c,104)+a|0;g=z[f+484414>>1];Fb(e+20|0,x[i>>2],c-1|0);c=Xc(e,g&1?16:8,1,0,Ib(x[x[e+20>>2]>>2],x[e+24>>2])?6:0);x[23549]=0;U(205,c|0,f+484380|0,b|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){d=d+1|0;continue}break}b=N()|0;break d}x[23549]=0;f=R(143,b|0)|0;h=x[23549];x[23549]=0;r:{s:{if((h|0)!=1){x[23549]=0;S(176,e|0,b|0,f|0);f=x[23549];x[23549]=0;if((f|0)==1){break s}f=hc(e+20|0,e);ub(e);if(!g){break r}h=x[a+484344>>2];if(!se(h,x[a+484348>>2],d&65535)){break r}x[23549]=0;S(228,Yb(h,d)|0,0,f|0);h=x[23549];x[23549]=0;if((h|0)!=1){break r}b=N()|0;ub(f);break d}b=N()|0;break d}b=N()|0;break d}ub(f);d=d+1|0;continue}break}b=N()|0;break d}b=N()|0;break d}He(i);break b}x[23549]=0;O(229,b|0,((f<<5)+a|0)+946304|0)|0;f=x[23549];x[23549]=0;if((f|0)!=1){d=d+1|0;continue}break}b=N()|0;break d}b=N()|0;break d}x[23549]=0;P(230,b|0,e+20|0);g=x[23549];x[23549]=0;t:{if((g|0)==1){break t}x[23549]=0;P(231,e+20|0,(D(f,104)+a|0)+484380|0);g=x[23549];x[23549]=0;if((g|0)==1){break t}g=y[e+36|0];Fb(e,x[i>>2],f-1|0);Dh(e,(g&3)!=0);d=d+1|0;continue}break}b=N()|0}He(i);break c}b=N()|0;Ab(e)}Q(b|0);p()}d=1}db=e+80|0;return d|0}function Nja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;d=db-320|0;db=d;wc(b);a:{if(!Bo(b,d+308|0)){break a}if(!iV(d+308|0)){break a}if((y[d+308|0]|y[d+309|0]<<8|(y[d+310|0]<<16|y[d+311|0]<<24))==1179472708){Zb(b,4)}if(!$h(b,d+300|0)|(y[d+300|0]|y[d+301|0]<<8|(y[d+302|0]<<16|y[d+303|0]<<24))!=1196314451){break a}if(!c){n=1;break a}_B(b,d+108|0,y[d+304|0]|y[d+305|0]<<8|(y[d+306|0]<<16|y[d+307|0]<<24));if((y[d+144|0]|y[d+145|0]<<8)>>>0>128|(y[d+150|0]|y[d+151|0]<<8)>>>0>16|((y[d+148|0]|y[d+149|0]<<8)>>>0>256|(y[d+142|0]|y[d+143|0]<<8)>>>0>128)){break a}Bd(a,8192);g=d+24|0;e=Tb(g,6480);zb(a+1298344|0,e);tb(e);e=Tb(g,10024);zb(a+1298356|0,e);tb(e);x[a+1298404>>2]=5;e=d+88|0;tl(e,2,d+108|0);Bc(g,e);zb(a+1298308|0,g);tb(g);w[d+24>>1]=y[d+150|0]|y[d+151|0]<<8;w[d+88>>1]=1;f=z[Ve(g,e)>>1];w[a+480188>>1]=f;x[a+480196>>2]=y[d+154|0];x[a+480204>>2]=D(y[d+155|0],1e4);v[d+24|0]=y[d+152|0];v[d+88|0]=64;e=y[Sb(g,e)|0];x[a+480200>>2]=e<<2;if(!e){x[a+480200>>2]=256}e=y[d+153|0];b:{if((e|0)==128){x[d+24>>2]=256/(f>>>0);x[d+88>>2]=128;e=x[Cb(d+24|0,d+88|0)>>2];break b}e=e&127}x[a+480228>>2]=e;while(1){if((h|0)==16){l=Wb(x[a+484360>>2],y[a+484376|0]);f=d+172|0;k=db-16|0;db=k;x[k+12>>2]=y[d+144|0]|y[d+145|0]<<8;e=k+12|0;tc(e,128);tc(e,65535);e=z[k+12>>1];Sf(l,e);h=0;while(1){if((e|0)==(h|0)){db=k+16|0}else{g=y[f+h|0];r=nk(x[l>>2],x[l+4>>2],h),s=(g|0)==255?-1:(g|0)==254?-2:g,w[r>>1]=s;h=h+1|0;continue}break}e=y[d+142|0]|y[d+143|0]<<8;if(e>>>0<(y[d+144|0]|y[d+145|0]<<8)>>>0){$e(Wb(x[a+484360>>2],y[a+484376|0]),e)}h=c&2;o=a+484344|0;n=1;k=c&1;l=d+60|0;while(1){if(!$h(b,d+300|0)){break a}c=d+24|0;Wd(c,b,y[d+304|0]|y[d+305|0]<<8|(y[d+306|0]<<16|y[d+307|0]<<24));j=hc(d+88|0,c);ub(c);c:{d:{if(!(!k|(y[d+300|0]|y[d+301|0]<<8|(y[d+302|0]<<16|y[d+303|0]<<24))!=1414807888)){x[23549]=0;g=q&65535;e=U(212,o|0,g|0,64)|0;c=x[23549];x[23549]=0;if((c|0)==1){break d}if(!e){break c}x[23549]=0;O(174,j|0,2)|0;c=x[23549];x[23549]=0;if((c|0)==1){break d}Uh(d+24|0);m=0;e:{while(1){c=x[j>>2];x[23549]=0;e=U(142,c|0,x[d+96>>2],1)|0;c=x[23549];x[23549]=0;f:{if((c|0)!=1){if(!(e&m>>>0<64)){break e}x[23549]=0;e=R(192,j|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break d}f=e<<24>>24;if(f){break f}m=m+1|0;continue}break d}c=d+24|0;e=f&15;if(e>>>0<z[a+480188>>1]){c=Yb(x[o>>2],g);c=$c(x[c>>2],x[x[c+48>>2]+12>>2],m,e)}g:{if((f|0)>=0){break g}x[23549]=0;i=R(192,j|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break d}if(!i){break g}v[c|0]=i>>>0<109?i+12|0:i}i=f&255;if(i&64){x[23549]=0;f=R(192,j|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break d}v[c+1|0]=f}if(i&32){v[c+2|0]=1;x[23549]=0;f=R(192,j|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break d}v[d+12|0]=f;v[d|0]=64;r=c,s=y[Sb(d+12|0,d)|0],v[r+4|0]=s}if(!(i&16)){continue}x[23549]=0;P(249,d+12|0,j|0);e=x[23549];x[23549]=0;if((e|0)!=1){f=fd(d+12|0);h:{i:{j:{k:{l:{e=y[d+12|0];switch(e-17|0){case 2:break k;case 0:case 1:break l;default:break j}}e=e&15;break i}v[d+12|0]=33;v[f|0]=145;e=y[d+12|0];break h}if(e>>>0<17){break h}e=(e&240)==32?9:-1}v[d+12|0]=e}v[c+3|0]=e;v[c+5|0]=y[f|0];Qf(c);continue}break}break d}q=q+1|0;break c}if((y[d+300|0]|y[d+301|0]<<8|(y[d+302|0]<<16|y[d+303|0]<<24))!=1414745673){break c}c=z[a+480190>>1];if(!Th(c)){break c}e=c+1|0;w[a+480190>>1]=e;x[23549]=0;P(309,j|0,d+24|0);c=x[23549];x[23549]=0;m:{if((c|0)==1){break m}x[23549]=0;f=(D(e&65535,104)+a|0)+484380|0;P(310,d+24|0,f|0);c=x[23549];x[23549]=0;if((c|0)==1){break m}tl(d,2,l);x[23549]=0;P(208,d+12|0,d|0);c=x[23549];x[23549]=0;if((c|0)==1){break m}c=d+12|0;zc(((z[a+480190>>1]<<5)+a|0)+946304|0,c);tb(c);if(!h){break c}i=y[d+37|0]|y[d+38|0]<<8;e=2;c=d+12|0;g=Xc(c,8,1,0,1);n:{if(!(i&64)){e=0;if(!(i&2)){break n}}Uf(g,e)}if(i&4){hd(g,16)}x[23549]=0;U(205,c|0,f|0,j|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break c}}}a=N()|0;ub(j);Q(a|0);p()}ub(j);continue}}f=(h<<5)+a|0;Te(f+480280|0);e=y[(d+h|0)+156|0];if(e>>>0<=128){w[f+480284>>1]=e<<1}h=h+1|0;continue}}db=d+320|0;return n|0}function Z9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0;e=db-288|0;db=e;d=-1;a:{b:{c:{if(!Pk(x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){b=Pl(e+184|0,b);x[23549]=0;d=O(403,e+172|0,13710)|0;f=x[23549];x[23549]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)!=1){x[23549]=0;x[e+152>>2]=83886084;x[e+156>>2]=0;S(404,b|0,d|0,e+152|0);f=x[23549];x[23549]=0;if((f|0)==1){break A}Ab(d);v[e+171|0]=0;x[23549]=0;d=O(403,e+152|0,14403)|0;f=x[23549];x[23549]=0;if((f|0)==1){break z}x[23549]=0;S(405,b|0,e+171|0,d|0);f=x[23549];x[23549]=0;if((f|0)==1){break y}Ab(d);x[23549]=0;f=y[e+171|0];d=O(403,e+140|0,15422)|0;g=x[23549];x[23549]=0;if((g|0)==1){break x}x[23549]=0;f=f?0:c;V(860,b|0,a+40|0,d|0,f|0);c=x[23549];x[23549]=0;if((c|0)==1){break w}Ab(d);w[e+138>>1]=65535;x[23549]=0;c=O(403,e+124|0,15044)|0;d=x[23549];x[23549]=0;if((d|0)==1){break v}x[23549]=0;U(433,b|0,e+138|0,c|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break u}Ab(c);w[e+122>>1]=0;x[23549]=0;c=O(403,e+108|0,14939)|0;d=x[23549];x[23549]=0;if((d|0)==1){break t}x[23549]=0;U(433,b|0,e+122|0,c|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break s}Ab(c);w[a>>1]=z[e+122>>1];x[23549]=0;c=O(403,e+96|0,14704)|0;d=x[23549];x[23549]=0;if((d|0)==1){break r}x[23549]=0;V(861,b|0,a+52|0,c|0,f|0);d=x[23549];x[23549]=0;if((d|0)==1){break q}Ab(c);x[23549]=0;c=O(403,e+84|0,14652)|0;d=x[23549];x[23549]=0;if((d|0)==1){break p}x[23549]=0;S(850,b|0,a+36|0,c|0);d=x[23549];x[23549]=0;if((d|0)==1){break o}Ab(c);x[23549]=0;c=O(403,e+72|0,15046)|0;d=x[23549];x[23549]=0;if((d|0)==1){break n}x[23549]=0;h=a+4|0;S(862,b|0,h|0,c|0);d=x[23549];x[23549]=0;if((d|0)==1){break m}Ab(c);x[23549]=0;c=O(403,e+60|0,14941)|0;d=x[23549];x[23549]=0;if((d|0)==1){break l}x[23549]=0;f=a+28|0;S(863,b|0,f|0,c|0);d=x[23549];x[23549]=0;if((d|0)==1){break k}Ab(c);x[23549]=0;c=O(403,e+48|0,14818)|0;d=x[23549];x[23549]=0;if((d|0)==1){break j}x[23549]=0;S(863,b|0,a+30|0,c|0);d=x[23549];x[23549]=0;if((d|0)==1){break i}Ab(c);x[23549]=0;c=O(403,e+36|0,14676)|0;d=x[23549];x[23549]=0;if((d|0)==1){break h}x[23549]=0;S(864,b|0,a+32|0,c|0);d=x[23549];x[23549]=0;if((d|0)==1){break g}Ab(c);w[e+34>>1]=0;x[23549]=0;c=O(403,e+20|0,14631)|0;d=x[23549];x[23549]=0;if((d|0)==1){break c}x[23549]=0;U(433,b|0,e+34|0,c|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break f}Ab(c);i=YL(B[a+32>>2]);B[a+32>>2]=i;d=-1;if(!bm(i)){break d}k=e,l=yb(x[a+4>>2]),x[k+16>>2]=l;c=yb(x[a+8>>2]);while(1){g=x[e+16>>2];if(!Kb(g,c)){break e}if(!bm(B[g>>2])){break d}Ae(e+16|0);continue}}a=N()|0;break a}a=N()|0;Ab(d);break a}a=N()|0;break a}a=N()|0;Ab(d);break a}a=N()|0;break a}a=N()|0;Ab(d);break a}a=N()|0;break a}a=N()|0;Ab(c);break a}a=N()|0;break a}a=N()|0;Ab(c);break a}a=N()|0;break a}a=N()|0;Ab(c);break a}a=N()|0;break a}a=N()|0;Ab(c);break a}a=N()|0;break a}a=N()|0;Ab(c);break a}a=N()|0;break a}a=N()|0;Ab(c);break a}a=N()|0;break a}a=N()|0;Ab(c);break a}a=N()|0;break a}a=N()|0;Ab(c);break a}a=N()|0;Ab(c);break a}if(y[b+3|0]&64){break d}c=z[f>>1];if((c+300&65535)>>>0>600){break d}g=z[a>>1];if(g>>>0>3|(g|0)==2){break d}j=w[a+30>>1];if((j|0)<0){break d}k=e,l=Hh(x[a+36>>2]),x[k+16>>2]=l;x[e+12>>2]=0;k=a,l=x[sj(e+16|0,e+12|0,44048)>>2],x[k+36>>2]=l;if(oc(x[a+4>>2],x[a+8>>2])>>>0>32767){break d}B:{C:{switch(g-1|0){case 2:f=w[e+34>>1];if((f|0)<=0){break d}w[e+10>>1]=j;B[e+16>>2]=B[a+32>>2];x[23549]=0;w[e+12>>1]=c;w[e+14>>1]=(c+f|0)-1;a=ba(865,a|0,e+10|0,e+16|0,e+12|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){if(a){break B}break d}a=N()|0;break a;case 0:g=w[e+34>>1];if((g|0)<=0){break d}B[e+16>>2]=B[a+32>>2];x[23549]=0;w[e+12>>1]=c;w[e+14>>1]=(c+g|0)-1;a=fa(866,a|0,h|0,e+16|0,e+12|0,f|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){if(a){break B}break d}a=N()|0;break a;default:break C}}x[23549]=0;W(867,a|0);a=x[23549];x[23549]=0;if((a|0)==1){break b}}d=1}Zg(b)}db=e+288|0;return d|0}a=N()|0;break a}a=N()|0}Zg(b);Q(a|0);p()}function Efa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;d=db-736|0;db=d;wc(b);e=db-16|0;db=e;i=d+128|0;NR(e+8|0,i);f=x[e+12>>2];lc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);g=x[e+4>>2];if((g|0)==(f|0)){Zb(b,x[e+12>>2])}db=e+16|0;e=(f|0)==(g|0);if(!e){MR(i)}a:{if(!e){break a}if(!PR(d+128|0)){break a}if(!Lb(x[b>>2],x[b+8>>2],Qc(OR(y[d+162|0]|y[d+163|0]<<8),hb))){break a}if(!c){q=1;break a}Bd(a,262144);f=d+92|0;tl(f,2,d+128|0);e=d+12|0;Bc(e,f);zb(a+1298308|0,e);tb(e);i=Tb(e,8215);zb(a+1298344|0,i);tb(i);e=Tb(e,10008);zb(a+1298356|0,e);tb(e);e=db-16|0;db=e;h=f;f=Tb(e+4|0,4134);ad(h,f);tb(f);db=e+16|0;v[d|0]=y[d+158|0];x[23549]=0;v[d+115|0]=y[d+157|0];P(629,d+116|0,d+115|0);e=x[23549];x[23549]=0;b:{c:{d:{if((e|0)!=1){x[23549]=0;V(239,d+12|0,d+92|0,d|0,d+116|0);e=x[23549];x[23549]=0;if((e|0)!=1){e=d+12|0;zb(a+1298368|0,e);tb(e);tb(d+116|0);f=d+92|0;Ab(f);x[a+480208>>2]=12;x[a+1298404>>2]=5;w[a+480188>>1]=y[d+166|0]|y[d+167|0]<<8;w[d+12>>1]=y[d+162|0]|y[d+163|0]<<8;w[d+92>>1]=3999;B=a,C=z[Uc(e,f)>>1],w[B+480190>>1]=C;MU(Wb(x[a+484360>>2],y[a+484376|0]),d+224|0,y[d+160|0]|y[d+161|0]<<8);e=0;while(1)if(z[a+480188>>1]<=e>>>0){e=d+12|0;Wd(e,b,D(y[d+162|0]|y[d+163|0]<<8,80));i=c&2;l=hc(d+92|0,e);ub(e);g=d+60|0;e=0;e:{f:{while(1){if(z[a+480190>>1]<=e>>>0){q=1;if(c&1){break f}break b}x[23549]=0;P(630,l|0,d+12|0);f=x[23549];x[23549]=0;if((f|0)==1){break e}tl(d,2,g);x[23549]=0;P(208,d+116|0,d|0);f=x[23549];x[23549]=0;if((f|0)==1){break e}e=e+1|0;f=d+116|0;zc(((e<<5)+a|0)+946304|0,f);tb(f);x[23549]=0;h=f;f=(D(e,104)+a|0)+484380|0;S(631,h|0,d+12|0,f|0);h=x[23549];x[23549]=0;g:{if((h|0)==1){break g}if(!i|!x[f>>2]){continue}x[23549]=0;h=O(141,b|0,y[d+30|0]|y[d+31|0]<<8|(y[d+32|0]<<16|y[d+33|0]<<24))|0;j=x[23549];x[23549]=0;if((j|0)==1){break g}if(!h){continue}x[23549]=0;U(205,d+116|0,f|0,b|0)|0;f=x[23549];x[23549]=0;if((f|0)!=1){continue}}break}break e}x[23549]=0;m=a+484344|0;P(211,m|0,y[d+164|0]|y[d+165|0]<<8);c=x[23549];x[23549]=0;if((c|0)==1){break e}r=d+16|0;s=d+14|0;t=d+17|0;u=d+15|0;A=d+13|0;e=0;while(1){if((y[d+164|0]|y[d+165|0]<<8)>>>0<=e>>>0){break b}x[23549]=0;c=U(212,m|0,e&65535,64)|0;f=x[23549];x[23549]=0;if((f|0)==1){break e}h:{if(!c){break h}c=(e<<1)+d|0;c=y[c+480|0]|y[c+481|0]<<8;if(!c){break h}x[23549]=0;c=O(141,b|0,c<<4)|0;f=x[23549];x[23549]=0;if((f|0)==1){break e}if(!c){break h}j=0;c=Yb(x[m>>2],e);n=$c(x[c>>2],x[x[c+48>>2]+12>>2],0,0);while(1){if(j>>>0>63){break h}c=x[b+8>>2];f=x[b>>2];x[23549]=0;c=U(142,f|0,c|0,1)|0;f=x[23549];x[23549]=0;i:{if((f|0)!=1){if(!c){break h}x[23549]=0;c=R(192,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break e}k=c<<24>>24;if(k){break i}j=j+1|0;n=D(z[a+480188>>1],6)+n|0;continue}break e}w[r>>1]=0;x[d+12>>2]=0;c=k&31;f=D(c,6)+n|0;h=Wh(d+12|0);i=c>>>0<z[a+480188>>1];o=i?f:h;g=k&255;j:{if(!(g&32)){break j}x[23549]=0;P(249,d+116|0,b|0);c=x[23549];x[23549]=0;if((c|0)==1){break e}c=y[d+116|0];v[o|0]=c;B=i?f+1|0:A,C=y[fd(d+116|0)|0],v[B|0]=C;k:{if(c){if((c|0)==254){break k}if(c>>>0<121){break j}}c=0}v[o|0]=c}l:{if(!(g&64)){break l}x[23549]=0;P(249,d+116|0,b|0);c=x[23549];x[23549]=0;if((c|0)==1){break e}g=i?f+3|0:u;c=y[d+116|0];v[g|0]=c;h=i?f+5|0:t;B=h,C=y[fd(d+116|0)|0],v[B|0]=C;m:{if(c>>>0>=16){if(c>>>0<=23){c=y[c+27063|0];v[g|0]=c;break m}v[g|0]=0;break l}Qf(o);c=y[g|0]}if((c|0)!=23){if((c|0)!=9){break l}v[g|0]=20;v[d|0]=y[h|0]>>>3;v[d+115|0]=1;B=h,C=y[af(d,d+115|0)|0]-1&15|128,v[B|0]=C;break l}v[d|0]=64;B=h,C=y[Sb(h,d)|0]<<1,v[B|0]=C}if((k|0)>=0){continue}v[(i?f+2|0:s)|0]=1;x[23549]=0;c=R(192,b|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break e}v[(i?f+4|0:r)|0]=c;continue}}e=e+1|0;continue}}b=N()|0;ub(l);break c}else{f=(e<<5)+a|0;Te(f+480280|0);w[f+480284>>1]=(y[(d+e|0)+192|0]<<4|4)&244;e=e+1|0;continue}}b=N()|0;tb(d+116|0);break d}b=N()|0}Ab(d+92|0)}Q(b|0);p()}ub(l)}db=d+736|0;return q|0}function kI(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;i=db-560|0;db=i;g=c;c=(c-3|0)/24|0;t=(c|0)>0?c:0;k=g+D(t,-24)|0;n=x[(e<<2)+72800>>2];j=d-1|0;if((n+j|0)>=0){g=d+n|0;c=t-j|0;while(1){C[(i+320|0)+(h<<3)>>3]=(c|0)<0?0:+x[(c<<2)+72816>>2];c=c+1|0;h=h+1|0;if((g|0)!=(h|0)){continue}break}}q=k-24|0;g=0;h=(n|0)>0?n:0;m=(d|0)<=0;while(1){a:{if(m){f=0;break a}r=g+j|0;c=0;f=0;while(1){f=C[(c<<3)+a>>3]*C[(i+320|0)+(r-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+i>>3]=f;c=(g|0)==(h|0);g=g+1|0;if(!c){continue}break}y=47-k|0;r=48-k|0;u=(k|0)<25;z=k-25|0;g=n;while(1){f=C[(g<<3)+i>>3];c=0;h=g;o=(g|0)<=0;if(!o){while(1){m=(i+480|0)+(c<<2)|0;l=f*5.960464477539063e-8;b:{if(F(l)<2147483648){j=~~l;break b}j=-2147483648}l=+(j|0);f=l*-16777216+f;c:{if(F(f)<2147483648){j=~~f;break c}j=-2147483648}x[m>>2]=j;h=h-1|0;f=C[(h<<3)+i>>3]+l;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=zj(f,q);f=f+J(f*.125)*-8;d:{if(F(f)<2147483648){m=~~f;break d}m=-2147483648}f=f-+(m|0);e:{f:{g:{h:{if(!u){h=(g<<2)+i|0;j=x[h+476>>2];c=j>>r;s=h;h=j-(c<<r)|0;x[s+476>>2]=h;m=c+m|0;j=h>>y;break h}if(q){break g}j=x[((g<<2)+i|0)+476>>2]>>23}if((j|0)<=0){break e}break f}j=2;if(f>=.5){break f}j=0;break e}c=0;h=0;if(!o){while(1){s=(i+480|0)+(c<<2)|0;o=x[s>>2];v=16777215;i:{j:{if(h){break j}v=16777216;if(o){break j}h=0;break i}x[s>>2]=v-o;h=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}k:{if(u){break k}c=8388607;l:{switch(z|0){case 1:c=4194303;break;case 0:break l;default:break k}}o=(g<<2)+i|0;x[o+476>>2]=x[o+476>>2]&c}m=m+1|0;if((j|0)!=2){break e}f=1-f;j=2;if(!h){break e}f=f-zj(1,q)}m:{n:{if(f==0){h=0;c=g;if((n|0)>=(c|0)){break m}while(1){c=c-1|0;h=x[(i+480|0)+(c<<2)>>2]|h;if((c|0)>(n|0)){continue}break}if(!h){break m}k=q;while(1){k=k-24|0;g=g-1|0;if(!x[(i+480|0)+(g<<2)>>2]){continue}break}break n}f=zj(f,24-k|0);o:{if(f>=16777216){d=(i+480|0)+(g<<2)|0;l=f*5.960464477539063e-8;p:{if(F(l)<2147483648){c=~~l;break p}c=-2147483648}f=+(c|0)*-16777216+f;q:{if(F(f)<2147483648){a=~~f;break q}a=-2147483648}x[d>>2]=a;g=g+1|0;break o}if(F(f)<2147483648){c=~~f}else{c=-2147483648}k=q}x[(i+480|0)+(g<<2)>>2]=c}f=zj(1,k);if((g|0)>=0){d=g;while(1){a=d;C[(a<<3)+i>>3]=f*+x[(i+480|0)+(a<<2)>>2];d=a-1|0;f=f*5.960464477539063e-8;if(a){continue}break}h=g;while(1){f=0;c=0;a=g-h|0;d=(a|0)>(n|0)?n:a;if((d|0)>=0){while(1){f=C[(c<<3)+75584>>3]*C[(c+h<<3)+i>>3]+f;k=(c|0)!=(d|0);c=c+1|0;if(k){continue}break}}C[(i+160|0)+(a<<3)>>3]=f;a=(h|0)>0;h=h-1|0;if(a){continue}break}}r:{s:{t:{switch(e|0){case 3:u:{if((g|0)<=0){break u}d=(i+160|0)+(g<<3)|0;f=C[d>>3];c=g;while(1){l=f;e=i+160|0;a=c-1|0;h=e+(a<<3)|0;w=C[h>>3];f=w+f;C[e+(c<<3)>>3]=l+(w-f);C[h>>3]=f;e=c>>>0>1;c=a;if(e){continue}break}if((g|0)<2){break u}f=C[d>>3];c=g;while(1){l=f;d=i+160|0;a=c-1|0;e=d+(a<<3)|0;p=C[e>>3];f=p+f;C[d+(c<<3)>>3]=l+(p-f);C[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}p=0;while(1){p=p+C[(i+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=C[i+160>>3];if(j){break s}C[b>>3]=f;f=C[i+168>>3];C[b+16>>3]=p;C[b+8>>3]=f;break r;case 0:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+C[(i+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;break r;case 1:case 2:break t;default:break r}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=a-1|0;f=f+C[(i+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;f=C[i+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+C[(i+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}C[b+8>>3]=j?-f:f;break r}C[b>>3]=-f;f=C[i+168>>3];C[b+16>>3]=-p;C[b+8>>3]=-f}db=i+560|0;return m&7}c=1;while(1){h=c;c=c+1|0;if(!x[(i+480|0)+(n-h<<2)>>2]){continue}break}h=g+h|0;while(1){j=d+g|0;g=g+1|0;C[(i+320|0)+(j<<3)>>3]=x[(t+g<<2)+72816>>2];c=0;f=0;if((d|0)>0){while(1){f=C[(c<<3)+a>>3]*C[(i+320|0)+(j-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+i>>3]=f;if((g|0)<(h|0)){continue}break}g=h;continue}}function I$(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=db-48|0;db=h;x[h+44>>2]=b;x[e>>2]=0;Nc(h,x[d+28>>2]);x[23549]=0;i=R(1115,x[h>>2])|0;j=x[23549];x[23549]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Xb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=N()|0;Xb(h);Q(a|0);p()}IG(a,f+24|0,h+44|0,c,e,i);break b}HG(a,f+16|0,h+44|0,c,e,i);break b}g=a;i=b;a=ib[x[x[a+8>>2]+12>>2]](a+8|0)|0;b=Mb(a);k=h,l=Hj(g,i,c,d,e,f,b,b+(Bb(x[a+4>>2],y[a+11|0])<<2)|0),x[k+44>>2]=l;break b}a=Mi(h+44|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}g=x[20471];x[h+24>>2]=x[20470];x[h+28>>2]=g;g=x[20469];x[h+16>>2]=x[20468];x[h+20>>2]=g;g=x[20467];x[h+8>>2]=x[20466];x[h+12>>2]=g;g=x[20465];x[h>>2]=x[20464];x[h+4>>2]=g;k=h,l=Hj(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}g=x[20479];x[h+24>>2]=x[20478];x[h+28>>2]=g;g=x[20477];x[h+16>>2]=x[20476];x[h+20>>2]=g;g=x[20475];x[h+8>>2]=x[20474];x[h+12>>2]=g;g=x[20473];x[h>>2]=x[20472];x[h+4>>2]=g;k=h,l=Hj(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}a=Mi(h+44|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=Mi(h+44|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=Mi(h+44|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=Mi(h+44|0,c,e,i,2);b=x[e>>2];a=a-1|0;F:{if(!(b&4|a>>>0>11)){x[f+16>>2]=a;break F}x[e>>2]=b|4}break b}a=Mi(h+44|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+44|0;b=db-16|0;db=b;x[b+12>>2]=c;while(1){H:{if(Jh(a,b+12|0)){break H}if(!Jk(i,1,Kk(x[a>>2]))){break H}yn(a);continue}break}if(Jh(a,b+12|0)){x[e>>2]=x[e>>2]|2}db=b+16|0;break b}b=h+44|0;a=ib[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Bb(x[a+4>>2],y[a+11|0])|0)==(0-Bb(x[a+16>>2],y[a+23|0])|0)){x[e>>2]=x[e>>2]|4;break I}c=Pr(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}g=rc(h,81920,44);k=g,l=Hj(a,b,c,d,e,f,g,g+44|0),x[k+44>>2]=l;break b}x[h+16>>2]=x[20496];g=x[20495];x[h+8>>2]=x[20494];x[h+12>>2]=g;g=x[20493];x[h>>2]=x[20492];x[h+4>>2]=g;k=h,l=Hj(a,b,c,d,e,f,h,h+20|0),x[k+44>>2]=l;break b}a=Mi(h+44|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}g=x[20507];x[h+24>>2]=x[20506];x[h+28>>2]=g;g=x[20505];x[h+16>>2]=x[20504];x[h+20>>2]=g;g=x[20503];x[h+8>>2]=x[20502];x[h+12>>2]=g;g=x[20501];x[h>>2]=x[20500];x[h+4>>2]=g;k=h,l=Hj(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}a=Mi(h+44|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=ib[x[x[a+8>>2]+24>>2]](a+8|0)|0;b=Mb(a);k=h,l=Hj(g,i,c,d,e,f,b,b+(Bb(x[a+4>>2],y[a+11|0])<<2)|0),x[k+44>>2]=l;break b}GG(f+20|0,h+44|0,c,e,i);break b}a=Mi(h+44|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=db-16|0;db=a;x[a+12>>2]=c;b=6;c=h+44|0;L:{M:{if(Jh(c,a+12|0)){break M}b=4;if((mn(i,Kk(x[c>>2]))|0)!=37){break M}b=2;if(!Jh(yn(c),a+12|0)){break L}}x[e>>2]=x[e>>2]|b}db=a+16|0}a=x[h+44>>2]}db=h+48|0;return a|0}function go(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;f=db+-64|0;db=f;r=pz(x[a+24>>2],y[a+32|0]);t=cj(r);c=t;e=x[a>>2];d=Cd(e,x[a+4>>2]);a:{if(c>>>0>d>>>0){k=db-32|0;db=k;c=c-d|0;l=x[wb(a)>>2];e=x[a+4>>2];b:{if(c>>>0<=(l-e|0)/12>>>0){e=db-16|0;db=e;c=It(e+4|0,a,c);d=x[c+4>>2];g=x[c+8>>2];while(1){if((d|0)==(g|0)){fc(c);db=e+16|0}else{VO(d);d=d+12|0;x[c+4>>2]=d;continue}break}break b}d=wb(a);d=Hl(k+12|0,ep(a,Cd(x[a>>2],e)+c|0),Cd(x[a>>2],x[a+4>>2]),d);g=db-16|0;db=g;c=eR(g+4|0,d+8|0,c);e=x[c>>2];while(1){if(x[c+4>>2]!=(e|0)){VO(e);e=x[c>>2]+12|0;x[c>>2]=e;continue}break}Kd(c);db=g+16|0;g=db-16|0;db=g;h=wb(a);c=vb(g+12|0,x[a+4>>2]);i=vb(g+8|0,x[a>>2]);j=vb(g+4|0,x[d+4>>2]);e=x[c>>2];i=x[i>>2];c=db+-64|0;db=c;j=x[j>>2];x[c+56>>2]=j;x[c+60>>2]=e;x[c+52>>2]=j;h=rd(c+24|0,h,c+52|0,c+56|0);x[c+16>>2]=x[h+8>>2];j=x[h+4>>2];x[c+8>>2]=x[h>>2];x[c+12>>2]=j;Ke(c+36|0,c+8|0);while(1){if(sd(e,i)){dA(dh(x[c+56>>2]),dh(e));e=Cj(c+60|0);Cj(c+56|0);e=x[e>>2];continue}break}Je(c+36|0);j=x[c+56>>2];if(!y[c+48|0]){h=db-16|0;db=h;e=vb(h+12|0,x[x[c+44>>2]>>2]);n=x[vb(h+8|0,x[x[c+40>>2]>>2])>>2];i=db-16|0;db=i;e=x[e>>2];x[i+12>>2]=e;while(1){if(ai(e,n)){He(Mv(e));e=x[Bj(i+12|0)>>2];continue}break}db=i+16|0;db=h+16|0}db=c- -64|0;x[d+4>>2]=j;Pb(a,d+4|0);Pb(a+4|0,d+8|0);Pb(wb(a),kc(d));x[d>>2]=x[d+4>>2];db=g+16|0;c=x[d+4>>2];while(1){e=x[d+8>>2];if((e|0)!=(c|0)){e=e-12|0;x[d+8>>2]=e;He(e);continue}break}c=x[d>>2];if(c){vr(d);Eb(c)}}db=k+32|0;break a}if(c>>>0<d>>>0){$O(a,e+D(c,12)|0)}}if(b){c=a+12|0;Sp(c,Ud(c));A=wb(c),B=0,x[A>>2]=B;l=c;c=gc(c);x[l>>2]=c;x[c>>2]=0;x[a+28>>2]=0}h=Nb(f+52|0);c=x[a+24>>2];c=lt(x[c+484344>>2],x[c+484348>>2]);x[23549]=0;i=U(567,f+40|0,c|0,30284)|0;c=x[23549];x[23549]=0;c:{if((c|0)!=1){g=a+12|0;d:{while(1){if((m|0)==(t|0)){id(i);bc(h);db=f- -64|0;return}c=x[a+24>>2];j=z[_b(x[r>>2],m)>>1];d=eP(c,j);x[f+36>>2]=d;c=$d(x[a>>2],m);e:{f:{if(b){x[23549]=0;v[f+20|0]=0;S(742,c|0,d|0,f+20|0);d=x[23549];x[23549]=0;if((d|0)!=1){break f}d=N()|0;break d}x[23549]=0;P(696,c|0,d|0);d=x[23549];x[23549]=0;if((d|0)==1){break e}}x[23549]=0;d=O(299,r|0,m&65535)|0;e=x[23549];x[23549]=0;if((e|0)==1){break e}g:{if(!d){break g}x[f+20>>2]=b?0:x[c+4>>2];s=x[Cb(f+20|0,f+36|0)>>2];n=Bf(g);c=z[_b(x[i>>2],j)>>1];if((c|0)!=65535){d=cP(g,z[nm(f+20|0,c,s)>>1],x[f+24>>2]);h:{if(xg(d,Bf(g))){c=cP(g,z[nm(f+20|0,z[_b(x[i>>2],j)>>1],x[f+36>>2])>>1],x[f+24>>2]);break h}c=Bf(g)}x[f+32>>2]=d;while(1){i:{if(!xg(d,c)){break g}e=Nb(f+20|0);d=an(td(d)+8|0);x[23549]=0;P(743,e|0,d|0);d=x[23549];x[23549]=0;if((d|0)!=1){d=Xj(f+12|0,n);k=nm(f+4|0,m,x[td(x[f+32>>2])+4>>2]);d=x[d>>2];x[23549]=0;d=ba(744,g|0,d|0,k|0,e|0)|0;k=x[23549];x[23549]=0;if((k|0)==1){break i}x[f+16>>2]=d;n=x[Vg(f+16|0)>>2];oe(e);d=x[Vg(f+32|0)>>2];continue}}break}d=N()|0;oe(e);break d}q=Yb(x[x[a+24>>2]+484344>>2],j);c=z[x[x[q+48>>2]+12>>2]+480188>>1];x[23549]=0;v[f+20|0]=0;S(720,h|0,c|0,f+20|0);c=x[23549];x[23549]=0;if((c|0)!=1){o=x[f+36>>2];j:while(1){k:{if((o|0)==(s|0)){if(s){break g}A=_b(x[i>>2],j),B=m,w[A>>1]=B;break g}c=1;k=0;e=x[x[q+48>>2]+12>>2];o=o-1|0;d=sf(x[q>>2],e,o);while(1){if(c>>>0<16&z[e+480188>>1]>k>>>0){u=Db(x[h>>2],k);e=y[u|0];l:{m:{n:{switch(y[d+3|0]-19|0){case 1:l=y[d+5|0];if((l&240)==176){break m}break l;case 0:break n;default:break l}}l=y[d+5|0];if((l&240)!=96){break l}}v[u|0]=l&15;l=y[Db(x[h>>2],k)|0];e=l?l:e}l=c;c=e&255;c=D(l,c?c+1|0:1);d=d+6|0;k=k+1|0;e=x[x[q+48>>2]+12>>2];continue}else{o:{if(c>>>0<=1){continue j}e=Nb(f+20|0);x[23549]=0;P(743,e|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break o}c=Xj(f,n);d=nm(f+4|0,m,o);c=x[c>>2];x[23549]=0;n=ba(744,g|0,c|0,d|0,e|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break k}oe(e);continue j}}break}}break}d=N()|0;oe(e);break d}d=N()|0;break d}m=m+1|0;continue}break}d=N()|0}id(i);break c}d=N()|0}bc(h);Q(d|0);p()}function hja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=db-320|0;db=e;wc(b);f=db-16|0;db=f;HU(f+8|0,e+102|0);g=x[f+12>>2];lc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);h=x[f+4>>2];if((h|0)==(g|0)){Zb(b,x[f+12>>2])}db=f+16|0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=(h|0)){break g}if(!JU(e+102|0)){break g}if(!Lb(x[b>>2],x[b+8>>2],Qc(IU(y[e+318|0],y[e+319|0]),hb))){break g}if(!c){d=1;break g}Bd(a,2);Dg(a);x[a+480188>>2]=524296;t=a,u=Le(455e3),x[t+480204>>2]=u;Jb(a+1074312|0,110,1);x[a+480208>>2]=x[a+480208>>2]|16777216;f=e+72|0;_e(f,2,e+133|0);d=e+88|0;Bc(d,f);zb(a+1298308|0,d);tb(d);d=0;h:{i:{while(1){if((d|0)==8){j:{d=Wb(x[a+484360>>2],y[a+484376|0]);o=y[e+318|0];m=o+1|0;Ao(d,b,m,65535,65535);f=Nb(e+88|0);x[23549]=0;S(223,b|0,f|0,m|0);d=x[23549];x[23549]=0;if((d|0)==1){break j}t=e,u=yb(x[f>>2]),x[t+72>>2]=u;d=yb(x[f+4>>2]);while(1){g=x[e+72>>2];q=Kb(g,d);if(q){if((y[g|0]-1&255)>>>0>7){break h}Oe(e+72|0);continue}break}t=a,u=y[Db(x[f>>2],0)|0],x[t+480196>>2]=u;d=y[e+317|0];h=y[e+319|0];g=Nb(e+72|0);x[23549]=0;n=h+1|0;S(223,b|0,g|0,n|0);h=x[23549];x[23549]=0;k:{if((h|0)==1){break k}x[23549]=0;h=a+484344|0;P(211,h|0,n|0);j=x[23549];x[23549]=0;if((j|0)==1){break k}r=d+1|0;if(!(c&1)){break i}c=0;while(1){if((c|0)==(n|0)){break i}d=y[Db(x[g>>2],c)|0];x[23549]=0;d=U(212,h|0,d|0,r|0)|0;j=x[23549];x[23549]=0;l:{if((j|0)!=1){if(!d){break i}j=0;l=Yb(x[h>>2],y[Db(x[g>>2],c)|0]);m:while(1){s=j&65535;if(s>>>0>7){break l}j=j+1|0;d=0;while(1){if(A[l+12>>2]<=d>>>0){continue m}x[23549]=0;i=R(192,b|0)|0;k=x[23549];x[23549]=0;n:{o:{if((k|0)!=1){i=i<<24>>24;if((i|0)>=0){break o}d=(i&127)+d|0;break n}d=N()|0;break b}k=$c(x[l>>2],x[x[l+48>>2]+12>>2],d,s);if((i|0)==1){v[k|0]=254;break n}if((i-1&255)>>>0>96){break n}v[k+1|0]=j;v[k|0]=i+12}d=d+1|0;continue}}}d=N()|0;break b}c=c+1|0;continue}}d=N()|0;break b}}else{h=e+88|0;f=(e+102|0)+D(d,19)|0;lB(h,f+63|0);g=e+72|0;Bc(g,h);Em(((d<<5)+a|0)+480289|0,g);tb(g);d=d+1|0;j=D(d,104)+a|0;i=j+484380|0;nd(i,2);v[e+83|0]=0;g=y[f+78|0]|y[f+79|0]<<8|(y[f+80|0]<<16|y[f+81|0]<<24);v[e+79|0]=g;v[e+80|0]=g>>>8;v[e+81|0]=g>>>16;v[e+82|0]=g>>>24;g=y[f+75|0]|y[f+76|0]<<8|(y[f+77|0]<<16|y[f+78|0]<<24);f=y[f+71|0]|y[f+72|0]<<8|(y[f+73|0]<<16|y[f+74|0]<<24);x[e+8>>2]=x[e+80>>2];x[e+72>>2]=f;x[e+76>>2]=g;f=x[e+76>>2];x[e>>2]=x[e+72>>2];x[e+4>>2]=f;xl(i,1,e);x[j+484404>>2]=8215;f=e+60|0;Bc(f,h);zc(((d<<5)+a|0)+946304|0,f);tb(f);continue}break}d=N()|0;break a}j=o+1|0;d=0;p:{q:{while(1){if((d|0)==(j|0)){x[23549]=0;b=O(1,e+60|0,8514)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break p}d=N()|0;break b}b=y[a+484376|0];c=x[a+484360>>2];x[23549]=0;i=d&65535;b=O(299,Wb(c,b)|0,i|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){r:{s:{if(b){b=Wb(x[a+484360>>2],y[a+484376|0]);break s}x[23549]=0;c=O(351,h|0,r|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break q}if((c|0)==65535){break r}b=Wb(x[a+484360>>2],y[a+484376|0]);t=_b(x[b>>2],d),u=c,w[t>>1]=u}b=kB(yb(x[Yb(x[h>>2],z[_b(x[b>>2],d)>>1])+4>>2]),1);c=y[b+5|0];l=y[Db(x[f>>2],(d+1>>>0)%(m>>>0)|0)|0];if((c|0)==(l|0)){break r}t:{if(y[b+3|0]!=16){break t}c=y[a+484376|0];k=x[a+484360>>2];x[23549]=0;c=O(352,Wb(k,c)|0,i|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break c}if((c|0)==65535){break t}b=kB(yb(x[Yb(x[h>>2],c)+4>>2]),1)}v[b+5|0]=l;v[b+3|0]=16}d=d+1|0;continue}break}d=N()|0;break b}d=N()|0;break b}zb(a+1298344|0,b);tb(b);x[23549]=0;b=O(1,e+48|0,5990)|0;c=x[23549];x[23549]=0;if((c|0)==1){break f}zb(a+1298356|0,b);tb(b);b=e+12|0;nj(b,2,e+113|0);x[23549]=0;P(208,e+24|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break e}x[23549]=0;S(11,e+36|0,5,e+24|0);b=x[23549];x[23549]=0;if((b|0)==1){break d}b=e+36|0;zb(a+1298368|0,b);tb(b);tb(e+24|0);x[a+1298404>>2]=5;bc(g)}bc(f);d=q^1}db=e+320|0;return d|0}d=N()|0;break b}d=N()|0;break b}d=N()|0;tb(e+24|0);break b}d=N()|0}bc(g)}bc(f);Q(d|0);p()}function mJ(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0;g=db-48|0;db=g;a:{b:{if(ms(c)){j=x[b+484344>>2];if(se(j,x[b+484348>>2],c&65535)){break b}}c=a;a=Gb(g+36|0);b=Gb(g+24|0);ii(c,a,b);tb(b);tb(a);break a}c=Yb(j,c);if(!(x[c+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Gb(g+36|0);b=Gb(g+24|0);ii(c,a,b);tb(b);tb(a);break a}if(!(z[b+480188>>1]>e>>>0&(e|0)>=0)){c=a;a=Gb(g+36|0);b=Gb(g+24|0);ii(c,a,b);tb(b);tb(a);break a}if(f>>>0>=6){c=a;a=Gb(g+36|0);b=Gb(g+24|0);ii(c,a,b);tb(b);tb(a);break a}c=$c(x[c>>2],x[x[c+48>>2]+12>>2],d,e&65535);c:{d:{e:{f:{switch(f|0){case 0:g:{h:{i:{j:{k:{d=y[c|0];if(!Tc(d)){if(!Hp(d)){break k}}e=g+24|0;SM(e,b,d,y[c+1|0]);x[23549]=0;P(989,g+36|0,e|0);b=x[23549];x[23549]=0;d=1;if((b|0)!=1){break j}c=N()|0;break g}d=0;x[23549]=0;O(54,g+36|0,16353)|0;b=x[23549];x[23549]=0;if((b|0)==1){break i}}b=9851;c=y[c|0];if(!Tc(c)){b=Hp(c)?10161:16353}x[23549]=0;b=O(54,g+12|0,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break h}c=a;a=g+36|0;ii(c,a,b);tb(b);tb(a);if(!d){break a}tb(g+24|0);break a}c=N()|0;break d}c=N()|0;tb(g+36|0);if(!d){break d}}tb(g+24|0);break d;case 1:b=c+1|0;l:{if(y[c+1|0]){Zt(g+36|0,b);break l}Tb(g+36|0,16358)}b=y[b|0];x[23549]=0;b=O(54,g+24|0,(b?10651:16358)|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break e}c=a;a=g+36|0;ii(c,a,b);tb(b);tb(a);break a;case 2:m:{if(Sg(y[c|0])){Tb(g+36|0,17394);break m}d=y[c+2|0];if(d){Ye(g+36|0,1,qM(x[x[b+8>>2]+88>>2],d));break m}Tb(g+36|0,17394)}b=17394;if(!Sg(y[c|0])){b=y[c+2|0]?5446:17394}x[23549]=0;b=O(54,g+24|0,b|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){c=a;a=g+36|0;ii(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d;case 4:n:{if(Sg(y[c|0])){k=g,l=Qj(y[c+2|0],y[c+4|0])&255,x[k+12>>2]=l;FA(g+36|0,g+12|0);break n}if(y[c+2|0]){Zt(g+36|0,c+4|0);break n}Tb(g+36|0,16358)}b=5430;if(!Sg(y[c|0])){b=y[c+2|0]?5430:16358}x[23549]=0;b=O(54,g+24|0,b|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){c=a;a=g+36|0;ii(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d;case 3:o:{if(Sg(y[c|0])){k=g,l=(Qj(y[c+3|0],y[c+5|0])&3840)!=0,v[k+12|0]=l;d=db-32|0;db=d;v[d+28|0]=44;x[d+20>>2]=-1;x[d+24>>2]=0;x[d+12>>2]=1058;x[d+16>>2]=1;j=g+36|0;b=db-48|0;db=b;h=x[d+12>>2]&2?16:10;f=db-32|0;db=f;e=Ye(f+20|0,1,0);p:{q:{r:{while(1){i=Mb(e);UJ(f+12|0,i,Bb(x[e+4>>2],y[e+11|0])+i|0,y[g+12|0],h);if(!x[f+16>>2]){break r}i=$f(Bb(x[e+4>>2],y[e+11|0]));x[23549]=0;P(58,e|0,i|0);i=x[23549];x[23549]=0;if((i|0)!=1){continue}break}break q}h=x[f+12>>2];i=Mb(e);x[23549]=0;P(59,e|0,h-i|0);h=x[23549];x[23549]=0;s:{if((h|0)!=1){x[23549]=0;P(60,b|0,e|0);h=x[23549];x[23549]=0;if((h|0)!=1){break s}break q}break q}tb(e);db=f+32|0;break p}a=N()|0;tb(e);Q(a|0);p()}e=b+12|0;Xl(e,b,x[d+12>>2]);f=x[d+16>>2];h=x[d+12>>2];x[23549]=0;V(73,b+24|0,e|0,h|0,f|0);e=x[23549];x[23549]=0;t:{u:{v:{w:{x:{if((e|0)!=1){e=y[d+28|0];f=x[d+24>>2];x[23549]=0;V(74,b+36|0,b+24|0,f|0,e|0);e=x[23549];x[23549]=0;if((e|0)==1){break x}x[23549]=0;P(57,j|0,b+36|0);e=x[23549];x[23549]=0;if((e|0)==1){break w}tb(b+36|0);tb(b+24|0);tb(b+12|0);tb(b);db=b+48|0;break t}a=N()|0;break u}a=N()|0;break v}a=N()|0;tb(b+36|0)}tb(b+24|0)}tb(b+12|0);tb(b);Q(a|0);p()}db=d+32|0;break o}d=y[c+3|0];if(d){Ye(g+36|0,1,pM(x[x[b+8>>2]+84>>2],d));break o}Tb(g+36|0,16359)}b=12165;if(!Sg(y[c|0])){b=y[c+3|0]?12165:16359}x[23549]=0;b=O(54,g+24|0,b|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){c=a;a=g+36|0;ii(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d;case 5:break f;default:break c}}y:{if(Sg(y[c|0])){k=g,l=Qj(y[c+3|0],y[c+5|0])&255,x[k+12>>2]=l;FA(g+36|0,g+12|0);break y}if(y[c+3|0]){Zt(g+36|0,c+5|0);break y}Tb(g+36|0,16358)}b=11008;if(!Sg(y[c|0])){b=y[c+3|0]?11008:16358}x[23549]=0;b=O(54,g+24|0,b|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){c=a;a=g+36|0;ii(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d}c=N()|0;tb(g+36|0)}Q(c|0);p()}c=a;a=Gb(g+36|0);b=Gb(g+24|0);ii(c,a,b);tb(b);tb(a)}db=g+48|0}function Hga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=db-208|0;db=d;wc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!Bo(b,d+196|0)){break l}if(!AS(d+196|0)){break l}g=xh(d+176|0);h=Gb(d+164|0);su(d+100|0);x[23549]=0;f=O(558,b|0,d+92|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break h}m:{if(!f){break m}m=d,n=$b($b(x[d+96>>2])-4|0),x[m+96>>2]=n;while(1){f=$b($b(x[d+96>>2])-8|0);x[d+96>>2]=f;n:{if(c){break n}if(($b(x[d+92>>2])|0)!=1347699796){break n}j=1;break m}x[23549]=0;S(176,d+72|0,b|0,$b(f)|0);f=x[23549];x[23549]=0;if((f|0)==1){break d}e=d+72|0;f=hc(d+12|0,e);ub(e);e=x[f>>2];x[23549]=0;i=R(164,e|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break b}o:{if(!i){break o}p:{e=$b(x[d+92>>2]);if((e|0)!=1129139796){if((e|0)!=1229866575){if((e|0)==1347699796){break p}if((e|0)!=1447383635){break o}x[23549]=0;O(174,f|0,4)|0;e=x[23549];x[23549]=0;if((e|0)==1){break b}x[23549]=0;e=R(559,f|0)|0;k=x[23549];x[23549]=0;if((k|0)==1){break b}if(!e){break o}e=$b(x[d+96>>2]);if(e>>>0<7){break o}x[23549]=0;S(560,f|0,h|0,e-6|0);e=x[23549];x[23549]=0;if((e|0)==1){break b}break o}x[23549]=0;l=O(561,f|0,d+100|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){break o}break b}qv(g,f);break o}x[23549]=0;j=U(562,a|0,f|0,c|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break b}}ub(f);if(i){x[23549]=0;f=O(558,b|0,d+92|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break i}if(f){continue}}break}if(xd(x[h+4>>2],y[h+11|0])){x[23549]=0;b=O(1,d+72|0,14548)|0;c=x[23549];x[23549]=0;if((c|0)==1){break g}zb(h,b);tb(b)}q:{if(!(j&l&1)){break q}b=y[d+142|0]|y[d+143|0]<<8;x[23549]=0;b=Hb(b)&256;U(253,a+1074312|0,5,!b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break f}c=Hb(y[d+138|0]|y[d+139|0]<<8);if(c){w[d+12>>1]=64;w[d+60>>1]=c;m=a,n=z[Uc(d+12|0,d+60|0)>>1],x[m+480228>>2]=n}c=!b;b=Hb(y[d+140|0]|y[d+141|0]<<8);if(!(c|!b)){x[a+480204>>2]=D(b,1e4)}if(y[d+100|0]){b=d+60|0;_e(b,2,d+100|0);x[23549]=0;P(208,d+12|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break e}b=d+12|0;zb(a+1298308|0,b);tb(b)}c=y[d+146|0]|y[d+147|0]<<8;if(!dq(c,1,12)){break q}f=y[d+144|0]|y[d+145|0]<<8;if(!dq(f,1,31)){break q}e=y[d+150|0]|y[d+151|0]<<8;if(!dq(e,0,23)){break q}i=y[d+152|0]|y[d+153|0]<<8;if(!dq(i,0,59)){break q}k=y[d+154|0]|y[d+155|0]<<8;if(!dq(k,0,59)){break q}b=Eq(d+12|0);m=b,n=Hb(y[d+148|0]|y[d+149|0]<<8),x[m+20>>2]=n;m=b,n=Hb(c)-1|0,x[m+16>>2]=n;m=b,n=Hb(f),x[m+12>>2]=n;m=b,n=Hb(e),x[m+8>>2]=n;m=b,n=Hb(i),x[m+4>>2]=n;m=b,n=Hb(k),x[m>>2]=n;x[23549]=0;P(387,a+1298408|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){break q}a=N()|0;break a}if(j&1){b=x[g>>2];x[23549]=0;b=R(164,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break h}if(b){b=Gb(d+12|0);x[23549]=0;S(257,g|0,b|0,32);c=x[23549];x[23549]=0;if((c|0)==1){break c}if(lu(b,13516)){x[23549]=0;S(11,d+60|0,13,b|0);c=x[23549];x[23549]=0;if((c|0)==1){break c}c=d+60|0;zb(a+1298320|0,c);tb(c)}c=x[g+8>>2];f=x[g>>2];x[23549]=0;c=O(563,f|0,c|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break c}if(!c){x[23549]=0;c=R(188,g|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break c}x[23549]=0;aa(301,a+1298332|0,g|0,c|0,40,0);c=x[23549];x[23549]=0;if((c|0)==1){break c}}tb(b)}x[23549]=0;b=O(1,d+60|0,17116)|0;c=x[23549];x[23549]=0;if((c|0)==1){break k}x[23549]=0;S(431,d+12|0,b|0,h|0);c=x[23549];x[23549]=0;if((c|0)==1){break j}c=d+12|0;zb(a+1298368|0,c);tb(c);tb(b)}x[a+480208>>2]=x[a+480208>>2]|2097152;x[23549]=0;a=U(253,a+1074312|0,84,1)|0;b=x[23549];x[23549]=0;if((b|0)==1){break h}x[23549]=0;a=U(253,a|0,83,1)|0;b=x[23549];x[23549]=0;if((b|0)==1){break h}x[23549]=0;O(254,a|0,85)|0;a=x[23549];x[23549]=0;if((a|0)==1){break h}}tb(h);ub(g)}db=d+208|0;return j&1}a=N()|0;break a}a=N()|0;tb(b);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;tb(b);break a}a=N()|0;ub(f)}tb(h);ub(g);Q(a|0);p()}function $ia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;j=db-720|0;db=j;a:{b:{if(d>>>0<=511){a=db-16|0;db=a;e=j+46|0;dc(a+8|0,e,554);d=x[a+12>>2];lc(a,x[b>>2],x[b+8>>2],x[a+8>>2],x[a+12>>2]);f=x[a+4>>2];if((f|0)==(d|0)){Zb(b,x[a+12>>2])}db=a+16|0;a=(d|0)==(f|0);if(!a){Vb(e,0,554)}if(!a){break b}d=db-32|0;db=d;c:{a=j+46|0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1229999433){break c}e=d+8|0;Yq(e,a+32|0);b=d+20|0;Bc(b,e);zc(c+492|0,b);tb(b);Xh(e,1,a+4|0);Bc(b,e);zc(c+524|0,b);tb(b);b=y[a+24|0]|y[a+25|0]<<8;x[c+4>>2]=64;x[c+8>>2]=128;x[c>>2]=b<<6;v[c+16|0]=y[a+26|0];v[c+17|0]=y[a+27|0];f=c+108|0;k=c+236|0;b=0;while(1)if((b|0)==120){b=y[c+60|0]&-2|v[a+17|0]&1;v[c+60|0]=b;b=b&-3|y[a+17|0]&2;v[c+60|0]=b;v[c+60|0]=b&251|y[a+17|0]&4;k=c+61|0;v[k|0]=y[a+18|0];g=c+62|0;v[g|0]=y[a+19|0];h=c+63|0;v[h|0]=y[a+20|0];i=c- -64|0;v[i|0]=y[a+21|0];f=c+48|0;ah(f,25);e=x[c+48>>2];b=0;while(1){d:{if((b|0)!=25){l=xb(e,b);m=b<<1;n=y[(a+m|0)+504|0];w[l>>1]=n;if((n|0)!=255){break d}ah(f,b);e=x[f>>2]}b=af(k,g);a=ne(e,x[c+52>>2]);if(a>>>0<=y[b|0]){v[c+60|0]=y[c+60|0]&253}if(a>>>0>y[af(h,i)|0]){break c}v[c+60|0]=y[c+60|0]&251;break c}v[l+2|0]=y[(a+(m|1)|0)+504|0];b=b+1|0;continue}}else{g=a+(b<<1)|0;e=y[g- -64|0];g=y[g+65|0];o=_b(k,b),q=g,w[o>>1]=q;o=Db(f,b),q=(e>>>0<120?e:b)+1|0,v[o|0]=q;b=b+1|0;continue}}db=d+32|0;break b}k=x[b+8>>2];d=db-32|0;db=d;x[d+28>>2]=674;x[d+8>>2]=674;e=x[b>>2];g=x[b+8>>2];f=x[Cb(d+28|0,d+8|0)>>2];if(!Lb(e,g,f)){f=rf(b)}g=d+8|0;e=j+46|0;vU(g,e);h=ec(d+16|0,x[d+8>>2],f);i=x[h>>2];lc(d,x[b>>2],x[b+8>>2],i,x[h+4>>2]);vU(g,e);Vb(x[d+8>>2]+f|0,0,674-f|0);Zb(b,x[d+28>>2]);db=d+32|0;g=x[a+480180>>2];a=0;d=db-32|0;db=d;if((y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))==1229999433){f=d+8|0;Yq(f,e+32|0);a=d+20|0;Bc(a,f);zc(c+492|0,a);tb(a);Xh(f,1,e+4|0);Bc(a,f);zc(c+524|0,a);tb(a);x[c>>2]=(y[e+20|0]|y[e+21|0]<<8)<<5;x[c+4>>2]=y[e+24|0]>>>1;tc(c+4|0,64);h=y[e+25|0]&127;x[c+8>>2]=h>>>0>64?128:h<<2;v[c+15|0]=y[c+15|0]&254|((y[e+25|0]^-1)&128)>>>7;v[d+20|0]=y[e+26|0];v[d+8|0]=100;o=c,q=y[Sb(a,f)|0],v[o+20|0]=q;v[d+20|0]=y[e+27|0];v[d+8|0]=64;o=c,q=y[Sb(a,f)|0],v[o+19|0]=q;v[c+16|0]=y[e+17|0];v[c+17|0]=y[e+18|0];v[c+18|0]=y[e+19|0];v[c+26|0]=y[e+22|0];v[c+27|0]=y[e+23|0];a=y[e+58|0];Mm(c,a&127,a>>>7|0);a=y[e+59|0];Lm(c,a&127,a>>>7|0);e:{f:{g:{h:{i:{j:{a=y[e+28|0]|y[e+29|0]<<8;switch(a-529|0){case 1:case 2:break h;case 0:case 3:break i;default:break j}}if((a|0)==544){break i}if((a|0)!=514){break h}}a=y[e+61|0];if((a|0)==255){break g}if(a>>>0<=128){v[c+30|0]=a}a=y[e+62|0]|y[e+63|0]<<8;if(a>>>0<129){break f}break e}a=v[e+61|0];if((a|0)<0){break g}v[c+30|0]=a+1}a=y[e+62|0];a=a<<24>>24>=0?a+1|0:0;f=v[e+63|0];if((f|0)<0){break f}a=((f&255)<<7)+a|0}w[c+28>>1]=a}a=v[e+60|0];v[c+31|0]=a;if((a|0)<0){v[c+31|0]=0;v[c+34|0]=a^128}a=0;f=g&16777216?240:25;lv(e+304|0,c+48|0,0,f);lv(e+386|0,c+68|0,32,f);lv(e+468|0,c+88|0,32,f);v[c+100|0]=y[c+100|0]&239|y[e+468|0]>>>3&16;g=c+108|0;h=c+236|0;while(1){if((a|0)!=120){i=e+(a<<1)|0;f=y[i- -64|0];i=y[i+65|0];o=_b(h,a),q=i,w[o>>1]=q;o=Db(g,a),q=(f>>>0<120?f:a)+1|0,v[o|0]=q;a=a+1|0;continue}break}a=554}db=d+32|0;d=0;k:{if(!a){break k}d=y[e+550|0]|y[e+551|0]<<8|(y[e+552|0]<<16|y[e+553|0]<<24);if(!((d|0)!=1481920589&(d|0)!=1297110104)){a=c+236|0;f=0;while(1){if((f|0)!=120){d=y[(e+f|0)+554|0];g=_b(a,f);w[g>>1]=z[g>>1]|d<<8;f=f+1|0;continue}break}a=674}d=a}Vc(b,d+k|0);if(!Bi(b,13740)){break b}d=j+4|0;Wd(d,b,pg(b));a=hc(j+24|0,d);ub(d);b=x[a>>2];x[23549]=0;R(146,b|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break a}x[23549]=0;b=O(354,a|0,13531)|0;d=x[23549];x[23549]=0;if((d|0)==1){break a}if(b){x[23549]=0;b=R(192,a|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break a}v[c+34|0]=b>>>0<=250?b:0}ub(a)}db=j+720|0;return}b=N()|0;ub(a);Q(b|0);p()}function zx(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;l=db-48|0;db=l;x[l+44>>2]=0;a:{if(d|g|h|i){j=g?l+44|0:0;b:{if(!j){break b}k=x[j>>2];if(!k){break b}Eb(k);x[j>>2]=0}x[23549]=0;X(91);k=x[23549];x[23549]=0;c:{d:{if((k|0)==1){m=Ra(92296,49120,49176,61816,92484,92588,92536,92428,92416,92732,92700,92668,92656,92880,0)|0;e:{f:{n=eb;if((n|0)==($(92296)|0)){k=Y(m|0)|0;x[23549]=0;P(1027,j|0,k|0);j=x[23549];x[23549]=0;k=277;if((j|0)==1){break f}break c}if(($(49120)|0)==(n|0)){k=Y(m|0)|0;x[23549]=0;P(1027,j|0,k|0);j=x[23549];x[23549]=0;k=358;if((j|0)!=1){break c}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){break d}break e}if(($(49176)|0)==(n|0)){k=Y(m|0)|0;x[23549]=0;P(1027,j|0,k|0);j=x[23549];x[23549]=0;k=359;if((j|0)!=1){break c}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){break d}break e}if(($(61816)|0)==(n|0)){k=Y(m|0)|0;x[23549]=0;P(1027,j|0,k|0);j=x[23549];x[23549]=0;k=357;if((j|0)!=1){break c}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){break d}break e}if(($(92484)|0)==(n|0)){k=Y(m|0)|0;x[23549]=0;P(1027,j|0,k|0);j=x[23549];x[23549]=0;k=300;if((j|0)!=1){break c}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){break d}break e}if(($(92588)|0)==(n|0)){k=Y(m|0)|0;x[23549]=0;P(1027,j|0,k|0);j=x[23549];x[23549]=0;k=299;if((j|0)!=1){break c}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){break d}break e}if(($(92536)|0)==(n|0)){k=Y(m|0)|0;x[23549]=0;P(1027,j|0,k|0);j=x[23549];x[23549]=0;k=298;if((j|0)!=1){break c}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){break d}break e}if(($(92428)|0)==(n|0)){k=Y(m|0)|0;x[23549]=0;P(1027,j|0,k|0);j=x[23549];x[23549]=0;k=297;if((j|0)!=1){break c}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){break d}break e}if(($(92416)|0)==(n|0)){k=Y(m|0)|0;x[23549]=0;P(1027,j|0,k|0);j=x[23549];x[23549]=0;k=296;if((j|0)!=1){break c}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){break d}break e}if(($(92732)|0)==(n|0)){k=Y(m|0)|0;x[23549]=0;P(1027,j|0,k|0);j=x[23549];x[23549]=0;k=289;if((j|0)!=1){break c}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){break d}break e}if(($(92700)|0)==(n|0)){k=Y(m|0)|0;x[23549]=0;P(1027,j|0,k|0);j=x[23549];x[23549]=0;k=288;if((j|0)!=1){break c}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){break d}break e}if(($(92668)|0)==(n|0)){k=Y(m|0)|0;x[23549]=0;P(1027,j|0,k|0);j=x[23549];x[23549]=0;k=287;if((j|0)!=1){break c}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){break d}break e}if(($(92656)|0)==(n|0)){k=Y(m|0)|0;x[23549]=0;P(1027,j|0,k|0);j=x[23549];x[23549]=0;k=286;if((j|0)!=1){break c}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){break d}break e}o=$(92880)|0;k=257;m=Y(m|0)|0;if((n|0)!=(o|0)){break c}x[23549]=0;P(1027,j|0,m|0);j=x[23549];x[23549]=0;k=267;if((j|0)!=1){break c}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)==1){break e}break d}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){break d}}T(0)|0;Rb()}p()}Q(a|0);p()}Z();m=!g;if(d){j=ib[d|0](k,e)|0}else{j=3}if(!(m|!(j&2))){x[g+16>>2]=k;m=g;g=x[l+44>>2];q=m,r=_f(g?g:21204),x[q+20>>2]=r}if(h){x[h>>2]=k}g=x[l+44>>2];if(i){q=i,r=_f(g?g:21204),x[q>>2]=r;g=x[l+44>>2]}if(g){Eb(g);x[l+44>>2]=0}if(!(j&1)){break a}}x[23549]=0;P(1025,l+32|0,a|0);g=x[23549];x[23549]=0;g:{h:{if((g|0)!=1){i:{if(f){g=x[f+24>>2];x[23549]=0;P(1026,g|0,l+32|0);g=x[23549];x[23549]=0;if((g|0)!=1){break i}break h}g=Mb(l+32|0);if(b){x[23549]=0;P(b|0,g|0,c|0);g=x[23549];x[23549]=0;if((g|0)==1){break h}break i}Fs(g,l)}tb(l+32|0);break a}g=T(0)|0;break g}g=T(0)|0;tb(l+32|0)}Y(g|0)|0;x[l+28>>2]=f;x[l+24>>2]=e;x[l+20>>2]=d;x[l+16>>2]=c;x[l+12>>2]=b;x[l+8>>2]=a?a:21204;x[l+4>>2]=250;x[l>>2]=9072;HK(17425,l);Es(93232);Z()}db=l+48|0}function AK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=db-256|0;db=f;g=x[b+4>>2];a:{if(!g){break a}h=x[b>>2];i=y[Sk(h,g)|0];if((i|0)==33){e=1}else{if((i|0)!=63){break a}e=0}cl(f+96|0,h,g,g-1|0);g=x[f+100>>2];x[b>>2]=x[f+96>>2];x[b+4>>2]=g}g=f+96|0;Rd(g);h=x[f+96>>2];Rd(f+236|0);i=Rk(h,x[f+240>>2],b);Rd(g);g=x[b+4>>2];h=x[b>>2];b:{c:{d:{e:{if((i|0)==x[f+100>>2]){a=mc(f+248|0,21204);i=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=i;if(Gc(h,g,f+8|0)){e=ac(8);x[23549]=0;c=Ch(f+236|0,c,d);a=x[23549];x[23549]=0;f:{g:{h:{if((a|0)!=1){x[23549]=0;S(942,f+96|0,17211,c|0);a=x[23549];x[23549]=0;if((a|0)==1){break h}a=0;b=pc(e,f+96|0);x[23549]=0;S(105,b|0,61816,931);b=x[23549];x[23549]=0;if((b|0)!=1){break b}b=N()|0;tb(f+96|0);break g}b=N()|0;break f}b=N()|0;a=1}tb(c);if(!a){break c}}jc(e);break c}if(!e){break e}e=ac(8);a=x[b+4>>2];b=x[b>>2];x[23549]=0;g=Ch(f+212|0,b,a);a=x[23549];x[23549]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[23549]=0;S(942,f+224|0,17247,g|0);a=x[23549];x[23549]=0;if((a|0)==1){break q}x[23549]=0;P(944,f+236|0,f+224|0);b=x[23549];x[23549]=0;a=1;if((b|0)==1){break p}x[23549]=0;c=Ch(f+200|0,c,d);a=x[23549];x[23549]=0;if((a|0)==1){break o}x[23549]=0;S(946,f+96|0,f+236|0,c|0);b=x[23549];x[23549]=0;a=1;if((b|0)==1){break n}a=pc(e,f+96|0);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break b}b=N()|0;tb(f+96|0);a=0;break m}b=N()|0;break i}b=N()|0;a=1;break j}b=N()|0;break k}b=N()|0;a=1;break l}b=N()|0}tb(c)}tb(f+236|0)}tb(f+224|0)}tb(g);if(!a){break c}}jc(e);break c}b=mc(f+192|0,21204);e=x[b+4>>2];x[f+88>>2]=x[b>>2];x[f+92>>2]=e;if(Gc(h,g,f+88|0)){e=ac(8);x[23549]=0;c=Ch(f+236|0,c,d);a=x[23549];x[23549]=0;r:{s:{t:{if((a|0)!=1){x[23549]=0;S(942,f+96|0,17211,c|0);a=x[23549];x[23549]=0;if((a|0)==1){break t}a=0;b=pc(e,f+96|0);x[23549]=0;S(105,b|0,61816,931);b=x[23549];x[23549]=0;if((b|0)!=1){break b}b=N()|0;tb(f+96|0);break s}b=N()|0;break r}b=N()|0;a=1}tb(c);if(!a){break c}}jc(e);break c}b=mc(f+184|0,12211);e=x[b+4>>2];x[f+80>>2]=x[b>>2];x[f+84>>2]=e;if(Gc(h,g,f+80|0)){b=mc(f+176|0,5542);e=x[b+4>>2];x[f+32>>2]=x[b>>2];x[f+36>>2]=e;if(Gc(c,d,f+32|0)){x[a+52>>2]=0;break e}b=mc(f+168|0,11143);e=x[b+4>>2];x[f+24>>2]=x[b>>2];x[f+28>>2]=e;if(Gc(c,d,f+24|0)){x[a+52>>2]=1;break e}b=mc(f+160|0,9104);e=x[b+4>>2];x[f+16>>2]=x[b>>2];x[f+20>>2]=e;if(Gc(c,d,f+16|0)){x[a+52>>2]=2;break e}e=ac(8);x[23549]=0;c=Ch(f+236|0,c,d);a=x[23549];x[23549]=0;u:{v:{w:{if((a|0)!=1){x[23549]=0;S(942,f+96|0,14281,c|0);a=x[23549];x[23549]=0;if((a|0)==1){break w}a=0;b=pc(e,f+96|0);x[23549]=0;S(105,b|0,61816,931);b=x[23549];x[23549]=0;if((b|0)!=1){break b}b=N()|0;tb(f+96|0);break v}b=N()|0;break u}b=N()|0;a=1}tb(c);if(!a){break c}}jc(e);break c}b=mc(f+152|0,11380);e=x[b+4>>2];x[f+72>>2]=x[b>>2];x[f+76>>2]=e;if(!Gc(h,g,f+72|0)){break e}b=mc(f+144|0,15205);e=x[b+4>>2];x[f+64>>2]=x[b>>2];x[f+68>>2]=e;b=0;x:{if(Gc(c,d,f- -64|0)){break x}b=mc(f+136|0,15210);e=x[b+4>>2];x[f+56>>2]=x[b>>2];x[f+60>>2]=e;b=1;if(Gc(c,d,f+56|0)){break x}b=mc(f+128|0,12485);e=x[b+4>>2];x[f+48>>2]=x[b>>2];x[f+52>>2]=e;b=2;if(Gc(c,d,f+48|0)){break x}b=mc(f+120|0,9168);e=x[b+4>>2];x[f+40>>2]=x[b>>2];x[f+44>>2]=e;b=3;if(Gc(c,d,f+40|0)){break x}a=ac(8);x[23549]=0;c=O(54,f+96|0,11416)|0;b=x[23549];x[23549]=0;if((b|0)==1){break d}a=pc(a,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}x[a+56>>2]=b;a=x[a+24>>2];if(!x[a+24668>>2]){break e}c=a+24664|0;d=x[c+4>>2];x[f+112>>2]=x[c>>2];x[f+116>>2]=d;c=a+24656|0;d=x[c+4>>2];x[f+104>>2]=x[c>>2];x[f+108>>2]=d;c=x[a+24652>>2];x[f+96>>2]=x[a+24648>>2];x[f+100>>2]=c;j=f,k=bK(b),x[j+116>>2]=k;if(!wx(f+96|0,a+24648|0)){break e}ty(a,f+96|0)}db=f+256|0;return}b=N()|0;jc(a)}Q(b|0)}p()}function jW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=db-3056|0;db=e;wc(b);f=db-16|0;db=f;h=e+1102|0;VB(f+8|0,h);i=x[f+12>>2];j=b;lc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(i|0)){Zb(j,x[f+12>>2])}db=f+16|0;b=(b|0)==(i|0);if(!b){UB(h)}a:{if(!b){break a}if(!WB(e+1102|0)){break a}b:{if(!c){break b}if(!Lb(x[j>>2],x[j+8>>2],Qc(1024,0))){break a}TB(j,e+576|0);TB(j,e- -64|0);while(1){if((g|0)!=128){b=g<<2;f=x[b+(e+576|0)>>2];if(f>>>0>16777215){break a}b=x[b+(e- -64|0)>>2];if(b-4097>>>0<4294963202){break a}g=g+1|0;if(Gl(x[j>>2],(b+f|0)+2978|0)){continue}break a}break}Bd(a,2);Dg(a);b=e+40|0;d=Tb(b,13597);zb(a+1298344|0,d);tb(d);d=Tb(b,14420);zb(a+1298356|0,d);tb(d);b=Tb(b,15062);zb(a+1298368|0,b);tb(b);x[a+1298404>>2]=5;b=y[e+1102|0];x[a+480204>>2]=143e4;x[a+480196>>2]=b;$e(Wb(x[a+484360>>2],y[a+484376|0]),y[e+1103|0]);x[a+480188>>2]=4194317;Jb(a+1074312|0,95,1);x[a+480208>>2]=x[a+480208>>2]|16777216;d=0;g=0;while(1){if((g|0)==4){c:{while(1){d:{if((d|0)==32){g=0;break d}b=d+1|0;g=D(b,104)+a|0;i=g+484380|0;nd(i,2);h=e+20|0;Xh(h,1,(D(d,13)+e|0)+1104|0);f=e+40|0;Bc(f,h);zc(((b<<5)+a|0)+946304|0,f);tb(f);d=(e+1102|0)+(d<<4)|0;f=y[d+422|0]|y[d+423|0]<<8|(y[d+424|0]<<16|y[d+425|0]<<24);x[i>>2]=f;h=f;f=y[d+430|0]|y[d+431|0]<<8|(y[d+432|0]<<16|y[d+433|0]<<24);if(h>>>0>=f>>>0){d=y[d+426|0]|y[d+427|0]<<8|(y[d+428|0]<<16|y[d+429|0]<<24);w[g+484414>>1]=2;x[g+484388>>2]=f;x[g+484384>>2]=d}x[g+484404>>2]=8287;d=b;continue}break}while(1){if((g|0)!=32){d=g+33|0;f=(D(d,104)+a|0)+484380|0;nd(f,2);i=e+20|0;Xh(i,1,(D(g,13)+e|0)+2032|0);b=e+40|0;Bc(b,i);zc(((d<<5)+a|0)+946304|0,b);tb(b);x[e+48>>2]=0;x[e+40>>2]=0;x[e+44>>2]=0;d=(e+1102|0)+D(g,11)|0;o=Db(b,0),q=y[d+1347|0],v[o|0]=q;o=Db(b,1),q=y[d+1352|0],v[o|0]=q;o=Db(b,2),q=y[d+1348|0],v[o|0]=q;o=Db(b,3),q=y[d+1353|0],v[o|0]=q;o=Db(b,4),q=y[d+1349|0],v[o|0]=q;o=Db(b,5),q=y[d+1354|0],v[o|0]=q;o=Db(b,6),q=y[d+1350|0],v[o|0]=q;o=Db(b,7),q=y[d+1355|0],v[o|0]=q;o=Db(b,8),q=y[d+1351|0],v[o|0]=q;o=Db(b,9),q=y[d+1356|0],v[o|0]=q;o=Db(b,10),q=y[d+1346|0],v[o|0]=q;x[e+16>>2]=x[e+48>>2];b=x[e+44>>2];x[e+8>>2]=x[e+40>>2];x[e+12>>2]=b;xl(f,1,e+8|0);g=g+1|0;continue}break}Qq(Wb(x[a+484360>>2],y[a+484376|0]),e+2800|0,256,255,65535);l=a+484344|0;mg(l,128);m=c&1;f=0;while(1){e:{f:{if((f|0)!=128){b=f<<2;Vc(j,x[b+(e+576|0)>>2]+2978|0);d=e+20|0;Wd(d,j,x[b+(e- -64|0)>>2]);b=hc(e+40|0,d);ub(d);if(!m){break e}x[23549]=0;d=U(212,l|0,f&65535,64)|0;g=x[23549];x[23549]=0;if((g|0)==1){break c}if(!d){break e}g=0;i=Yb(x[l>>2],f);while(1){if(g>>>0>63){break e}d=x[b>>2];x[23549]=0;d=U(142,d|0,x[e+48>>2],1)|0;h=x[23549];x[23549]=0;g:{if((h|0)!=1){if(!d){break e}x[23549]=0;d=R(192,b|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break c}if(d>>>0>12){break g}h=$c(x[i>>2],x[x[i+48>>2]+12>>2],g,d);x[23549]=0;P(249,e+20|0,b|0);k=x[23549];x[23549]=0;if((k|0)==1){break c}k=y[e+20|0];d=d>>>0>3;v[h|0]=((k&15)+(d?13:37)|0)+D(k>>>4&7,12);k=fd(e+20|0);v[h+1|0]=((y[k|0]>>>4|0)+(d?33:1)|0)+(y[e+20|0]>>>3&16);SB(h,y[k|0],d);continue}break c}h=d-32|0;if((h&255)>>>0<=12){h=$c(x[i>>2],x[x[i+48>>2]+12>>2],g,h&65535);x[23549]=0;k=R(192,b|0)|0;n=x[23549];x[23549]=0;if((n|0)==1){break c}SB(h,k,d>>>0>35);continue}if((d|0)!=64){if((d|0)!=96){break f}if(!g){break e}o=$c(x[i>>2],x[x[i+48>>2]+12>>2],g-1|0,0),q=14,v[o+3|0]=q;break e}x[23549]=0;d=R(192,b|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break c}g=d+g|0;continue}}d=1;if(!(c&2)){break a}while(1){if((d|0)==33){break b}lg(Xc(e+40|0,8,1,0,1),(D(d,104)+a|0)+484380|0,j);d=d+1|0;continue}}ub(b);d=0;break a}ub(b);f=f+1|0;continue}}}else{w[((g<<5)+a|0)+480284>>1]=g&1?192:64;g=g+1|0;continue}break}a=N()|0;ub(b);Q(a|0);p()}d=1}db=e+3056|0;return d|0}function SM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=db-16|0;db=i;a:{b:{c:{if(!Tc(c)|!d|x[b+480180>>2]!=16777216|z[b+480192>>1]<d>>>0){break c}d=x[((d<<2)+b|0)+900380>>2];if(!d){break c}d=x[d+44>>2];if(!d){break c}w[i+14>>1]=c-61;b=db+-64|0;db=b;d:{e:{e=w[d+28>>1];f=i+14|0;c=w[f>>1];if((e|0)<=(c|0)){if((c|0)<=(oc(x[d+4>>2],x[d+8>>2])+e|0)-1<<16>>16){break e}}Gb(a);break d}f:{e=z[d+30>>1];if(!e){c=d+52|0;d=Yx(c,f);if(!xg(d,Bf(c))){break f}qg(a,td(d)+4|0);break d}e=Xx(c,e<<16>>16);w[b+62>>1]=e;c=Gb(a);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{a=d+52|0;g=Yx(a,b+62|0);t:{if(xg(g,Bf(a))){x[23549]=0;P(121,c|0,td(g)+4|0);a=x[23549];x[23549]=0;if((a|0)==1){break t}a=w[d+30>>1];d=w[f>>1];x[23549]=0;m=b,n=Vx(d,a)+5|0,x[m+36>>2]=n;P(118,b+48|0,b+36|0);a=x[23549];x[23549]=0;u:{if((a|0)!=1){x[23549]=0;O(87,c|0,b+48|0)|0;a=x[23549];x[23549]=0;if((a|0)==1){break u}tb(b+48|0);break d}a=N()|0;break g}a=N()|0;tb(b+48|0);break g}if(w[d+30>>1]>26){break q}x[23549]=0;e=U(484,b+36|0,1,e+65<<24>>24)|0;a=x[23549];x[23549]=0;if((a|0)==1){break s}x[23549]=0;S(11,b+48|0,0,e|0);a=x[23549];x[23549]=0;if((a|0)==1){break r}a=b+48|0;g=zb(c,a);tb(a);tb(e);x[23549]=0;O(119,g|0,14304)|0;a=x[23549];x[23549]=0;if((a|0)!=1){break p}}a=N()|0;break g}a=N()|0;break g}a=N()|0;tb(e);break g}x[23549]=0;j=e;a=e<<16>>16;e=(a|0)/16|0;x[b+32>>2]=j-(e<<4)<<16>>16;P(817,b+36|0,b+32|0);g=x[23549];x[23549]=0;if((g|0)==1){break o}x[23549]=0;x[b+16>>2]=(e<<16>>16)%16;P(817,b+20|0,b+16|0);e=x[23549];x[23549]=0;if((e|0)==1){break n}x[23549]=0;S(2,b+48|0,b+36|0,b+20|0);e=x[23549];x[23549]=0;if((e|0)==1){break m}e=b+48|0;h=zb(c,e);tb(e);tb(b+20|0);tb(b+36|0);if((a|0)<256){break p}x[23549]=0;S(8,b+4|0,0,h|0);a=x[23549];x[23549]=0;if((a|0)==1){break k}k=b+36|0;g=b+4|0;e=od(g);l=tf(g);j=od(g);a=db-16|0;db=a;x[a+8>>2]=j;x[a+12>>2]=e;while(1){if(Kb(e,l)){m=x[a+8>>2],n=Dp(v[e|0]),v[m|0]=n;e=Oe(a+12|0);Oe(a+8|0);e=x[e>>2];continue}break}db=a+16|0;ad(k,g);x[23549]=0;S(11,b+48|0,0,k|0);a=x[23549];x[23549]=0;if((a|0)==1){break j}a=b+48|0;zb(h,a);tb(a);tb(b+36|0);tb(b+4|0)}a=w[d+30>>1];d=w[f>>1];x[23549]=0;m=b,n=Vx(d,a)+5|0,x[m+20>>2]=n;P(118,b+48|0,b+20|0);a=x[23549];x[23549]=0;if((a|0)==1){break i}x[23549]=0;O(87,c|0,b+48|0)|0;a=x[23549];x[23549]=0;if((a|0)==1){break h}tb(b+48|0);break d}a=N()|0;break g}a=N()|0;break l}a=N()|0;tb(b+20|0)}tb(b+36|0);break g}a=N()|0;break g}a=N()|0;tb(b+36|0);tb(b+4|0);break g}a=N()|0;break g}a=N()|0;tb(b+48|0)}tb(c);Q(a|0);p()}e=db-16|0;db=e;g=e+4|0;c=db-32|0;db=c;d=Ye(c+20|0,1,0);v:{while(1){h=Mb(d);Ns(c+12|0,h,Bb(x[d+4>>2],y[d+11|0])+h|0,w[f>>1]);if(!x[c+16>>2]){break v}h=$f(Bb(x[d+4>>2],y[d+11|0]));x[23549]=0;P(58,d|0,h|0);h=x[23549];x[23549]=0;if((h|0)!=1){continue}break}break a}f=x[c+12>>2];h=Mb(d);x[23549]=0;P(59,d|0,f-h|0);f=x[23549];x[23549]=0;w:{if((f|0)!=1){x[23549]=0;P(71,g|0,d|0);f=x[23549];x[23549]=0;if((f|0)!=1){break w}break a}break a}tb(d);db=c+32|0;x[23549]=0;P(70,a|0,g|0);a=x[23549];x[23549]=0;x:{if((a|0)!=1){tb(e+4|0);db=e+16|0;break x}a=N()|0;tb(e+4|0);Q(a|0);p()}}db=b- -64|0;break b}f=x[b>>2];b=db-32|0;db=b;y:{if(Hp(c)){x[b+16>>2]=x[8040];d=x[8039];x[b+8>>2]=x[8038];x[b+12>>2]=d;d=x[8037];x[b>>2]=x[8036];x[b+4>>2]=d;Tb(a,(b+(c<<2)|0)-1004|0);break y}if(Tc(c)){d=Gb(b);x[23549]=0;c=c-1|0;e=(c|0)/12|0;c=O(818,d|0,f+(D(e,-12)+c<<16>>16<<2)|0)|0;f=x[23549];x[23549]=0;z:{if((f|0)==1){break z}x[23549]=0;c=O(819,c|0,e+48<<24>>24)|0;f=x[23549];x[23549]=0;if((f|0)==1){break z}x[23549]=0;O(3,a|0,c|0)|0;a=x[23549];x[23549]=0;if((a|0)==1){break z}tb(c);break y}break a}if(!c){Tb(a,16353);break y}Tb(a,14275)}db=b+32|0}db=i+16|0;return}a=N()|0;tb(d);Q(a|0);p()}function Ej(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;i=1;o(+b);c=j(1)|0;e=j(0)|0;a:{b:{g=c;p=c&2147483647;c:{if(!(p|e)){break c}o(+a);c=j(1)|0;f=j(0)|0;if(!f&(c|0)==1072693248){break c}q=c&2147483647;t=f;if(!(!(q>>>0>2146435072|(q|0)==2146435072&(f|0)!=0|p>>>0>2146435072)&(!e|(p|0)!=2146435072))){return a+b}d:{e:{f:{g:{h:{r=0;i:{if((c|0)>0|(c|0)>=0){break i}r=2;if(p>>>0>1128267775){break i}r=0;if(p>>>0<1072693248){break i}f=p>>>20|0;if(p>>>0<1094713344){break h}m=1075-f|0;f=e>>>m|0;r=0;if((e|0)!=f<<m){break i}r=2-(f&1)|0}m=r;if(e){break f}if((p|0)!=2146435072){break g}if(!(q-1072693248|t)){break c}if(q>>>0<1072693248){break e}return(g|0)>0|(g|0)>=0?b:0}if(e){break f}f=1043-f|0;e=p>>>f|0;if((p|0)!=e<<f){break g}m=2-(e&1)|0}if((p|0)==1072693248){if((g|0)>0|(g|0)>=0){return a}return 1/a}if((g|0)==1073741824){return a*a}if((g|0)!=1071644672|(c|0)<0){break f}return M(a)}d=F(a);if(t){break d}j:{if((c|0)<0){if((c|0)==-2147483648|(c|0)==-1074790400|(c|0)==-1048576){break j}break d}if(!c|(c|0)==2146435072){break j}if((c|0)!=1072693248){break d}}i=(g|0)<0?1/d:d;if((c|0)>0|(c|0)>=0){break c}if(!(q-1072693248|m)){a=i-i;return a/a}return(m|0)==1?-i:i}return(g|0)>0|(g|0)>=0?0:-b}k:{if((c|0)>0|(c|0)>=0){break k}l:{switch(m|0){case 0:a=a-a;return a/a;case 1:break l;default:break k}}i=-1}m:{if(p>>>0>=1105199105){if(p>>>0>=1139802113){if(q>>>0<=1072693247){return(g|0)<0?Infinity:0}return(g|0)>0?Infinity:0}if(q>>>0<=1072693246){return(g|0)<0?i*1e300*1e300:i*1e-300*1e-300}if(q>>>0>=1072693249){return(g|0)>0?i*1e300*1e300:i*1e-300*1e-300}a=d+-1;d=a*1.9259629911266175e-8+a*a*(.5-a*(a*-.25+.3333333333333333))*-1.4426950408889634;h=d;d=a*1.4426950216293335;o(+(h+d));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=h-(a-d);break m}a=d*9007199254740992;e=q>>>0<1048576;d=e?a:d;o(+a);c=j(1)|0;j(0)|0;m=e?c:q;f=m&1048575;c=f|1072693248;m=(m>>20)+(e?-1076:-1023)|0;e=0;n:{if(f>>>0<235663){break n}if(f>>>0<767610){e=1;break n}c=f|1071644672;m=m+1|0}f=((e<<18)+(c>>>1|0)|0)+537395200|0;e=e<<3;w=C[e+3536>>3];o(+d);j(1)|0;t=0;l(0,j(0)|t);l(1,c|0);k=+n();s=C[e+3520>>3];h=k-s;u=1/(s+k);d=h*u;o(+d);c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();x=a;l(0,t|0);l(1,f|0);v=a*a;y=h;h=+n();k=u*(y-a*h-a*(k-(h-s)));h=k*(d+a);a=d*d;s=h+a*a*(a*(a*(a*(a*(a*.20697501780033842+.23066074577556175)+.272728123808534)+.33333332981837743)+.4285714285785502)+.5999999999999946);o(+(v+3+s));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();h=x*a;d=k*a+d*(s-(a+-3-v));o(+(h+d));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=w+(a*-7.028461650952758e-9+(d-(a-h))*.9617966939259756);h=d;k=C[e+3552>>3];d=a*.9617967009544373;s=+(m|0);o(+(k+(h+d)+s));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=h-(a-s-k-d)}l(0,0);l(1,g|0);k=+n();d=(b-k)*a+d*b;b=a*k;a=d+b;o(+a);c=j(1)|0;g=j(0)|0;o:{if((c|0)>=1083179008){if(g|c-1083179008){break b}if(!(d+8008566259537294e-32>a-b)){break o}break b}if((c&2147482624)>>>0<1083231232){break o}if(g|c+1064252416){break a}if(!(d<=a-b)){break o}break a}e=0;f=c&2147483647;if(f>>>0>=1071644673){g=c+(1048576>>>(f>>>20|0)-1022|0)|0;f=g>>>20&2047;e=(g&1048575|1048576)>>>1043-f|0;e=(c|0)<0?0-e|0:e;l(0,0);l(1,g&-1048576>>f-1023);b=b-+n();o(+(d+b));c=j(1)|0;j(0)|0}l(0,0);l(1,c|0);a=+n();k=a*.6931471824645996;d=(d-(a-b))*.6931471805599453+a*-1.904654299957768e-9;a=k+d;b=a*a;b=a-b*(b*(b*(b*(b*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);h=a*b/(b+-2);b=a;a=d-(a-k);a=b-(h-(b*a+a))+1;o(+a);c=j(1)|0;g=j(0)|0;c=(e<<20)+c|0;p:{if((c|0)<=1048575){a=zj(a,e);break p}l(0,g|0);l(1,c|0);a=+n()}i=i*a}return i}return i*1e300*1e300}return i*1e-300*1e-300}function O$(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=db-16|0;db=h;x[h+12>>2]=b;x[e>>2]=0;Nc(h,x[d+28>>2]);x[23549]=0;i=R(18,x[h>>2])|0;j=x[23549];x[23549]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Xb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=N()|0;Xb(h);Q(a|0);p()}LG(a,f+24|0,h+12|0,c,e,i);break b}KG(a,f+16|0,h+12|0,c,e,i);break b}g=a;i=b;a=ib[x[x[a+8>>2]+12>>2]](a+8|0)|0;b=Mb(a);k=h,l=Ij(g,i,c,d,e,f,b,Bb(x[a+4>>2],y[a+11|0])+b|0),x[k+12>>2]=l;break b}a=Ni(h+12|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}x[h>>2]=623865125;x[h+4>>2]=2032480100;k=h,l=Ij(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}x[h>>2]=623728933;x[h+4>>2]=1680158061;k=h,l=Ij(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}a=Ni(h+12|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=Ni(h+12|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=Ni(h+12|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=Ni(h+12|0,c,e,i,2);b=x[e>>2];a=a-1|0;F:{if(!(b&4|a>>>0>11)){x[f+16>>2]=a;break F}x[e>>2]=b|4}break b}a=Ni(h+12|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+12|0;b=db-16|0;db=b;x[b+12>>2]=c;while(1){H:{if(Og(a,b+12|0)){break H}c=Mk(x[a>>2]);if(!ih(x[i+8>>2],1,c)){break H}Tl(a);continue}break}if(Og(a,b+12|0)){x[e>>2]=x[e>>2]|2}db=b+16|0;break b}b=h+12|0;a=ib[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Bb(x[a+4>>2],y[a+11|0])|0)==(0-Bb(x[a+16>>2],y[a+23|0])|0)){x[e>>2]=x[e>>2]|4;break I}c=Rr(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}g=y[81832]|y[81833]<<8|(y[81834]<<16|y[81835]<<24);v[h+7|0]=g;v[h+8|0]=g>>>8;v[h+9|0]=g>>>16;v[h+10|0]=g>>>24;g=y[81829]|y[81830]<<8|(y[81831]<<16|y[81832]<<24);x[h>>2]=y[81825]|y[81826]<<8|(y[81827]<<16|y[81828]<<24);x[h+4>>2]=g;k=h,l=Ij(a,b,c,d,e,f,h,h+11|0),x[k+12>>2]=l;break b}v[h+4|0]=y[81840];x[h>>2]=y[81836]|y[81837]<<8|(y[81838]<<16|y[81839]<<24);k=h,l=Ij(a,b,c,d,e,f,h,h+5|0),x[k+12>>2]=l;break b}a=Ni(h+12|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}x[h>>2]=624576549;x[h+4>>2]=1394948685;k=h,l=Ij(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}a=Ni(h+12|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=ib[x[x[a+8>>2]+24>>2]](a+8|0)|0;b=Mb(a);k=h,l=Ij(g,i,c,d,e,f,b,Bb(x[a+4>>2],y[a+11|0])+b|0),x[k+12>>2]=l;break b}JG(f+20|0,h+12|0,c,e,i);break b}a=Ni(h+12|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=db-16|0;db=a;x[a+12>>2]=c;b=6;c=h+12|0;L:{M:{if(Og(c,a+12|0)){break M}b=4;if((nn(i,Mk(x[c>>2]))|0)!=37){break M}b=2;if(!Og(Tl(c),a+12|0)){break L}}x[e>>2]=x[e>>2]|b}db=a+16|0}a=x[h+12>>2]}db=h+16|0;return a|0}function TK(){var a=0,b=0,c=0,d=0,e=0,f=0;if(y[467680]){return x[116919]}b=Pd(469320);x[b>>2]=82040;a=db-16|0;db=a;c=b+8|0;x[c>>2]=0;x[c+4>>2]=0;e=xc(c+8|0),f=0,v[e+128|0]=f;Id(a+8|0,x[vb(a+4|0,c)>>2]);x[23549]=0;W(1189,c|0);d=x[23549];x[23549]=0;a:{if((d|0)!=1){nG(c,30);d=a+8|0;Hd(d);mG(d);db=a+16|0;break a}c=N()|0;mG(a+8|0);Q(c|0);p()}x[23549]=0;d=O(54,b+152|0,13962)|0;a=x[23549];x[23549]=0;b:{c:{d:{if((a|0)!=1){lG(c);Pd(468992);x[117248]=84628;x[23549]=0;W(1156,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469e3);x[117250]=84660;x[23549]=0;W(1157,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}a=Pd(469008);v[a+12|0]=0;x[a+8>>2]=0;x[a>>2]=82060;x[a+8>>2]=82112;x[23549]=0;W(1158,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469024);x[117256]=83576;x[23549]=0;W(1159,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469032);x[117258]=83724;x[23549]=0;W(1160,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}x[23549]=0;X(1161);a=x[23549];x[23549]=0;if((a|0)==1){break d}x[23549]=0;W(1162,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469056);x[117264]=83872;x[23549]=0;W(1163,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469064);x[117266]=84104;x[23549]=0;W(1164,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469072);x[117268]=83988;x[23549]=0;W(1165,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469080);x[117270]=84220;x[23549]=0;W(1166,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}a=Pd(469088);w[a+8>>1]=11310;x[a>>2]=83192;Gb(a+12|0);x[23549]=0;W(1167,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}a=Pd(469112);x[a+8>>2]=46;x[a+12>>2]=44;x[a>>2]=83232;Gb(a+16|0);x[23549]=0;W(1168,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469144);x[117286]=84692;x[23549]=0;W(1169,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469152);x[117288]=84936;x[23549]=0;W(1170,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469160);x[117290]=85148;x[23549]=0;W(1171,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469168);x[117292]=85380;x[23549]=0;W(1172,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469176);x[117294]=86364;x[23549]=0;W(1173,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469184);x[117296]=86512;x[23549]=0;W(1174,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469192);x[117298]=86628;x[23549]=0;W(1175,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469200);x[117300]=86744;x[23549]=0;W(1176,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469208);x[117302]=86860;x[23549]=0;W(1177,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469216);x[117304]=87024;x[23549]=0;W(1178,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469224);x[117306]=87188;x[23549]=0;W(1179,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469232);x[117308]=87352;x[23549]=0;W(1180,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469240);x[117312]=88608;x[117312]=85628;x[117310]=85580;x[23549]=0;W(1181,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469256);x[117316]=88644;x[117316]=85892;x[117314]=85844;x[23549]=0;W(1182,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}x[23549]=0;X(1183);a=x[23549];x[23549]=0;if((a|0)==1){break d}x[23549]=0;W(1184,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}x[23549]=0;X(1185);a=x[23549];x[23549]=0;if((a|0)==1){break d}x[23549]=0;W(1186,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469304);x[117326]=87516;x[23549]=0;W(1187,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}Pd(469312);x[117328]=87636;x[23549]=0;W(1188,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break d}break b}b=N()|0;break c}b=N()|0;tb(d)}oG(c);Q(b|0);p()}x[116918]=469320;v[467680]=1;x[116919]=467672;return 467672}function DN(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=db-16|0;db=e;g=a+1074376|0;h=D(b,872);f=(g+h|0)+616|0;d=c&15;a:{b:{switch((c&240)-16>>>4|0){case 0:a=(a+h|0)+1075080|0;x[a>>2]=x[a>>2]&-1048577|((d|0)!=0)<<20;break a;case 1:if(!(y[a+480209|0]&16)){break a}if(gj(x[f+656>>2])){a=D(b,872)+a|0;w[a+1075764>>1]=d-8;a=a+1075843|0;v[a|0]=y[a|0]|64;break a}if(x[a+480180>>2]!=64){b=D(b,872)+a|0;c=d<<28>>24;w[b+1075764>>1]=c;f=z[(d<<1)+33504>>1];x[b+1075696>>2]=f;d=b+1075692|0;if(!x[d>>2]){break a}k=d,l=Rg(a,y[b+1075789|0],c,f),x[k>>2]=l;break a}a=D(b,872)+a|0;b=x[a+1075096>>2];if(!b){break a}x[a+1075696>>2]=x[b+24>>2]+D(d,80);break a;case 2:if(x[a+480180>>2]==2){v[(D(b,872)+a|0)+1075814|0]=c&3;break a}Fb(e+8|0,a+1074312|0,21);if(Ib(x[x[e+8>>2]>>2],x[e+12>>2])){v[(D(b,872)+a|0)+1075814|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075814|0]=c&7;break a;case 3:if(x[a+480180>>2]==2){v[(D(b,872)+a|0)+1075817|0]=c&3;break a}Fb(e+8|0,a+1074312|0,21);if(Ib(x[x[e+8>>2]>>2],x[e+12>>2])){v[(D(b,872)+a|0)+1075817|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075817|0]=c&7;break a;case 4:Fb(e+8|0,a+1074312|0,21);if(Ib(x[x[e+8>>2]>>2],x[e+12>>2])){a=D(b,872)+a|0;v[a+1075813|0]=0;v[a+1075820|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075820|0]=c&7;break a;case 5:if(x[a+1074392>>2]|!(y[a+480209|0]&16)){break a}a=a+1074400|0;x[a>>2]=x[a>>2]+d;break a;case 6:if(!(y[a+480209|0]&16)){break a}if(d>>>0<=2){c=z[a+480188>>1];h=c>>>0<=256?256:c;i=b+1|0;j=d-1|0;while(1){if((c|0)==(h|0)){break a}f=D(c,872)+a|0;c:{if(z[f+1075778>>1]!=(i|0)){break c}d:{e:{switch(j|0){case 0:$n(a,f+1074992|0);if(!(y[f+1075081|0]&2)){break d}d=x[a+1298300>>2];if(!ud(d)){break d}Rj(d,c&65535);break d;case 1:g=f+1075080|0;d=x[g>>2];x[g>>2]=d|4096;if(!(d&512)){break d}d=x[a+1298300>>2];if(!ud(d)){break d}Rj(d,c&65535);break d;default:break e}}x[f+1075688>>2]=0;g=f+1075080|0;d=x[g>>2];x[g>>2]=d|4096;if(!(d&512)){break d}d=x[a+1298300>>2];if(!ud(d)){break d}aj(d,c&65535,1)}d=x[f+1075648>>2];if(!d){break c}g=y[d+34|0];if(!g){break c}g=x[(D(g,160)+a|0)+906140>>2];if(!g){break c}ib[x[x[g>>2]+92>>2]](g,d,y[f+1075789|0]+255|0,0,b)}c=c+1|0;continue}}gQ(f,d,x[a+480180>>2]);break a;case 7:if(!(y[a+480209|0]&16)){break a}im(a,f,d,4);break a;case 8:b=f;c=x[a+480208>>2];f:{if(!(c&4096)){break f}g:{switch(d|0){case 0:x[b+88>>2]=x[b+88>>2]&-257;break f;case 1:x[b+692>>2]=128;x[b+88>>2]=x[b+88>>2]|256;break f;case 8:x[b+88>>2]=x[b+88>>2]&-25165825|16777216;break f;case 9:x[b+88>>2]=x[b+88>>2]&-25165825|8388608;break f;case 10:x[a+480208>>2]=c&-16385;break f;case 11:x[a+480208>>2]=c|16384;break f;case 12:x[a+480208>>2]=c&-8193;break f;case 13:x[a+480208>>2]=c|8192;break f;case 14:x[b+88>>2]=x[b+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(x[b>>2]|x[b+4>>2]){break h}a=x[b+76>>2];if(!a){break h}if(!(k=Tc(y[b+788|0]),l=1,m=y[b+88|0]&2,m?k:l)){break h}x[b>>2]=-1;x[b+4>>2]=a-1}x[b+88>>2]=x[b+88>>2]|128}break a;case 9:if(!(y[a+480209|0]&16)){break a}c=D(b,872)+a|0;v[c+1075828|0]=d;Fb(e+8|0,a+1074312|0,35);if(Ib(x[x[e+8>>2]>>2],x[e+12>>2])){break a}if(!Tc(y[c+1075780|0])){break a}b=x[(D(b,872)+a|0)+1075068>>2];a=d<<16;if(b>>>0<=a>>>0){break a}x[f+4>>2]=a;break a;case 10:if(!(y[a+480209|0]&16)){break a}Wy(a,g,b,d);break a;case 11:i:{if(d){break i}d=1;c=x[a+480180>>2];if(c&16777248){break i}d=0;if((c|0)==2){break a}}Fb(e+8|0,a+1074312|0,30);Ky(a,b,d,Ib(x[x[e+8>>2]>>2],x[e+12>>2])|x[a+480180>>2]==2);break a;case 14:break b;default:break a}}if(x[a+480180>>2]==2){break a}v[(D(b,872)+a|0)+1075836|0]=d}db=e+16|0}function YW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=db-560|0;db=e;wc(b);d=db-16|0;db=d;f=e+63|0;SC(d+8|0,f);g=x[d+12>>2];lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);j=x[d+4>>2];if((j|0)==(g|0)){Zb(b,x[d+12>>2])}db=d+16|0;d=(g|0)==(j|0);if(!d){RC(f)}a:{if(!d){break a}if(!VC(e+63|0)){break a}b:{if(!c){break b}if(!Lb(x[b>>2],x[b+8>>2],Qc(UC(y[e+173|0],y[e+174|0]),hb))){break a}Bd(a,64);x[a+480204>>2]=78e4;x[a+480260>>2]=112;x[a+480264>>2]=13696;x[a+480196>>2]=4;w[a+480188>>1]=8;Jb(a+1074312|0,7,1);d=e+36|0;g=Tb(d,14317);zb(a+1298344|0,g);tb(g);d=Tb(d,14350);zb(a+1298356|0,d);tb(d);Wc(a+1298368|0,(y[e+63|0]|y[e+64|0]<<8)==26217?14317:14345);x[a+1298404>>2]=5;f=y[e+173|0];w[a+480190>>1]=f;g=1;while(1){j=g&65535;if(j>>>0<=f>>>0){f=db-16|0;db=f;d=e+36|0;dc(f+8|0,d,25);l=x[f+12>>2];lc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);i=x[f+4>>2];if((i|0)==(l|0)){Zb(b,x[f+12>>2])}db=f+16|0;if((i|0)!=(l|0)){v[d|0]=0;v[d+1|0]=0;v[d+2|0]=0;v[d+3|0]=0;v[d+4|0]=0;v[d+5|0]=0;v[d+6|0]=0;v[d+7|0]=0;v[d+24|0]=0;v[d+16|0]=0;v[d+17|0]=0;v[d+18|0]=0;v[d+19|0]=0;v[d+20|0]=0;v[d+21|0]=0;v[d+22|0]=0;v[d+23|0]=0;v[d+8|0]=0;v[d+9|0]=0;v[d+10|0]=0;v[d+11|0]=0;v[d+12|0]=0;v[d+13|0]=0;v[d+14|0]=0;v[d+15|0]=0}if((y[e+49|0]|y[e+50|0]<<8|(y[e+51|0]<<16|y[e+52|0]<<24))>>>0>67108863){break a}f=(D(j,104)+a|0)+484380|0;nd(f,0);x[f+24>>2]=8363;l=e+36|0;d=l;i=y[d+13|0]|y[d+14|0]<<8|(y[d+15|0]<<16|y[d+16|0]<<24);x[f>>2]=i;k=y[d+17|0]|y[d+18|0]<<8|(y[d+19|0]<<16|y[d+20|0]<<24);x[f+4>>2]=k;d=y[d+21|0]|y[d+22|0]<<8|(y[d+23|0]<<16|y[d+24|0]<<24);x[f+8>>2]=d;c:{if(!(k|d>>>0<=i>>>0)){x[f+8>>2]=0;break c}if(d){w[f+34>>1]=2;ok(f)}}f=e+12|0;Xh(f,2,l);d=e+24|0;Bc(d,f);zc(((j<<5)+a|0)+946304|0,d);g=g+1|0;tb(d);f=z[a+480190>>1];continue}break}g=e+24|0;h=e+65|0;Tf(g,3,h,36);d=e+36|0;Bc(d,g);zb(a+1298308|0,d);tb(d);g=0;QC(a+1298332|0,h,108,36,0);d=a+484376|0;av(Wb(x[a+484360>>2],y[d|0]),e+176|0,128,255,254);d=Wb(x[a+484360>>2],y[d|0]);h=y[e+175|0];if(z[_b(x[d>>2],h)>>1]<y[e+174|0]){$e(d,h)}while(1)if((g|0)==8){j=a+484344|0;mg(j,y[e+174|0]);n=c&1;f=0;while(1)if(y[e+174|0]<=f>>>0){h=1;if(!(c&2)){break a}c=Xc(e+36|0,8,1,0,1);g=1;while(1){d=g&65535;if(d>>>0>z[a+480190>>1]){break b}lg(c,(D(d,104)+a|0)+484380|0,b);g=g+1|0;continue}}else{d:{e:{if(n){if($g(j,f&65535,64)){break e}}Zb(b,1536);break d}x[e+24>>2]=-1;x[e+28>>2]=-1;l=0;f:while(1){if((l|0)==64){d=x[j>>2];g=(e+63|0)+f|0;h=y[g+369|0];if(h>>>0<63){me(Yb(d,f),wh(Fe(Be(e+36|0,14,0),h)));d=x[j>>2]}me(Yb(d,f),wh(Be(e+36|0,16,y[g+241|0])));break d}g=0;d=Yb(x[j>>2],f);h=sf(x[d>>2],x[x[d+48>>2]+12>>2],l);while(1){if((g|0)==8){l=l+1|0;continue f}d=e+36|0;Sq(d,b);i=fd(d);k=Ue(d);i=y[i|0];d=y[e+36|0];if(d>>>0<=253){v[h|0]=(d>>>2|0)+37;v[h+1|0]=(d<<4&48|i>>>4)+1;v[(e+24|0)+g|0]=255;d=y[e+36|0]}if((d&255)!=255){v[h+2|0]=1;v[h+4|0]=(((i&15)<<6|8)>>>0)/15}d=y[k|0];if((d|0)!=255){v[(e+24|0)+g|0]=d}i=(e+24|0)+g|0;g:{h:{if(!(d&15)&(d|0)!=48){break h}k=y[i|0];if((k|0)==255){break g}m=k<<24>>24;d=m&15;v[h+5|0]=d;i:{if((m|0)<0){break i}k=k>>>4|0;v[h+3|0]=y[k+26232|0];j:{switch(k-3|0){case 0:v[h+5|0]=d|32;break h;case 1:v[h+5|0]=d|m<<4;break g;case 2:break h;case 3:break j;default:break g}}k:{switch(d|0){case 0:v[h+5|0]=79;break g;case 1:break k;default:break i}}v[h+5|0]=244;break g}v[h+3|0]=0;break g}v[i|0]=255}h=h+6|0;g=g+1|0;continue}}}f=f+1|0;continue}}else{d=(g<<5)+a|0;Te(d+480280|0);w[d+480284>>1]=g&1?208:48;g=g+1|0;continue}}h=1}db=e+560|0;return h|0}function H6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=db-112|0;db=f;g=x[b+4>>2];h=y[b+11|0];a:{if(xd(g,h)){break a}e=y[eK(b)|0];if((e|0)==33){d=1}else{if((e|0)!=63){break a}d=0}e=f+100|0;yr(e,b,0,Oc(g,h)-1|0);zb(b,e);tb(e)}g=f+100|0;Rd(g);e=x[f+100>>2];Rd(f+88|0);e=dK(e,x[f+92>>2],b);Rd(g);b:{c:{d:{e:{if((e|0)==x[f+104>>2]){if(ie(b,21204)){a=ac(8);x[23549]=0;S(933,f+100|0,17211,c|0);b=x[23549];x[23549]=0;if((b|0)==1){break d}a=pc(a,f+100|0);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break b}b=N()|0;tb(f+100|0);break c}if(!d){break e}a=ac(8);x[23549]=0;S(933,f+76|0,17247,b|0);b=x[23549];x[23549]=0;f:{g:{h:{i:{j:{if((b|0)!=1){x[23549]=0;P(944,f+88|0,f+76|0);b=x[23549];x[23549]=0;if((b|0)==1){break j}x[23549]=0;S(486,f+100|0,f+88|0,c|0);b=x[23549];x[23549]=0;d=1;if((b|0)==1){break i}b=pc(a,f+100|0);x[23549]=0;S(105,b|0,61816,931);b=x[23549];x[23549]=0;if((b|0)!=1){break b}b=N()|0;tb(f+100|0);d=0;break h}b=N()|0;break f}b=N()|0;d=1;break g}b=N()|0}tb(f+88|0)}tb(f+76|0);if(!d){break c}}jc(a);break c}k:{switch(x[e+4>>2]){case 0:ze(f+68|0,b);b=db-176|0;db=b;e=b+12|0;lh(e,c);x[23549]=0;P(77,b+24|0,e|0);c=x[23549];x[23549]=0;l:{m:{n:{o:{p:{if((c|0)!=1){x[23549]=0;c=O(78,b+36|0,b+24|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break p}tb(b+24|0);tb(b+12|0);e=x[x[c>>2]-12>>2];x[23549]=0;g=ca(61)|0;h=x[23549];x[23549]=0;if((h|0)==1){break n}x[23549]=0;S(62,b+8|0,c+e|0,g|0);e=x[23549];x[23549]=0;if((e|0)==1){break n}Xb(b+8|0);x[23549]=0;e=O(82,c|0,b+24|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break n}c=Pk(x[(e+x[x[e>>2]-12>>2]|0)+16>>2]);g=x[b+24>>2];mf(e);db=b+176|0;b=(c^-1)&(g|0)!=0;break l}a=N()|0;break o}a=N()|0;tb(b+24|0)}tb(b+12|0);break m}a=N()|0;mf(c)}Q(a|0);p()}c=x[f+72>>2];x[f>>2]=x[f+68>>2];x[f+4>>2]=c;DK(a,f,b,d);break e;case 1:ze(f+60|0,b);b=db-176|0;db=b;e=b+12|0;lh(e,c);x[23549]=0;P(77,b+24|0,e|0);c=x[23549];x[23549]=0;q:{r:{s:{t:{u:{if((c|0)!=1){x[23549]=0;c=O(78,b+36|0,b+24|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break u}tb(b+24|0);tb(b+12|0);e=x[x[c>>2]-12>>2];x[23549]=0;g=ca(61)|0;h=x[23549];x[23549]=0;if((h|0)==1){break s}x[23549]=0;S(62,b+8|0,c+e|0,g|0);e=x[23549];x[23549]=0;if((e|0)==1){break s}Xb(b+8|0);x[23549]=0;e=O(84,c|0,b+24|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break s}c=Pk(x[(e+x[x[e>>2]-12>>2]|0)+16>>2]);g=x[b+24>>2];h=x[b+28>>2];mf(e);db=b+176|0;b=c?0:g;c=c?0:h;break q}a=N()|0;break t}a=N()|0;tb(b+24|0)}tb(b+12|0);break r}a=N()|0;mf(c)}Q(a|0);p()}e=x[f+64>>2];x[f+8>>2]=x[f+60>>2];x[f+12>>2]=e;BK(a,f+8|0,b,c,d);break e;case 2:ze(f+52|0,b);b=db-176|0;db=b;e=b+12|0;lh(e,c);x[23549]=0;P(77,b+24|0,e|0);c=x[23549];x[23549]=0;v:{w:{x:{y:{z:{if((c|0)!=1){x[23549]=0;c=O(78,b+36|0,b+24|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break z}tb(b+24|0);tb(b+12|0);e=x[x[c>>2]-12>>2];x[23549]=0;g=ca(61)|0;h=x[23549];x[23549]=0;if((h|0)==1){break x}x[23549]=0;S(62,b+8|0,c+e|0,g|0);e=x[23549];x[23549]=0;if((e|0)==1){break x}Xb(b+8|0);x[23549]=0;e=O(85,c|0,b+24|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break x}c=Pk(x[(e+x[x[e>>2]-12>>2]|0)+16>>2]);i=C[b+24>>3];mf(e);db=b+176|0;i=c?0:i;break v}a=N()|0;break y}a=N()|0;tb(b+24|0)}tb(b+12|0);break w}a=N()|0;mf(c)}Q(a|0);p()}b=x[f+56>>2];x[f+16>>2]=x[f+52>>2];x[f+20>>2]=b;CK(a,f+16|0,i,d);break e;case 3:break k;default:break e}}ze(f+44|0,b);ze(f+32|0,c);b=x[f+48>>2];x[f+24>>2]=x[f+44>>2];x[f+28>>2]=b;AK(a,f+24|0,x[f+32>>2],x[f+36>>2],d)}db=f+112|0;return}b=N()|0;jc(a)}Q(b|0)}p()}function jja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=db-960|0;db=e;wc(b);d=db-16|0;db=d;h=e+862|0;PU(d+8|0,h);f=x[d+12>>2];lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){Zb(b,x[d+12>>2])}db=d+16|0;d=(f|0)==(g|0);if(!d){OU(h)}a:{if(!d){break a}if(!RU(e+862|0)){break a}if(!Lb(x[b>>2],x[b+8>>2],Qc(QU(y[e+909|0]|y[e+910|0]<<8),hb))){break a}if(!c){l=1;break a}Bd(a,512);x[a+480228>>2]=32;w[a+480188>>1]=16;x[a+480196>>2]=y[e+937|0];x[a+480208>>2]=16;x[a+480200>>2]=256;x[a+480204>>2]=8e5;Jb(a+1074312|0,7,1);d=e+88|0;f=Tb(d,8122);zb(a+1298344|0,f);tb(f);f=Tb(d,8810);zb(a+1298356|0,f);tb(f);x[a+1298404>>2]=5;f=e+12|0;NU(f,e+866|0);Bc(d,f);zb(a+1298308|0,d);tb(d);d=0;while(1){if((d|0)==16){b:{d=y[e+958|0]|y[e+959|0]<<8;if(d){EB(a+1298332|0,b,d,132,0)}d=db-16|0;db=d;h=e+88|0;dc(d+8|0,h,771);f=x[d+12>>2];lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){Zb(b,x[d+12>>2])}db=d+16|0;l=(f|0)==(g|0);if(!l){Vb(h,0,771)}if(!l){break a}d=a+484376|0;MU(Wb(x[a+484360>>2],y[d|0]),e+88|0,y[e+345|0]);$e(Wb(x[a+484360>>2],y[d|0]),y[e+346|0]);Vc(b,y[e+909|0]|y[e+910|0]<<8);o=a+484344|0;q=c&1;h=0;while(1){c:{if((h|0)==256){if(!(c&2)){break a}$V(b,e+60|0);d=0;while(1){if((d|0)==64){break a}if(!(y[e+60+(d>>>3)|0]>>>(d&7)&1)){d=d+1|0;continue}if(!mB(b,e+12|0)){break a}d=d+1|0;w[a+480190>>1]=d;_e(e,1,e+12|0);h=e+68|0;Bc(h,e);zc(((z[a+480190>>1]<<5)+a|0)+946304|0,h);tb(h);c=(D(d,104)+a|0)+484380|0;nd(c,0);i=y[e+44|0]|y[e+45|0]<<8|(y[e+46|0]<<16|y[e+47|0]<<24);x[c>>2]=i;f=y[e+50|0]|y[e+51|0]<<8|(y[e+52|0]<<16|y[e+53|0]<<24);x[c+4>>2]=f;g=y[e+54|0]|y[e+55|0]<<8|(y[e+56|0]<<16|y[e+57|0]<<24);x[c+24>>2]=16726;x[c+8>>2]=g;w[c+30>>1]=y[e+49|0]<<4;if(v[e+58|0]&1){g=g>>>1|0;x[c+8>>2]=g;f=f>>>1|0;x[c+4>>2]=f;x[c>>2]=i>>>1}if(!(!(y[e+59|0]&8)|f>>>0>=g>>>0)){w[c+34>>1]=z[c+34>>1]|2}Xc(h,v[e+58|0]&1?16:8,1,0,0);lg(h,c,b);continue}}d:{d=(h<<1)+e|0;g=y[d+347|0]|y[d+348|0]<<8;if(g){f=e+68|0;Wd(f,b,g);i=hc(e+12|0,f);ub(f);n=((y[d+347|0]|y[d+348|0]<<8)-2|0)/64|0;e:{if(!q){break e}x[23549]=0;d=U(212,o|0,h&65535,n|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break d}if(!d){break e}x[23549]=0;d=R(192,i|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break b}x[23549]=0;O(174,i|0,1)|0;f=x[23549];x[23549]=0;if((f|0)==1){break b}r=d?d>>>0>=n-2>>>0?-1:d+1|0:-1;f=0;f:while(1){g:{d=Yb(x[o>>2],h);if((f|0)==(n|0)){break g}m=0;s=sf(x[d>>2],x[x[d+48>>2]+12>>2],f);while(1){if((m|0)==16){f=f+1|0;continue f}x[23549]=0;P(341,e+68|0,i|0);d=x[23549];x[23549]=0;if((d|0)==1){break c}d=D(m,6)+s|0;j=e+68|0;g=Ue(j);j=Ai(j);k=y[e+68|0];if((k-1&255)>>>0<=71){v[d|0]=k+36;t=d,u=y[fd(e+68|0)|0]+1|0,v[t+1|0]=u}if((y[g|0]-1&255)>>>0<=15){v[d+2|0]=1;v[d+4|0]=((y[g|0]<<6)+-64>>>0)/15}k=y[j|0];g=k&15;v[d+5|0]=g;h:{i:{switch((y[j|0]>>>4|0)-1|0){case 0:case 1:v[d+5|0]=k|240;break h;case 2:v[d+5|0]=g<<2;break h;case 3:v[d+5|0]=(6/(g+1>>>0)|0)+1;break h;case 5:case 6:v[d+5|0]=g<<3;break h;case 9:v[d+4|0]=(g<<2)+4;v[d+2|0]=1;break h;case 10:v[d+5|0]=g|128;break h;case 11:break i;default:break h}}v[d+5|0]=(6/(g+1>>>0)|0)+1|13}v[d+3|0]=y[(y[j|0]>>>4|0)+26448|0];m=m+1|0;continue}}break}me(d,wh(Fe(Be(e+68|0,14,0),r)))}ub(i)}h=h+1|0;continue}}break}}}else{f=(d<<5)+a|0;h=f+480280|0;Te(h);g=h;h=(e+862|0)+d|0;x[g>>2]=!y[h+50|0]<<10;w[f+480284>>1]=(y[h+76|0]<<4|8)&248;d=d+1|0;continue}break}a=N()|0;ub(i);Q(a|0);p()}db=e+960|0;return l|0}function pea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=db-176|0;db=e;a:{b:{if(Lb(x[c>>2],x[c+8>>2],8)){Zb(c,4);while(1){if(gu(x[c>>2],x[c+8>>2])){break b}m=db-288|0;db=m;h=zP(m+6|0);i=db-368|0;db=i;f=rc(h,zP(i+80|0),282);h=0;c:{d:{e:{f:{g:{if(Bi(c,13432)){ng(c,4);l=le(i+60|0,c);x[23549]=0;j=O(732,l|0,f|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break g}h:{if(!j){break h}j=x[l+8>>2];g=x[l>>2];k=y[f+26|0];x[23549]=0;j=U(142,g|0,j|0,k|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break g}if(!j){break h}j=0;i:{while(1){if(y[f+26|0]<=h>>>0){g=x[l+8>>2];k=x[l>>2];h=0;x[23549]=0;j=j&65535;g=U(142,k|0,g|0,j|0)|0;k=x[23549];x[23549]=0;if((k|0)==1){break e}if(!g){break h}x[23549]=0;O(174,l|0,j|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break e}ng(l,AP(f));h=xc(i+56|0);g=i+80|0;rz(g);x[23549]=0;P(733,l|0,g|0);g=x[23549];x[23549]=0;if((g|0)!=1){w[i+102>>1]=0;w[i+104>>1]=0;h=sz(h,i+80|0,i+107|0);g=y[f+26|0];x[23549]=0;O(174,l|0,g|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){break i}}h=N()|0;break d}x[23549]=0;g=R(184,l|0)|0;k=x[23549];x[23549]=0;if((k|0)!=1){v[(f+h|0)+27|0]=g;h=h+1|0;j=g+j|0;continue}break}h=N()|0;break d}k=h;h=f+27|0;k=sz(k,h,h+y[f+26|0]|0);x[23549]=0;S(176,i+16|0,l|0,j|0);h=x[23549];x[23549]=0;if((h|0)==1){break f}g=i+16|0;j=hc(i+36|0,g);ub(g);h=0;x[23549]=0;P(519,g|0,j|0);g=x[23549];x[23549]=0;if((g|0)==1){h=N()|0;ub(j);break d}g=i+16|0;lC(i+8|0,g);n=k;k=x[i+8>>2];k=sz(n,k,Db(k,x[i+12>>2]));Jc(g);ub(j);if(x[k>>2]!=(y[f+22|0]|y[f+23|0]<<8|(y[f+24|0]<<16|y[f+25|0]<<24))){break h}h=AP(f);x[23549]=0;O(174,c|0,h|0)|0;f=x[23549];x[23549]=0;h=1;if((f|0)==1){break e}}ub(l)}db=i+368|0;break c}h=N()|0;break d}h=N()|0;break d}h=N()|0}ub(l);Q(h|0);p()}db=m+288|0;if(h){continue}break}}wc(c);lg(b,a,c);a=1;break a}v[d|0]=1;wc(c);i=pg(c);d=e+136|0;Wd(d,c,rf(c));h=hc(e+156|0,d);ub(d);c=z[a+34>>1]&-66|y[b|0]>15;b=y[b+1|0]!=1;c=c|b<<6;w[a+34>>1]=c;x[a>>2]=i>>>(c&1)>>>b;x[e+132>>2]=0;x[e+128>>2]=0;x[23549]=0;P(519,d|0,h|0);b=x[23549];x[23549]=0;j:{k:{l:{m:{if((b|0)!=1){c=Ee(e+136|0);d=x[e+136>>2];i=DA(c,Hh(d),e+132|0,e+128|0);x[23549]=0;b=x[e+132>>2];O(174,h|0,b|0)|0;f=x[23549];x[23549]=0;if((f|0)!=1){if(!i){break j}zg(a);l=b+c|0;d=d-b|0;b=x[e+128>>2];c=0;while(1){n:{if(b){if(!d|(b|0)!=1){break k}b=x[a>>2];if(c>>>0<b>>>0){break n}break k}b=x[a>>2];if(c>>>0>=b>>>0){break k}}if(!Sd(b,x[a+20>>2])){break k}x[e+124>>2]=0;x[e+120>>2]=0;j=cT(i,l,Hh(d),e+124|0,e+116|0,e+120|0);x[23549]=0;O(174,h|0,j|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break m}Zh(e+120|0,Hh(x[a>>2]-c|0));b=x[e+120>>2];o:{if((b|0)<=0){break o}f=x[e+124>>2];k=z[a+34>>1];if((Jd(k)|0)!=(f|0)){break o}m=D(c,f);g=x[a+20>>2];if(k&1){f=rd(e+104|0,g+(m<<1)|0,f,b);m=rd(e+92|0,x[e+116>>2],x[e+124>>2],b);x[23549]=0;x[e- -64>>2]=x[f+8>>2];g=x[f+4>>2];x[e+56>>2]=x[f>>2];x[e+60>>2]=g;x[e+48>>2]=x[m+8>>2];f=x[m+4>>2];x[e+40>>2]=x[m>>2];x[e+44>>2]=f;P(520,e+56|0,e+40|0);f=x[23549];x[23549]=0;if((f|0)!=1){break o}break m}f=rd(e+80|0,g+m|0,f,b);m=rd(e+68|0,x[e+116>>2],x[e+124>>2],b);x[23549]=0;x[e+32>>2]=x[f+8>>2];g=x[f+4>>2];x[e+24>>2]=x[f>>2];x[e+28>>2]=g;x[e+16>>2]=x[m+8>>2];f=x[m+4>>2];x[e+8>>2]=x[m>>2];x[e+12>>2]=f;P(521,e+24|0,e+8|0);f=x[23549];x[23549]=0;if((f|0)==1){break m}}d=d-j|0;l=j+l|0;c=b+c|0;b=bT(i);continue}}break m}c=N()|0;break l}c=N()|0;Jc(e+136|0)}ub(h);Q(c|0);p()}aT(i)}Jc(e+136|0);ub(h);a=(i|0)!=0}db=e+176|0;return a|0}function Iy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,B=0,C=0,E=0;f=db-16|0;db=f;k=D(b,872)+a|0;m=k+1075800|0;i=y[m|0];l=a+1074312|0;Fb(f+8|0,l,23);h=c&15;a:{b:{c:{d:{e:{f:{g:{h:{i:{if(Ib(x[x[f+8>>2]>>2],x[f+12>>2])){if(!(x[a+1074392>>2]|!y[(D(b,872)+a|0)+1075780|0])){v[m|0]=h;break i}e=y[m|0];if(e){g=e-1|0;v[m|0]=g;e=0;if(g&255){break c}}v[m|0]=h;e=1;break c}Fb(f+8|0,l,52);g=c&256;if(!(!g|!Ib(x[x[f+8>>2]>>2],x[f+12>>2]))){g=x[a+480208>>2]&4096;if(!g){break e}e=D(b,872)+a|0;if(y[e+1075781|0]){i=wU(y[e+1075780|0])?1:i}if(y[(D(b,872)+a|0)+1075784|0]?y[e+1075782|0]==1:0){break b}e=0;if(h>>>0>i>>>0){break c}if(!g){break d}if(Tc(y[(D(b,872)+a|0)+1075780|0])){break c}break d}j=x[a+480180>>2];if(j&16777250){e=!(i?(i>>>0)%((h>>>0<=1?1:h)>>>0)|0:1);i=i+1|0;break c}if((j|0)==16){break g}if((j|0)!=1){break f}e=A[a+1074392>>2]%A[a+1074416>>2]|0;if(!e){if(Tc(y[(D(b,872)+a|0)+1075780|0])){break a}}if(h){break h}}e=0;break c}e=!((e>>>0)%(h>>>0)|0);break c}e=x[a+1074392>>2]==(h|0)&(h|0)!=0;break c}j:{if(!g){break j}e=D(b,872)+a|0;if(y[e+1075782|0]!=1){break j}h=(y[e+1075785|0]>15)+h|0}k:{if(x[a+480208>>2]&4096?g:1){h=h>>>0<=1?1:h;e=0;e=!x[a+1074416>>2]|g?e:!(A[a+1074392>>2]%(h>>>0)|0);i=i+1|0;break k}e=0;i=j&1048580?0:i}if(!(!(y[(D(b,872)+a|0)+1075780|0]|!g?x[a+1074392>>2]:1)|(i&255)>>>0<h>>>0)){e=1}Fb(f+8|0,l,52);if(!Ib(x[x[f+8>>2]>>2],x[f+12>>2])|c){break c}e=!x[a+1074392>>2];break c}if(h>>>0>i>>>0){break c}}i=0;e=1}h=k+1074992|0;n=(D(b,872)+a|0)+1075068|0;l:{if(x[n>>2]){break l}Fb(f+8|0,l,38);if(!Ib(x[x[f+8>>2]>>2],x[f+12>>2])){break l}if(!Pj(x[h+656>>2])){break a}}Fb(f+8|0,l,106);if(B=0,C=Ib(x[x[f+8>>2]>>2],x[f+12>>2]),E=x[(D(b,872)+a|0)+1075688>>2],E?B:C){break a}if(e){j=D(b,872)+a|0;q=j+1075680|0;g=x[q>>2];x[f+4>>2]=g;e=c>>>4&15;m:{if(!e){e=x[j+1075080>>2];break m}Fb(f+8|0,l,52);n:{if(B=Ib(x[x[f+8>>2]>>2],x[f+12>>2]),C=0,E=y[(D(b,872)+a|0)+1075782|0]==1,E?B:C){break n}if(!(16191>>>e&1)){x[f+4>>2]=(D(g,v[e+33920|0])|0)/16;break n}x[f+4>>2]=g+(v[e+33936|0]<<2)}ke(f+4|0,0,256);g=(D(b,872)+a|0)+1075080|0;e=x[g>>2]|2097152;x[g>>2]=e}k=D(b,872)+a|0;r=k+1075692|0;s=x[r>>2];g=y[k+1075794|0];j=0;if(e&512){Fb(f+8|0,l,108);j=Ib(x[x[f+8>>2]>>2],x[f+12>>2])}if(!((j^-1)&x[a+480180>>2]==2|(!x[n>>2]|(g-1&255)>>>0>119))){KN(a,b,0,g,1)}k=k+1075080|0;o:{if(!(x[a+480180>>2]&1048580)){break o}t=(c|0)<256;if((c|0)>255){break o}e=y[(D(b,872)+a|0)+1075781|0];if(!e){break o}t=1;Pp(a,h,e,0,0,1)}o=D(b,872)+a|0;p=o+1075652|0;u=x[p>>2];w=x[k>>2];x[p>>2]=0;Fb(f+8|0,l,23);e=1;p:{if(Ib(x[x[f+8>>2]>>2],x[f+12>>2])){break p}e=0;if(x[a+480180>>2]!=2){break p}e=(j^1)&x[n>>2]!=0}ht(a,h,g,e,t,0,b);if(!y[o+1075781|0]){x[p>>2]=u}if(!(!(w&4096)|x[a+480180>>2]!=4)){x[k>>2]=x[k>>2]|4096}j=o+1075780|0;x[q>>2]=x[f+4>>2];if(z[a+480192>>1]){v[j|0]=g;HN(a,b)}g=x[a+480180>>2];if(!(!(g&16777248)|(y[j|0]|!s))){x[r>>2]=s}if(e){x[h>>2]=0;x[h+4>>2]=0}e=g&16777250;q:{if(d-11>>>0<4294967286){break q}g=x[(D(b,872)+a|0)+1075096>>2];if(!g){break q}r:{if((d|0)==1){b=x[(D(b,872)+a|0)+1075656>>2];break r}j=(D(b,872)+a|0)+1075656|0;b=x[xb(g+68|0,d-2|0)>>2];x[j>>2]=b}fo(a,h,b)}i=e?i:0}a=f+8|0;Fb(a,l,52);b=x[x[f+8>>2]>>2];d=x[f+12>>2];Fb(a,l,23);if(Ib(x[x[f+8>>2]>>2],x[f+12>>2])){break a}i=(Ib(b,d)&c>>>8)+i|0}v[m|0]=i}db=f+16|0}function Nba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=db-96|0;db=e;g=a+140|0;mj(e+76|0,g,1296125513);x[23549]=0;f=R(164,x[e+76>>2])|0;h=x[23549];x[23549]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((h|0)!=1){if(f){f=Gb(e+28|0);x[23549]=0;h=R(146,x[e+76>>2])|0;i=x[23549];x[23549]=0;if((i|0)==1){break p}x[23549]=0;S(753,e+76|0,f|0,h|0);h=x[23549];x[23549]=0;if((h|0)==1){break p}h=z[a+174>>1];x[23549]=0;S(754,e- -64|0,h|0,f|0);h=x[23549];x[23549]=0;if((h|0)==1){break o}x[23549]=0;S(8,e+4|0,c|0,e- -64|0);c=x[23549];x[23549]=0;if((c|0)==1){break n}c=e+4|0;zc(d,c);tb(c);tb(e- -64|0);tb(f)}if(y[a+176|0]){x[23549]=0;P(755,e+28|0,d|0);c=x[23549];x[23549]=0;if((c|0)==1){break e}c=e+28|0;Ce(b+43|0,c);tb(c)}x[23549]=0;S(748,e+28|0,g|0,1413894985);c=x[23549];x[23549]=0;if((c|0)==1){break l}x[23549]=0;f=R(756,e+28|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break k}g=e+28|0;ub(g);c=a+40|0;wc(c);x[23549]=0;g=O(757,c|0,g|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break j}if(g){q:{if((y[e+56|0]|y[e+57|0]<<8|(y[e+58|0]<<16|y[e+59|0]<<24))>>>0<2){break q}x[23549]=0;g=O(758,c|0,e+4|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break i}if(!g){break q}xM(e+4|0,b+12|0,b+16|0,x[b>>2],b+34|0,8,16,f)}x[23549]=0;c=O(758,c|0,e+4|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break i}if(c){xM(e+4|0,b+4|0,b+8|0,x[b>>2],b+34|0,2,4,f)}c=y[e+40|0]|y[e+41|0]<<8|(y[e+42|0]<<16|y[e+43|0]<<24);v[b+42|0]=c&128?0:c+1|0;ok(b)}r:{if(y[b+42|0]){break r}c=x[a+60>>2];x[23549]=0;c=O(616,c|0,7)|0;f=x[23549];x[23549]=0;if((f|0)==1){break j}if(!c){break r}c=a+60|0;wc(c);x[23549]=0;c=O(759,c|0,e+4|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break d}if(!c){break r}c=v[e+4|0];v[b+42|0]=(c|0)>=0?c+1|0:0}c=x[a+120>>2];x[23549]=0;c=R(164,c|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break j}if(!c){break f}x[23549]=0;h=a+120|0;c=R(143,h|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break c}x[e+64>>2]=c;tc(e- -64|0,9);f=b+68|0;g=x[e+64>>2];c=0;while(1){if((c|0)==(g|0)){break g}x[23549]=0;P(760,h|0,e+4|0);i=x[23549];x[23549]=0;if((i|0)==1){break h}i=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);j=xb(f,c),k=i,x[j>>2]=k;c=c+1|0;continue}}a=N()|0;break a}a=N()|0;break m}a=N()|0;break m}a=N()|0;tb(e- -64|0)}tb(f);break a}a=N()|0;break a}a=N()|0;ub(e+28|0);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}Uz(f+(g<<2)|0,oU(f),42904)}c=a+80|0;wc(c);x[23549]=0;f=O(761,c|0,e+4|0)|0;g=x[23549];x[23549]=0;s:{if((g|0)==1){break s}if(!f){break b}if(y[e+4|0]&32){w[b+34>>1]=z[b+34>>1]|32}w[e+64>>1]=z[e+8>>1];w[e+2>>1]=256;j=b,k=z[Uc(e- -64|0,e+2|0)>>1],w[j+28>>1]=k;w[e+64>>1]=z[e+10>>1];w[e+2>>1]=256;j=b,k=z[Uc(e- -64|0,e+2|0)>>1],w[j+30>>1]=k;w[e+64>>1]=z[e+12>>1];w[e+2>>1]=64;j=b,k=z[Uc(e- -64|0,e+2|0)>>1],w[j+32>>1]=k;v[b+38|0]=y[e+16|0];v[b+39|0]=y[e+17|0];v[b+40|0]=y[e+18|0];v[b+41|0]=y[e+19|0];f=x[a+88>>2];a=x[a+80>>2];x[23549]=0;a=U(142,a|0,f|0,32)|0;f=x[23549];x[23549]=0;if((f|0)==1){break s}if(!a){break b}x[23549]=0;P(762,c|0,d|0);a=x[23549];x[23549]=0;if((a|0)==1){break s}x[23549]=0;a=R(188,c|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break s}x[23549]=0;S(763,c|0,b+43|0,a|0);a=x[23549];x[23549]=0;if((a|0)!=1){break b}}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}ub(e+76|0);db=e+96|0;return}ub(e+76|0);Q(a|0);p()}function tfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=db-176|0;db=e;wc(b);a:{if(!mB(b,e+128|0)){break a}if(!xR(e+128|0)){break a}if(!Lb(x[b>>2],x[b+8>>2],Qc(wR(y[e+159|0],y[e+161|0]),hb))){break a}b:{if(!c){break b}Bd(a,256);g=e+16|0;nj(g,2,e+128|0);d=e+48|0;Bc(d,g);zb(a+1298308|0,d);tb(d);f=Tb(d,14924);zb(a+1298344|0,f);tb(f);d=Tb(d,10003);zb(a+1298356|0,d);tb(d);hf(g,4212);x[23549]=0;P(238,e+116|0,e+159|0);d=x[23549];x[23549]=0;c:{d:{if((d|0)!=1){x[23549]=0;V(638,e+48|0,e+16|0,e+158|0,e+116|0);d=x[23549];x[23549]=0;if((d|0)!=1){d=e+48|0;zb(a+1298368|0,d);tb(d);tb(e+116|0);Ab(e+16|0);x[a+1298404>>2]=5;d=Jb(a+1074312|0,107,1);x[a+480260>>2]=64;x[a+480264>>2]=32767;x[a+480188>>2]=2031620;Jb(d,107,1);f=y[e+160|0];d=y[e+159|0];if(d>>>0<=20){g=((f&255)>>>0)/10|0;f=g<<4|D(g,-10)+f}g=(f&255?f:96)&255;f=$z(g);x[a+480196>>2]=g>>>4;x[a+480204>>2]=f;if(d>>>0>=11){v[e+48|0]=64;o=a,q=y[Sb(e+162|0,e+48|0)|0]<<2,x[o+480200>>2]=q}f=0;while(1)if((f|0)==4){f=1;while(1){if((f|0)!=32){Ut(b,e+16|0);d=y[e+28|0];if(d?(d|0)!=46:0){break c}i=db-32|0;db=i;d=(D(f,104)+a|0)+484380|0;nd(d,0);j=i+8|0;k=e+16|0;g=k;ck(j,2,g);h=i+20|0;Bc(h,j);Ce(d+43|0,h);tb(h);x[d+24>>2]=y[g+24|0]|y[g+25|0]<<8;v[i+20|0]=y[g+22|0];v[i+8|0]=64;o=d,q=y[Sb(h,j)|0]<<2,w[o+30>>1]=q;h=y[g+16|0]|y[g+17|0]<<8;x[d>>2]=h;j=y[g+18|0]|y[g+19|0]<<8;x[d+4>>2]=j;g=y[g+20|0]|y[g+21|0]<<8;x[d+8>>2]=g;e:{if(h>>>0<=1){x[d>>2]=0;break e}if((g|0)==65535|h>>>0<=j>>>0|g>>>0<=j>>>0){break e}w[d+34>>1]=2;o=d,q=x[Cb(d+8|0,d)>>2],x[o+8>>2]=q}db=i+32|0;g=e+4|0;ck(g,2,k);d=e+116|0;Bc(d,g);zc(((f<<5)+a|0)+946304|0,d);tb(d);w[((f<<1)+e|0)+46>>1]=y[e+30|0]|y[e+31|0]<<8;f=f+1|0;continue}break}d=a+484376|0;Ao(Wb(x[a+484360>>2],y[d|0]),b,y[e+159|0]?128:64,65535,65535);f=0;if(!uR(Wb(x[a+484360>>2],y[d|0]))){break a}m=c&1;if(m){mg(a+484344|0,y[e+161|0])}h=a+484344|0;while(1)if(y[e+161|0]<=l>>>0){f=1;if(!(c&2)){break a}c=Xc(e+16|0,8,1,0,0);while(1){if((f|0)==32){break b}d=D(f,104)+a|0;g=d+484380|0;f:{if(!x[g>>2]|!z[d+484410>>1]){break f}d=z[((f<<1)+e|0)+46>>1];if(d>>>0<4){break f}if(!Vc(b,d<<4)){break f}lg(c,g,b)}f=f+1|0;continue}}else{g:{h:{if(m){if($g(h,l&65535,64)){break h}}f=0;while(1){if((f|0)==256){break g}if((ee(b)+2&255)>>>0<=252){Zb(b,3)}f=f+1|0;continue}}o=e,q=yb(x[Yb(x[h>>2],l)>>2]),x[o+116>>2]=q;w[e+2>>1]=65535;x[e+4>>2]=63;i=0;i:while(1){f=0;if((i|0)==64){d=z[e+2>>1];if((d|0)==65535){break g}me(Yb(x[h>>2],l),Bm(Fe(Be(e+16|0,12,d&255),x[e+4>>2])));break g}while(1){j:{k:{l:{if((f&65535)>>>0<=3){d=0;j=0;k=0;n=0;m:{n:{o:{p:{g=ee(b);switch(g-251|0){case 1:break j;case 0:break n;case 2:break p;default:break o}}v[x[e+116>>2]]=254;break j}d=e+16|0;Sq(d,b);j=y[Db(d,0)|0];k=y[Db(d,1)|0];n=y[Db(d,2)|0];d=254;if((g|0)==254){break m}if(g>>>0>=96){break l}d=g}d=(D(d>>>4|0,12)+(d&15)|0)+37|0}g=d;d=x[e+116>>2];v[d|0]=g;break k}i=i+1|0;continue i}d=x[e+116>>2]}v[d+1|0]=(j&248)>>>3;g=k>>>1&120|j&7;if(g>>>0<=64){v[d+4|0]=g;v[d+2|0]=1}v[d+5|0]=n;v[d+3|0]=k&15;tR(d,i,y[e+159|0],e+2|0,e+4|0)}f=f+1|0;qA(e+116|0);continue}}}l=l+1|0;continue}}else{d=(f<<5)+a|0;Te(d+480280|0);w[d+480284>>1]=f&1?64:192;f=f+1|0;continue}}f=N()|0;tb(e+116|0);break d}f=N()|0}Ab(e+16|0);Q(f|0);p()}f=0;break a}f=1}db=e+176|0;return f|0}function jw(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=db-96|0;db=f;a:{if(ed(a,11)|x[a+4>>2]){d=x[a+28>>2];b=x[a+12>>2];g=x[a+64>>2];c=g+x[a+8>>2]|0;b=gh(f+80|0,c,c>>>0<g>>>0?b+1|0:b);c=x[b+12>>2];x[f+32>>2]=x[b+8>>2];x[f+36>>2]=c;c=x[b+4>>2];x[f+24>>2]=x[b>>2];x[f+28>>2]=c;Gj(d,f+24|0);b=x[a+28>>2];if(Pk(x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){hh(a,1073741826);break a}b=x[a+92>>2];c=a+44|0;e=x[c>>2];d=fh(e,x[c+4>>2]);b:{if(b>>>0>d>>>0){l=db-32|0;db=l;b=b-d|0;d=x[wb(c)>>2];e=x[c+4>>2];c:{if(b>>>0<=d-e>>4>>>0){d=db-16|0;db=d;b=fp(d+4|0,c,b);c=x[b+4>>2];e=x[b+8>>2];while(1){if((c|0)==(e|0)){fc(b);db=d+16|0}else{DE(c);c=c+16|0;x[b+4>>2]=c;continue}break}break c}d=wb(c);d=Wv(l+12|0,Yv(c,fh(x[c>>2],e)+b|0),fh(x[c>>2],x[c+4>>2]),d);g=db-16|0;db=g;b=BE(g+4|0,d+8|0,b);e=x[b>>2];while(1){if(x[b+4>>2]!=(e|0)){DE(e);e=x[b>>2]+16|0;x[b>>2]=e;continue}break}Kd(b);db=g+16|0;i=db-16|0;db=i;b=vb(i+12|0,x[c+4>>2]);g=vb(i+8|0,x[c>>2]);h=x[vb(i+4|0,x[d+4>>2])>>2];j=db-16|0;db=j;n=j+8|0;e=db-32|0;db=e;Od(e+24|0,x[b>>2],x[g>>2]);o=e+16|0;b=x[e+24>>2];p=x[e+28>>2];g=db-16|0;db=g;x[g+8>>2]=h;x[g+12>>2]=b;while(1){if(sd(b,p)){b=wk(b);h=wk(x[g+8>>2]);k=z[b+10>>1]|z[b+12>>1]<<16;m=z[b+6>>1]|z[b+8>>1]<<16;w[h+6>>1]=m;w[h+8>>1]=m>>>16;w[h+10>>1]=k;w[h+12>>1]=k>>>16;k=x[b+4>>2];x[h>>2]=x[b>>2];x[h+4>>2]=k;b=Jl(g+12|0);Jl(g+8|0);b=x[b>>2];continue}break}vc(o,b,g+8|0);db=g+16|0;b=x[e+16>>2];x[e+12>>2]=x[e+20>>2];vc(n,b,e+12|0);db=e+32|0;db=j+16|0;x[d+4>>2]=x[j+12>>2];Pb(c,d+4|0);Pb(c+4|0,d+8|0);Pb(wb(c),kc(d));x[d>>2]=x[d+4>>2];db=i+16|0;JE(d)}db=l+32|0;break b}if(b>>>0<d>>>0){Dd(c,e+(b<<4)|0)}}g=a+32|0;sn(g,x[a+92>>2]<<2);d=0;while(1){if(A[a+92>>2]>d>>>0){b=x[a+28>>2];if(Pk(x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){hh(a,1073741828);break a}c=z[a+16>>1];w[f+78>>1]=c;if((c|0)==65535){mw(b,f+78|0);c=z[f+78>>1]}b=Pc(x[a+32>>2],x[a+36>>2]);e=c&65535;d:{if(!e){c=0;break d}if(e>>>0>(b^-1)>>>0){break d}Ji(g,b+e|0);Lk(x[a+28>>2],Db(x[a+32>>2],b),e)}e=_c(x[a+44>>2],d);x[e>>2]=b;w[e+12>>1]=c;if(ed(a,6)){yk(x[a+28>>2],f+56|0);b=x[f+56>>2];if(x[f+60>>2]<0){hh(a,1073741829);break a}q=_c(x[a+44>>2],d),r=b,x[q+4>>2]=r}b=x[a+4>>2];e:{if(b){c=_c(x[a+44>>2],d);x[c+8>>2]=b;break e}if(!ed(a,7)){c=_c(x[a+44>>2],d);break e}yk(x[a+28>>2],f+56|0);b=x[f+56>>2];if(x[f+60>>2]<0){hh(a,1073741829);break a}c=_c(x[a+44>>2],d);x[c+8>>2]=b}f:{if(x[c+8>>2]==-1){break f}if(ed(a,6)){break f}g:{if(!d){c=0;h=_c(x[a+44>>2],0);break g}b=x[a+44>>2];c=_c(b,d-1|0);c=x[c+8>>2]+x[c+4>>2]|0;h=_c(b,d)}x[h+4>>2]=c}if(ed(a,8)){w[f+56>>1]=0;mw(x[a+28>>2],f+56|0);b=ed(a,9);Sl(x[a+28>>2],z[f+56>>1]<<b)}d=d+1|0;continue}break}ae(f+56|0,x[a+28>>2]);b=x[f+68>>2];x[a+72>>2]=x[f+64>>2];x[a+76>>2]=b}zk(a,4,1);d=x[a+72>>2];e=x[a+76>>2];c=x[a+12>>2];b=x[a+88>>2];g=x[a+8>>2]+b|0;c=b>>>0>g>>>0?c+1|0:c;h=d;d=(b|0)==x[a+64>>2];b=d?h:g;x[a+80>>2]=b;c=d?e:c;x[a+84>>2]=c;d=x[a+28>>2];b=gh(f+40|0,b,c);c=x[b+12>>2];x[f+16>>2]=x[b+8>>2];x[f+20>>2]=c;c=x[b+4>>2];x[f+8>>2]=x[b>>2];x[f+12>>2]=c;Gj(d,f+8|0);if(ed(a,6)){break a}if(!(ed(a,7)|x[a+4>>2])){break a}b=x[a+80>>2]-x[a+8>>2]|0;c=x[a+44>>2];d=x[a+92>>2];a=0;while(1){if((a|0)==(d|0)){break a}e=_c(c,a);x[e+4>>2]=b+x[e+4>>2];a=a+1|0;continue}}db=f+96|0}function ZK(a){var b=0,c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=E(0),m=E(0),n=0,o=E(0),p=0,q=E(0),r=E(0),s=E(0),t=0,u=E(0);j=db-16|0;db=j;b=a+4208|0;i=Uj(E(B[xb(b,12)>>2]*E(3)));x[a+4264>>2]=i;d=E(x[x[a+16>>2]+24620>>2]>>>((i^-1)>>>1&1)>>>0);B[a+4268>>2]=d;t=a,u=E(E(B[xb(b,9)>>2]*E(100))*E(.0061803399585187435)),B[t+4272>>2]=u;t=j,u=qe(E(10),E(E(YK(a)+E(E(B[xb(b,5)>>2]*E(11e3))+E(-1e4)))/E(2e3))),B[t+12>>2]=u;x[j+8>>2]=1065353216;t=a,u=E(B[$l(j+12|0,j+8|0)>>2]*E(.7609999775886536)),B[t+4280>>2]=u;c=qe(E(10),E(E(E(E(B[xb(b,1)>>2]*E(1e4))+E(-1e4))/E(100))/E(10)));if(c!=E(1)){d=zp(E(E(XK(a)*E(6.2831854820251465))/d));f=E(c+c);e=E(c*c);c=cz(E(E(E(E(d*f)+E(-2))+E(M(E(E(E(E(d*E(E(d*e)*E(4)))+E(c*E(8)))-E(e*E(4)))-E(E(d*c)*E(8))))))/E(f+E(-2))),E(0),E(1))}else{c=E(0)}B[a+4276>>2]=c;i=db-16|0;db=i;c=B[a+4268>>2];b=a+4208|0;d=E(B[xb(b,6)>>2]*E(.30000001192092896));t=i,u=E(B[xb(b,8)>>2]*E(.10000000149011612)),B[t+12>>2]=u;x[i+8>>2]=1000593162;f=B[Lx(i+12|0,i+8|0)>>2];e=E(c*E(E(d+f)+E(.007000000216066837)));a:{if(E(F(e))<E(2147483648)){b=~~e;break a}b=-2147483648}x[a+4352>>2]=b;b=1;while(1){if((b|0)==12){t=i,u=E(E(E(E(B[xb(a+4208|0,10)>>2]*E(100))/E(100))+E(.10000000149011612))*E(.9090999960899353)),B[t+12>>2]=u;x[i+8>>2]=1065353216;d=B[$l(i+12|0,i+8|0)>>2];f=E(c*E(E(d*E(75))/E(1e3)));d=E(c*E(E(d*E(67))/E(1e3)));b=0;while(1){if((b|0)==6){h=a+4348|0;d=E(c*E(.0035299998708069324));b:{if(E(F(d))<E(2147483648)){b=~~d;break b}b=-2147483648}x[h>>2]=b;h=a+4344|0;d=E(c*E(.0032500000670552254));c:{if(E(F(d))<E(2147483648)){b=~~d;break c}b=-2147483648}x[h>>2]=b;h=a+4340|0;c=E(c*E(.009999999776482582));d:{if(E(F(c))<E(2147483648)){b=~~c;break d}b=-2147483648}x[h>>2]=b}else{h=(b<<2)+a|0;p=h+4316|0;n=b+n|0;e=qe(E(.9300000071525574),E(n|0));g=E(f*e);e:{if(E(F(g))<E(2147483648)){k=~~g;break e}k=-2147483648}x[p>>2]=k;k=h+4292|0;e=E(d*e);f:{if(E(F(e))<E(2147483648)){h=~~e;break f}h=-2147483648}x[k>>2]=h;b=b+1|0;continue}break}b=0;while(1){if((b|0)!=15){bL((D(b,24)+a|0)+4504|0,x[((b<<2)+a|0)+4292>>2]);b=b+1|0;continue}break}db=i+16|0}else{k=((D(b&1,24)+a|0)+(b<<1&-4)|0)+4352|0;e=E(c*E(E(f*B[(b<<2)+47120>>2])+d));g:{if(E(F(e))<E(2147483648)){h=~~e;break g}h=-2147483648}x[k>>2]=h;b=b+1|0;continue}break}b=db-16|0;db=b;d=kh(a,5);e=kh(a,11);c=E(d*kh(a,4));d=E(E(c*E(.03999999910593033))+E(E(d*E(.02250000089406967))+E(0)));f=E(e*kh(a,10));e=E(E(f*E(.03999999910593033))+E(E(e*E(.02250000089406967))+E(0)));if(v[a+4264|0]&1){g=kh(a,3);l=kh(a,9);g=E(c*g);c=E(g*kh(a,2));d=E(E(c*E(.1444000005722046))+E(E(g*E(.12250000238418579))+d));g=E(f*l);f=E(g*kh(a,8));e=E(E(f*E(.1444000005722046))+E(E(g*E(.12250000238418579))+e))}kh(a,12);g=B[a+4496>>2];l=kh(a,1);m=kh(a,7);q=kh(a,0);r=kh(a,6);t=b,u=qe(E(10),E(E(YK(a)+E(E(B[xb(a+4208|0,7)>>2]*E(12e3))+E(-1e4)))/E(2e3))),B[t+12>>2]=u;x[b+8>>2]=1065353216;o=B[$l(b+12|0,b+8|0)>>2];s=c;c=E(g*g);g=E(l*E(s*c));l=E(q*g);c=E(m*E(f*c));f=E(r*c);m=E(E(E(l+f)*E(-.5))+E(1));B[a+4284>>2]=o*E(M(E(m/E(E(l*E(.1444000005722046))+E(E(c*E(.1444000005722046))+d)))));B[a+4288>>2]=o*E(M(E(m/E(E(f*E(.1444000005722046))+E(E(g*E(.1444000005722046))+e)))));db=b+16|0;v[a+5046|0]=0;db=j+16|0}function rN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,z=0;if(b){i=a+327720|0;c=db-352|0;db=c;wP(c+340|0,8);x[23549]=0;na(734,c+328|0,9);j=x[23549];x[23549]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((j|0)!=1){x[23549]=0;j=O(735,c+312|0,14)|0;e=x[23549];x[23549]=0;if((e|0)==1){break l}x[23549]=0;P(736,c+340|0,j|0);e=x[23549];x[23549]=0;if((e|0)==1){break k}x[23549]=0;P(736,c+328|0,j|0);e=x[23549];x[23549]=0;if((e|0)==1){break k}vP(c+240|0,4900);vP(c+168|0,32e3);nP(c+96|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);x[23549]=0;e=O(737,c+72|0,c+340|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break j}pt(c+84|0,c+240|0,e);oe(e);x[23549]=0;e=O(737,c+48|0,c+328|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break i}pt(c+60|0,c+168|0,e);oe(e);x[23549]=0;e=O(737,c+24|0,c+84|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break h}pt(c+36|0,c+96|0,e);oe(e);x[23549]=0;e=O(737,c|0,c+60|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break g}g=c+12|0;pt(g,c+96|0,e);oe(e);e=c+84|0;Up(e);l=c+36|0;Up(l);m=c+60|0;Up(m);Up(g);q=c+328|0;Up(q);Tp(x[c+84>>2],x[c+88>>2],ho(i,0));Tp(x[c+36>>2],x[c+40>>2],ho(i,1));Tp(x[c+60>>2],x[c+64>>2],ho(i,2));Tp(x[c+12>>2],x[c+16>>2],ho(i,3));Tp(x[c+328>>2],x[c+332>>2],ho(i,4));oe(g);oe(l);oe(m);oe(e);ql(j);oe(q);oe(c+340|0);db=c+352|0;break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;break d}a=N()|0;break e}a=N()|0;break f}a=N()|0;oe(c+36|0)}oe(c+60|0)}oe(c+84|0)}ql(j)}oe(c+328|0)}oe(c+340|0);Q(a|0);p()}ky(a+131112|0,9.6377,.97);ky(a+196648|0,8.5,.5);ky(a+262184|0,2.7625,.425)}c=a+368680|0;if(!(u=0,v=AM(c,a),z=b,z?u:v)){e=a+24|0;s=C[a+8>>3];g=y[a+16|0];i=db+-64|0;db=i;m:while(1){if((n|0)!=8193){t=+(n-4096|0)*.0001220703125;b=0;o=0;while(1)if((b|0)==8){d=1/o;l=n<<3;b=0;while(1)if((b|0)==8){n=n+1|0;continue m}else{m=e+(b+l<<1)|0;h=J(C[i+(b<<3)>>3]*32768*d+.5);h=h<-32768?-32768:h>32768?32768:h;n:{if(F(h)<2147483648){j=~~h;break n}j=-2147483648}w[m>>1]=j;b=b+1|0;continue}}else{h=s;f=1;d=+(b|0)-t;r=d+-3.5;if(!(F(r)<1e-8)){o:{p:{switch(g|0){case 0:f=Pe(d*.8975979010256552)*-.5+.5;break o;case 1:f=Pe(d*.8975979010256552)*-.46+.54;break o;case 2:f=Pe(d*1.7951958020513104)*.08+(Pe(d*.8975979010256552)*-.5+.42);break o;case 3:f=Pe(d*1.7951958020513104)*.05677+(Pe(d*.8975979010256552)*-.49364+.44959);break o;case 4:f=Pe(d*1.7951958020513104)*.07922+(Pe(d*.8975979010256552)*-.49755+.42323);break o;case 5:f=Pe(d*1.7951958020513104);k=Pe(d*.8975979010256552);f=Pe(d*2.6927937030769655)*-.01168+(f*.14128+(k*-.48829+.35875));break o;case 6:f=Pe(d*1.7951958020513104);k=Pe(d*.8975979010256552);f=Pe(d*2.6927937030769655)*-.00183+(f*.09392+(k*-.49703+.40217));break o;case 7:break p;default:break o}}f=Pe(d*1.7951958020513104);k=Pe(d*.8975979010256552);f=Pe(d*2.6927937030769655)*-.00122+(f*.09831+(k*-.49804+.40243))}d=r*3.141592653589793;h=ui(d*h)/d}h=f*h;C[i+(b<<3)>>3]=h;o=o+h;b=b+1|0;continue}}break}db=i- -64|0;b=x[a+20>>2];x[c+16>>2]=x[a+16>>2];x[c+20>>2]=b;b=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=b;b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b}}function DK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=db-240|0;db=e;v[e+239|0]=c;f=x[b+4>>2];a:{if(!f){break a}g=x[b>>2];h=y[Sk(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}cl(e+80|0,g,f,f-1|0);f=x[e+84>>2];x[b>>2]=x[e+80>>2];x[b+4>>2]=f}f=e+80|0;Rd(f);g=x[e+80>>2];Rd(e+216|0);h=Rk(g,x[e+220>>2],b);Rd(f);f=x[b+4>>2];g=x[b>>2];b:{c:{d:{e:{f:{g:{h:{if((h|0)==x[e+84>>2]){a=mc(e+228|0,21204);c=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=c;if(Gc(g,f,e)){d=ac(8);x[23549]=0;P(935,e+216|0,e+239|0);a=x[23549];x[23549]=0;if((a|0)==1){break g}x[23549]=0;S(942,e+80|0,17211,e+216|0);a=x[23549];x[23549]=0;if((a|0)==1){break f}a=0;b=pc(d,e+80|0);x[23549]=0;S(105,b|0,61816,931);b=x[23549];x[23549]=0;if((b|0)!=1){break b}b=N()|0;tb(e+80|0);break e}if(!d){break h}d=ac(8);a=x[b+4>>2];b=x[b>>2];x[23549]=0;a=Ch(e+192|0,b,a);b=x[23549];x[23549]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){x[23549]=0;S(942,e+204|0,17247,a|0);b=x[23549];x[23549]=0;if((b|0)==1){break p}x[23549]=0;P(944,e+216|0,e+204|0);b=x[23549];x[23549]=0;c=1;if((b|0)==1){break o}x[23549]=0;P(935,e+180|0,e+239|0);b=x[23549];x[23549]=0;if((b|0)==1){break n}x[23549]=0;S(946,e+80|0,e+216|0,e+180|0);b=x[23549];x[23549]=0;if((b|0)==1){break m}b=pc(d,e+80|0);x[23549]=0;S(105,b|0,61816,931);b=x[23549];x[23549]=0;if((b|0)!=1){break b}b=N()|0;tb(e+80|0);c=0;break l}b=N()|0;break d}b=N()|0;c=1;break i}b=N()|0;break j}b=N()|0;break k}b=N()|0}tb(e+180|0)}tb(e+216|0)}tb(e+204|0)}tb(a);if(c){break d}break c}b=mc(e+172|0,21204);d=x[b+4>>2];x[e+72>>2]=x[b>>2];x[e+76>>2]=d;if(Gc(g,f,e+72|0)){d=ac(8);x[23549]=0;P(935,e+216|0,e+239|0);a=x[23549];x[23549]=0;q:{r:{if((a|0)!=1){x[23549]=0;S(942,e+80|0,17211,e+216|0);a=x[23549];x[23549]=0;if((a|0)==1){break r}a=0;b=pc(d,e+80|0);x[23549]=0;S(105,b|0,61816,931);b=x[23549];x[23549]=0;if((b|0)!=1){break b}b=N()|0;tb(e+80|0);break q}b=N()|0;break d}b=N()|0;a=1}tb(e+216|0);if(a){break d}break c}b=mc(e+164|0,7360);d=x[b+4>>2];x[e+64>>2]=x[b>>2];x[e+68>>2]=d;s:{if(!Gc(g,f,e- -64|0)){b=mc(e+156|0,7342);d=x[b+4>>2];x[e+56>>2]=x[b>>2];x[e+60>>2]=d;if(!Gc(g,f,e+56|0)){break s}}v[a+60|0]=c;break h}b=mc(e+148|0,6875);d=x[b+4>>2];x[e+48>>2]=x[b>>2];x[e+52>>2]=d;t:{if(!Gc(g,f,e+48|0)){b=mc(e+140|0,6856);d=x[b+4>>2];x[e+40>>2]=x[b>>2];x[e+44>>2]=d;if(!Gc(g,f,e+40|0)){break t}}v[a+61|0]=c;break h}b=mc(e+132|0,6959);d=x[b+4>>2];x[e+32>>2]=x[b>>2];x[e+36>>2]=d;if(Gc(g,f,e+32|0)){v[a+62|0]=c;break h}b=mc(e+124|0,6005);d=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=d;if(Gc(g,f,e+24|0)){v[a+63|0]=c;break h}b=mc(e+116|0,7409);d=x[b+4>>2];x[e+16>>2]=x[b>>2];x[e+20>>2]=d;if(Gc(g,f,e+16|0)){v[a+64|0]=c;break h}b=mc(e+108|0,13225);d=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=d;if(!Gc(g,f,e+8|0)){break h}b=x[a+24>>2];d=b+24664|0;f=x[d+4>>2];x[e+96>>2]=x[d>>2];x[e+100>>2]=f;d=b+24656|0;f=x[d+4>>2];x[e+88>>2]=x[d>>2];x[e+92>>2]=f;d=x[b+24652>>2];x[e+80>>2]=x[b+24648>>2];x[e+84>>2]=d;if(c){a=bK(x[a+56>>2])}else{a=0}x[e+100>>2]=a;if(!wx(e+80|0,b+24648|0)){break h}ty(b,e+80|0)}db=e+240|0;return}b=N()|0;break d}b=N()|0;a=1}tb(e+216|0);if(!a){break c}}jc(d)}Q(b|0)}p()}function lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=db-224|0;db=f;ae(f+208|0,b);g=db-32|0;db=g;x[g+28>>2]=0;ak(b,g+28|0);a:{b:{c:{if(x[g+28>>2]!=(Jm(13832)|0)){break c}x[g+24>>2]=0;e=db-32|0;db=e;x[e+28>>2]=0;Rv(e+8|0,e+28|0);vn(e+20|0,b,x[e+8>>2],x[e+12>>2]);x[g+24>>2]=x[e+28>>2];db=e+32|0;e=-1;i=x[g+24>>2];if(i-3>>>0<4294967294){break c}d:{e:{f:{if(i>>>0<=1){i=Gb(g+12|0);x[23549]=0;h=U(437,b|0,i|0,256)|0;j=x[23549];x[23549]=0;if((j|0)==1){break b}if(!h){break e}x[23549]=0;S(11,g|0,d|0,i|0);h=x[23549];x[23549]=0;if((h|0)!=1){break f}break b}i=Gb(g+12|0);x[23549]=0;h=O(439,b|0,i|0)|0;j=x[23549];x[23549]=0;if((j|0)==1){break b}if(!h){break d}x[23549]=0;S(11,g|0,d|0,i|0);h=x[23549];x[23549]=0;if((h|0)==1){break b}}zb(c,g);tb(g);tb(i);Mf(b,g);i=0;x[g+12>>2]=0;ak(b,g+12|0);h=x[g+12>>2];if(h>>>0>50){break c}g:{while(1){if((h|0)==(i|0)){break g}i=i+1|0;if(UL(a,b,d)){continue}break}break c}x[g+12>>2]=0;ak(b,g+12|0);e=x[g+12>>2]==(Jm(13870)|0)?1:-1;break c}tb(i);break c}tb(i)}db=g+32|0;break a}a=N()|0;tb(i);Q(a|0);p()}h:{if(e){break h}dn(x[x[b>>2]-12>>2]+b|0,0);e=x[f+220>>2];x[f+16>>2]=x[f+216>>2];x[f+20>>2]=e;e=x[f+212>>2];x[f+8>>2]=x[f+208>>2];x[f+12>>2]=e;b=Pl(f+104|0,Gj(b,f+8|0));x[23549]=0;e=O(403,f+92|0,13958)|0;g=x[23549];x[23549]=0;i:{if((g|0)!=1){x[23549]=0;x[f+72>>2]=3;x[f+76>>2]=0;S(404,b|0,e|0,f+72|0);g=x[23549];x[23549]=0;if((g|0)!=1){Ab(e);v[f+91|0]=0;x[23549]=0;e=O(403,f+72|0,14403)|0;g=x[23549];x[23549]=0;if((g|0)!=1){x[23549]=0;S(405,b|0,f+91|0,e|0);g=x[23549];x[23549]=0;if((g|0)!=1){Ab(e);x[23549]=0;g=y[f+91|0];e=R(418,b|0)|0;i=x[23549];x[23549]=0;if((i|0)!=1){x[23549]=0;i=R(419,b|0)|0;h=x[23549];x[23549]=0;if((h|0)!=1){g=g?0:d;x[f+68>>2]=e;j:{k:{l:{m:{while(1){if(!Kb(e,i)){a=x[b>>2];Zg(b);e=a&1073741824?-1:1;break h}x[23549]=0;d=O(403,f+52|0,15422)|0;e=x[23549];x[23549]=0;if((e|0)==1){break l}e=x[b+36>>2];h=x[b+32>>2];x[23549]=0;e=ba(420,h|0,e|0,x[f+68>>2],d|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break k}Ab(d);n:{o:{if(!e){x[23549]=0;V(421,b|0,f+68|0,c|0,g|0);d=x[23549];x[23549]=0;if((d|0)!=1){break o}break j}x[23549]=0;d=O(403,f+40|0,15044)|0;e=x[23549];x[23549]=0;p:{q:{if((e|0)!=1){e=x[b+36>>2];h=x[b+32>>2];x[23549]=0;e=ba(420,h|0,e|0,x[f+68>>2],d|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break q}Ab(d);if(e){break p}x[23549]=0;S(422,b|0,f+68|0,f+66|0);d=x[23549];x[23549]=0;if((d|0)==1){break j}break o}a=N()|0;break i}a=N()|0;Ab(d);break i}x[23549]=0;d=O(403,f+28|0,14939)|0;e=x[23549];x[23549]=0;if((e|0)==1){break n}e=x[b+36>>2];h=x[b+32>>2];x[23549]=0;e=ba(420,h|0,e|0,x[f+68>>2],d|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break m}Ab(d);if(e){break o}x[23549]=0;V(423,b|0,f+68|0,a|0,g|0);d=x[23549];x[23549]=0;if((d|0)==1){break j}}jl(f+68|0);e=x[f+68>>2];continue}break}a=N()|0;break i}a=N()|0;Ab(d);break i}a=N()|0;break i}a=N()|0;Ab(d);break i}a=N()|0;break i}a=N()|0;break i}a=N()|0;break i}a=N()|0;Ab(e);break i}a=N()|0;break i}a=N()|0;Ab(e);break i}a=N()|0}Zg(b);Q(a|0);p()}db=f+224|0;return e|0}function CK(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=db-160|0;db=e;C[e+152>>3]=c;f=x[b+4>>2];a:{if(!f){break a}g=x[b>>2];h=y[Sk(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}cl(e+128|0,g,f,f-1|0);f=x[e+132>>2];x[b>>2]=x[e+128>>2];x[b+4>>2]=f}f=e+128|0;Rd(f);g=x[e+128>>2];Rd(e+116|0);h=Rk(g,x[e+120>>2],b);Rd(f);f=x[b+4>>2];g=x[b>>2];b:{c:{d:{e:{if((h|0)==x[e+132>>2]){a=mc(e+144|0,21204);h=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=h;if(Gc(g,f,e+8|0)){d=ac(8);x[23549]=0;P(939,e+116|0,e+152|0);a=x[23549];x[23549]=0;f:{g:{h:{if((a|0)!=1){x[23549]=0;S(942,e+128|0,17211,e+116|0);a=x[23549];x[23549]=0;if((a|0)==1){break h}a=0;b=pc(d,e+128|0);x[23549]=0;S(105,b|0,61816,931);b=x[23549];x[23549]=0;if((b|0)!=1){break b}b=N()|0;tb(e+128|0);break g}b=N()|0;break f}b=N()|0;a=1}tb(e+116|0);if(!a){break c}}jc(d);break c}if(!d){break e}d=ac(8);a=x[b+4>>2];b=x[b>>2];x[23549]=0;f=Ch(e+92|0,b,a);a=x[23549];x[23549]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[23549]=0;S(942,e+104|0,17247,f|0);a=x[23549];x[23549]=0;if((a|0)==1){break q}x[23549]=0;P(944,e+116|0,e+104|0);b=x[23549];x[23549]=0;a=1;if((b|0)==1){break p}x[23549]=0;P(939,e+80|0,e+152|0);a=x[23549];x[23549]=0;if((a|0)==1){break o}x[23549]=0;S(946,e+128|0,e+116|0,e+80|0);b=x[23549];x[23549]=0;a=1;if((b|0)==1){break n}a=pc(d,e+128|0);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break b}b=N()|0;tb(e+128|0);a=0;break m}b=N()|0;break i}b=N()|0;a=1;break j}b=N()|0;break k}b=N()|0;a=1;break l}b=N()|0}tb(e+80|0)}tb(e+116|0)}tb(e+104|0)}tb(f);if(!a){break c}}jc(d);break c}b=mc(e+72|0,21204);d=x[b+4>>2];x[e+40>>2]=x[b>>2];x[e+44>>2]=d;if(Gc(g,f,e+40|0)){d=ac(8);x[23549]=0;P(939,e+116|0,e+152|0);a=x[23549];x[23549]=0;r:{s:{t:{if((a|0)!=1){x[23549]=0;S(942,e+128|0,17211,e+116|0);a=x[23549];x[23549]=0;if((a|0)==1){break t}a=0;b=pc(d,e+128|0);x[23549]=0;S(105,b|0,61816,931);b=x[23549];x[23549]=0;if((b|0)!=1){break b}b=N()|0;tb(e+128|0);break s}b=N()|0;break r}b=N()|0;a=1}tb(e+116|0);if(!a){break c}}jc(d);break c}b=mc(e- -64|0,7657);d=x[b+4>>2];x[e+32>>2]=x[b>>2];x[e+36>>2]=d;if(Gc(g,f,e+32|0)){if(!vd(y[a+28|0])){break e}if(c<=0|c>4){a=ac(8);x[23549]=0;d=O(54,e+128|0,7752)|0;b=x[23549];x[23549]=0;if((b|0)==1){break d}a=pc(a,d);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break b}b=N()|0;tb(d);break c}a=x[a+24>>2];i=a,j=Le(65536/c),x[i+480244>>2]=j;Ip(a);break e}b=mc(e+56|0,7709);d=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=d;if(Gc(g,f,e+24|0)){if(!vd(y[a+28|0])){break e}if(c<=0|c>4){a=ac(8);x[23549]=0;d=O(54,e+128|0,7773)|0;b=x[23549];x[23549]=0;if((b|0)!=1){a=pc(a,d);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break b}b=N()|0;tb(d);break c}b=N()|0;jc(a);break c}a=x[a+24>>2];i=a,j=Le(c*65536),x[i+480240>>2]=j;Ip(a);break e}b=mc(e+48|0,7727);d=x[b+4>>2];x[e+16>>2]=x[b>>2];x[e+20>>2]=d;if(!Gc(g,f,e+16|0)){break e}i=x[a+24>>2],j=pm(c*65536),x[i+480236>>2]=j}db=e+160|0;return}b=N()|0;jc(a)}Q(b|0)}p()}function ug(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=db-112|0;db=j;k=i&2147483647;a:{b:{l=e&2147483647;m=!(b|c);if(!(d|l?l-2147418112>>>0<2147549184:m)){o=k-2147418112|0;if(!h&(o|0)==-2147418112?f|g:(o|0)==-2147418112&(h|0)!=0|o>>>0>2147549184){break b}}if(!(!d&(l|0)==2147418112?m:l>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!h&(k|0)==2147418112?!(f|g):k>>>0<2147418112)){i=i|32768;break a}if(!(b|d|(l^2147418112|c))){n=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:n;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|h|(k^2147418112|g))){break a}if(!(b|d|(c|l))){if(f|h|(g|k)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|h|(g|k)){break b}f=b;g=c;h=d;i=e;break a}n=(k|0)==(l|0);r=n&(d|0)==(h|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:n&d>>>0<h>>>0|k>>>0>l>>>0;m=r;l=m?f:b;o=m?g:c;n=m?i:e;s=n;m=m?h:d;q=n&65535;d=r?d:h;e=r?e:i;t=e;n=e>>>16&32767;p=s>>>16&32767;if(!p){e=!(m|q);i=e;k=e?l:m;e=e<<6;i=G(i?o:q);e=e+((i|0)==32?G(k)+32|0:i)|0;zf(j+96|0,l,o,m,q,e-15|0);m=x[j+104>>2];q=x[j+108>>2];o=x[j+100>>2];p=16-e|0;l=x[j+96>>2]}f=r?b:f;g=r?c:g;h=d;i=t&65535;if(!n){b=!(h|i);e=b;k=b?f:h;b=b<<6;e=G(e?g:i);b=b+((e|0)==32?G(k)+32|0:e)|0;zf(j+80|0,f,g,h,i,b-15|0);n=16-b|0;h=x[j+88>>2];i=x[j+92>>2];g=x[j+84>>2];f=x[j+80>>2]}c=i<<3|h>>>29;b=h<<3|g>>>29;c=c|524288;h=m<<3|o>>>29;i=q<<3|m>>>29;r=s^t;e=g<<3|f>>>29;d=f<<3;c:{if((n|0)==(p|0)){break c}f=p-n|0;if(f>>>0>127){b=0;c=0;e=0;d=1;break c}zf(j- -64|0,d,e,b,c,128-f|0);em(j+48|0,d,e,b,c,f);b=x[j+56>>2];c=x[j+60>>2];e=x[j+52>>2];d=x[j+48>>2]|(x[j+64>>2]|x[j+72>>2]|(x[j+68>>2]|x[j+76>>2]))!=0}m=d;k=e;n=h;q=i|524288;e=o<<3|l>>>29;o=l<<3;l=e;d:{if((r|0)<0){f=0;g=0;h=0;i=0;if(!(m^o|b^n|(k^l|c^q))){break a}d=o-m|0;e=l-((m>>>0>o>>>0)+k|0)|0;f=n-b|0;g=(k|0)==(l|0)&m>>>0>o>>>0|k>>>0>l>>>0;h=f-g|0;b=(q-((b>>>0>n>>>0)+c|0)|0)-(f>>>0<g>>>0)|0;i=b;if(b>>>0>524287){break d}b=!(h|i);f=b;g=b?d:h;b=b<<6;f=G(f?e:i);b=b+((f|0)==32?G(g)+32|0:f)|0;b=b-12|0;zf(j+32|0,d,e,h,i,b);p=p-b|0;h=x[j+40>>2];i=x[j+44>>2];d=x[j+32>>2];e=x[j+36>>2];break d}e=k+l|0;d=m+o|0;e=d>>>0<o>>>0?e+1|0:e;f=(k|0)==(e|0)&d>>>0<m>>>0|e>>>0<k>>>0;k=c+q|0;b=b+n|0;k=b>>>0<n>>>0?k+1|0:k;h=b+f|0;i=h>>>0<b>>>0?k+1|0:k;if(!(i&1048576)){break d}d=m&1|((e&1)<<31|d>>>1);e=h<<31|e>>>1;p=p+1|0;h=(i&1)<<31|h>>>1;i=i>>>1|0}c=0;l=s&-2147483648;if((p|0)>=32767){h=c;i=l|2147418112;f=0;g=0;break a}n=0;e:{if((p|0)>0){n=p;break e}zf(j+16|0,d,e,h,i,p+127|0);em(j,d,e,h,i,1-p|0);d=x[j>>2]|(x[j+16>>2]|x[j+24>>2]|(x[j+20>>2]|x[j+28>>2]))!=0;e=x[j+4>>2];h=x[j+8>>2];i=x[j+12>>2]}o=d&7;d=(e&7)<<29|d>>>3;f=(o>>>0>4)+d|0;b=h<<29|e>>>3;g=d>>>0>f>>>0?b+1|0:b;d=(b|0)==(g|0)&d>>>0>f>>>0|b>>>0>g>>>0;b=c|((i&7)<<29|h>>>3);h=d+b|0;i=l|(i>>>3&65535|n<<16);i=b>>>0>h>>>0?i+1|0:i;f:{if((o|0)==4){b=0;k=g+b|0;d=f;c=f&1;f=f+c|0;g=d>>>0>f>>>0?k+1|0:k;b=(b|0)==(g|0)&c>>>0>f>>>0|b>>>0>g>>>0;h=b+h|0;i=b>>>0>h>>>0?i+1|0:i;break f}if(!o){break a}}}x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;db=j+112|0}function yia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=db-352|0;db=e;g=db-32|0;db=g;d=g+12|0;$A(d,b);Kq(g+4|0,d);x[23549]=0;S(417,e+200|0,x[g+4>>2],x[g+8>>2]);b=x[23549];x[23549]=0;a:{if((b|0)!=1){Jc(g+12|0);db=g+32|0;break a}a=N()|0;Jc(g+12|0);Q(a|0);p()}x[23549]=0;S(399,e+96|0,x[e+200>>2],x[e+204>>2]);b=x[23549];x[23549]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((b|0)!=1){x[23549]=0;g=O(78,e+212|0,e+96|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break z}tb(e+96|0);bc(e+200|0);if(c>>>0<2189){break g}b=Pl(e+96|0,g);x[23549]=0;c=O(403,e+200|0,10007)|0;d=x[23549];x[23549]=0;if((d|0)==1){break x}x[23549]=0;x[e+80>>2]=19927555;x[e+84>>2]=0;S(404,b|0,c|0,e+80|0);d=x[23549];x[23549]=0;if((d|0)==1){break w}Ab(c);v[e+95|0]=0;x[23549]=0;c=O(403,e+80|0,10897)|0;d=x[23549];x[23549]=0;if((d|0)==1){break i}x[23549]=0;S(405,b|0,e+95|0,c|0);d=x[23549];x[23549]=0;if((d|0)==1){break v}Ab(c);c=0;c=y[e+95|0]?c:x[a+1298404>>2];f=x[a+4>>2];x[23549]=0;d=O(403,e+68|0,15422)|0;h=x[23549];x[23549]=0;if((h|0)==1){break u}x[23549]=0;V(406,b|0,f|0,d|0,c|0);f=x[23549];x[23549]=0;if((f|0)==1){break t}Ab(d);x[23549]=0;d=O(403,e+56|0,15044)|0;f=x[23549];x[23549]=0;if((f|0)==1){break s}x[23549]=0;V(407,b|0,a|0,d|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break r}Ab(d);x[23549]=0;c=O(403,e+44|0,14939)|0;d=x[23549];x[23549]=0;if((d|0)==1){break q}x[23549]=0;d=a+484360|0;S(408,b|0,d|0,c|0);f=x[23549];x[23549]=0;if((f|0)==1){break p}Ab(c);x[23549]=0;c=O(403,e+32|0,26710)|0;f=x[23549];x[23549]=0;if((f|0)==1){break o}x[23549]=0;S(409,b|0,a+484344|0,c|0);f=x[23549];x[23549]=0;if((f|0)==1){break n}Ab(c);f=x[a+1298404>>2];x[23549]=0;c=O(403,e+20|0,26716)|0;h=x[23549];x[23549]=0;if((h|0)==1){break m}x[23549]=0;V(410,b|0,d|0,c|0,f|0);d=x[23549];x[23549]=0;if((d|0)==1){break l}Ab(c);if(y[b+3|0]&64){x[23549]=0;c=O(1,e+8|0,15896)|0;d=x[23549];x[23549]=0;if((d|0)==1){break k}a=x[a+1298464>>2];x[23549]=0;S(359,a|0,1,c|0);a=x[23549];x[23549]=0;if((a|0)==1){break j}tb(c)}Zg(b);break f}a=N()|0;break y}a=N()|0;tb(e+96|0)}bc(e+200|0);break b}a=N()|0;break h}a=N()|0;Ab(c);break h}a=N()|0;Ab(c);break h}a=N()|0;break h}a=N()|0;Ab(d);break h}a=N()|0;break h}a=N()|0;Ab(d);break h}a=N()|0;break h}a=N()|0;Ab(c);break h}a=N()|0;break h}a=N()|0;Ab(c);break h}a=N()|0;break h}a=N()|0;Ab(c);break h}a=N()|0;break h}a=N()|0;tb(c);break h}a=N()|0}Zg(b);break c}b=Gb(e+96|0);d=x[a+1298404>>2];f=x[a+4>>2];x[23549]=0;d=ba(411,f|0,g|0,b|0,d|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break e}A:{if((d|0)!=1){x[23549]=0;c=O(1,e+200|0,16202)|0;d=x[23549];x[23549]=0;B:{if((d|0)!=1){a=x[a+1298464>>2];x[23549]=0;S(359,a|0,1,c|0);a=x[23549];x[23549]=0;if((a|0)==1){break B}tb(c);break A}a=N()|0;break d}a=N()|0;tb(c);break d}d=x[a+1298404>>2];x[23549]=0;V(412,g|0,a|0,d|0,c>>>0<2188|0);a=x[23549];x[23549]=0;if((a|0)==1){break e}}tb(b)}mf(g);db=e+352|0;return}a=N()|0}tb(b)}mf(g)}Q(a|0);p()}function Eb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=x[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=x[d>>2];d=d-b|0;if(d>>>0<A[23429]){break a}a=a+b|0;c:{d:{if(x[23430]!=(d|0)){if(b>>>0<=255){e=b>>>3|0;b=x[d+12>>2];c=x[d+8>>2];if((b|0)==(c|0)){i=93700,j=x[23425]&Cka(-2,e),x[i>>2]=j;break b}x[c+12>>2]=b;x[b+8>>2]=c;break b}g=x[d+24>>2];b=x[d+12>>2];if((d|0)!=(b|0)){c=x[d+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break c}e=d+20|0;c=x[e>>2];if(!c){c=x[d+16>>2];if(!c){break d}e=d+16|0}while(1){h=e;b=c;e=b+20|0;c=x[e>>2];if(c){continue}e=b+16|0;c=x[b+16>>2];if(c){continue}break}x[h>>2]=0;break c}b=x[f+4>>2];if((b&3)!=3){break b}x[23427]=a;x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[f>>2]=a;return}b=0}if(!g){break b}c=x[d+28>>2];e=(c<<2)+94004|0;e:{if(x[e>>2]==(d|0)){x[e>>2]=b;if(b){break e}i=93704,j=x[23426]&Cka(-2,c),x[i>>2]=j;break b}x[g+(x[g+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}x[b+24>>2]=g;c=x[d+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[d+20>>2];if(!c){break b}x[b+20>>2]=c;x[c+24>>2]=b}if(d>>>0>=f>>>0){break a}b=x[f+4>>2];if(!(b&1)){break a}f:{g:{h:{i:{if(!(b&2)){if(x[23431]==(f|0)){x[23431]=d;a=x[23428]+a|0;x[23428]=a;x[d+4>>2]=a|1;if(x[23430]!=(d|0)){break a}x[23427]=0;x[23430]=0;return}if(x[23430]==(f|0)){x[23430]=d;a=x[23427]+a|0;x[23427]=a;x[d+4>>2]=a|1;x[a+d>>2]=a;return}a=(b&-8)+a|0;if(b>>>0<=255){e=b>>>3|0;b=x[f+12>>2];c=x[f+8>>2];if((b|0)==(c|0)){i=93700,j=x[23425]&Cka(-2,e),x[i>>2]=j;break g}x[c+12>>2]=b;x[b+8>>2]=c;break g}g=x[f+24>>2];b=x[f+12>>2];if((f|0)!=(b|0)){c=x[f+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break h}e=f+20|0;c=x[e>>2];if(!c){c=x[f+16>>2];if(!c){break i}e=f+16|0}while(1){h=e;b=c;e=b+20|0;c=x[e>>2];if(c){continue}e=b+16|0;c=x[b+16>>2];if(c){continue}break}x[h>>2]=0;break h}x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[a+d>>2]=a;break f}b=0}if(!g){break g}c=x[f+28>>2];e=(c<<2)+94004|0;j:{if(x[e>>2]==(f|0)){x[e>>2]=b;if(b){break j}i=93704,j=x[23426]&Cka(-2,c),x[i>>2]=j;break g}x[g+(x[g+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}x[b+24>>2]=g;c=x[f+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[f+20>>2];if(!c){break g}x[b+20>>2]=c;x[c+24>>2]=b}x[d+4>>2]=a|1;x[a+d>>2]=a;if(x[23430]!=(d|0)){break f}x[23427]=a;return}if(a>>>0<=255){b=(a&-8)+93740|0;c=x[23425];a=1<<(a>>>3);k:{if(!(c&a)){x[23425]=a|c;a=b;break k}a=x[b+8>>2]}x[b+8>>2]=d;x[a+12>>2]=d;x[d+12>>2]=b;x[d+8>>2]=a;return}c=31;if(a>>>0<=16777215){b=G(a>>>8|0);c=((a>>>38-b&1)-(b<<1)|0)+62|0}x[d+28>>2]=c;x[d+16>>2]=0;x[d+20>>2]=0;b=(c<<2)+94004|0;l:{m:{e=x[23426];h=1<<c;n:{if(!(e&h)){x[23426]=e|h;x[b>>2]=d;x[d+24>>2]=b;break n}c=a<<((c|0)!=31?25-(c>>>1|0)|0:0);b=x[b>>2];while(1){e=b;if((x[b+4>>2]&-8)==(a|0)){break m}b=c>>>29|0;c=c<<1;h=e+(b&4)|0;b=x[h+16>>2];if(b){continue}break}x[h+16>>2]=d;x[d+24>>2]=e}x[d+12>>2]=d;x[d+8>>2]=d;break l}a=x[e+8>>2];x[a+12>>2]=d;x[e+8>>2]=d;x[d+24>>2]=0;x[d+12>>2]=e;x[d+8>>2]=a}a=x[23433]-1|0;x[23433]=a?a:-1}}function cka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=db-720|0;db=e;wc(b);f=db-16|0;db=f;h=e+110|0;KV(f+8|0,h);g=x[f+12>>2];j=b;lc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(g|0)){Zb(j,x[f+12>>2])}db=f+16|0;b=(b|0)==(g|0);if(!b){JV(h)}a:{if(!b){break a}if(!LV(e+110|0)){break a}b:{if(!c){break b}Bd(a,67108864);Dg(a);b=y[e+135|0];w[a+480190>>1]=31;w[a+480188>>1]=b;x[a+480228>>2]=256/(b>>>0);b=Tb(e,8077);zb(a+1298344|0,b);tb(b);b=Tb(e,10654);zb(a+1298356|0,b);tb(b);d=e+84|0;hf(d,4115);f=y[e+134|0];x[e+64>>2]=f>>>4;b=0;x[23549]=0;x[e+104>>2]=f&15;V(290,e|0,d|0,e- -64|0,e+104|0);d=x[23549];x[23549]=0;c:{d:{if((d|0)!=1){zb(a+1298368|0,e);tb(e);Ab(e+84|0);x[a+1298404>>2]=13;Bu(Wb(x[a+484360>>2],y[a+484376|0]),e+158|0,y[e+157|0]+1|0);while(1){e:{if((b|0)==31){QB(j,a+1298308|0,32);d=1;break e}d=b+1|0;g=D(d,104)+a|0;h=g+484380|0;nd(h,1);f=(e+110|0)+(b<<2)|0;o=h,q=$b(y[f+176|0]|y[f+177|0]<<8|(y[f+178|0]<<16|y[f+179|0]<<24)),x[o>>2]=q;k=$b(y[f+300|0]|y[f+301|0]<<8|(y[f+302|0]<<16|y[f+303|0]<<24));x[g+484384>>2]=k;f=$b(y[f+424|0]|y[f+425|0]<<8|(y[f+426|0]<<16|y[f+427|0]<<24));x[g+484388>>2]=f+k;if(f){f=g+484414|0;w[f>>1]=z[f>>1]|2}ok(h);b=(e+110|0)+b|0;v[e|0]=y[b+548|0];v[e+84|0]=64;o=g+484410|0,q=y[Sb(e,e+84|0)|0]<<2,w[o>>1]=q;v[g+484417|0]=y[b+579|0]<<4;b=d;continue}break}while(1){if((d|0)!=32){IV(j,((d<<5)+a|0)+946304|0,30);d=d+1|0;continue}break}m=c&1;if(m){mg(a+484344|0,y[e+156|0]+1|0)}k=a+484344|0;f=0;while(1){if(y[e+156|0]<f>>>0){d=1;if(!(c&2)){break a}b=Xc(e,8,1,1,0);while(1){if((d|0)==32){break b}lg(b,(D(d,104)+a|0)+484380|0,j);d=d+1|0;continue}}g=xh(e+84|0);f:{g:{if(y[e+136|0]){x[23549]=0;b=R(260,j|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break f}x[23549]=0;S(176,e- -64|0,j|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break f}break g}b=z[a+480188>>1];x[23549]=0;S(176,e- -64|0,j|0,b<<8);b=x[23549];x[23549]=0;if((b|0)==1){break d}}b=e- -64|0;d=hc(e,b);Zc(g,d);ub(d);ub(b);h:{if(!m){break h}x[23549]=0;b=U(212,k|0,f&65535,64)|0;d=x[23549];x[23549]=0;if((d|0)==1){break d}if(!b){break h}b=0;if(y[e+136|0]){h=0;x[23549]=0;P(291,g|0,e|0);b=x[23549];x[23549]=0;if((b|0)==1){break d}i:while(1){if((h|0)==64){break h}i=e+h|0;b=128;d=0;l=Yb(x[k>>2],f);l=sf(x[l>>2],x[x[l+48>>2]+12>>2],h);while(1){if(z[a+480188>>1]<=d>>>0){h=h+1|0;continue i}j:{if(!(y[i|0]&b)){break j}x[23549]=0;P(292,g|0,l+D(d,6)|0);n=x[23549];x[23549]=0;if((n|0)!=1){break j}break d}b=b>>>1|0;d=d+1|0;continue}}}k:while(1){d=0;h=b&65535;if(h>>>0>=z[a+480188>>1]){break h}while(1){if((d|0)==64){b=b+1|0;continue k}i=Yb(x[k>>2],f);i=$c(x[i>>2],x[x[i+48>>2]+12>>2],d,h);x[23549]=0;P(292,g|0,i|0);i=x[23549];x[23549]=0;if((i|0)!=1){d=d+1|0;continue}break}break}break d}ub(g);f=f+1|0;continue}break}break d}d=N()|0;Ab(e+84|0);break c}d=N()|0;ub(g)}Q(d|0);p()}d=1}db=e+720|0;return d|0}function OM(a,b){var c=0,d=0,e=0,f=0,g=E(0),h=0,i=0,j=0,k=0,l=E(0),m=E(0),n=0,o=0,p=0,q=0,r=0,s=E(0),t=0;if(b){uy(a);c=a+24596|0;x[c>>2]=0;x[c+4>>2]=0;x[a+24588>>2]=0;x[a+24592>>2]=0;UM(a)}NM(a+24648|0);o=x[a+24620>>2];f=db-144|0;db=f;d=!b;e=a+397456|0;c=x[e+4>>2];if(c>>>0>=29){x[e+4>>2]=0;c=0}h=D(c,44)+47696|0;if(!((h|0)==x[e+8>>2]&d)){x[e+8>>2]=h;m=E(o>>>0);c=f+12|0;d=x[h+24>>2];x[c>>2]=d;j=x[h+16>>2];x[c+4>>2]=j;x[c+8>>2]=x[h+4>>2];k=(d|0)>(j|0)?d:j;if((k|0)<=-601){i=j;j=k+600|0;x[c+4>>2]=i-j;x[c>>2]=d-j}g=E(B[h+36>>2]*E(79.30999755859375));a:{if(E(F(g))<E(2147483648)){d=~~g;break a}d=-2147483648}x[c+16>>2]=d- -8192;g=E(E(E(B[h+32>>2]*E(.0036000001709908247))+E(.15000000596046448))*E(32767));b:{if(E(F(g))<E(2147483648)){d=~~g;break b}d=-2147483648}x[c+20>>2]=(d|0)>=32512?32512:d;j=0;g=B[h+8>>2];l=B[h+20>>2];l=E((l>E(.10000000149011612)?E(.10000000149011612):l)*m);c:{if(E(F(l))<E(2147483648)){d=~~l;break c}d=-2147483648}k=(d|0)<=96?96:d;i=k-7500|0;n=k>>>0>=i>>>0?i:0;l=E(B[h+28>>2]*m);d:{if(E(F(l))<E(2147483648)){i=~~l;break d}i=-2147483648}d=n+(i+((d|0)<96?d-96|0:0)|0)|0;i=(d|0)<=128?128:d;p=i>>>0>=3800?3800:i;x[c+24>>2]=p;n=(d|0)<128?d-128|0:0;g=E(g*m);e:{if(E(F(g))<E(2147483648)){q=~~g;break e}q=-2147483648}d=i-3800|0;i=(q+n|0)+(d>>>0<=i>>>0?d:0)|0;x[c+32>>2]=i;n=k>>>0>=7500?7500:k;while(1){if((j|0)==8){g=E(i|0);l=E(qe(E(.0010000000474974513),(i|0)<4721?E(1):E(E(4720)/g))*E(32768));f:{if(E(F(l))<E(2147483648)){d=~~l;break f}d=-2147483648}x[c+12>>2]=d;g=E(B[h+12>>2]*g);r=c,s=qe(E(.0010000000474974513),g<=E(4720)?E(1):E(E(4720)/g)),B[r+28>>2]=s}else{d=D(j,12);k=d+c|0;w[k+42>>1]=z[d+48986>>1];w[k+36>>1]=z[d+48980>>1];w[k+40>>1]=z[d+48984>>1];w[k+38>>1]=z[d+48982>>1];x[k+44>>2]=n+((D(x[d+48976>>2],p)+50|0)/100|0);j=j+1|0;continue}break}x[e+20>>2]=x[f+44>>2];c=NK(OK(x[f+20>>2]),m);w[e+86>>1]=c;w[e+84>>1]=c;c=z[f+28>>1]<<1;w[e+94>>1]=c;w[e+92>>1]=c;c=0;while(1){if((c|0)==8){x[e+49892>>2]=x[f+36>>2];c=x[f+16>>2];if((c|0)>-9e3){c=MK(c)}else{c=0}x[e+80>>2]=c;d=e+49948|0;c=x[f+12>>2];if((c|0)>=-8999){c=MK(c)}else{c=0}x[d>>2]=c;c=x[f+32>>2];d=e+49932|0;x[d>>2]=268464128;x[d+4>>2]=1879052288;c=c>>>0>=32512?32512:c;w[e+49906>>1]=c;w[e+49904>>1]=c;w[e+49902>>1]=c;w[e+49900>>1]=c;x[f+8>>2]=x[f+24>>2];ke(f+8|0,0,32752);c=z[f+8>>1];w[e+49914>>1]=c;w[e+49910>>1]=0;w[e+49912>>1]=0;w[e+49908>>1]=c;g=B[f+40>>2];r=f,t=NK(E(g*g),m),x[r+4>>2]=t;ke(f+4|0,256,32512);c=z[f+4>>1];w[e+49922>>1]=c;w[e+49918>>1]=0;w[e+49920>>1]=0;w[e+49916>>1]=c}else{d=(c<<4)+e|0;h=(f+12|0)+D(c,12)|0;j=x[h+44>>2];x[d+100>>2]=j;x[d+104>>2]=j;w[d+108>>1]=z[h+36>>1];w[d+110>>1]=z[h+42>>1];w[d+112>>1]=z[h+40>>1];w[d+114>>1]=z[h+38>>1];c=c+1|0;continue}break}}if(b){x[e+16>>2]=0;QK(e,a+397448|0,a+397452|0)}b=D(o,5);if(b>>>0>A[e+20>>2]){x[e+20>>2]=b}db=f+144|0;b=x[a+1298300>>2];if(ud(b)){FP(b,x[a+24620>>2])}}function Ht(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=x[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=x[a>>2];b=c+b|0;c:{d:{e:{a=a-c|0;if((a|0)!=x[23430]){if(c>>>0<=255){d=x[a+8>>2];e=x[a+12>>2];if((d|0)!=(e|0)){break e}i=93700,j=x[23425]&Cka(-2,c>>>3|0),x[i>>2]=j;break b}g=x[a+24>>2];c=x[a+12>>2];if((c|0)!=(a|0)){d=x[a+8>>2];x[d+12>>2]=c;x[c+8>>2]=d;break c}e=a+20|0;d=x[e>>2];if(!d){d=x[a+16>>2];if(!d){break d}e=a+16|0}while(1){h=e;c=d;e=c+20|0;d=x[e>>2];if(d){continue}e=c+16|0;d=x[c+16>>2];if(d){continue}break}x[h>>2]=0;break c}c=x[f+4>>2];if((c&3)!=3){break b}x[23427]=b;x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[f>>2]=b;return}x[d+12>>2]=e;x[e+8>>2]=d;break b}c=0}if(!g){break b}d=x[a+28>>2];e=(d<<2)+94004|0;f:{if(x[e>>2]==(a|0)){x[e>>2]=c;if(c){break f}i=93704,j=x[23426]&Cka(-2,d),x[i>>2]=j;break b}x[g+(x[g+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}x[c+24>>2]=g;d=x[a+16>>2];if(d){x[c+16>>2]=d;x[d+24>>2]=c}d=x[a+20>>2];if(!d){break b}x[c+20>>2]=d;x[d+24>>2]=c}g:{h:{i:{j:{c=x[f+4>>2];if(!(c&2)){if(x[23431]==(f|0)){x[23431]=a;b=x[23428]+b|0;x[23428]=b;x[a+4>>2]=b|1;if(x[23430]!=(a|0)){break a}x[23427]=0;x[23430]=0;return}if(x[23430]==(f|0)){x[23430]=a;b=x[23427]+b|0;x[23427]=b;x[a+4>>2]=b|1;x[a+b>>2]=b;return}b=(c&-8)+b|0;if(c>>>0<=255){e=c>>>3|0;c=x[f+12>>2];d=x[f+8>>2];if((c|0)==(d|0)){i=93700,j=x[23425]&Cka(-2,e),x[i>>2]=j;break h}x[d+12>>2]=c;x[c+8>>2]=d;break h}g=x[f+24>>2];c=x[f+12>>2];if((f|0)!=(c|0)){d=x[f+8>>2];x[d+12>>2]=c;x[c+8>>2]=d;break i}e=f+20|0;d=x[e>>2];if(!d){d=x[f+16>>2];if(!d){break j}e=f+16|0}while(1){h=e;c=d;e=c+20|0;d=x[e>>2];if(d){continue}e=c+16|0;d=x[c+16>>2];if(d){continue}break}x[h>>2]=0;break i}x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[a+b>>2]=b;break g}c=0}if(!g){break h}d=x[f+28>>2];e=(d<<2)+94004|0;k:{if(x[e>>2]==(f|0)){x[e>>2]=c;if(c){break k}i=93704,j=x[23426]&Cka(-2,d),x[i>>2]=j;break h}x[g+(x[g+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}x[c+24>>2]=g;d=x[f+16>>2];if(d){x[c+16>>2]=d;x[d+24>>2]=c}d=x[f+20>>2];if(!d){break h}x[c+20>>2]=d;x[d+24>>2]=c}x[a+4>>2]=b|1;x[a+b>>2]=b;if(x[23430]!=(a|0)){break g}x[23427]=b;return}if(b>>>0<=255){c=(b&-8)+93740|0;d=x[23425];b=1<<(b>>>3);l:{if(!(d&b)){x[23425]=b|d;b=c;break l}b=x[c+8>>2]}x[c+8>>2]=a;x[b+12>>2]=a;x[a+12>>2]=c;x[a+8>>2]=b;return}d=31;if(b>>>0<=16777215){c=G(b>>>8|0);d=((b>>>38-c&1)-(c<<1)|0)+62|0}x[a+28>>2]=d;x[a+16>>2]=0;x[a+20>>2]=0;c=(d<<2)+94004|0;m:{e=x[23426];h=1<<d;n:{if(!(e&h)){x[23426]=e|h;x[c>>2]=a;x[a+24>>2]=c;break n}d=b<<((d|0)!=31?25-(d>>>1|0)|0:0);c=x[c>>2];while(1){e=c;if((x[c+4>>2]&-8)==(b|0)){break m}c=d>>>29|0;d=d<<1;h=e+(c&4)|0;c=x[h+16>>2];if(c){continue}break}x[h+16>>2]=a;x[a+24>>2]=e}x[a+12>>2]=a;x[a+8>>2]=a;return}b=x[e+8>>2];x[b+12>>2]=a;x[e+8>>2]=a;x[a+24>>2]=0;x[a+12>>2]=e;x[a+8>>2]=b}}function hX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0;e=db-32|0;db=e;x[e+28>>2]=b;a:{if((d|0)<=0){break a}x[e+8>>2]=d;x[e+16>>2]=214748364;u=e,w=D(x[Cb(e+28|0,e+16|0)>>2],20),x[u+20>>2]=w;sn(c,x[Cb(e+8|0,e+20|0)>>2]);x[e+12>>2]=b;x[e+8>>2]=a;while(1){b:{c:{d:{e:{if((d|0)<=0){break e}g=bh(a,b,i);h=bh(a,b,i+4|0);f=bh(a,b,i+5|0);u=e,w=bh(a,b,i+6|0)<<8|bh(a,b,i+7|0),x[u+24>>2]=w;n=f|h<<8;t=i+8|0;f:{g:{switch(g|0){case 0:i=0;if(d>>>0<n>>>0){i=ac(8);x[23549]=0;a=R(179,i|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break f}break d}while(1){if((i|0)!=(n|0)){u=e,w=bh(a,b,i+t|0),v[u+20|0]=w;qn(c,e+20|0);i=i+1|0;continue}break};s=n;break b;case 1:break g;default:break e}}Zh(e+24|0,d);s=x[e+24>>2];o=bh(a,b,i+10|0);v[e+20|0]=o;qn(c,e+20|0);j=i+11|0;n=n+3&65532;i=s-1|0;h=0;l=0;q=0;m=0;while(1){if((i|0)<=0){break c}f=og(j,h,1,e+8|0);h:{i:{j:{k:{l:{if((l|0)<=7){if(f){g=h;break i}g=h+1|0;m=8;break l}g=h+1|0;m:{if(!f){if(!og(j,g,1,e+8|0)){break i}k=2;n:{o:{f=h+2|0;if(!og(j,f,1,e+8|0)){break o}k=3;f=h+3|0;if(!og(j,f,1,e+8|0)){break o}k=og(j,f,3,e+8|0);g=h+6|0;break n}g=f+1|0}f=4;p:{q:{r:{h=((m<<3)+k|0)-17|0;s:{if((h|0)<0){a=ac(8);x[23549]=0;b=R(179,a|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break r}break s}if(h>>>0<56){break p}a=ac(8);x[23549]=0;b=R(179,a|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break q}}b=N()|0;jc(a);Q(b|0);p()}da(b|0,26136,154);p()}da(b|0,26136,154);p()}m=y[h+26176|0];if((m|0)!=8){break k}break m}f=4;if((m|0)!=8){break k}}m=8;f=1;if((q|0)>19){break k}}f=0;break j}q=q+8|0}while(1){if(!((f|0)<0|(i|0)<=0)){k=(g|0)/8|0;h=k+j|0;r=bh(x[e+8>>2],x[e+12>>2],h);o=o-gd((bh(x[e+8>>2],x[e+12>>2],h+1|0)<<8|r<<16|bh(x[e+8>>2],x[e+12>>2],h+2|0))<<(g-(k<<3)|0)+8,32-m|0)|0;v[e+20|0]=o;qn(c,e+20|0);f=f-1|0;i=i-1|0;g=g+m|0;continue}break}l=(l|0)==31?31:l+1|0;h=g;break h}t:{u:{v:{f=g+1|0;if(!og(j,f,1,e+8|0)){h=2;break v}f=g+2|0;if(!og(j,f,1,e+8|0)){h=4;break v}f=g+3|0;if(!og(j,f,1,e+8|0)){h=6;break v}f=g+5|0;if(!og(j,g+4|0,1,e+8|0)){g=g+8|0;f=og(j,f,3,e+8|0)+8|0;break t}g=g+10|0;h=16;f=og(j,f,5,e+8|0);break u}g=f+2|0;f=og(j,f+1|0,1,e+8|0)}f=f+h|0}w:{if(og(j,g,1,e+8|0)){k=-256;h=12;break w}g=g+1|0;h=og(j,g,1,e+8|0);k=h?-4352:0;h=h?14:8}r=g+1|0;g=og(j,r,h,e+8|0);if(f>>>0>=3){l=l-((f|0)!=3)|0;l=((l|0)<=1?1:l)-1|0}k=(g^-1)+k|0;g=Pc(x[c>>2],x[c+4>>2])+k|0;if(g>>>0<k>>>0){h=h+r|0;while(1){if((f|0)<=0|(i|0)<=0){break h}o=y[Db(x[c>>2],g)|0];v[e+20|0]=o;qn(c,e+20|0);i=i-1|0;g=g+1|0;f=f-1|0;continue}}i=ac(8);x[23549]=0;a=R(179,i|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break d}da(a|0,26136,154);p()}q=q-(q>>3)|0;continue}}da(a|0,26136,154);p()}i=qc(x[c>>2],x[c+4>>2])^1;break a}a=N()|0;jc(i);Q(a|0);p()}x[e+24>>2]=i}d=d-s|0;i=n+t|0;continue}}db=e+32|0;return i|0}function yea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=db-32|0;db=j;a:{b:{if(wt(a)>>>0<b>>>0){if((b|0)<0){break b}m=oo(j+20|0);x[23549]=0;P(700,m|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break a}tm(j+12|0,x[a>>2]);bq(j+4|0,x[a>>2],x[a+4>>2]);l=db-48|0;db=l;e=x[m+4>>2];c=ec(l+40|0,x[j+12>>2],x[j+16>>2]);f=ec(l+32|0,x[j+4>>2],x[j+8>>2]);b=db-16|0;db=b;c=ec(b+8|0,x[c>>2],x[c+4>>2]);f=ec(b,x[f>>2],x[f+4>>2]);c=UR(x[c>>2],x[c+4>>2],x[f>>2],x[f+4>>2]);db=b+16|0;c=c+e|0;x[m+4>>2]=c;c:{d:{if(!e){b=c-1|0;break d}b=c-1|0;if((b^e-1)>>>0<32){break c}}x[x[m>>2]+((c>>>0>=33?b>>>5|0:0)<<2)>>2]=0}c=ec(l+24|0,x[j+12>>2],x[j+16>>2]);g=ec(l+16|0,x[j+4>>2],x[j+8>>2]);b=l+8|0;Qo(b,x[m>>2],e);e=x[c>>2];n=db-48|0;db=n;c=x[c+4>>2];e:{if((c|0)==x[b+4>>2]){f=ec(n+40|0,e,c);c=ec(n+32|0,x[g>>2],x[g+4>>2]);b=ec(n+24|0,x[b>>2],x[b+4>>2]);e=db-16|0;db=e;g=x[f>>2];d=x[f+4>>2];c=sm(x[c>>2],x[c+4>>2],g,d);x[e+12>>2]=c;f:{if((c|0)<=0){c=x[b>>2];break f}if(d){i=32-d|0;x[e+8>>2]=i;h=c;c=x[qd(e+8|0,e+12|0)>>2];x[e+12>>2]=h-c;h=x[b>>2];d=-1<<d&-1>>>i-c;x[h>>2]=x[h>>2]&(d^-1)|d&x[g>>2];c=c+x[b+4>>2]|0;x[b+4>>2]=c&31;x[b>>2]=h+(c>>>3&536870908);g=x[f>>2]+4|0;x[f>>2]=g;c=x[e+12>>2]}h=g;g=(c|0)/32|0;TR(h,g,x[b>>2]);d=c-(g<<5)|0;x[e+12>>2]=d;g=g<<2;c=g+x[b>>2]|0;x[b>>2]=c;if((d|0)<=0){break f}c=f;f=g+x[f>>2]|0;x[c>>2]=f;c=x[b>>2];g=-1>>>32-d|0;x[c>>2]=x[c>>2]&(g^-1)|g&x[f>>2];x[b+4>>2]=x[e+12>>2]}ec(l,c,x[b+4>>2]);db=e+16|0;break e}c=ec(n+16|0,e,c);e=ec(n+8|0,x[g>>2],x[g+4>>2]);g=ec(n,x[b>>2],x[b+4>>2]);f=db-16|0;db=f;h=x[e>>2];d=x[e+4>>2];b=x[c>>2];e=x[c+4>>2];d=sm(h,d,b,e);x[f+12>>2]=d;g:{if((d|0)<=0){e=x[g+4>>2];c=x[g>>2];break g}h:{if(!e){e=x[g+4>>2];break h}k=32-e|0;x[f+8>>2]=k;i=f+8|0;h=x[qd(i,f+12|0)>>2];x[f+12>>2]=d-h;d=x[g+4>>2];q=x[b>>2];x[f+8>>2]=h;o=32-d|0;x[f+4>>2]=o;b=x[g>>2];r=x[b>>2];i=x[Cb(i,f+4|0)>>2];k=q&(-1<<e&-1>>>k-h);x[b>>2]=(-1<<d&-1>>>o-i^-1)&r|(e>>>0<d>>>0?k<<d-e:k>>>e-d|0);d=d+i|0;e=d&31;x[g+4>>2]=e;d=b+(d>>>3&536870908)|0;x[g>>2]=d;b=h-i|0;if((b|0)>0){x[d>>2]=x[d>>2]&(-1>>>32-b^-1)|k>>>i+x[c+4>>2];x[g+4>>2]=b;e=b}b=x[c>>2]+4|0;x[c>>2]=b;d=x[f+12>>2]}h=32-e|0;i=-1<<e;k=i^-1;while(1){if((d|0)>=32){d=x[g>>2];b=x[b>>2];x[d>>2]=k&x[d>>2]|b<<e;x[g>>2]=d+4;x[d+4>>2]=i&x[d+4>>2]|b>>>h;d=x[f+12>>2]-32|0;x[f+12>>2]=d;b=x[c>>2]+4|0;x[c>>2]=b;continue}break}c=x[g>>2];if((d|0)<=0){break g}k=x[b>>2];x[f+8>>2]=h;o=x[c>>2];b=x[qd(f+12|0,f+8|0)>>2];i=o&(i&-1>>>h-b^-1);h=k&-1>>>32-d;x[c>>2]=i|h<<e;d=b+e|0;e=d&31;x[g+4>>2]=e;c=(d>>>3&536870908)+c|0;x[g>>2]=c;d=x[f+12>>2]-b|0;x[f+12>>2]=d;if((d|0)<=0){break g}x[c>>2]=x[c>>2]&(-1>>>32-d^-1)|h>>>b;e=x[f+12>>2];x[g+4>>2]=e}ec(l,c,e);db=f+16|0}db=n+48|0;db=l+48|0;Dt(a,m);He(m)}db=j+32|0;return}Rc();p()}a=N()|0;He(m);Q(a|0);p()}function jU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=db-128|0;db=g;i=ig(g+116|0);a:{b:{c:{if(d){x[23549]=0;S(424,a|0,i|0,c|0);c=x[23549];x[23549]=0;if((c|0)!=1){break c}break b}x[23549]=0;S(425,a|0,i|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}}k=Nb(g+104|0);c=1;while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{h=c&65535;if(h>>>0<=z[b+480192>>1]){x[23549]=0;w[g+102>>1]=0;P(426,a|0,g+102|0);d=x[23549];x[23549]=0;t:{u:{v:{w:{if((d|0)!=1){j=db-16|0;db=j;m=z[g+102>>1];d=Ud(i);e=gc(i);f=db-16|0;db=f;while(1){if(d){l=yo(z[d+16>>1],m);e=l?e:d;d=x[(l?d+4|0:d)>>2];continue}break}d=x[vb(f+12|0,e)>>2];db=f+16|0;x:{if(Kb(d,Kf(i))){if(!yo(z[g+102>>1],z[td(d)>>1])){break x}}d=Kf(i)}d=vb(j+12|0,d);db=j+16|0;j=((h<<2)+b|0)+900380|0;if(!x[j>>2]){break d}d=x[d>>2];if(!xg(d,Bf(i))){break u}x[23549]=0;d=O(3,g+88|0,td(d)+4|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break t}x[23549]=0;e=O(1,g+76|0,16369)|0;f=x[23549];x[23549]=0;if((f|0)==1){break v}f=qq(d,e);tb(e);if(f){break p}e=x[b+4>>2];x[23549]=0;e=O(427,e|0,d|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break r}x[x[j>>2]+44>>2]=e;if(!x[x[j>>2]+44>>2]){break w}break e}c=N()|0;break f}x[23549]=0;e=O(1,g- -64|0,13256)|0;f=x[23549];x[23549]=0;y:{z:{A:{if((f|0)!=1){B:{if(!qq(d,e)){x[23549]=0;f=O(1,g+52|0,13416)|0;h=x[23549];x[23549]=0;if((h|0)==1){break A}h=qq(d,f);tb(f);tb(e);if(h){break B}break s}tb(e)}x[23549]=0;e=R(428,d|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break z}x[g+36>>2]=e;e=x[b+4>>2];f=x[Vf(g+48|0,g+36|0)>>2];x[23549]=0;e=O(429,e|0,f|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break y}Lf(g+36|0);if(e){break e}break s}c=N()|0;break g}c=N()|0;tb(e);break g}c=N()|0;break g}c=N()|0;Lf(g+36|0);break g}c=N()|0;break g}d=x[j>>2];if(!d){break d}x[d+44>>2]=0;break d}c=N()|0;break f}Yd(k);hU(i);db=g+128|0;return}e=yb(x[k>>2]);h=yb(x[k+4>>2]);f=db-16|0;db=f;x[f+12>>2]=e;while(1){C:{if(!Kb(e,h)){break C}if(qq(e,d)){break C}e=x[Bj(f+12|0)>>2];continue}break}db=f+16|0;if(Kb(e,yb(x[k+4>>2]))){break p}x[23549]=0;P(430,k|0,d|0);e=x[23549];x[23549]=0;if((e|0)!=1){break q}}c=N()|0;break g}x[23549]=0;e=O(1,g+12|0,17070)|0;f=x[23549];x[23549]=0;if((f|0)==1){break o}x[23549]=0;S(431,g+24|0,e|0,d|0);f=x[23549];x[23549]=0;if((f|0)==1){break n}x[23549]=0;f=O(1,g|0,15945)|0;h=x[23549];x[23549]=0;if((h|0)==1){break m}x[23549]=0;S(2,g+36|0,g+24|0,f|0);h=x[23549];x[23549]=0;if((h|0)==1){break l}h=x[b+1298464>>2];x[23549]=0;S(359,h|0,2,g+36|0);h=x[23549];x[23549]=0;if((h|0)==1){break k}tb(g+36|0);tb(f);tb(g+24|0);tb(e)}x[x[j>>2]+44>>2]=0;break e}c=N()|0;break g}c=N()|0;break h}c=N()|0;break i}c=N()|0;break j}c=N()|0;tb(g+36|0)}tb(f)}tb(g+24|0)}tb(e)}tb(d)}Yd(k);break a}tb(d)}c=c+1|0;continue}}c=N()|0}hU(i);Q(c|0);p()}function Zea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0;g=db-4128|0;db=g;h=Hb(y[a+14|0]|y[a+15|0]<<8);if(!(!h|h>>>0>20|z[b+480190>>1]<=y[a+23|0])){nd(d,32);w[d+34>>1]=1;f=g+12|0;h=a+20|0;x[f>>2]=h;x[f+4>>2]=(h+80|0)-h>>2;YQ(g+4120|0,x[g+12>>2],x[g+16>>2],Hb(y[a+14|0]|y[a+15|0]<<8));h=x[g+4120>>2];i=y[xb(h,0)+3|0];x[g+12>>2]=1;i=x[Yc(_j(b,i+1|0)+24|0,f)>>2];j=f;f=x[g+4124>>2];YQ(j,h,f,c?f:1);s=1/+(i>>>0);f=x[g+12>>2];i=xb(f,x[g+16>>2]);h=x[d>>2];j=x[g+4120>>2];k=z[b+480190>>1];while(1){if((f|0)==(i|0)){a:{o=zg(d);if(!o){break a}i=(e<<12>>>0)/1e4|0;f=x[g+4124>>2];e=db-16|0;db=e;j=g+4108|0;x[j>>2]=0;x[j+4>>2]=0;xc(j+8|0);Id(e+8|0,x[vb(e+4|0,j)>>2]);b:{if(!f){break b}x[23549]=0;P(692,j|0,f|0);h=x[23549];x[23549]=0;if((h|0)!=1){x[23549]=0;MQ(j,f);f=x[23549];x[23549]=0;if((f|0)!=1){break b}}a=N()|0;Jt(e+8|0);Q(a|0);p()}f=e+8|0;Hd(f);Jt(f);db=e+16|0;r=x[j>>2];l=x[g+4120>>2];u=x[g+4124>>2];f=0;while(1){if((f|0)==(u|0)){h=b+24648|0}else{k=xb(l,f);e=XQ(r,f);n=y[k+3|0];c:{if(n>>>0>=z[b+480190>>1]){break c}q=v[k+1|0];if((q|0)<0){break c}h=0;k=y[k+2|0];if((k+14&255)>>>0<=5){h=v[k+26862|0]}k=_j(b,n+1|0);n=x[k+24>>2];t=s*(Dj(+(h<<24>>24)/96+ +(q-v[xb(l,0)+1|0]|0)/12)*+(n>>>0));if(t<=0){break c}h=WQ(t);x[e+8>>2]=h;n=hb;x[e+12>>2]=n;x[e+16>>2]=x[k+20>>2];q=x[k>>2];x[e+76>>2]=q;x[e+88>>2]=z[k+34>>1]&1023;d:{if(c){x[e+664>>2]=m;m=Le(+(q>>>0)/Vz(h,n))+m|0;h=i;break d}h=(i>>>0)/(Hb(y[a+14|0]|y[a+15|0]<<8)>>>0)|0}x[e+20>>2]=h;x[e+24>>2]=h}f=f+1|0;continue}break}b=0;while(1){e:{a=x[d>>2];if(a>>>0>b>>>0){Vb(g+12|0,0,4096);x[g+8>>2]=512;x[g+4>>2]=a-b;c=x[Cb(g+8|0,g+4|0)>>2];B=g,C=yb(x[j>>2]),x[B+8>>2]=C;i=yb(x[j+4>>2]);while(1){a=x[g+8>>2];if(!Kb(a,i)){break e}f:{g:{if(!x[a+16>>2]){break g}e=x[a+664>>2];if(e>>>0>=c>>>0){x[a+664>>2]=e-c;break g}f=x[a+88>>2];x[g+4>>2]=c-e;B=g,C=Le((+A[a+76>>2]-Vz(x[a>>2],x[a+4>>2]))/Vz(x[a+8>>2],x[a+12>>2])),x[B>>2]=C;m=x[Cb(g+4|0,g)>>2];x[23549]=0;V(x[((f&1|(f&64?18:16))<<2)+27456>>2],a|0,h|0,(g+12|0)+(e<<3)|0,m|0);e=x[23549];x[23549]=0;if((e|0)==1){break f}x[a+664>>2]=0;if(A[a+76>>2]>A[a+4>>2]){break g}x[a+16>>2]=0}x[g+8>>2]=x[g+8>>2]+872;continue}break}a=N()|0;Kt(j);Q(a|0);p()}Kt(j);break a}e=x[d+20>>2]+(b<<1)|0;f=g+12|0;a=db-16|0;db=a;x[a+12>>2]=c;tc(a+12|0,512);m=x[a+12>>2];while(1){if(m){i=gd(x[f>>2]+2048|0,12);i=(i|0)>=32767?32767:i;w[e>>1]=(i|0)<=-32768?-32768:i;f=f+8|0;e=e+2|0;m=m-1|0;continue}break}db=a+16|0;b=b+c|0;continue}}f=(o|0)!=0}else{l=y[f+3|0];h:{if(l>>>0>=k>>>0){break h}o=v[f+1|0];if((o|0)<0){break h}l=_j(b,l+1|0);r=x[l>>2];h=Le(s*(Dj(+(o-v[xb(j,0)+1|0]|0)/-12)*+(r>>>0)*+A[l+24>>2]))+h|0;x[d>>2]=h}f=f+4|0;continue}break}}db=g+4128|0;return f|0}function pX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=db-144|0;db=d;wc(b);ap(a);a:{if(!sv(b,d+108|0)){break a}if(!yD(d+108|0)){break a}j=x[b+8>>2];b:{if(!Vc(b,y[d+124|0]|y[d+125|0]<<8|(y[d+126|0]<<16|y[d+127|0]<<24))){break b}while(1){c:{if((y[d+120|0]|y[d+121|0]<<8|(y[d+122|0]<<16|y[d+123|0]<<24))>>>0>h>>>0){if(Lb(x[b>>2],x[b+8>>2],5)){break c}}f=i&1;break b}d:{if((y[d+112|0]|y[d+113|0]<<8)>>>0>=64){if((pi(b)|0)<=0){break d}}f=0;g=1;while(1){l=ee(b);if(l){m=f>>>0>4;e=m&g;if(!((g^1)&1|m)){e=(Dp(l<<24>>24)&255)==y[f+12955|0]}g=e;f=f+1|0;continue}break}Zb(b,4);i=(f|0)==5?g&1?1:i:i}h=h+1|0;continue}}Vc(b,j);if(!f){break a}if(!Lb(x[b>>2],x[b+8>>2],xD(d+108|0))){break a}if(!c){k=1;break a}e=db-16|0;db=e;c=d+108|0;Vc(b,y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24));i=d+96|0;f=Nb(i);g=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);x[23549]=0;P(167,f|0,g|0);g=x[23549];x[23549]=0;e:{f:{g:{if((g|0)!=1){g=0;h:{i:{while(1){if((y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24))>>>0<=g>>>0){break h}h=x[b+8>>2];j=x[b>>2];x[23549]=0;h=U(142,j|0,h|0,5)|0;j=x[23549];x[23549]=0;if((j|0)==1){break g}if(!h){break h}h=y[c+4|0]|y[c+5|0]<<8;x[23549]=0;S(168,e+4|0,b|0,h|0);h=x[23549];x[23549]=0;if((h|0)!=1){x[23549]=0;P(169,f|0,e+4|0);h=x[23549];x[23549]=0;if((h|0)==1){break i}g=g+1|0;tb(e+4|0);continue}break}a=N()|0;break f}a=N()|0;tb(e+4|0);break f}db=e+16|0;break e}a=N()|0;break f}a=N()|0}Yd(f);Q(a|0);p()}x[23549]=0;V(162,d+84|0,b|0,c|0,i|0);c=x[23549];x[23549]=0;j:{if((c|0)!=1){x[23549]=0;O(141,b|0,y[d+132|0]|y[d+133|0]<<8|(y[d+134|0]<<16|y[d+135|0]<<24))|0;c=x[23549];x[23549]=0;k:{if((c|0)!=1){g=d+36|0;l:{m:{n:{o:{while(1){p:{q:{if((y[d+128|0]|y[d+129|0]<<8|(y[d+130|0]<<16|y[d+131|0]<<24))>>>0>k>>>0){c=x[b+8>>2];e=x[b>>2];x[23549]=0;c=U(142,e|0,c|0,8)|0;e=x[23549];x[23549]=0;if((e|0)==1){break q}if(c){break p}}k=qc(x[a>>2],x[a+4>>2])^1;sc(d+84|0);Yd(d+96|0);break a}b=N()|0;break k}x[23549]=0;aa(163,d+60|0,b|0,d+108|0,d+84|0,d+96|0);c=x[23549];x[23549]=0;if((c|0)!=1){e=cp(d+60|0);x[23549]=0;c=R(164,x[d+60>>2])|0;f=x[23549];x[23549]=0;if((f|0)==1){break o}if(c){x[23549]=0;c=R(165,d+24|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break n}e=x[e>>2];r:{if((e|0)<0){break r}f=x[d+96>>2];if(Cd(f,x[d+100>>2])>>>0<=e>>>0){break r}x[23549]=0;S(11,d+12|0,8,$d(f,e)|0);e=x[23549];x[23549]=0;if((e|0)==1){break m}e=d+12|0;zb(c,e);tb(e)}qv(g,d+60|0);x[23549]=0;P(166,a|0,c|0);e=x[23549];x[23549]=0;if((e|0)==1){break m}Vo(c)}k=k+1|0;ub(d+60|0);continue}break}b=N()|0;break k}b=N()|0;break l}b=N()|0;break l}b=N()|0;Vo(c)}ub(d+60|0);break k}b=N()|0}sc(d+84|0);break j}b=N()|0}Yd(d+96|0);Q(b|0);p()}db=d+144|0;return k|0}function WK(a){var b=E(0),c=E(0),d=0,e=E(0),f=E(0),g=0,h=0,i=E(0),k=0,m=E(0),p=E(0),s=E(0),t=0,u=0,v=E(0),w=E(0);d=a+4208|0;DO(xb(d,0),B[a+4272>>2]);b=E(E(B[xb(d,0)>>2]*E(15920))+E(80));s=qe(E(10),E(E(E(B[xb(d,2)>>2]+E(-.5))*E(30))/E(40)));c=E(E(b/E(A[x[a+16>>2]+24620>>2]))*E(6.2831854820251465));b=nL(c);v=zp(c);w=b;f=E(E(c*E(E(E(B[xb(d,1)>>2]*E(35))+E(1))*E(.02888113260269165)))/b);m=(l(2,(q(f),j(2))&-2147483648|1056964608),r());c=E(F(f));k=(q(f),j(2))&2147483647;a:{if(k>>>0<=1118925334){b:{c:{d:{e:{f:{g:{h=(q(c),j(2));d=h&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=E(-1);if((h|0)<0){break b}if(d>>>0<1118925336){break g}b=E(c*E(17014118346046923e22));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((h|0)>=0){d=1;e=E(905800061445916e-20);b=E(c+E(-.6931381225585938));break f}d=-1;e=E(-905800061445916e-20);b=E(c+E(.6931381225585938));break f}b=E(E(c*E(1.4426950216293335))+(l(2,(q(c),j(2))&-2147483648|1056964608),r()));h:{if(E(F(b))<E(2147483648)){d=~~b;break h}d=-2147483648}b=E(d|0);e=E(b*E(905800061445916e-20));b=E(c+E(b*E(-.6931381225585938)))}c=E(b-e);e=E(E(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}b=E(c*E(.5));i=E(c*b);p=E(E(i*E(E(i*E(.0015807170420885086))+E(-.03333321213722229)))+E(1));b=E(E(3)-E(p*b));p=E(i*E(E(p-b)/E(E(6)-E(c*b))));b=E(c-E(E(c*p)-i));if(!d){break b}e=E(E(E(c*E(p-e))-e)-i);i:{switch(d+1|0){case 0:b=E(E(E(c-e)*E(.5))+E(-.5));break b;case 2:b=E(E(e-E(c+E(.5)))*E(-2));if(c<E(-.25)){break b}b=E(c-e);b=E(E(b+b)+E(1));break b;default:break i}}h=d<<23;b=(l(2,h+1065353216|0),r());if(d>>>0>=57){c=E(E(c-e)+E(1));b=E(((d|0)==128?E(E(c+c)*E(17014118346046923e22)):E(c*b))+E(-1));break b}i=(l(2,1065353216-h|0),r());c=E((d>>>0<=22?E(E(E(1)-i)+E(c-e)):E(E(c-E(e+i))+E(1)))*b)}b=c}if(k>>>0<=1065353215){if(k>>>0<964689920){break a}f=E(m*E(E(b+b)-E(E(b*b)/E(b+E(1)))));break a}f=E(m*E(b+E(b/E(b+E(1)))));break a}m=E(E(m+m)*E(1661534994731145e20));b=E(c+E(-162.88958740234375));d=Zw(b)&2047;j:{k:{if(Zw(E(88))>>>0>d>>>0){break k}c=E(0);if(((q(b),j(2))|0)==-8388608){break j}c=E(b+b);if(Zw(E(Infinity))>>>0<=d>>>0){break j}if(b>E(88.72283172607422)){c=mD(0);break j}if(!(b<E(-103.97207641601562))){break k}c=TC(0);break j}g=C[165]*+b;t=C[164];u=g+t;g=g-(u-t);g=(C[166]*g+C[167])*(g*g)+(C[168]*g+1);o(+u);j(1)|0;d=j(0)|0;h=d<<15;d=((d&31)<<3)+1024|0;k=x[d>>2];d=x[d+4>>2]+h|0;l(0,k|0);l(1,(k>>>0<k>>>0?d+1|0:d)|0);c=E(g*+n())}f=E(E(m*c)*E(1661534994731145e20))}c=E(w*f);f=E(c/s);b=E(f+E(1));B[a+4236>>2]=E(E(1)-f)/b;f=E(E(v*E(-2))/b);B[a+4232>>2]=f;c=E(c*s);B[a+4228>>2]=E(E(1)-c)/b;B[a+4224>>2]=f;B[a+4220>>2]=E(c+E(1))/b}function BK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=db-144|0;db=f;x[f+136>>2]=c;x[f+140>>2]=d;g=x[b+4>>2];a:{if(!g){break a}h=x[b>>2];i=y[Sk(h,g)|0];if((i|0)==33){e=1}else{if((i|0)!=63){break a}e=0}cl(f+112|0,h,g,g-1|0);g=x[f+116>>2];x[b>>2]=x[f+112>>2];x[b+4>>2]=g}g=f+112|0;Rd(g);h=x[f+112>>2];Rd(f+100|0);i=Rk(h,x[f+104>>2],b);Rd(g);g=x[b+4>>2];h=x[b>>2];b:{c:{d:{e:{f:{g:{h:{if((i|0)==x[f+116>>2]){a=mc(f+128|0,21204);c=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=c;if(Gc(h,g,f+8|0)){a=ac(8);x[23549]=0;P(937,f+100|0,f+136|0);b=x[23549];x[23549]=0;if((b|0)==1){break g}x[23549]=0;S(942,f+112|0,17211,f+100|0);b=x[23549];x[23549]=0;if((b|0)==1){break f}e=0;b=pc(a,f+112|0);x[23549]=0;S(105,b|0,61816,931);b=x[23549];x[23549]=0;if((b|0)!=1){break b}b=N()|0;tb(f+112|0);break e}if(!e){break h}a=ac(8);c=x[b>>2];b=x[b+4>>2];x[23549]=0;c=Ch(f+76|0,c,b);b=x[23549];x[23549]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){x[23549]=0;S(942,f+88|0,17247,c|0);b=x[23549];x[23549]=0;if((b|0)==1){break p}x[23549]=0;P(944,f+100|0,f+88|0);b=x[23549];x[23549]=0;e=1;if((b|0)==1){break o}x[23549]=0;P(937,f- -64|0,f+136|0);b=x[23549];x[23549]=0;if((b|0)==1){break n}x[23549]=0;S(946,f+112|0,f+100|0,f- -64|0);b=x[23549];x[23549]=0;if((b|0)==1){break m}b=pc(a,f+112|0);x[23549]=0;S(105,b|0,61816,931);b=x[23549];x[23549]=0;if((b|0)!=1){break b}b=N()|0;tb(f+112|0);e=0;break l}b=N()|0;break d}b=N()|0;e=1;break i}b=N()|0;break j}b=N()|0;break k}b=N()|0}tb(f- -64|0)}tb(f+100|0)}tb(f+88|0)}tb(c);if(e){break d}break c}b=mc(f+56|0,21204);e=x[b+4>>2];x[f+32>>2]=x[b>>2];x[f+36>>2]=e;if(Gc(h,g,f+32|0)){a=ac(8);x[23549]=0;P(937,f+100|0,f+136|0);b=x[23549];x[23549]=0;q:{r:{if((b|0)!=1){x[23549]=0;S(942,f+112|0,17211,f+100|0);b=x[23549];x[23549]=0;if((b|0)==1){break r}e=0;b=pc(a,f+112|0);x[23549]=0;S(105,b|0,61816,931);b=x[23549];x[23549]=0;if((b|0)!=1){break b}b=N()|0;tb(f+112|0);break q}b=N()|0;break d}b=N()|0;e=1}tb(f+100|0);if(e){break d}break c}b=mc(f+48|0,10824);e=x[b+4>>2];x[f+24>>2]=x[b>>2];x[f+28>>2]=e;if(Gc(h,g,f+24|0)){uK(a,Cc(c,d));break h}b=mc(f+40|0,8525);e=x[b+4>>2];x[f+16>>2]=x[b>>2];x[f+20>>2]=e;if(!Gc(h,g,f+16|0)){break h}a=x[a+32>>2];b=ez(c,d);b=b>>>0>=4?1:b;c=db-16|0;db=c;s:{if((Lj(y[a+140|0])|0)==(b|0)){d=a+120|0;ts(y[d+20|0]);b=db-16|0;db=b;x[b+12>>2]=c+15;a=db-16|0;db=a;e=x[15382];x[a+8>>2]=x[15381];x[a+12>>2]=e;e=x[15380];x[a>>2]=x[15379];x[a+4>>2]=e;ib[x[vp(a,Lj(y[d+20|0]))>>2]](b+12|0,d);db=a+16|0;db=b+16|0;break s}$J(a,b,aK(a))}db=c+16|0}db=f+144|0;return}b=N()|0;break d}b=N()|0;e=1}tb(f+100|0);if(!e){break c}}jc(a)}Q(b|0)}p()}function aE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=db-144|0;db=d;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((b|0)<=5){Cv(d+108|0,b);x[23549]=0;b=O(1,d+96|0,17347)|0;e=x[23549];x[23549]=0;if((e|0)==1){break E}x[23549]=0;S(2,d+120|0,d+108|0,b|0);e=x[23549];x[23549]=0;if((e|0)==1){break D}x[23549]=0;c=O(3,d+72|0,c|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break C}x[23549]=0;e=O(1,d+60|0,19152)|0;f=x[23549];x[23549]=0;if((f|0)==1){break B}x[23549]=0;S(4,d+84|0,c|0,e|0);f=x[23549];x[23549]=0;if((f|0)==1){break A}x[23549]=0;S(2,d+132|0,d+120|0,d+84|0);f=x[23549];x[23549]=0;if((f|0)==1){break z}tb(d+84|0);tb(e);tb(c);c=d+120|0;tb(c);tb(b);tb(d+108|0);b=x[a>>2];x[23549]=0;S(5,c|0,1,(b?b:21204)|0);b=x[23549];x[23549]=0;if((b|0)==1){break t}b=x[a+4>>2];x[23549]=0;S(5,d+108|0,1,(b?b:21204)|0);b=x[23549];x[23549]=0;if((b|0)==1){break s}a=x[a+8>>2];x[23549]=0;x[d+48>>2]=a;P(6,d+84|0,d+48|0);a=x[23549];x[23549]=0;if((a|0)==1){break r}x[23549]=0;W(7,17226);a=x[23549];x[23549]=0;if((a|0)==1){break q}x[23549]=0;S(8,d+48|0,0,d+120|0);a=x[23549];x[23549]=0;if((a|0)==1){break p}x[23549]=0;W(9,d+48|0);a=x[23549];x[23549]=0;if((a|0)==1){break o}x[23549]=0;W(7,17030);a=x[23549];x[23549]=0;if((a|0)==1){break o}x[23549]=0;S(8,d+36|0,0,d+84|0);a=x[23549];x[23549]=0;if((a|0)==1){break n}x[23549]=0;W(9,d+36|0);a=x[23549];x[23549]=0;if((a|0)==1){break m}x[23549]=0;W(7,17028);a=x[23549];x[23549]=0;if((a|0)==1){break m}x[23549]=0;W(7,17347);a=x[23549];x[23549]=0;if((a|0)==1){break m}x[23549]=0;S(8,d+24|0,0,d+132|0);a=x[23549];x[23549]=0;if((a|0)==1){break l}x[23549]=0;W(9,d+24|0);a=x[23549];x[23549]=0;if((a|0)==1){break k}x[23549]=0;W(7,13282);a=x[23549];x[23549]=0;if((a|0)==1){break k}x[23549]=0;S(8,d+12|0,0,d+108|0);a=x[23549];x[23549]=0;if((a|0)==1){break j}x[23549]=0;W(9,d+12|0);a=x[23549];x[23549]=0;if((a|0)==1){break i}x[23549]=0;W(7,13280);a=x[23549];x[23549]=0;if((a|0)==1){break i}x[23549]=0;X(10);a=x[23549];x[23549]=0;if((a|0)==1){break i}tb(d+12|0);tb(d+24|0);tb(d+36|0);tb(d+48|0);tb(d+84|0);tb(d+108|0);tb(d+120|0);tb(d+132|0)}db=d+144|0;return}a=N()|0;break u}a=N()|0;break v}a=N()|0;break w}a=N()|0;break x}a=N()|0;break y}a=N()|0;tb(d+84|0)}tb(e)}tb(c)}tb(d+120|0)}tb(b)}tb(d+108|0);break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;break e}a=N()|0;break e}a=N()|0;break f}a=N()|0;break f}a=N()|0;break g}a=N()|0;break g}a=N()|0;break h}a=N()|0;break h}a=N()|0;tb(d+12|0)}tb(d+24|0)}tb(d+36|0)}tb(d+48|0)}tb(d+84|0)}tb(d+108|0)}tb(d+120|0)}tb(d+132|0)}Q(a|0);p()}function HF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;h=db-48|0;db=h;o(+a);d=j(1)|0;i=j(0)|0;a:{b:{e=d;k=e&2147483647;c:{if(k>>>0<=1074752122){if((d&1048575)==598523){break c}if(k>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6077100506506192e-26;C[b>>3]=c;C[b+8>>3]=a-c+-6077100506506192e-26;d=1;break a}a=a+1.5707963267341256;c=a+6077100506506192e-26;C[b>>3]=c;C[b+8>>3]=a-c+6077100506506192e-26;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;C[b>>3]=c;C[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;C[b>>3]=c;C[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(k>>>0<=1075594811){if(k>>>0<=1075183036){if((k|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;C[b>>3]=c;C[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;C[b>>3]=c;C[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((k|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;C[b>>3]=c;C[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;C[b>>3]=c;C[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(k>>>0>1094263290){break b}}f=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+f*-1.5707963267341256;g=f*6077100506506192e-26;p=c-g;e=p<-.7853981633974483;if(F(f)<2147483648){d=~~f}else{d=-2147483648}d:{if(e){d=d-1|0;f=f+-1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256;break d}if(!(p>.7853981633974483)){break d}d=d+1|0;f=f+1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256}a=c-g;C[b>>3]=a;o(+a);e=j(1)|0;j(0)|0;i=k>>>20|0;e:{if((i-(e>>>20&2047)|0)<17){break e}g=c;a=f*6077100506303966e-26;c=c-a;g=f*20222662487959506e-37-(g-c-a);a=c-g;C[b>>3]=a;o(+a);e=j(1)|0;j(0)|0;if((i-(e>>>20&2047)|0)<50){break e}g=c;a=f*20222662487111665e-37;c=c-a;g=f*84784276603689e-45-(g-c-a);a=c-g;C[b>>3]=a}C[b+8>>3]=c-a-g;break a}if(k>>>0>=2146435072){a=a-a;C[b>>3]=a;C[b+8>>3]=a;d=0;break a}l(0,i|0);l(1,e&1048575|1096810496);a=+n();d=0;i=1;while(1){m=(h+16|0)+(d<<3)|0;if(F(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);C[m>>3]=c;a=(a-c)*16777216;d=1;m=i;i=0;if(m){continue}break}C[h+32>>3]=a;d=2;while(1){i=d;d=d-1|0;if(C[(h+16|0)+(i<<3)>>3]==0){continue}break}d=kI(h+16|0,h,(k>>>20|0)-1046|0,i+1|0,1);a=C[h>>3];if((e|0)<0){C[b>>3]=-a;C[b+8>>3]=-C[h+8>>3];d=0-d|0;break a}C[b>>3]=a;C[b+8>>3]=C[h+8>>3]}db=h+48|0;return d}function hba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;x[a+24588>>2]=0;x[a+24592>>2]=0;x[a+8>>2]=43792;x[a+4>>2]=0;x[a>>2]=32224;b=a+24596|0;x[b>>2]=0;x[b+4>>2]=0;Zp(a+24604|0);wN(a+24648|0,0);x[a+397448>>2]=0;x[a+397452>>2]=0;b=a+397456|0;x[b>>2]=8;x[b+4>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;v[b+12|0]=0;x[b+8>>2]=0;w[b+24>>1]=0;Vb(b+28|0,0,40);Vb(b+68|0,0,49824);Vb(b+49892|0,0,32832);v[a+480224|0]=0;w[a+480212>>1]=0;x[a+480204>>2]=0;x[a+480208>>2]=0;x[a+480180>>2]=0;x[a+480184>>2]=0;b=a+480186|0;w[b>>1]=0;w[b+2>>1]=0;w[b+4>>1]=0;w[b+6>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;i=Nb(a+480248|0);x[a+480272>>2]=0;c=a+484344|0;b=a+480280|0;while(1){v[b+8|0]=0;x[b>>2]=0;x[b+4>>2]=4194432;OC(b+9|0);b=b+32|0;if((c|0)!=(b|0)){continue}break}f=Nb(c);x[f+12>>2]=a;x[23549]=0;j=O(785,a+484360|0,a|0)|0;b=x[23549];x[23549]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){d=a+900380|0;b=a+484380|0;while(1){x[23549]=0;b=R(647,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break i}b=b+104|0;if((d|0)!=(b|0)){continue}break}x[23549]=0;R(786,a+901404|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break h}c=a+946300|0;g=a+906300|0;b=g;while(1){b=vN(b)+160|0;if((c|0)!=(b|0)){continue}break}x[a+946300>>2]=0;e=a+1074304|0;h=a+946304|0;b=h;while(1){b=tt(b)+32|0;if((e|0)!=(b|0)){continue}break}x[a+1074304>>2]=0;x[a+1074308>>2]=0;dr(a+1074312|0);x[23549]=0;X(787);b=x[23549];x[23549]=0;if((b|0)==1){break g}t=a,u=qN(),x[t+1074328>>2]=u;b=a+1074332|0;x[b+12>>2]=1065353216;hN(b,4);x[23549]=0;e=R(788,a+1074376|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break g}x[23549]=0;k=U(544,a+1298264|0,a|0,255)|0;b=x[23549];x[23549]=0;if((b|0)==1){break f}l=xc(a+1298300|0);m=xc(a+1298304|0);n=Gb(a+1298308|0);o=Gb(a+1298320|0);q=Gb(a+1298332|0);r=uN(a+1298344|0);s=Nb(a+1298408|0);v[a+1298420|0]=0;b=a+1298424|0;x[b>>2]=0;x[b+4>>2]=0;x[b+32>>2]=0;x[b+36>>2]=1072693248;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[a+1298464>>2]=0;Jp(a+12|0);Cy(a+8204|0);Cy(a+12300|0);b=a+1074408|0;x[b>>2]=4;x[b+4>>2]=16;x[a+480216>>2]=4;x[a+480220>>2]=16;Vb(d,0,1024);pN(h);x[23549]=0;b=R(789,12)|0;d=x[23549];x[23549]=0;if((d|0)==1){break e}x[b>>2]=0;x[b+4>>2]=0;x[b+8>>2]=0;t=a,u=Nb(b),x[t+4>>2]=u;return a|0}b=N()|0;break a}b=N()|0;break b}b=N()|0;break b}b=N()|0;break c}b=N()|0;break d}b=N()|0;tN(s);Fy(r);tb(q);tb(o);tb(n);Ey(m);Dy(l);gt(k)}Sy(e)}while(1){c=_s(c-160|0);if((g|0)!=(c|0)){continue}break}}Cz(j)}mN(f);sc(i);Q(b|0);p()}function Jga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=db-560|0;db=f;a:{if(!Vc(b,1464)){break a}if(!zo(b,f+556|0)){break a}Bd(a,1);Jb(Jb(Of(a+1074312|0,83),84,1),85,1);b:{if(de(f+556|0,26948)){d=f+32|0;e=Tb(d,8328);zb(a+1298344|0,e);tb(e);e=Tb(d,14487);zb(a+1298356|0,e);tb(e);d=Tb(d,14552);zb(a+1298368|0,d);break b}if(!de(f+556|0,15151)){break a}d=f+32|0;e=Tb(d,8502);zb(a+1298344|0,e);tb(e);e=Tb(d,12130);zb(a+1298356|0,e);tb(e);d=Tb(d,15007);zb(a+1298368|0,d)}tb(d);x[a+1298404>>2]=13;e=0;Vc(b,0);bB(b,a+1298308|0,20);w[a+480190>>1]=31;d=1;while(1)if((d|0)==32){if(e>>>0>40){break a}d=f+554|0;Yu(d,b);m=fd(d);if(y[f+554|0]>128){break a}e=f+32|0;d=db-16|0;db=d;c:{if(!Lb(x[b>>2],x[b+8>>2],512)){BS(e);break c}Gu(d+8|0,e);pd(d,b,x[d+8>>2],x[d+12>>2])}db=d+16|0;d=0;e=y[m|0];while(1){n=(d|0)==512;if(!n){i=(f+32|0)+d|0;d=d+1|0;if(e>>>0>=y[i|0]){continue}break a}break}if(!c){break a}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;w[a+480192>>1]=0;w[a+480188>>1]=4;x[a+480228>>2]=64;x[a+480208>>2]=x[a+480208>>2]|18874368;vh(a,0);Sf(Wb(x[a+484360>>2],y[a+484376|0]),y[f+554|0]);k=a+484344|0;mg(k,y[f+554|0]);i=0;while(1)if(y[f+554|0]<=i>>>0){if(!(c&2)){break a}Vc(b,(y[m|0]<<8)+1468|0);d=1;while(1){if((d|0)==32){break a}c=(D(d,104)+a|0)+484380|0;if(x[c>>2]){lg(Xc(f+8|0,8,1,0,0),c,b)}d=d+1|0;continue}}else{q=_b(x[Wb(x[a+484360>>2],y[a+484376|0])>>2],i),r=i,w[q>>1]=r;d:{if(!$g(k,i&65535,64)){break d}l=i<<2;g=0;e:while(1){if((g|0)==4){q=f,r=yb(x[Yb(x[k>>2],i)>>2]),x[q+24>>2]=r;e=0;while(1){if((e|0)==64){break d}d=0;f:{while(1){if((d&65535)>>>0>=4){g:{v[f+30|0]=o;v[f+31|0]=p;d=h&255;if(d){break g}h=0;break f}}else{g=x[f+24>>2];h:{if((y[g+3|0]&254)!=16){break h}v[g+3|0]=16;h=0;j=y[g+5|0];if(j>>>0<16){break h}h=j>>>4|0;v[g+5|0]=h;l=h;g=j&15;h=(g|0)!=(h|0)&(g|0)!=0;o=h?l:o;p=h?g:p}d=d+1|0;qA(f+24|0);continue}break}me(Yb(x[k>>2],i),Fe(Be(f+8|0,16,y[(d+f|0)+29|0]),e));h=h+1|0;h=(h&255)==3?1:h}e=e+1|0;continue}}Vc(b,(y[f+32+(g+l)|0]<<8)+1468|0);e=0;d=Yb(x[k>>2],i);d=$c(x[d>>2],x[x[d+48>>2]+12>>2],0,g&65535);while(1)if((e|0)==64){g=g+1|0;continue e}else{Au(b,d);i:{j:{j=y[d+3|0];k:{if((j|0)!=14){if(!j){if(y[d+5|0]){break j}break k}if((j-5&255)>>>0<5){break k}break j}if(y[d+5|0]<=15){break j}}v[d+3|0]=0;break i}Qf(d)}d=d+24|0;e=e+1|0;continue}}}i=i+1|0;continue}}else{e=yA(b,f+32|0,(D(d,104)+a|0)+484380|0,((d<<5)+a|0)+946304|0,1)+e|0;d=d+1|0;continue}}db=f+560|0;return n|0}function laa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=db-32|0;db=c;a:{b:{if(!Kb(x[b>>2],x[b+4>>2])){break b}l=a+16|0;m=x[b+12>>2];k=z[x[x[b+48>>2]+12>>2]+480188>>1];d=k;e=db-16|0;db=e;g=c+20|0;x[g>>2]=0;x[g+4>>2]=0;xc(g+8|0);Id(e+8|0,x[vb(e+4|0,g)>>2]);c:{d:{if(d){x[23549]=0;P(402,g|0,d|0);f=x[23549];x[23549]=0;if((f|0)==1){break d}h=db-16|0;db=h;f=Bq(h+4|0,g,d);d=x[f+4>>2];i=x[f+8>>2];while(1){if((d|0)==(i|0)){fc(f);db=h+16|0}else{Uh(d);d=d+6|0;x[f+4>>2]=d;continue}break}}d=e+8|0;Hd(d);ul(d);db=e+16|0;break c}a=N()|0;ul(e+8|0);Q(a|0);p()}while(1){e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if(!(x[x[x[a>>2]-12>>2]+l>>2]|j>>>0>=m>>>0)){x[23549]=0;v[c+19|0]=0;O(853,a|0,c+19|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break a}e=v[c+19|0];if(!e){j=j+1|0;continue}v[c+18|0]=0;t:{if((e|0)>=0){break t}x[23549]=0;O(853,a|0,c+18|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){break t}break a}v[c+17|0]=0;Uh(c+11|0);u:{e=e&127;f=(e?e-1|0:0)&65535;i=f>>>0>=k>>>0;v:{w:{if(!i){h=$c(x[b>>2],x[x[b+48>>2]+12>>2],j,f);e=y[c+18|0];if(e&1){break w}d=Ad(x[g>>2],f);break v}h=c+11|0;e=y[c+18|0];if(!(e&1)){break u}}x[23549]=0;O(853,a|0,c+17|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break a}if(i){break u}d=Ad(x[g>>2],f);v[d|0]=y[c+17|0]}v[h|0]=y[d|0];e=y[c+18|0];if(!(e&2)){break r}break s}if(e&2){break s}break q}ek(g);break b}x[23549]=0;O(853,a|0,c+17|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break a}if(i){break q}d=Ad(x[g>>2],f);v[d+1|0]=y[c+17|0]}v[h+1|0]=y[d+1|0];if(e&4){break p}break o}if(!(e&4)){break n}}x[23549]=0;O(853,a|0,c+17|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break a}if(i){break n}d=Ad(x[g>>2],f);v[d+2|0]=y[c+17|0]}v[h+2|0]=y[d+2|0];if(!(e&8)){break l}break m}if(!(e&8)){break k}}x[23549]=0;O(853,a|0,c+17|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break a}if(i){break k}d=Ad(x[g>>2],f);v[d+4|0]=y[c+17|0]}v[h+4|0]=y[d+4|0];if(e&16){break j}break i}if(!(e&16)){break h}}x[23549]=0;O(853,a|0,c+17|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break a}if(i){break h}d=Ad(x[g>>2],f);v[d+3|0]=y[c+17|0]}v[h+3|0]=y[d+3|0];if(!(e&32)){break f}break g}if(!(e&32)){break e}}x[23549]=0;O(853,a|0,c+17|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break a}if(i){break e}d=Ad(x[g>>2],f);v[d+5|0]=y[c+17|0]}v[h+5|0]=y[d+5|0]}if(!(e&64)){continue}x[23549]=0;O(853,a|0,c+10|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){x[23549]=0;O(854,a|0,y[c+10|0])|0;e=x[23549];x[23549]=0;if((e|0)!=1){continue}}break}break a}db=c+32|0;return}a=N()|0;ek(g);Q(a|0);p()}function O6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=db-192|0;db=d;e=x[b+4>>2];a:{if(!e){break a}f=x[b>>2];g=y[Sk(f,e)|0];if((g|0)==33){c=1}else{if((g|0)!=63){break a}c=0}cl(d+168|0,f,e,e-1|0);e=x[d+172>>2];x[b>>2]=x[d+168>>2];x[b+4>>2]=e}f=d+168|0;Rd(f);e=x[d+168>>2];Rd(d+156|0);e=Rk(e,x[d+160>>2],b);Rd(f);b:{c:{d:{e:{if((e|0)==x[d+172>>2]){a=x[b+4>>2];e=x[b>>2];f=mc(d+184|0,21204);g=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=g;if(Gc(e,a,d)){a=ac(8);x[23549]=0;c=O(54,d+168|0,10365)|0;b=x[23549];x[23549]=0;if((b|0)==1){break d}a=pc(a,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}e=0;if(!c){break e}a=ac(8);c=x[b+4>>2];b=x[b>>2];x[23549]=0;e=Ch(d+156|0,b,c);b=x[23549];x[23549]=0;f:{g:{h:{if((b|0)!=1){x[23549]=0;S(942,d+168|0,17247,e|0);b=x[23549];x[23549]=0;if((b|0)==1){break h}c=0;b=pc(a,d+168|0);x[23549]=0;S(105,b|0,61816,931);b=x[23549];x[23549]=0;if((b|0)!=1){break b}b=N()|0;tb(d+168|0);break g}b=N()|0;break f}b=N()|0;c=1}tb(e);if(!c){break c}}jc(a);break c}if(x[e+4>>2]){a=ac(8);x[23549]=0;c=O(54,d+168|0,11442)|0;b=x[23549];x[23549]=0;if((b|0)!=1){a=pc(a,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}c=x[b+4>>2];b=x[b>>2];e=mc(d+148|0,21204);f=x[e+4>>2];x[d+72>>2]=x[e>>2];x[d+76>>2]=f;if(Gc(b,c,d+72|0)){a=ac(8);x[23549]=0;c=O(54,d+168|0,10365)|0;b=x[23549];x[23549]=0;if((b|0)!=1){a=pc(a,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}e=mc(d+140|0,7360);f=x[e+4>>2];x[d+64>>2]=x[e>>2];x[d+68>>2]=f;i:{if(!Gc(b,c,d- -64|0)){e=mc(d+132|0,7342);f=x[e+4>>2];x[d+56>>2]=x[e>>2];x[d+60>>2]=f;if(!Gc(b,c,d+56|0)){break i}}e=y[a+60|0]!=0;break e}e=mc(d+124|0,6875);f=x[e+4>>2];x[d+48>>2]=x[e>>2];x[d+52>>2]=f;j:{if(!Gc(b,c,d+48|0)){e=mc(d+116|0,6856);f=x[e+4>>2];x[d+40>>2]=x[e>>2];x[d+44>>2]=f;if(!Gc(b,c,d+40|0)){break j}}e=y[a+61|0]!=0;break e}e=mc(d+108|0,6959);f=x[e+4>>2];x[d+32>>2]=x[e>>2];x[d+36>>2]=f;if(Gc(b,c,d+32|0)){e=y[a+62|0]!=0;break e}e=mc(d+100|0,6005);f=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=f;if(Gc(b,c,d+24|0)){e=y[a+63|0]!=0;break e}e=mc(d+92|0,7409);f=x[e+4>>2];x[d+16>>2]=x[e>>2];x[d+20>>2]=f;if(Gc(b,c,d+16|0)){e=y[a+64|0]!=0;break e}e=mc(d+84|0,13225);f=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=f;e=0;if(!Gc(b,c,d+8|0)){break e}e=x[x[a+24>>2]+24668>>2]!=0}db=d+192|0;return e|0}b=N()|0;jc(a)}Q(b|0)}p()}function rm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=db+-64|0;db=e;h=Nb(a);x[23549]=0;a=R(268,b|0)|0;c=x[23549];x[23549]=0;a:{b:{c:{d:{e:{if((c|0)==1){break e}c=x[b+8>>2];d=x[b>>2];x[23549]=0;c=U(142,d|0,c|0,a|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break e}if(c){break d}x[23549]=0;a=R(188,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break e}x[23549]=0;O(174,b|0,a|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){break c}}a=N()|0;break a}x[23549]=0;S(176,e+24|0,b|0,a|0);b=x[23549];x[23549]=0;f:{g:{h:{if((b|0)!=1){b=e+24|0;c=hc(e+44|0,b);ub(b);if(a>>>0<10){break g}x[23549]=0;b=R(674,c|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break b}if(!b){break g}x[23549]=0;b=R(268,c|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break b}x[e+20>>2]=b;a=a-10|0;tc(e+20|0,a>>>0>25264513?-1:D(a,170));x[23549]=0;d=x[e+20>>2];P(274,h|0,d|0);a=x[23549];x[23549]=0;if((a|0)!=1){break h}break b}a=N()|0;break a}b=0;i:while(1){f=0;j:{k:{while(1){if(f){break j}a=x[c+8>>2];f=x[c>>2];x[23549]=0;a=O(675,f|0,a|0)|0;f=x[23549];x[23549]=0;l:{m:{n:{o:{if((f|0)!=1){if(a){break j}x[23549]=0;a=R(476,c|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break b}f=1;switch(a|0){case 3:break l;case 2:break m;case 1:break n;case 0:break o;default:continue}}break b}x[23549]=0;a=R(192,c|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}g=x[c+8>>2];i=x[c>>2];x[23549]=0;g=U(142,i|0,g|0,a|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break b}if(!g){continue}ge(e+24|0,x[h>>2],x[h+4>>2]);yq(e+8|0,x[e+24>>2],x[e+28>>2],b,a);x[23549]=0;hn(413,e,c,x[e+8>>2],x[e+12>>2]);f=x[23549];x[23549]=0;if((f|0)!=1){d=d-a|0;b=a+b|0;continue i}break b}x[23549]=0;a=R(192,c|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break b}g=a<<2;if(g>>>0>d>>>0){continue}x[23549]=0;i=O(676,c|0,e+16|0)|0;j=x[23549];x[23549]=0;if((j|0)==1){break b}if(!i){continue}while(1){if(!(a&255)){break k}f=e+16|0;i=gc(f);Et(f,i,Ie(yb(x[h>>2]),b));b=b+4|0;a=a-1|0;continue}}if(d>>>0<8){continue}x[23549]=0;a=O(676,c|0,e+16|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break b}if(!a){continue}a=e+16|0;f=gc(a);Et(a,f,Ie(yb(x[h>>2]),b));Et(a,f,Ie(Ie(yb(x[h>>2]),b),4));d=d-8|0;b=b+8|0;continue i}x[23549]=0;a=R(192,c|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}break}d=d-a|0;b=a+b|0;continue}d=d-g|0;continue}break}if(!d){break f}a=Nb(e+24|0);Dt(a,h);bc(a);break f}x[23549]=0;S(318,c|0,h|0,a|0);a=x[23549];x[23549]=0;if((a|0)==1){break b}}ub(c)}db=e- -64|0;return}a=N()|0;ub(c)}bc(h);Q(a|0);p()}function bga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=db-16|0;db=g;a:{if(!Lb(x[a>>2],x[a+8>>2],2)){$g(c+484344|0,b,64);break a}k=c+484344|0;l=Vd(PB(a),1,1024);if(!$g(k,b,l)){break a}o=z[c+480188>>1];b:while(1){if((j|0)==(l|0)){break a}i=0;e=Yb(x[k>>2],b);m=sf(x[e>>2],x[x[e+48>>2]+12>>2],j);while(1)if((i|0)==(o|0)){j=j+1|0;continue b}else{f=g+12|0;Im(f,a);e=D(i,6)+m|0;p=Ue(f);f=Ai(f);h=y[g+12|0];c:{if((h-1&255)>>>0>35){break c}v[e|0]=h+48;n=y[fd(g+12|0)|0];h=n+1|0;v[e+1|0]=h;q=h;h=h&255;if((q|0)!=(h|0)|h>>>0>z[c+480190>>1]){break c}h=_j(c,h);if(!(!y[Db(d,i)|0]|z[h+30>>1]>255)){v[e+4|0]=64;v[e+2|0]=1}h=h+68|0;d:{if(x[xb(h,0)>>2]==1){if(y[Db(d,i)|0]){break d}}if(x[xb(h,0)>>2]){break c}if(y[Db(d,i)|0]){break c}}v[e+1|0]=n+101}e:{f:{switch(y[p|0]){case 1:if(!y[f|0]){break e}v[e+3|0]=2;v[e+5|0]=y[f|0];break e;case 2:if(!y[f|0]){break e}v[e+3|0]=3;v[e+5|0]=y[f|0];break e;case 12:if(!y[f|0]){break e}v[e+3|0]=1;v[e+5|0]=y[f|0];break e;case 13:if(!y[f|0]){break e}v[e+3|0]=39;v[g+11|0]=15;r=e,s=y[Sb(g+11|0,f)|0]|16,v[r+5|0]=s;break e;case 30:if(!y[f|0]){break e}v[e+3|0]=38;v[g+10|0]=15;r=e,s=y[Sb(g+10|0,f)|0]|16,v[r+5|0]=s;break e;case 21:if(!y[f|0]){break e}v[e+3|0]=39;v[g+9|0]=15;r=e,s=y[Sb(g+9|0,f)|0]|80,v[r+5|0]=s;break e;case 17:if(!y[f|0]){break e}v[e+3|0]=38;v[g+8|0]=15;r=e,s=y[Sb(g+8|0,f)|0]|80,v[r+5|0]=s;break e;case 15:v[e+3|0]=19;v[e+5|0]=y[f|0]!=0;break e;case 25:v[e+3|0]=12;v[e+5|0]=y[f|0];break e;case 27:qo(e);v[e|0]=255;break e;case 28:if(y[f|0]>31){break e}v[e+3|0]=16;v[e+5|0]=y[f|0];break e;case 31:h=y[f|0];if(h&15){r=e,s=y[Db(d,i)|0]?22:11,v[r+3|0]=s;v[e+5|0]=y[f|0]&15;h=y[f|0]}g:{h:{switch(h>>>4|0){case 4:if((h|0)!=64){break g}case 0:case 1:case 2:case 3:if(y[Db(d,i)|0]){v[e+3|0]=21;v[e+5|0]=y[f|0];break g}v[e+2|0]=1;f=y[f|0];v[e+3|0]=0;v[e+4|0]=f;break g;case 5:v[e+5|0]=y[e+5|0]<<4;break g;case 6:v[g+7|0]=y[e+5|0];v[g+6|0]=14;r=e,s=y[Sb(g+7|0,g+6|0)|0]|240,v[r+5|0]=s;break g;case 7:v[g+5|0]=y[e+5|0];v[g+4|0]=14;r=e,s=y[Sb(g+5|0,g+4|0)|0]<<4|15,v[r+5|0]=s;break g;default:break h}}v[e+3|0]=0}if((y[e+3|0]-21&255)>>>0>1){break e}f=D(v[Db(d,i)|0]+i|0,6)+m|0;if(Lq(f+3|0,f+5|0,1)){v[f+2|0]=y[f+3|0];v[f+4|0]=y[f+5|0]}v[f+3|0]=y[e+3|0];v[f+5|0]=y[e+5|0];break e;case 0:break e;default:break f}}v[e+3|0]=0}i=i+1|0;continue}}}db=g+16|0}function rea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=db+-64|0;db=d;w[d+62>>1]=c;Wf(d+62|0,32);j=Nb(a);x[23549]=0;n=z[d+62>>1];P(480,j|0,n|0);a=x[23549];x[23549]=0;a:{b:{if((a|0)!=1){c:{d:{while(1){if((o&65535)>>>0>=n>>>0){break d}f=1;c=z[b+480190>>1];a=c+1|0;w[d+60>>1]=a;e:{f:{g:{if((a&65535)>>>0<4e3){break g}h:{while(1){g=f&65535;if(g>>>0>c>>>0){break h}i:{e=_j(b,g);if(!Sd(x[e>>2],x[e+20>>2])){if(!Kb(rA(yb(x[j>>2]),yb(x[j+4>>2]),f),yb(x[j+4>>2]))){break i}c=z[b+480190>>1]}f=f+1|0;continue}break}w[d+60>>1]=f;a=1;while(1){c=a&65535;if(c>>>0>z[b+480192>>1]){a=f}else{j:{c=x[((c<<2)+b|0)+900380>>2];if(!c){break j}c=c+236|0;e=uq(c);while(1){if((c|0)==(e|0)){break j}if((g|0)==z[c>>1]){w[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}}if((a&65535)>>>0<4e3){break g}f=oo(d+48|0);x[23549]=0;a=O(717,b|0,f|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break b}if(!a){break e}x[23549]=0;P(718,b|0,f|0);c=x[23549];x[23549]=0;a=1;if((c|0)==1){break b}while(1){c=a&65535;if(c>>>0<=z[b+480192>>1]){k:{c=x[((c<<2)+b|0)+900380>>2];if(!c){break k}c=c+236|0;g=uq(c);while(1){if((c|0)==(g|0)){break k}e=z[c>>1];l:{if(e>>>0>=A[d+52>>2]){break l}Fb(d+40|0,x[f>>2],e);if(Ib(x[x[d+40>>2]>>2],x[d+44>>2])){break l}w[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}tm(d+24|0,x[f>>2]);vQ(d+32|0,x[d+24>>2],x[d+28>>2],1);bq(d+16|0,x[f>>2],x[d+52>>2]);l=db-16|0;db=l;g=d+40|0;e=ec(l,x[d+32>>2],x[d+36>>2]);a=sm(x[d+16>>2],x[d+20>>2],x[d+32>>2],x[d+36>>2]);c=db-16|0;db=c;x[c+12>>2]=a;h=x[e+4>>2];m:{if(h){i=32-h|0;x[c+8>>2]=i;m=x[Cb(c+8|0,c+12|0)>>2];k=-1<<h&-1>>>i-m;i=x[e>>2];k=k&(x[i>>2]^-1);if(k){ec(g,i,xka(k));break m}if((a|0)==(m|0)){vQ(g,i,h,a);break m}a=a-m|0;x[c+12>>2]=a;x[e>>2]=i+4}while(1){if(a>>>0>=32){h=x[e>>2];i=x[h>>2];if((i|0)!=-1){ec(g,h,xka(i^-1));break m}else{x[e>>2]=h+4;a=a-32|0;x[c+12>>2]=a;continue}}break}e=x[e>>2];if(!a){ec(g,e,0);break m}h=(x[e>>2]^-1)&-1>>>32-a;if(!h){ec(g,e,a);break m}ec(g,e,xka(h))}db=c+16|0;db=l+16|0;tm(d+8|0,x[f>>2]);a=sm(x[d+40>>2],x[d+44>>2],x[d+8>>2],x[d+12>>2]);w[d+60>>1]=a;He(f);if((a&65535)>>>0>3999){break f}}x[23549]=0;P(246,j|0,d+60|0);c=x[23549];x[23549]=0;if((c|0)==1){break c}if(z[b+480190>>1]>=(a&65535)>>>0){break f}w[b+480190>>1]=a}o=o+1|0;continue}break}He(f)}db=d- -64|0;return}c=N()|0;break a}c=N()|0;break a}c=N()|0;He(f)}id(j);Q(c|0);p()}function sba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,A=0,B=0,C=0,F=0,G=0,H=0,I=0;l=db-32|0;db=l;r=x[a+4>>2];j=Qe(x[a+8>>2],b);t=x[j>>2];a:{if(t+1>>>0<2){break a}h=(D(b,872)+r|0)+616|0;if(!(si(x[h+8>>2],x[h+12>>2])|y[j+4|0])){break a}g=D(b,872)+r|0;if(!x[g+720>>2]){break a}i=x[g+704>>2]&2;u=x[(i?g+700|0:g+692|0)>>2];n=x[g+700>>2];f=x[g+696>>2];w=Ob(x[a>>2]+1074312|0,31);e=bf(x[g+624>>2],x[g+628>>2],c);o=y[g+704|0]&128;j=o?0-e|0:e;m=hb;m=o?0-(m+((e|0)!=0)|0)|0:m;e=0;o=i?e:0;e=f;q=i?e:0;n=n-e|0;B=n<<1;C=g+1316|0;p=g+1467|0;A=g+1362|0;F=(y[A|0]&17)!=1;b:{while(1){if((s|0)==(t|0)){break b}c:{if(d>>>0>s>>>0){e=(y[A|0]&17)==1;break c}v[p|0]=y[p|0]&254;e=x[a>>2];f=x[a+4>>2];i=Yb(x[e+484344>>2],z[f+70>>1]);f=$c(x[i>>2],x[x[i+48>>2]+12>>2],x[f+48>>2],b);i=y[f+3|0];if(y[f+2|0]==11){k=l+8|0;Yy(k,e,i,y[f+4|0],0);k=Ue(k);Zn(x[a>>2],h,z[l+8>>1]);e=1;if(y[k|0]){break c}}e=1;d:{switch(i-4|0){case 0:Zn(x[a>>2],h,y[f+5|0]);break c;case 2:break d;default:break c}}Zn(x[a>>2],h,0)}x[l+28>>2]=x[C>>2];if(w){et(x[a>>2],h)}if(!F){_N(x[a>>2],h,l+28|0);e=1}if(!w){et(x[a>>2],h)}x[l+24>>2]=0;ZN(h,l+24|0);e:{f:{if(y[g+705|0]&2){break f}g:{if(!e){if(!y[Qe(x[a+8>>2],b)+4|0]){break g}}if(y[p|0]&96){hQ(h,E(1),0,x[a>>2]);j=y[p|0];v[p|0]=(j&64?-65:-33)&j}Zy(l+8|0,x[a>>2],h,x[l+28>>2],0);j=x[l+12>>2];x[g+624>>2]=x[l+8>>2];x[g+628>>2]=j;H=Qe(x[a+8>>2],b),I=0,v[H+4|0]=I;e=bf(x[g+624>>2],x[g+628>>2],c);f=y[g+704|0]&128;j=f?0-e|0:e;i=hb;m=f?0-(i+((e|0)!=0)|0)|0:i}Qb(h,j,m);f=x[h>>2];e=x[h+4>>2];if((f>>>0<G>>>0&(e|0)<=(u|0)|(e|0)<(u|0))&((e|0)>=(q|0)&f>>>0>=o>>>0|(e|0)>(q|0)|((m|0)>0|(m|0)>=0))){break f}k=x[g+704>>2];if(!(k&2)){break e}if(k&4){i=x[g+696>>2];if(f>>>0<o>>>0&(e|0)<=(q|0)|(e|0)<(q|0)){H=h,I=Gg(0,i<<1,f,e),x[H>>2]=I;e=hb;x[h+4>>2]=e;x[g+704>>2]=k^128;f=j;j=0-f|0;m=0-(((f|0)!=0)+m|0)|0}e=(e-i>>>0)%(B-Ob(x[a>>2]+1074312|0,33)>>>0)|0;h:{if(e>>>0<n>>>0){f=e+x[g+696>>2]|0;break h}f=x[g+700>>2]+(n-e|0)|0}x[h+4>>2]=f;f=x[g+704>>2];if((f&128)>>>7^e>>>0<n>>>0){break f}x[g+704>>2]=f^128;e=j;j=0-e|0;m=0-(((e|0)!=0)+m|0)|0;break f}k=x[g+700>>2];if(k+n>>>0<=e>>>0){e=k+((e-k>>>0)%(n>>>0)|0)|0}while(1){i=e;e=e-n|0;if(i>>>0>=k>>>0){continue}break}x[h>>2]=f;x[h+4>>2]=i}s=s+1|0;continue}break}kQ(h);x[(D(b,872)+r|0)+1324>>2]=0}H=Qe(x[a+8>>2],b),I=0,x[H>>2]=I}db=l+32|0}function d_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=db-320|0;db=d;e=db-16|0;db=e;x[a>>2]=0;f=a+32|0;sn(f,32);v[e+15|0]=0;qn(f,e+15|0);db=e+16|0;e=x[a+28>>2];a:{if(x[(x[x[e>>2]-12>>2]+e|0)+16>>2]){hh(a,1073741825);break a}ae(d+56|0,e);e=x[d+68>>2];x[a+8>>2]=x[d+64>>2];x[a+12>>2]=e;x[d+56>>2]=3;g=x[a+28>>2];f=d+16|0;e=0;while(1){if(A[d+56>>2]>e>>>0){hi(g,e+f|0);e=e+1|0;continue}break}if(cd(f,26032,3)){hh(a,1073741827);break a}v[d+319|0]=0;hi(x[a+28>>2],d+319|0);Vb(d+56|0,0,256);e=y[d+319|0];if(e){Lk(x[a+28>>2],d+56|0,e)}f=b;b=jn(d+16|0,d+56|0,e);e=pw(f,b);Ab(b);if(!e){hh(a,1073741830)}if(y[a+3|0]&64){break a}hi(x[a+28>>2],d+55|0);b=y[d+55|0];e=b&3;w[a+16>>1]=(e|0)==3?4:e;if(Ki(b,6)){zk(a,9,1)}x[d+48>>2]=0;QF(x[a+28>>2],d+48|0);e=x[d+48>>2];v[d+47|0]=0;if(e>>>0>=2){hi(x[a+28>>2],d+55|0);f=-1;if(!y[d+55|0]){hi(x[a+28>>2],d+47|0);f=-2}Sl(x[a+28>>2],e+f|0)}x[d+32>>2]=0;x[d+36>>2]=0;b:{if(!Ki(b,4)){break b}yk(x[a+28>>2],d+32|0);e=x[d+36>>2];f=x[d+32>>2];x[a+56>>2]=f;x[a+60>>2]=e;g=x[c+4>>2];if((g|0)==(e|0)&A[c>>2]>=f>>>0|e>>>0<g>>>0){break b}hh(a,536871424)}if(Ki(b,5)){hi(x[a+28>>2],d+55|0);Sl(x[a+28>>2],y[d+55|0])}e=y[d+47|0];c:{if(!Ki(e,0)){break c}hi(x[a+28>>2],d+55|0);c=y[d+55|0];c=c&1?-1:c>>>1|0;w[a+16>>1]=c;if(c){break c}hh(a,536871168)}x[a+4>>2]=0;c=1;if(Ki(e,1)){QF(x[a+28>>2],a+4|0)}zk(a,6,Ki(b,2));zk(a,7,Ki(b,3));zk(a,5,z[a+16>>1]!=0);zk(a,8,Ki(b,7));d:{if(ed(a,5)){break d}if(ed(a,6)){break d}if(ed(a,7)){break d}c=ed(a,8)}zk(a,11,c);ed(a,11);if(Ki(e,2)){w[d+16>>1]=0;mw(x[a+28>>2],d+16|0);Sl(x[a+28>>2],z[d+16>>1]<<ed(a,9))}if(Ki(e,3)){Sl(x[a+28>>2],5)}yk(x[a+28>>2],d+32|0);c=x[d+36>>2];b=x[d+32>>2];if(!c&b>>>0>=16001|c){hh(a,1073741831);break a}x[a+92>>2]=b;if(!b){hh(a,536871040)}e:{if(!ed(a,11)){break e}yk(x[a+28>>2],d+32|0);b=x[d+32>>2];c=x[d+36>>2];if((c|0)>0|(c|0)>=0){break e}hh(a,1073741829);break a}ae(d,x[a+28>>2]);c=x[a+8>>2];f=x[a+12>>2];e=x[d+4>>2];x[d+16>>2]=x[d>>2];x[d+20>>2]=e;e=x[d+12>>2];x[d+24>>2]=x[d+8>>2];x[d+28>>2]=e;e=x[d+24>>2];f=x[d+28>>2]-(f+(c>>>0>e>>>0)|0)|0;c=e-c|0;x[d+24>>2]=c;x[d+28>>2]=f;c=x[d+24>>2];e=x[d+28>>2];if((e|0)==1|e>>>0>1){hh(a,1073741832);break a}x[a+88>>2]=c;c=ed(a,11);x[a+64>>2]=c?b:x[a+88>>2];if(!ed(a,11)){b=x[a+12>>2];e=x[a+88>>2];c=e+x[a+8>>2]|0;x[a+72>>2]=c;x[a+76>>2]=c>>>0<e>>>0?b+1|0:b}zk(a,10,1)}db=d+320|0}function h3(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=db-160|0;db=d;x[d+156>>2]=c;a:{b:{c:{if(b>=.8){x[23549]=0;e=ca(1055)|0;f=x[23549];x[23549]=0;d:{e:{f:{if((f|0)!=1){x[d+72>>2]=e;x[23549]=0;c=R(1056,c|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break e}x[d+152>>2]=c;Kn(e,c);a=le(d+132|0,a);x[23549]=0;c=x[a+12>>2];x[d+56>>2]=x[a+8>>2];x[d+60>>2]=c;x[d- -64>>2]=x[a+16>>2];c=x[a+4>>2];x[d+48>>2]=x[a>>2];x[d+52>>2]=c;a=U(1048,e|0,d+48|0,15)|0;c=x[23549];x[23549]=0;if((c|0)==1){break f}if(a){x[23549]=0;W(790,e|0);a=x[23549];x[23549]=0;g=1;if((a|0)==1){break f}}Wi(d+152|0);Xi(d+72|0);break b}c=T(0)|0;break c}c=T(0)|0;Wi(d+152|0);break d}c=T(0)|0}Xi(d+72|0);break c}if(b>=.6){x[23549]=0;e=ca(1055)|0;f=x[23549];x[23549]=0;g:{h:{i:{if((f|0)!=1){x[d+72>>2]=e;x[23549]=0;c=R(1056,c|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break h}x[d+152>>2]=c;Kn(e,c);a=le(d+112|0,a);x[23549]=0;c=x[a+12>>2];x[d+32>>2]=x[a+8>>2];x[d+36>>2]=c;x[d+40>>2]=x[a+16>>2];c=x[a+4>>2];x[d+24>>2]=x[a>>2];x[d+28>>2]=c;a=U(1048,e|0,d+24|0,2)|0;c=x[23549];x[23549]=0;if((c|0)==1){break i}if(a){x[23549]=0;W(790,e|0);a=x[23549];x[23549]=0;g=.8;if((a|0)==1){break i}}Wi(d+152|0);Xi(d+72|0);break b}c=T(0)|0;break c}c=T(0)|0;Wi(d+152|0);break g}c=T(0)|0}Xi(d+72|0);break c}g=.2;if(b>=.2){x[23549]=0;e=ca(1055)|0;f=x[23549];x[23549]=0;j:{k:{l:{if((f|0)!=1){x[d+72>>2]=e;x[23549]=0;c=R(1056,c|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break k}x[d+152>>2]=c;Kn(e,c);a=le(d+92|0,a);x[23549]=0;c=x[a+12>>2];x[d+8>>2]=x[a+8>>2];x[d+12>>2]=c;x[d+16>>2]=x[a+16>>2];c=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=c;a=U(1048,e|0,d|0,0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break l}g=0;if(a){x[23549]=0;W(790,e|0);a=x[23549];x[23549]=0;g=.6;if((a|0)==1){break l}}Wi(d+152|0);Xi(d+72|0);break b}c=T(0)|0;break c}c=T(0)|0;Wi(d+152|0);break j}c=T(0)|0}Xi(d+72|0);break c}if(!(b>=.1)){break b}x[23549]=0;S(189,d+72|0,a|0,2048);c=x[23549];x[23549]=0;if((c|0)!=1){c=Ee(d+72|0);a=x[a>>2];x[23549]=0;e=x[d+72>>2];a=R(146,a|0)|0;f=x[23549];x[23549]=0;m:{if((f|0)==1){break m}x[23549]=0;a=CF(1057,c,e,a,0);c=x[23549];x[23549]=0;if((c|0)==1){break m}g=C[(a<<3)+61544>>3];Jc(d+72|0);break b}c=T(0)|0;Jc(d+72|0);break c}c=T(0)|0}Y(c|0)|0;x[23549]=0;X(17);a=x[23549];x[23549]=0;g=0;if((a|0)==1){break a}}xe(d+156|0);db=d+160|0;return+g}a=N()|0;xe(d+156|0);Q(a|0);p()}function WW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=db-368|0;db=e;wc(b);d=db-16|0;db=d;h=e+330|0;KC(d+8|0,h);g=x[d+12>>2];lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);i=x[d+4>>2];if((i|0)==(g|0)){Zb(b,x[d+12>>2])}db=d+16|0;d=(g|0)==(i|0);if(!d){JC(h)}a:{if(!d){break a}if(!MC(e+330|0)){break a}if(!Lb(x[b>>2],x[b+8>>2],Qc(LC(y[e+365|0]),hb))){break a}b:{if(!c){break b}Bd(a,2097152);Dg(a);vh(a,1);w[a+480188>>1]=8;x[a+480196>>2]=y[e+362|0];x[a+480204>>2]=D(y[e+363|0],1e4);w[a+480190>>1]=y[e+364|0];d=y[e+367|0];if(d>>>0<y[e+366|0]){$e(Wb(x[a+484360>>2],y[a+484376|0]),d)}d=e- -64|0;f=Tb(d,6460);zb(a+1298344|0,f);tb(f);f=Tb(d,10994);zb(a+1298356|0,f);tb(f);x[a+1298404>>2]=5;_u(b,d);Qq(Wb(x[a+484360>>2],y[a+484376|0]),d,y[e+366|0],65535,65535);f=1;while(1){i=f&65535;if(i>>>0>z[a+480190>>1]){Zb(b,D(64-y[e+364|0]|0,37));h=a+484344|0;mg(h,y[e+365|0]);i=c&1;f=0;while(1)if(y[e+365|0]<=f>>>0){if(!(c&2)){break b}c=Xc(e+24|0,8,1,0,0);f=1;while(1){d=f&65535;if(d>>>0>z[a+480190>>1]){break b}lg(c,(D(d,104)+a|0)+484380|0,b);f=f+1|0;continue}}else{c:{d:{if(i){if($g(h,f&65535,64)){break d}}Zb(b,2048);break c}d=Yb(x[h>>2],f);n=e,o=yb(x[d>>2]),x[n+24>>2]=o;j=yb(x[d+4>>2]);while(1){d=x[e+24>>2];if(!Kb(d,j)){break c}g=e+12|0;Im(g,b);l=fd(g);m=Ue(g);g=Ai(g);k=y[e+12|0];if((k-1&255)>>>0<=106){v[d|0]=k+13}v[d+1|0]=y[l|0];v[d+3|0]=y[m|0];v[d+5|0]=y[g|0];Qf(d);lk(e+24|0);continue}}f=f+1|0;continue}}else{d=e+24|0;IC(b,d);h=db-16|0;db=h;g=(D(i,104)+a|0)+484380|0;nd(g,0);v[g+37|0]=y[d+22|0]<<4;v[h+15|0]=y[d+23|0];v[h+14|0]=64;n=g,o=y[Sb(h+15|0,h+14|0)|0]<<2,w[n+30>>1]=o;v[g+36|0]=y[d+24|0];x[g>>2]=y[d+25|0]|y[d+26|0]<<8|(y[d+27|0]<<16|y[d+28|0]<<24);j=y[d+33|0]|y[d+34|0]<<8|(y[d+35|0]<<16|y[d+36|0]<<24);if(!(j>>>0<3|j+(y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24))>>>0>(y[d+25|0]|y[d+26|0]<<8|(y[d+27|0]<<16|y[d+28|0]<<24))>>>0)){w[g+34>>1]=z[g+34>>1]|2;x[g+4>>2]=y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24);x[g+8>>2]=(y[d+33|0]|y[d+34|0]<<8|(y[d+35|0]<<16|y[d+36|0]<<24))+(y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24))}db=h+16|0;zl(e,2,d);d=e+12|0;Bc(d,e);zc(((i<<5)+a|0)+946304|0,d);f=f+1|0;tb(d);continue}}}f=1}db=e+368|0;return f|0}function H3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=db-144|0;db=d;h=TJ(d+128|0);x[h>>2]=49508;Nb(h+4|0);Kn(x[a+24>>2],h);e=x[a+24>>2];i=y[a+62|0];f=y[a+61|0];g=y[a+60|0];b=le(d+108|0,b);x[23549]=0;j=x[b+12>>2];x[d+8>>2]=x[b+8>>2];x[d+12>>2]=j;x[d+16>>2]=x[b+16>>2];j=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=j;b=g?13:15;b=f?b&14:b;b=U(1048,e|0,d|0,(i?b&3:b)|0)|0;e=x[23549];x[23549]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}if(!b){b=ac(8);x[23549]=0;c=O(54,d+96|0,11868)|0;a=x[23549];x[23549]=0;if((a|0)!=1){a=pc(b,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=N()|0;jc(b);break b}if(!y[a+63|0]){x[23549]=0;P(1049,a|0,a+36|0);b=x[23549];x[23549]=0;if((b|0)==1){break e}}v[a+28|0]=1;Kn(x[a+24>>2],x[a+4>>2]);x[23549]=0;P(1050,d+96|0,h|0);b=x[23549];x[23549]=0;if((b|0)==1){break c}k=d,l=yb(x[d+96>>2]),x[k+92>>2]=l;e=a+68|0;i=yb(x[d+100>>2]);f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{while(1){b=x[d+92>>2];if(!Kb(b,i)){k=d,l=kj(x[c>>2]),x[k+80>>2]=l;c=Bf(c);while(1){b=x[d+80>>2];if(!xg(b,c)){break d}x[23549]=0;e=td(b);b=O(53,d+20|0,e|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break h}x[23549]=0;V(943,a|0,b|0,e+12|0,0);e=x[23549];x[23549]=0;if((e|0)==1){break g}tb(b);Vg(d+80|0);continue}}f=x[a+24>>2];g=x[b>>2];x[23549]=0;j=f;f=b+4|0;S(1051,j|0,g|0,f|0);g=x[23549];x[23549]=0;if((g|0)!=1){b=x[b>>2];x[23549]=0;P(1052,d+44|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break r}x[23549]=0;P(989,d+56|0,d+44|0);b=x[23549];x[23549]=0;if((b|0)==1){break q}x[23549]=0;b=O(54,d+32|0,17347)|0;g=x[23549];x[23549]=0;if((g|0)==1){break p}x[23549]=0;S(946,d+68|0,d+56|0,b|0);g=x[23549];x[23549]=0;if((g|0)==1){break o}x[23549]=0;S(486,d+80|0,d+68|0,f|0);f=x[23549];x[23549]=0;if((f|0)==1){break n}x[23549]=0;P(169,e|0,d+80|0);f=x[23549];x[23549]=0;if((f|0)==1){break m}tb(d+80|0);tb(d+68|0);tb(b);tb(d+56|0);tb(d+44|0);jl(d+92|0);continue}break}a=N()|0;break f}a=N()|0;break f}a=N()|0;break i}a=N()|0;break j}a=N()|0;break k}a=N()|0;break l}a=N()|0;tb(d+80|0)}tb(d+68|0)}tb(b)}tb(d+56|0)}tb(d+44|0);break f}a=N()|0;break f}a=N()|0;tb(b)}ux(d+96|0);break b}a=N()|0;break b}ux(d+96|0);rs(h);db=d+144|0;return}a=N()|0}rs(h);Q(a|0)}p()}function Nea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=db-16|0;db=k;e=x[b>>2];d=hg(e,x[b+4>>2]);a:{if(d>>>0<c>>>0){n=db-32|0;db=n;d=c-d|0;f=x[wb(b)>>2];e=x[b+4>>2];b:{if(d>>>0<=f-e>>5>>>0){h=db-16|0;db=h;e=Mz(h+4|0,b,d);d=x[e+4>>2];g=x[e+8>>2];while(1){if((d|0)==(g|0)){fc(e);db=h+16|0}else{lA(d);d=d+32|0;x[e+4>>2]=d;continue}break}break b}h=wb(b);h=xt(n+12|0,$p(b,hg(x[b>>2],e)+d|0),hg(x[b>>2],x[b+4>>2]),h);g=db-16|0;db=g;d=GQ(g+4|0,h+8|0,d);e=x[d>>2];while(1){if(x[d+4>>2]!=(e|0)){lA(e);e=x[d>>2]+32|0;x[d>>2]=e;continue}break}Kd(d);db=g+16|0;l=db-16|0;db=l;d=vb(l+12|0,x[b+4>>2]);e=vb(l+8|0,x[b>>2]);f=x[vb(l+4|0,x[h+4>>2])>>2];m=db-16|0;db=m;o=m+8|0;g=db-32|0;db=g;Od(g+24|0,x[d>>2],x[e>>2]);p=g+16|0;d=x[g+24>>2];q=x[g+28>>2];j=db-16|0;db=j;x[j+8>>2]=f;x[j+12>>2]=d;while(1){if(sd(d,q)){d=Wj(d);e=Wj(x[j+8>>2]);f=y[d+28|0]|y[d+29|0]<<8|(y[d+30|0]<<16|y[d+31|0]<<24);i=y[d+24|0]|y[d+25|0]<<8|(y[d+26|0]<<16|y[d+27|0]<<24);v[e+24|0]=i;v[e+25|0]=i>>>8;v[e+26|0]=i>>>16;v[e+27|0]=i>>>24;v[e+28|0]=f;v[e+29|0]=f>>>8;v[e+30|0]=f>>>16;v[e+31|0]=f>>>24;f=y[d+20|0]|y[d+21|0]<<8|(y[d+22|0]<<16|y[d+23|0]<<24);i=y[d+16|0]|y[d+17|0]<<8|(y[d+18|0]<<16|y[d+19|0]<<24);v[e+16|0]=i;v[e+17|0]=i>>>8;v[e+18|0]=i>>>16;v[e+19|0]=i>>>24;v[e+20|0]=f;v[e+21|0]=f>>>8;v[e+22|0]=f>>>16;v[e+23|0]=f>>>24;f=y[d+12|0]|y[d+13|0]<<8|(y[d+14|0]<<16|y[d+15|0]<<24);i=y[d+8|0]|y[d+9|0]<<8|(y[d+10|0]<<16|y[d+11|0]<<24);v[e+8|0]=i;v[e+9|0]=i>>>8;v[e+10|0]=i>>>16;v[e+11|0]=i>>>24;v[e+12|0]=f;v[e+13|0]=f>>>8;v[e+14|0]=f>>>16;v[e+15|0]=f>>>24;f=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[e|0]=d;v[e+1|0]=d>>>8;v[e+2|0]=d>>>16;v[e+3|0]=d>>>24;v[e+4|0]=f;v[e+5|0]=f>>>8;v[e+6|0]=f>>>16;v[e+7|0]=f>>>24;d=po(j+12|0);po(j+8|0);d=x[d>>2];continue}break}vc(p,d,j+8|0);db=j+16|0;d=x[g+16>>2];x[g+12>>2]=x[g+20>>2];vc(o,d,g+12|0);db=g+32|0;db=m+16|0;x[h+4>>2]=x[m+12>>2];Pb(b,h+4|0);Pb(b+4|0,h+8|0);Pb(wb(b),kc(h));x[h>>2]=x[h+4>>2];db=l+16|0;IQ(h)}db=n+32|0;break a}if(c>>>0<d>>>0){Dd(b,e+(c<<5)|0)}}if(Lb(x[a>>2],x[a+8>>2],c<<5)){c=x[b>>2];dc(k+8|0,c,hg(c,x[b+4>>2])<<5);pd(k,a,x[k+8>>2],x[k+12>>2])}db=k+16|0}function BW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0;f=db-32|0;db=f;k=Wh(f+26|0);o=k+3|0;p=k+5|0;q=k+4|0;r=k+2|0;s=k+1|0;t=f+25|0;u=f+23|0;while(1){a:{if(A[a+12>>2]>l>>>0){B=sf(x[a>>2],x[x[a+48>>2]+12>>2],l);b:while(1){if(!Lb(x[c>>2],x[c+8>>2],1)){break a}d=ee(c);if((d|0)==255){break a}m=d<<24>>24;d=m&31;h=D(d,6)+B|0;i=d>>>0<z[x[x[a+48>>2]+12>>2]+480188>>1];j=i?h:k;e=1;if(!(m&64)){d=ee(c);g=d<<24>>24;e=255;d=d&127;c:{d:{if((d|0)==1){break d}e=d-1|0;if(b?e>>>0<=120:0){break d}if((d-109&255)>>>0<159|b){break c}e=d+13|0}v[j|0]=e}E=i?h+1|0:s,F=ee(c),v[E|0]=F;e=(g|0)<0}g=i?h+3|0:o;d=i?h+5|0:p;n=i?h+4|0:q;i=i?h+2|0:r;while(1){e:{f:{g:{if(e&1){w[f+24>>1]=y[j+4|0]|y[j+5|0]<<8;x[f+20>>2]=y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24);e=ee(c);h=e&63;C=e<<24>>24;if(e&64){v[i|0]=1;v[n|0]=h;break e}e=ee(c);v[d|0]=e;if(h>>>0<=15){v[g|0]=h;Qf(j);h:{i:{j:{e=y[g|0];switch(e-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}v[g|0]=9;v[d|0]=D(y[d|0]&15,17);break f}v[g|0]=0;v[i|0]=1;x[f+16>>2]=y[d|0]+1>>>1;x[f+12>>2]=64;E=n,F=x[qd(f+16|0,f+12|0)>>2],v[E|0]=F;break f}if((e|0)!=19){break f}if(y[d|0]==128){break g}Pu(j);break f}if(h>>>0>44){break f}v[g|0]=y[h+26288|0];k:{switch(h-16|0){case 0:if(e>>>0>1){break g}v[d|0]=e|158;break f;case 1:case 2:v[f+16|0]=15;E=d,F=y[Sb(f+16|0,d)|0]|224,v[E|0]=F;break f;case 5:case 6:x[f+16>>2]=16;x[f+12>>2]=e+1;E=d,F=x[qd(f+16|0,f+12|0)>>2]/2|240,v[E|0]=F;break f;case 14:l:{m:{n:{o:{p:{h=e>>>4|0;switch(h-1|0){case 1:break n;case 0:break o;default:break p}}switch(h-10|0){case 1:break l;case 0:break m;default:break g}}v[g|0]=2;v[d|0]=e|240;break f}v[g|0]=3;v[d|0]=e|240;break f}v[g|0]=11;v[d|0]=(e<<3&120)+8|15;break f}v[g|0]=11;v[d|0]=(e&15)+1>>>1|240;break f;case 12:break k;default:break f}}x[f+16>>2]=e+1>>>1;x[f+12>>2]=64;E=d,F=x[qd(f+16|0,f+12|0)>>2],v[E|0]=F;break f}if((m|0)>=0){continue b}break a}v[g|0]=0}Ou(g,d,u,t);e=y[f+23|0];if(th(e)>>>0<=th(y[g|0])>>>0){break e}q:{if(y[i|0]){break q}if(!Lq(g,d,1)){break q}v[i|0]=y[g|0];v[n|0]=y[d|0]}v[g|0]=e;v[d|0]=y[f+25|0]}e=(C|0)<0;continue}}}db=f+32|0;return}l=l+1|0;continue}}function Aaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=db-16|0;db=h;f=x[a+8>>2];e=x[a>>2];x[23549]=0;f=O(563,e|0,f|0)|0;e=x[23549];x[23549]=0;a:{b:{if((e|0)!=1){if(f){break b}x[23549]=0;f=R(192,a|0)|0;e=x[23549];x[23549]=0;c:{if((e|0)==1){break c}x[23549]=0;j=d+484344|0;k=Vd(f+1|0,1,1024);f=U(212,j|0,b|0,k|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break c}if(!f){break b}d=z[d+480188>>1];if(!d){break b}l=d-1|0;d=0;while(1){if(d>>>0>=k>>>0){break b}f=x[a+8>>2];e=x[a>>2];x[23549]=0;f=U(142,e|0,f|0,1)|0;e=x[23549];x[23549]=0;d:{if((e|0)!=1){if(!f){break b}x[23549]=0;i=R(192,a|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break a}if(i){break d}d=d+1|0;continue}break a}e=x[j>>2];w[h+14>>1]=i&31;w[h+12>>1]=l;e=Yb(e,b);e=$c(x[e>>2],x[x[e+48>>2]+12>>2],d,z[Uc(h+14|0,h+12|0)>>1]);if(i>>>0<32){continue}e:{if(i<<24>>24>=0){break e}x[23549]=0;g=R(192,a|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break a}v[e+5|0]=g;x[23549]=0;g=R(192,a|0)|0;f=x[23549];x[23549]=0;f:{g:{if((f|0)!=1){if(g>>>0<26){break g}break f}break a}f=y[g+42912|0];v[e+3|0]=f;h:{switch(f-1|0){case 0:if(!y[e+5|0]){break f}break e;case 12:if(y[e+2|0]){break e}v[e+2|0]=1;f=y[e+5|0];v[e+5|0]=0;v[e+3|0]=0;m=e,n=Vd(f,0,64),v[m+4|0]=n;break e;case 5:case 6:case 10:case 23:case 28:f=y[e+5|0]&240;if(!f){break e}v[e+5|0]=f;break e;case 8:f=y[e+5|0];if(f>>>0<=128){m=e,n=xi(f<<1),v[m+5|0]=n;break e}if((f|0)!=164){break e}v[e+5|0]=145;v[e+3|0]=20;break e;case 13:f=y[e+5|0];v[e+5|0]=D(f>>>4|0,10)+(f&15);break e;case 18:Pu(e);break e;case 16:if(y[e+5|0]>31){break e}v[e+3|0]=16;break e;case 27:break h;default:break e}}g=y[e+5|0];f=g&240;i:{if((f|0)==16){f=2}else{if((f|0)!=32){break i}f=3}v[e+3|0]=f}v[e+5|0]=g&15|224;break e}v[e+3|0]=0}j:{k:{if(!(i&64)){break k}x[23549]=0;P(249,h+10|0,a|0);f=x[23549];x[23549]=0;if((f|0)==1){break j}v[e+1|0]=y[h+10|0];g=y[fd(h+10|0)|0];v[e|0]=g;f=255;if((g|0)!=128){f=253;if(g>>>0<129){break k}}v[e|0]=f}if(!(i&32)){continue}v[e+2|0]=1;x[23549]=0;g=R(192,a|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break a}v[e+4|0]=g;if(!c){continue}v[e+4|0]=(g<<6>>>0)/127;continue}break}break a}break a}break a}ub(a);db=h+16|0;return}b=N()|0;ub(a);Q(b|0);p()}function sca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=db-48|0;db=f;y=x[a+16>>2];z=cg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;r=x[a+128>>2];if(r){k=x[a+8>>2];g=x[a+12>>2];s=dg(k,g,r);t=hb;h=x[a+76>>2];Ff(x[a>>2],x[a+4>>2],bf(k,g,d),hb);q=hb>>>0>h>>>0?d:0}else{q=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}o=x[a+40>>2];p=x[a+36>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;q=q-1|0;h=q;s=h?s:0;t=h?t:0;k=(((g&2147483647)<<1|b>>>31)&-2)+y|0;g=r;a:{b:while(1){c:{if((g|0)<=0){Qb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(!h){break a}b=x[f+40>>2];g=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;i=0;b=0;break c}b=x[f+40>>2];h=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;b=0;i=0;while(1)if((b|0)==2){Md(j,i>>>3<<16>>16);Ld(j,4);Qb(f+40|0,s,t);g=g-1|0;continue b}else{i=(v[k+(b+h|0)|0]<<8)+i|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){i=(v[k+(b+g|0)|0]<<8)+i|0;b=b+1|0;continue}break}Md(j,i>>>3<<16>>16);Ld(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=bg(j,z);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];i=x[a+68>>2];E=i>>31;k=x[a+64>>2];F=k>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){u=(b<<2)+f|0;e=x[u>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];l=x[g+4>>2];x[g+8>>2]=l;w=e<<8;e=w;e=yka(h,G,e,e>>31);m=hb;n=e;e=Ub(l,-16777216,16776704);e=yka(k,F,e,e>>31);l=n+e|0;n=hb+m|0;n=e>>>0>l>>>0?n+1|0:n;e=Ub(H,-16777216,16776704);m=yka(i,E,e,e>>31);l=m+l|0;e=hb+n|0;e=l>>>0<m>>>0?e+1|0:e;m=l+8388608|0;e=m>>>0<8388608?e+1|0:e;e=Lc(m,e,24);x[g+4>>2]=e-(w&C);x[u>>2]=(e|0)/256;b=b+1|0;continue}break}b=x[a+32>>2];p=x[a+28>>2]+p|0;x[c>>2]=x[c>>2]+D(x[f>>2],p>>12);o=b+o|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],o>>12);Qb(f+8|0,A,B);c=c+8|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=o;x[a+20>>2]=p>>12;x[a+36>>2]=p;x[a+24>>2]=o>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}db=f+48|0}function kt(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=db-16|0;db=k;g=x[a+24>>2];i=pz(g,y[a+32|0]);j=x[i>>2];a:{if(Ic(j,x[i+4>>2])>>>0<=b>>>0){break a}if(eP(g,z[_b(j,b)>>1])>>>0<=c>>>0){break a}i=x[a>>2];b:{if(Cd(i,x[a+4>>2])>>>0>b>>>0){if(A[$d(i,b)+4>>2]>c>>>0){break b}}go(a,0);if(Cd(x[a>>2],x[a+4>>2])>>>0<=b>>>0){break a}g=x[a+24>>2]}dc(k,x[d>>2],z[g+480188>>1]);g=k+8|0;l=x[k>>2];d=e?-2046629010:-2078137563;j=e?-1352371636:-873292572;e=x[k+4>>2];while(1){if(!f&(e|0)==(h|0)){x[g>>2]=d;x[g+4>>2]=j;e=g}else{i=y[XQ(l,h)+841|0];m=i^yka(d^h,f^j,435,256);i=!i;d=(q=d,r=yka(m,hb,435,256),s=i,s?q:r);j=i?j:hb;h=h+1|0;f=h?f:f+1|0;continue}break}d=0;f=nm(k,b,c);j=db-16|0;db=j;i=a+12|0;g=i;h=WO(z[f>>1],x[f+4>>2],Ud(g),gc(g));c:{if(Kb(h,Kf(g))){l=z[f>>1];m=x[f+4>>2];f=td(h);if(!el(l,m,z[f>>1],x[f+4>>2])){break c}}h=Kf(g)}f=x[vb(j+12|0,h)>>2];db=j+16|0;if(xg(f,Bf(i))){d=td(f);d=qc(x[d+8>>2],x[d+12>>2])^1}j=x[e>>2]!=-2078137563|x[e+4>>2]!=-873292572;Fb(k,x[$d(x[a>>2],b)>>2],c);h=1;n=Ib(x[x[k>>2]>>2],x[k+4>>2])^1;g=d|j;if(!(n|g)){break a}d:{e:{f:{g:{if(d){m=td(f);g=yb(x[m+8>>2]);o=yb(x[m+12>>2]);f=x[e>>2];p=x[e+4>>2];l=db-16|0;db=l;x[l+12>>2]=g;while(1){h:{if(!Kb(g,o)){break h}if(yE(x[g>>2],x[g+4>>2],f,p)){break h}g=x[mt(l+12|0)>>2];continue}break}db=l+16|0;if(Kb(g,yb(x[m+12>>2]))){break a}if(!j){break e}break g}if(j){break g}if(!g){break d}break f}x[a+28>>2]=x[a+28>>2]+1}if(d|n){break e}d=UO(i,nm(k,b,c));i:{if(A[d+4>>2]<A[wb(d)>>2]){f=db-16|0;db=f;d=TO(f+4|0,d);SO(x[d+4>>2]);x[d+4>>2]=x[d+4>>2]+8;fc(d);db=f+16|0;break i}h=db-32|0;db=h;f=wb(d);f=ir(h+12|0,jr(d,Hg(x[d>>2],x[d+4>>2])+1|0),Hg(x[d>>2],x[d+4>>2]),f);SO(x[f+8>>2]);x[f+8>>2]=x[f+8>>2]+8;oz(d,f);hr(f);db=h+32|0}}d=UO(i,nm(k,b,c));j:{if(A[d+4>>2]<A[wb(d)>>2]){f=db-16|0;db=f;d=TO(f+4|0,d);NN(x[d+4>>2],x[e>>2],x[e+4>>2]);x[d+4>>2]=x[d+4>>2]+8;fc(d);db=f+16|0;break j}h=db-32|0;db=h;f=wb(d);f=ir(h+12|0,jr(d,Hg(x[d>>2],x[d+4>>2])+1|0),Hg(x[d>>2],x[d+4>>2]),f);NN(x[f+8>>2],x[e>>2],x[e+4>>2]);x[f+8>>2]=x[f+8>>2]+8;oz(d,f);hr(f);db=h+32|0}}Fb(k,x[$d(x[a>>2],b)>>2],c);Dh(k,1);h=0}db=k+16|0;return h|0}function j4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Gb(a);x[23549]=0;X(91);c=x[23549];x[23549]=0;a:{b:{if((c|0)==1){c=Qa(61816,92296,92880,0)|0;d=eb;c:{d:{e:{if(($(61816)|0)==(d|0)){c=Y(c|0)|0;x[23549]=0;b=O(916,a|0,b|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break e}x[23549]=0;b=O(916,b|0,17347)|0;d=x[23549];x[23549]=0;if((d|0)==1){break e}x[23549]=0;d=O(916,b|0,17323)|0;b=x[23549];x[23549]=0;if((b|0)==1){break e}b=ib[x[x[c>>2]+8>>2]](c)|0;x[23549]=0;O(916,d|0,(b?b:21204)|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break e}x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){break b}b=N()|0;break a}f:{if(($(92296)|0)==(d|0)){c=Y(c|0)|0;x[23549]=0;b=O(916,a|0,b|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break f}x[23549]=0;b=O(916,b|0,17347)|0;d=x[23549];x[23549]=0;if((d|0)==1){break f}x[23549]=0;d=O(916,b|0,17298)|0;b=x[23549];x[23549]=0;if((b|0)==1){break f}b=ib[x[x[c>>2]+8>>2]](c)|0;x[23549]=0;O(916,d|0,(b?b:21204)|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break f}x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){break b}b=N()|0;break a}e=$(92880)|0;c=Y(c|0)|0;g:{if((d|0)==(e|0)){x[23549]=0;b=O(916,a|0,b|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break g}x[23549]=0;b=O(916,b|0,17347)|0;d=x[23549];x[23549]=0;if((d|0)==1){break g}x[23549]=0;d=O(916,b|0,17314)|0;b=x[23549];x[23549]=0;if((b|0)==1){break g}b=ib[x[x[c>>2]+8>>2]](c)|0;x[23549]=0;O(916,d|0,(b?b:21204)|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break g}x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){break b}b=N()|0;break a}x[23549]=0;b=O(916,a|0,b|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break d}x[23549]=0;b=O(916,b|0,17347)|0;c=x[23549];x[23549]=0;if((c|0)==1){break d}x[23549]=0;O(916,b|0,13493)|0;b=x[23549];x[23549]=0;if((b|0)==1){break d}x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){break b}b=N()|0;break a}b=N()|0;x[23549]=0;X(17);c=x[23549];x[23549]=0;if((c|0)!=1){break a}break c}b=N()|0;x[23549]=0;X(17);c=x[23549];x[23549]=0;if((c|0)!=1){break a}break c}b=N()|0;x[23549]=0;X(17);c=x[23549];x[23549]=0;if((c|0)==1){break c}break a}b=N()|0;x[23549]=0;X(17);c=x[23549];x[23549]=0;if((c|0)!=1){break a}}T(0)|0;Rb()}p()}return}tb(a);Q(b|0);p()}function xia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=E(0);c=db-112|0;db=c;d=db-16|0;db=d;e=b+16|0;MT(d+8|0,e);f=x[d+12>>2];lc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){Zb(a,x[d+12>>2])}db=d+16|0;if((f|0)!=(g|0)){Vb(e,0,128)}v[b+79|0]=0;v[b+143|0]=0;x[b+152>>2]=-2147483648;x[b+156>>2]=-2147483648;d=c+72|0;Wd(d,a,pg(a));f=hc(c+92|0,d);ub(d);x[23549]=0;d=R(188,f|0)|0;e=x[23549];x[23549]=0;a:{b:{if((e|0)==1){break b}x[23549]=0;P(274,b+4|0,d|0);d=x[23549];x[23549]=0;if((d|0)==1){break b}ge(c- -64|0,x[b+4>>2],x[b+8>>2]);x[23549]=0;hn(413,c+72|0,f,x[c+64>>2],x[c+68>>2]);d=x[23549];x[23549]=0;if((d|0)!=1){x[23549]=0;d=R(143,a|0)|0;e=x[23549];x[23549]=0;c:{if((e|0)==1){break c}x[23549]=0;S(176,c+44|0,a|0,d|0);a=x[23549];x[23549]=0;if((a|0)==1){break c}a=c+44|0;d=hc(c+72|0,a);ub(a);a=x[d>>2];x[23549]=0;a=R(164,a|0)|0;e=x[23549];x[23549]=0;d:{if((e|0)!=1){e:{f:{if(!a){break f}while(1){g:{a=x[d+8>>2];e=x[d>>2];x[23549]=0;a=U(142,e|0,a|0,5)|0;e=x[23549];x[23549]=0;if((e|0)==1){break e}if(!a){break f}x[23549]=0;O(414,d|0,c+40|0)|0;a=x[23549];x[23549]=0;h:{if((a|0)!=1){a=4;e=y[c+40|0]|y[c+41|0]<<8|(y[c+42|0]<<16|y[c+43|0]<<24);if((e|0)==1414682436|(e|0)==1196380752){break h}x[23549]=0;a=R(143,d|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){break h}a=N()|0;break d}a=N()|0;break d}x[23549]=0;S(176,c+20|0,d|0,a|0);a=x[23549];x[23549]=0;i:{j:{k:{if((a|0)!=1){a=c+20|0;e=hc(c+44|0,a);ub(a);if((y[c+40|0]|y[c+41|0]<<8|(y[c+42|0]<<16|y[c+43|0]<<24))!=1414682436){break k}x[23549]=0;h=E(va(415,e|0));a=x[23549];x[23549]=0;if((a|0)==1){break g}B[c+20>>2]=h;x[c+16>>2]=0;x[c+12>>2]=1065353216;a=nq(c+20|0,c+16|0,c+12|0);g=x[a>>2];B[b+144>>2]=B[a>>2];if((g&2147483647)-8388608>>>0<2130706432){break j}x[b+144>>2]=0;break j}a=N()|0;break d}if((y[c+40|0]|y[c+41|0]<<8|(y[c+42|0]<<16|y[c+43|0]<<24))!=1196380752){break j}x[23549]=0;a=R(143,e|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break i}x[b+148>>2]=a}ub(e);continue}}break}a=N()|0;ub(e);break d}ub(d);ub(f);db=c+112|0;return}a=N()|0;break d}a=N()|0}ub(d);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0}ub(f);Q(a|0);p()}function o7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=0,h=E(0),i=0,j=0,k=0,l=E(0),m=0,n=0,o=0,p=0,q=0,r=E(0),s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,C=0,D=0,F=E(0),G=E(0),H=E(0),I=0,J=0,K=0,L=0,M=E(0),N=E(0),O=E(0),P=E(0),Q=E(0),R=E(0),S=0,T=0,U=E(0);if(Yh(a+44|0)){f=x[a+44>>2];y=Ac(f,0);z=Ac(f,1);f=x[a+56>>2];A=Ac(f,0);C=Ac(f,1);n=x[a+4300>>2];s=x[a+4296>>2];m=s+1|0;k=a+4304|0;f=a+4272|0;t=m+x[xb(f,0)>>2]&4095;o=k+(t<<4)|0;u=m+x[xb(f,1)>>2]&4095;j=((u<<4)+k|0)+4|0;v=m+x[xb(f,2)>>2]&4095;p=((v<<4)+k|0)+8|0;i=x[xb(f,3)>>2];g=x[xb(f,4)>>2]+n|0;w=i+m&4095;D=((w<<4)+k|0)+12|0;q=x[xb(f,5)>>2]+n|0;i=a+4232|0;I=a+69840|0;J=a+78032|0;m=d;while(1){if(m){u=u-1&4095;f=((u<<4)+k|0)+4|0;e=B[f>>2];K=g&1023;g=(K<<3)+I|0;r=B[g>>2];M=B[D>>2];N=B[p>>2];O=B[j>>2];P=B[o>>2];Q=B[z>>2];R=B[y>>2];F=B[xb(i,0)>>2];G=B[g+4>>2];j=xb(i,0);t=t-1&4095;o=(t<<4)+k|0;h=B[o>>2];H=B[j>>2];g=n<<3;j=g+I|0;l=e;e=E(E(e*E(.6180340051651001))+E(r*F));B[j+4>>2]=l+E(e*E(-.6180340051651001));l=h;h=E(E(G*H)+E(h*E(-.6180340051651001)));B[j>>2]=l+E(h*E(.6180340051651001));B[o>>2]=e;B[f>>2]=h;w=w-1&4095;j=(w<<4)+k|0;D=j+12|0;e=B[D>>2];L=q&1023;p=(L<<3)+J|0;r=B[p>>2];F=B[xb(i,1)>>2];G=B[p+4>>2];S=xb(i,1);v=v-1&4095;q=(v<<4)+k|0;p=q+8|0;h=B[p>>2];H=B[S>>2];g=g+J|0;l=e;e=E(E(e*E(.6180340051651001))+E(r*F));B[g+4>>2]=l+E(e*E(-.6180340051651001));l=h;h=E(E(G*H)+E(h*E(-.6180340051651001)));B[g>>2]=l+E(h*E(.6180340051651001));B[q+8>>2]=e;B[j+12>>2]=h;h=e;e=E(R+E(1.0000000031710769e-30));B[A>>2]=h+E(E(e*B[a+4224>>2])+B[o>>2]);h=E(Q+E(1.0000000031710769e-30));B[C>>2]=E(E(h*B[a+4224>>2])+B[f>>2])+B[j+12>>2];g=(s<<4)+k|0;l=e;e=B[a+4228>>2];r=E(l*e);T=g,U=E(r+E(E(B[o>>2]*B[xb(i,2)>>2])+E(P*B[xb(i,3)>>2]))),B[T>>2]=U;e=E(h*e);T=g,U=E(e+E(E(B[f>>2]*B[xb(i,4)>>2])+E(O*B[xb(i,5)>>2]))),B[T+4>>2]=U;T=g,U=E(E(E(B[q+8>>2]*B[xb(i,6)>>2])+E(N*B[xb(i,7)>>2]))-e),B[T+8>>2]=U;T=g,U=E(r+E(E(B[j+12>>2]*B[xb(i,8)>>2])+E(M*B[xb(i,9)>>2]))),B[T+12>>2]=U;m=m-1|0;C=C+4|0;A=A+4|0;z=z+4|0;y=y+4|0;q=L-1|0;g=K-1|0;n=n-1&1023;s=s-1&4095;j=f;continue}else{x[a+4300>>2]=n;x[a+4296>>2]=s;f=a;a=x[a+56>>2];li(f,b,c,Ac(a,0),Ac(a,1),d)}break}}}function Dx(a){a=a|0;var b=0,c=0,d=E(0),e=0;Vb(a+4960|0,0,76);v[a+5044|0]=0;x[a+5036>>2]=0;x[a+5040>>2]=0;b=x[a+4292>>2];d=B[a+4268>>2];x[23549]=0;e=a+4504|0;if(d<E(4294967296)&d>=E(0)){c=~~d>>>0}else{c=0}aa(904,e|0,67,5,c|0,b|0);b=x[23549];x[23549]=0;a:{if((b|0)==1){break a}b=x[a+4296>>2];x[23549]=0;aa(904,a+4528|0,62,5,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break a}b=x[a+4300>>2];x[23549]=0;aa(904,a+4552|0,53,5,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break a}b=x[a+4304>>2];x[23549]=0;aa(904,a+4576|0,43,5,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break a}b=x[a+4308>>2];x[23549]=0;aa(904,a+4600|0,32,5,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break a}b=x[a+4312>>2];x[23549]=0;aa(904,a+4624|0,22,5,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break a}b=x[a+4316>>2];x[23549]=0;aa(904,a+4648|0,75,5,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break a}b=x[a+4320>>2];x[23549]=0;aa(904,a+4672|0,69,5,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break a}b=x[a+4324>>2];x[23549]=0;aa(904,a+4696|0,60,5,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break a}b=x[a+4328>>2];x[23549]=0;aa(904,a+4720|0,48,5,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break a}b=x[a+4332>>2];x[23549]=0;aa(904,a+4744|0,36,5,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break a}b=x[a+4336>>2];x[23549]=0;aa(904,a+4768|0,25,5,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break a}x[23549]=0;aa(904,a+4792|0,0,0,0,0);b=x[23549];x[23549]=0;if((b|0)==1){break a}b=x[a+4344>>2];x[23549]=0;aa(904,a+4816|0,3,0,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break a}b=x[a+4348>>2];x[23549]=0;aa(904,a+4840|0,3,0,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break a}x[23549]=0;aa(904,a+4864|0,407,1,c|0,0);b=x[23549];x[23549]=0;if((b|0)==1){break a}x[23549]=0;aa(904,a+4888|0,400,1,c|0,0);b=x[23549];x[23549]=0;if((b|0)==1){break a}x[23549]=0;aa(904,a+4912|0,10,0,c|0,-1);b=x[23549];x[23549]=0;if((b|0)==1){break a}x[23549]=0;aa(904,a+4936|0,10,0,c|0,-1);c=x[23549];x[23549]=0;if((c|0)==1){break a}v[a+5045|0]=1;return}c=T(92296)|0;if((eb|0)==($(92296)|0)){Y(c|0)|0;v[a+5045|0]=0;Z();return}Q(c|0);p()}function rca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=db-48|0;db=f;y=x[a+16>>2];z=cg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;q=x[a+128>>2];if(q){i=x[a+8>>2];g=x[a+12>>2];r=dg(i,g,q);s=hb;h=x[a+76>>2];Ff(x[a>>2],x[a+4>>2],bf(i,g,d),hb);p=hb>>>0>h>>>0?d:0}else{p=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];a:while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;p=p-1|0;h=p;r=h?r:0;s=h?s:0;i=((((g&2147483647)<<1|b>>>31)&2147483646)<<1)+y|0;b=q;while(1)if((b|0)<=0){Qb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(h){b=x[f+40>>2];b=(x[f+44>>2]&2147483647)<<1|b>>>31;Md(j,(w[(b<<1|2)+i>>1]+w[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Ld(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=bg(j,z);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];t=x[a+68>>2];E=t>>31;i=x[a+64>>2];F=i>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){u=(b<<2)+f|0;e=x[u>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];k=x[g+4>>2];x[g+8>>2]=k;v=e<<8;e=v;e=yka(h,G,e,e>>31);l=hb;m=e;e=Ub(k,-16777216,16776704);e=yka(i,F,e,e>>31);k=m+e|0;m=hb+l|0;m=e>>>0>k>>>0?m+1|0:m;e=Ub(H,-16777216,16776704);l=yka(t,E,e,e>>31);k=l+k|0;e=hb+m|0;e=k>>>0<l>>>0?e+1|0:e;l=k+8388608|0;e=l>>>0<8388608?e+1|0:e;e=Lc(l,e,24);x[g+4>>2]=e-(v&C);x[u>>2]=(e|0)/256;b=b+1|0;continue}break}b=x[a+32>>2];o=x[a+28>>2]+o|0;x[c>>2]=x[c>>2]+D(x[f>>2],o>>12);n=b+n|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],n>>12);Qb(f+8|0,A,B);c=c+8|0;continue a}else{g=x[f+40>>2];g=(x[f+44>>2]&2147483647)<<1|g>>>31;Md(j,(w[(g<<1|2)+i>>1]+w[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Ld(j,4);Qb(f+40|0,r,s);b=b-1|0;continue}}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}db=f+48|0}
function C8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=E(0),h=E(0),i=0,j=0,k=E(0),l=0,m=0,n=E(0),o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=E(0),w=0,z=0,A=0,C=0,D=0,G=0,H=E(0),I=0,J=0,K=0,L=0,M=0,N=E(0),O=0,P=E(0);a:{if(!x[a+4316>>2]){break a}if(!Yh(a+44|0)){break a}D=a+4300|0;G=a+4288|0;I=a+4264|0;J=a+4276|0;e=x[a+44>>2];r=Ac(e,0);s=Ac(e,1);e=x[a+56>>2];t=Ac(e,0);u=Ac(e,1);K=ib[x[x[a>>2]+192>>2]](a)|0;v=E(E(ib[x[x[a>>2]+200>>2]](a))/E(100));H=E(ib[x[x[a>>2]+188>>2]](a));w=ib[x[x[a>>2]+212>>2]](a)|0;L=w&1;o=x[a+4324>>2];l=x[a+4320>>2];m=x[a+4328>>2];j=x[a+4312>>2];M=x[a+4276>>2];p=x[a+4264>>2];z=x[a+4256>>2];A=y[a+4260|0];C=d;while(1){if(C){h=B[s>>2];k=B[r>>2];i=x[a+4316>>2];e=Qn(i,j+z|0);i=Qn(i,j);b:{if(A){O=xb(G,m),P=k,B[O>>2]=P;O=xb(D,m),P=h,B[O>>2]=P;q=xb(p,e);O=xb(p,i),P=E(E(B[q>>2]*v)+k),B[O>>2]=P;g=E(E(B[xb(M,e)>>2]*v)+h);e=J;break b}g=E(E(B[xb(p,e)>>2]*v)+E(E(k+h)*E(.5)));e=I}O=xb(x[e>>2],i),P=g,B[O>>2]=P;c:{if(K){f=B[a+4244>>2];g=E(f+B[a+4236>>2]);B[a+4236>>2]=g;f=E(f+B[a+4240>>2]);B[a+4240>>2]=f;if(g>E(1)){g=E(g+E(-2));B[a+4236>>2]=g}if(f>E(1)){f=E(f+E(-2));B[a+4240>>2]=f}g=E(F(g));g=E(E(g+g)+E(-1));f=E(F(f));f=E(E(f+f)+E(-1));break c}f=B[a+4240>>2];n=B[a+4244>>2];g=E(E(f*n)+B[a+4236>>2]);B[a+4236>>2]=g;f=E(f-E(g*n));B[a+4240>>2]=f}if(A){e=(m+2|0)%3|0;k=B[xb(G,e)>>2];h=B[xb(D,e)>>2]}e=x[a+4316>>2];i=xb(p,Qn(e,j+l|0));q=e;e=j+4096|0;N=B[xb(p,Qn(q,e+l|0))>>2];n=B[i>>2];B[t>>2]=E(E(E(E(E(N-n)*E(E(l&4095)*E(.000244140625)))+n)-k)*H)+k;l=x[(A?4276:4264)+a>>2];i=x[a+4316>>2];q=xb(l,Qn(i,j+o|0));n=B[xb(l,Qn(i,e+o|0))>>2];k=B[q>>2];B[u>>2]=E(E(E(E(E(n-k)*E(E(o&4095)*E(.000244140625)))+k)-h)*H)+h;m=((m|0)<=0?m+3|0:m)-1|0;x[a+4328>>2]=m;j=(((j|0)<=0?x[a+4316>>2]<<12:0)+j|0)-4096|0;x[a+4312>>2]=j;h=L?f:g;f=B[a+4248>>2];h=E(h*f);d:{if(E(F(h))<E(2147483648)){e=~~h;break d}e=-2147483648}o=(w>>>0>1?e:0-e|0)+z|0;x[a+4324>>2]=o;s=s+4|0;r=r+4|0;g=E(g*f);e:{if(E(F(g))<E(2147483648)){e=~~g;break e}e=-2147483648}l=(w>>>0<4?e:0-e|0)+z|0;x[a+4320>>2]=l;C=C-1|0;u=u+4|0;t=t+4|0;continue}else{e=a;a=x[a+56>>2];li(e,b,c,Ac(a,0),Ac(a,1),d)}break}}}function M6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=db-112|0;db=d;e=x[b+4>>2];a:{if(!e){break a}f=x[b>>2];h=y[Sk(f,e)|0];if((h|0)==33){c=1}else{if((h|0)!=63){break a}c=0}cl(d+88|0,f,e,e-1|0);e=x[d+92>>2];x[b>>2]=x[d+88>>2];x[b+4>>2]=e}f=d+88|0;Rd(f);e=x[d+88>>2];Rd(d+76|0);e=Rk(e,x[d+80>>2],b);Rd(f);b:{c:{d:{e:{if((e|0)==x[d+92>>2]){a=x[b+4>>2];e=x[b>>2];f=mc(d+104|0,21204);h=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=h;if(Gc(e,a,d)){a=ac(8);x[23549]=0;c=O(54,d+88|0,10365)|0;b=x[23549];x[23549]=0;if((b|0)==1){break d}a=pc(a,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}g=0;if(!c){break e}a=ac(8);c=x[b+4>>2];b=x[b>>2];x[23549]=0;e=Ch(d+76|0,b,c);b=x[23549];x[23549]=0;f:{g:{h:{if((b|0)!=1){x[23549]=0;S(942,d+88|0,17247,e|0);b=x[23549];x[23549]=0;if((b|0)==1){break h}c=0;b=pc(a,d+88|0);x[23549]=0;S(105,b|0,61816,931);b=x[23549];x[23549]=0;if((b|0)!=1){break b}b=N()|0;tb(d+88|0);break g}b=N()|0;break f}b=N()|0;c=1}tb(e);if(!c){break c}}jc(a);break c}if(x[e+4>>2]!=2){a=ac(8);x[23549]=0;c=O(54,d+88|0,11442)|0;b=x[23549];x[23549]=0;if((b|0)!=1){a=pc(a,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}c=x[b+4>>2];b=x[b>>2];e=mc(d+68|0,21204);f=x[e+4>>2];x[d+32>>2]=x[e>>2];x[d+36>>2]=f;if(Gc(b,c,d+32|0)){a=ac(8);x[23549]=0;c=O(54,d+88|0,10365)|0;b=x[23549];x[23549]=0;if((b|0)!=1){a=pc(a,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}e=mc(d+60|0,7657);f=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=f;if(Gc(b,c,d+24|0)){g=1;if(!vd(y[a+28|0])){break e}g=65536/+A[x[a+24>>2]+480244>>2];break e}e=mc(d+52|0,7709);f=x[e+4>>2];x[d+16>>2]=x[e>>2];x[d+20>>2]=f;if(Gc(b,c,d+16|0)){g=1;if(!vd(y[a+28|0])){break e}g=+A[x[a+24>>2]+480240>>2]*152587890625e-16;break e}e=mc(d+44|0,7727);f=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=f;g=0;if(!Gc(b,c,d+8|0)){break e}g=+A[x[a+24>>2]+480236>>2]*152587890625e-16}db=d+112|0;return+g}b=N()|0;jc(a)}Q(b|0)}p()}function wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=db-48|0;db=f;u=x[a+16>>2];w=cg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;p=x[a+128>>2];if(p){k=x[a+8>>2];g=x[a+12>>2];q=dg(k,g,p);r=hb;h=x[a+76>>2];Ff(x[a>>2],x[a+4>>2],bf(k,g,d),hb);o=hb>>>0>h>>>0?d:0}else{o=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}y=x[a+24>>2];z=x[a+20>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;o=o-1|0;h=o;q=h?q:0;r=h?r:0;k=(((g&2147483647)<<1|b>>>31)&-2)+u|0;g=p;a:{b:while(1){c:{if((g|0)<=0){Qb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(!h){break a}b=x[f+40>>2];g=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;i=0;b=0;break c}b=x[f+40>>2];h=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;b=0;i=0;while(1)if((b|0)==2){Md(j,i>>>3<<16>>16);Ld(j,4);Qb(f+40|0,q,r);g=g-1|0;continue b}else{i=(v[k+(b+h|0)|0]<<8)+i|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){i=(v[k+(b+g|0)|0]<<8)+i|0;b=b+1|0;continue}break}Md(j,i>>>3<<16>>16);Ld(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=bg(j,w);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];i=x[a+68>>2];E=i>>31;k=x[a+64>>2];F=k>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){s=(b<<2)+f|0;e=x[s>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];l=x[g+4>>2];x[g+8>>2]=l;t=e<<8;e=t;e=yka(h,G,e,e>>31);m=hb;n=e;e=Ub(l,-16777216,16776704);e=yka(k,F,e,e>>31);l=n+e|0;n=hb+m|0;n=e>>>0>l>>>0?n+1|0:n;e=Ub(H,-16777216,16776704);m=yka(i,E,e,e>>31);l=m+l|0;e=hb+n|0;e=l>>>0<m>>>0?e+1|0:e;m=l+8388608|0;e=m>>>0<8388608?e+1|0:e;e=Lc(m,e,24);x[g+4>>2]=e-(t&C);x[s>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],z);x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],y);Qb(f+8|0,A,B);c=c+8|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}db=f+48|0}function zK(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=db-128|0;db=j;a:{b:{c:{if(!mm(f,g,h,i,0,0,0,0)){break c}l=i&65535;n=i>>>16&32767;d:{e:{if((n|0)!=32767){k=4;if(n){break e}k=f|h|(g|l)?3:2;break d}k=!(f|h|(g|l))}}s=e>>>16|0;o=s&32767;if((o|0)==32767){break c}if(k){break b}}Ed(j+16|0,b,c,d,e,f,g,h,i);b=x[j+16>>2];d=x[j+20>>2];e=x[j+24>>2];c=x[j+28>>2];aL(j,b,d,e,c,b,d,e,c);d=x[j+8>>2];e=x[j+12>>2];h=x[j>>2];i=x[j+4>>2];break a}k=d;p=e&2147483647;n=h;m=i&2147483647;if((mm(b,c,k,p,f,g,h,m)|0)<=0){if(mm(b,c,k,p,f,g,n,m)){h=b;i=c;break a}Ed(j+112|0,b,c,d,e,0,0,0,0);d=x[j+120>>2];e=x[j+124>>2];h=x[j+112>>2];i=x[j+116>>2];break a}q=i>>>16&32767;if(o){i=c;h=b}else{Ed(j+96|0,b,c,k,p,0,0,0,1081540608);k=x[j+104>>2];h=x[j+108>>2];p=h;o=(h>>>16|0)-120|0;i=x[j+100>>2];h=x[j+96>>2]}if(!q){Ed(j+80|0,f,g,n,m,0,0,0,1081540608);n=x[j+88>>2];f=x[j+92>>2];m=f;q=(f>>>16|0)-120|0;g=x[j+84>>2];f=x[j+80>>2]}r=n;t=m&65535|65536;p=p&65535|65536;if((o|0)>(q|0)){while(1){m=k-r|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=m-l|0;l=(p-((k>>>0<r>>>0)+t|0)|0)-(l>>>0>m>>>0)|0;f:{if((l|0)>0|(l|0)>=0){k=h;h=h-f|0;i=i-((f>>>0>k>>>0)+g|0)|0;if(!(h|n|(i|l))){Ed(j+32|0,b,c,d,e,0,0,0,0);d=x[j+40>>2];e=x[j+44>>2];h=x[j+32>>2];i=x[j+36>>2];break a}l=l<<1|n>>>31;k=n<<1|i>>>31;break f}l=p<<1|k>>>31;k=k<<1|i>>>31}p=l;l=i<<1|h>>>31;h=h<<1;i=l;o=o-1|0;if((o|0)>(q|0)){continue}break}o=q}m=k-r|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=m-l|0;l=(p-((k>>>0<r>>>0)+t|0)|0)-(l>>>0>m>>>0)|0;m=l;g:{if((l|0)<0){n=k;m=p;break g}k=h;h=h-f|0;i=i-((f>>>0>k>>>0)+g|0)|0;if(h|n|(i|m)){break g}Ed(j+48|0,b,c,d,e,0,0,0,0);d=x[j+56>>2];e=x[j+60>>2];h=x[j+48>>2];i=x[j+52>>2];break a}if((m|0)==65535|m>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;p=i<<1|h>>>31;h=h<<1;i=p;c=b;b=m<<1|n>>>31;n=c|n<<1;m=b;if(b>>>0<65536){continue}break}}b=s&32768;if((o|0)<=0){Ed(j- -64|0,h,i,n,m&65535|(b|o+120)<<16,0,0,0,1065811968);d=x[j+72>>2];e=x[j+76>>2];h=x[j+64>>2];i=x[j+68>>2];break a}d=n;e=m&65535|(b|o)<<16}x[a>>2]=h;x[a+4>>2]=i;x[a+8>>2]=d;x[a+12>>2]=e;db=j+128|0}function Tea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=db-112|0;db=d;a:{b:{c:{d:{switch(y[a|0]-23|0){case 0:e=v[a+1|0];f=d,g=tS(c,+y[a+2|0]*1e4/240),v[f+12|0]=g;x[d+88>>2]=127;x[d+76>>2]=(D(y[a+3|0],127)>>>0)/185;f=d,g=x[qd(d+88|0,d+76|0)>>2],v[f+111|0]=g;e:{switch(((e>>>0)%5|0)-1|0){case 0:hf(d+76|0,15216);x[23549]=0;P(502,d- -64|0,d+12|0);a=x[23549];x[23549]=0;f:{g:{h:{i:{if((a|0)!=1){x[23549]=0;P(502,d+52|0,d+111|0);a=x[23549];x[23549]=0;if((a|0)==1){break i}x[23549]=0;V(503,d+88|0,d+76|0,d- -64|0,d+52|0);a=x[23549];x[23549]=0;if((a|0)==1){break h}a=d+88|0;ze(d+100|0,a);Xe(b,x[d+100>>2],x[d+104>>2]);tb(a);tb(d+52|0);tb(d- -64|0);Ab(d+76|0);break b}a=N()|0;break f}a=N()|0;break g}a=N()|0;tb(d+52|0)}tb(d- -64|0)}break c;case 1:hf(d+76|0,15156);x[23549]=0;P(502,d- -64|0,d+12|0);a=x[23549];x[23549]=0;j:{k:{l:{m:{if((a|0)!=1){x[23549]=0;P(502,d+52|0,d+111|0);a=x[23549];x[23549]=0;if((a|0)==1){break m}x[23549]=0;V(503,d+88|0,d+76|0,d- -64|0,d+52|0);a=x[23549];x[23549]=0;if((a|0)==1){break l}a=d+88|0;ze(d+44|0,a);Xe(b,x[d+44>>2],x[d+48>>2]);tb(a);tb(d+52|0);tb(d- -64|0);Ab(d+76|0);break b}a=N()|0;break j}a=N()|0;break k}a=N()|0;tb(d+52|0)}tb(d- -64|0)}break c;default:break e}}a=mc(d+36|0,15243);Xe(b,x[a>>2],x[a+4>>2]);break b;case 1:break d;default:break a}}c=v[a+1|0];v[d+111|0]=(c|0)<5?c:0;c=v[a+2|0];v[d+35|0]=(c|0)<0?127:c;a=v[a+3|0];v[d+34|0]=(a|0)<0?127:a;a=db-16|0;db=a;c=Tb(a+4|0,3989);ad(d+76|0,c);tb(c);db=a+16|0;x[23549]=0;P(502,d- -64|0,d+111|0);a=x[23549];x[23549]=0;n:{o:{p:{q:{r:{s:{if((a|0)!=1){x[23549]=0;P(502,d+52|0,d+35|0);a=x[23549];x[23549]=0;if((a|0)==1){break s}x[23549]=0;P(502,d+12|0,d+34|0);a=x[23549];x[23549]=0;if((a|0)==1){break r}x[23549]=0;aa(678,d+88|0,d+76|0,d- -64|0,d+52|0,d+12|0);a=x[23549];x[23549]=0;if((a|0)==1){break q}a=d+88|0;ze(d+24|0,a);Xe(b,x[d+24>>2],x[d+28>>2]);tb(a);tb(d+12|0);tb(d+52|0);tb(d- -64|0);Ab(d+76|0);break b}a=N()|0;break n}a=N()|0;break o}a=N()|0;break p}a=N()|0;tb(d+12|0)}tb(d+52|0)}tb(d- -64|0)}}Ab(d+76|0);Q(a|0);p()}e=1}db=d+112|0;return e|0}function tha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=db-16|0;db=f;a:{b:{if(!c){break b}n=f,o=ee(a),v[n+8|0]=o;qn(b,f+8|0);j=c-1|0;while(1){e=1;if(!j){break a}c:{c=g<<1&254;d:{if(!c){if(!ef(a,f+8|0)){break b}d=y[f+8|0]<<1|1;c=d&255;if(d>>>0<256){break d}break c}if((g&65535)>>>0>127){break c}}if(!ef(a,f+8|0)){break b}ZU(b,f+8|0);j=j-1|0;g=c;continue}e=1;while(1){e:{f:{g:{g=c<<1&254;if(g){c=(c&65535)>>>0>127}else{if(!ef(a,f+8|0)){break g}c=y[f+8|0]<<1|1;g=c&255;c=c>>>0>255}e=fq(e,1)+c|0;c=g<<1&254;if(c){break f}if(!ef(a,f+8|0)){break g}d=y[f+8|0]<<1|1;c=d&255;if(d>>>0>255){continue}break e}c=0;break e}if(g>>>0>127){continue}}break}h:{if((e|0)<=2){h=0;d=e-2|0;break h}if(!ef(a,f+8|0)){break b}d=fq(e-3|0,8)|y[f+8|0];h=((d|0)>1279?2:1)+((d|0)>31999)|0;l=d^-1;d=0}e=c<<1&254;if(e){c=c>>>0>127}else{if(!ef(a,f+8|0)){break b}c=y[f+8|0]<<1|1;e=c&255;c=c>>>0>255}i=fq(d,1);g=e<<1&254;if(g){d=e>>>0>127}else{if(!ef(a,f+8|0)){break b}d=y[f+8|0]<<1|1;g=d&255;d=d>>>0>255}e=1;c=fq(c+i|0,1)+d|0;if(!c){while(1){i:{j:{k:{c=g<<1&254;if(c){d=(g&65535)>>>0>127}else{if(!ef(a,f+8|0)){break k}d=y[f+8|0]<<1|1;c=d&255;d=d>>>0>255}e=fq(e,1)+d|0;g=c<<1&254;if(g){break j}if(!ef(a,f+8|0)){break k}c=y[f+8|0]<<1|1;g=c&255;if(c>>>0>255){continue}break i}g=0;break i}if(c>>>0>127){continue}}break}c=e+2|0}d=c+h|0;e=0;if(d>>>0>j>>>0|(d|0)<=0|(l|0)>=0){break a}c=x[b+4>>2];e=0;if((0-Pc(x[b>>2],c)|0)>(l|0)){break a}c=vb(f+12|0,yb(c));v[f+8|0]=0;i=f+8|0;m=db-32|0;db=m;e=x[c>>2];c=x[b>>2];h=he(e,yb(c))+c|0;c=x[wb(b)>>2];k=x[b+4>>2];l:{if(d>>>0<=c-k>>>0){c=d;e=k-h|0;if(c>>>0>e>>>0){Ro(b,d-e|0,i);c=e;if(!c){break l}}$U(b,h,k,d+h|0);Sh(h,c,i+(h>>>0<=i>>>0?i>>>0<A[b+4>>2]?d:0:0)|0);break l}c=wb(b);c=Ol(m+12|0,Ek(b,Pc(x[b>>2],k)+d|0),h-x[b>>2]|0,c);RT(c,d,i);h=_U(b,c,h);Ml(c)}yb(h);db=m+32|0;n=f,o=Ie(CA(yb(x[b+4>>2]),d),l),x[n+8>>2]=o;n=f,o=CA(yb(x[b+4>>2]),d),x[n+4>>2]=o;c=d;while(1){e=y[_S(f+8|0)|0];n=_S(f+4|0),o=e,v[n|0]=o;e=c>>>0>1;c=c-1|0;if(e){continue}break}j=j-d|0;continue}}e=0}db=f+16|0;return e|0}function Xca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=db-48|0;db=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}u=b+196648|0;break a}u=b+131112|0;break a}u=b+262184|0}A=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+28|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}o=x[a+40>>2];p=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;B=x[a+32>>2];C=x[a+28>>2];E=x[a+72>>2];z=x[a+68>>2];F=z>>31;l=x[a+64>>2];G=l>>31;j=x[a+60>>2];H=j>>31;while(1){if(d){b=x[f+16>>2];v=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+A|0;b=(b>>>16&65520)+u|0;m=w[b+14>>1];s=w[b+12>>1];t=w[b+10>>1];y=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];q=0;r=0;while(1){if((r|0)!=2){k=v+(r<<1)|0;x[(f+8|0)+(r<<2)>>2]=(((((((D(w[k-8>>1],e)+D(w[k-12>>1],b)|0)+D(w[k-4>>1],i)|0)+D(w[k>>1],g)|0)+D(w[k+4>>1],y)|0)+D(w[k+8>>1],t)|0)+D(s,w[k+12>>1])|0)+D(m,w[k+16>>1])|0)/32768;r=r+1|0;continue}break}while(1){if((q|0)!=2){t=(f+8|0)+(q<<2)|0;e=x[t>>2];b=(f+28|0)+(q<<3)|0;y=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;s=e<<8;e=s;e=yka(j,H,e,e>>31);i=hb;v=e;e=Ub(g,-16777216,16776704);e=yka(l,G,e,e>>31);g=v+e|0;m=hb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Ub(y,-16777216,16776704);i=yka(z,F,e,e>>31);g=i+g|0;e=hb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Lc(i,e,24);x[b+4>>2]=e-(s&E);x[t>>2]=(e|0)/256;q=q+1|0;continue}break}p=p+C|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],p>>12);o=o+B|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],o>>12);Qb(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=o;x[a+20>>2]=p>>12;x[a+36>>2]=p;x[a+24>>2]=o>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}db=f+48|0}function Yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;f=db-48|0;db=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}u=b+196648|0;break a}u=b+131112|0;break a}u=b+262184|0}B=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+28|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}o=x[a+40>>2];p=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;C=x[a+32>>2];E=x[a+28>>2];F=x[a+72>>2];A=x[a+68>>2];G=A>>31;l=x[a+64>>2];H=l>>31;j=x[a+60>>2];I=j>>31;while(1){if(d){b=x[f+16>>2];y=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+B|0;b=(b>>>16&65520)+u|0;m=w[b+14>>1];s=w[b+12>>1];t=w[b+10>>1];z=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];q=0;r=0;while(1){if((r|0)!=2){k=r+y|0;x[(f+8|0)+(r<<2)>>2]=(((((((D(v[k-4|0],e)+D(v[k-6|0],b)|0)+D(v[k-2|0],i)|0)+D(v[k|0],g)|0)+D(v[k+2|0],z)|0)+D(v[k+4|0],t)|0)+D(s,v[k+6|0])|0)+D(m,v[k+8|0])<<8)/32768;r=r+1|0;continue}break}while(1){if((q|0)!=2){t=(f+8|0)+(q<<2)|0;e=x[t>>2];b=(f+28|0)+(q<<3)|0;z=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;s=e<<8;e=s;e=yka(j,I,e,e>>31);i=hb;y=e;e=Ub(g,-16777216,16776704);e=yka(l,H,e,e>>31);g=y+e|0;m=hb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Ub(z,-16777216,16776704);i=yka(A,G,e,e>>31);g=i+g|0;e=hb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Lc(i,e,24);x[b+4>>2]=e-(s&F);x[t>>2]=(e|0)/256;q=q+1|0;continue}break}p=p+E|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],p>>12);o=o+C|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],o>>12);Qb(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=o;x[a+20>>2]=p>>12;x[a+36>>2]=p;x[a+24>>2]=o>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}db=f+48|0}function mh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{c:{switch(b|0){case 1:b=Gb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[23549]=0;P(45,b|0,Oc(e,d)|0);d=x[23549];x[23549]=0;d:{if((d|0)!=1){e:{while(1){if(Oc(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=x[_i(c,a)>>2];x[23549]=0;P(46,b|0,(d>>>0>=128?63:d)<<24>>24);d=x[23549];x[23549]=0;if((d|0)==1){break e}a=a+1|0;continue}break}break d}}break a}return;case 2:b=Gb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[23549]=0;P(45,b|0,Oc(e,d)|0);d=x[23549];x[23549]=0;f:{if((d|0)!=1){g:{while(1){if(Oc(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=x[_i(c,a)>>2];x[23549]=0;P(46,b|0,(d>>>0>=256?63:d)<<24>>24);d=x[23549];x[23549]=0;if((d|0)==1){break g}a=a+1|0;continue}break}break f}}break a}return;case 3:jm(a,c,49728);return;case 5:jm(a,c,50752);return;case 4:jm(a,c,51776);return;case 6:jm(a,c,52800);return;case 7:jm(a,c,53824);return;case 8:jm(a,c,54848);return;case 9:Xy(a,c,55872);return;case 10:Xy(a,c,49728);return;case 11:Xy(a,c,53824);return;default:a=ac(8);x[23549]=0;b=O(44,a|0,10956)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break b}b=N()|0;jc(a);Q(b|0);p();case 0:break c}}e=db-16|0;db=e;f=Gb(a);h:{while(1){i:{j:{k:{if(Oc(x[c+4>>2],y[c+11|0])>>>0>g>>>0){b=x[_i(c,g)>>2];if(b>>>0>=2097152){x[23549]=0;P(46,f|0,63);a=x[23549];x[23549]=0;if((a|0)!=1){break j}break i}a=0;while(1){if((a|0)==6){b=7;a=6;break k}d=b&63;v[(e+10|0)+a|0]=d;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break k}a=1;b=2;if((d|0)!=1){break k}a=y[e+10|0]|64}else{a=y[e+10|0]}x[23549]=0;P(46,f|0,a<<24>>24);a=x[23549];x[23549]=0;if((a|0)!=1){break j}break i}db=e+16|0;break h}i=(2<<a)+255<<7-a;d=b-1|0;j=d+(e+10|0)|0;a=b;while(1){if(!a){break j}l:{if((a|0)==(b|0)){a=y[j|0];x[23549]=0;P(46,f|0,(a|i)<<24>>24);h=x[23549];x[23549]=0;a=d;break l}x[23549]=0;a=a-1|0;P(46,f|0,v[a+(e+10|0)|0]|-128);h=x[23549];x[23549]=0}if((h|0)!=1){continue}break}break i}g=g+1|0;continue}break}a=N()|0;tb(f);Q(a|0);p()}return}da(b|0,92428,24);p()}a=N()|0;tb(b);Q(a|0);p()}function Pfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(x[a+4>>2]!=x[wb(a)>>2]){e=db-16|0;db=e;c=e+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+56;a=x[c+4>>2];x[23549]=0;P(621,a|0,b|0);a=x[23549];x[23549]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+56;fc(c);db=e+16|0;break a}a=N()|0;fc(c);Q(a|0);p()}return}l=db-32|0;db=l;j=wb(a);c=l+12|0;d=Pt(x[a>>2],x[a+4>>2])+1|0;h=db-16|0;db=h;x[h+12>>2]=d;f=db-16|0;db=f;x[f+12>>2]=76695844;x[f+8>>2]=2147483647;e=x[Cb(f+12|0,f+8|0)>>2];db=f+16|0;b:{if(e>>>0>=d>>>0){d=_R(a);if(d>>>0<e>>>1>>>0){x[h+8>>2]=d<<1;e=x[Yc(h+8|0,h+12|0)>>2]}db=h+16|0;break b}Rc();p()}f=Pt(x[a>>2],x[a+4>>2]);h=db-16|0;db=h;Hf(c+12|0,j);c:{if(!e){e=0;break c}if(e>>>0>=76695845){wi();p()}d=Hc(D(e,56));x[h+12>>2]=e;x[h+8>>2]=d;i=x[h+12>>2];e=x[h+8>>2]}x[c>>2]=e;d=e+D(f,56)|0;x[c+8>>2]=d;x[c+4>>2]=d;m=kc(c),n=e+D(i,56)|0,x[m>>2]=n;db=h+16|0;e=x[c+8>>2];x[23549]=0;P(621,e|0,b|0);b=x[23549];x[23549]=0;d:{if((b|0)!=1){x[c+8>>2]=x[c+8>>2]+56;k=db-16|0;db=k;f=wb(a);d=vb(k+12|0,x[a+4>>2]);e=vb(k+8|0,x[a>>2]);b=vb(k+4|0,x[c+4>>2]);i=x[d>>2];e=x[e>>2];g=db+-64|0;db=g;b=x[b>>2];x[g+56>>2]=b;x[g+60>>2]=i;x[g+52>>2]=b;d=rd(g+24|0,f,g+52|0,g+56|0);x[g+16>>2]=x[d+8>>2];b=x[d+4>>2];x[g+8>>2]=x[d>>2];x[g+12>>2]=b;Ke(g+36|0,g+8|0);while(1){if(sd(i,e)){b=Nt(x[g+56>>2]);f=Nt(i);d=Zj(b,f);Zj(d+12|0,f+12|0);dA(d+24|0,f+24|0);w[d+52>>1]=z[f+52>>1];b=x[f+48>>2];x[d+44>>2]=x[f+44>>2];x[d+48>>2]=b;b=x[f+40>>2];x[d+36>>2]=x[f+36>>2];x[d+40>>2]=b;b=YR(g+60|0);YR(g+56|0);i=x[b>>2];continue}break}Je(g+36|0);d=x[g+56>>2];if(!y[g+48|0]){h=db-16|0;db=h;b=vb(h+12|0,x[x[g+44>>2]>>2]);e=x[vb(h+8|0,x[x[g+40>>2]>>2])>>2];j=db-16|0;db=j;i=x[b>>2];x[j+12>>2]=i;while(1){if(ai(i,e)){f=db-16|0;db=f;x[f+12>>2]=i;b=Nt(x[XR(f+12|0)>>2]);db=f+16|0;cq(b);i=x[XR(j+12|0)>>2];continue}break}db=j+16|0;db=h+16|0}db=g- -64|0;x[c+4>>2]=d;Pb(a,c+4|0);Pb(a+4|0,c+8|0);Pb(wb(a),kc(c));x[c>>2]=x[c+4>>2];db=k+16|0;ZR(c);db=l+32|0;break d}a=N()|0;ZR(c);Q(a|0);p()}}function qP(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;c=db-176|0;db=c;i=1;p=2;d=x[a+12>>2];q=1<<d;m=q;a:while(1){if(d>>>0>=p>>>0){m=m>>>2|0;v=D(i,3);w=i<<1;h=0;b:while(1){if((h|0)==(m|0)){p=p+2|0;i=i<<2;d=x[a+12>>2];continue a}d=x[a>>2];e=_c(d,h<<1);zM(c+160|0,C[e>>3],C[e+8>>3]);d=_c(d,h);zM(c+144|0,C[d>>3],C[d+8>>3]);qi(c+128|0,C[c+144>>3],C[c+152>>3],C[c+160>>3],C[c+168>>3]);d=h<<p;e=i+d|0;y=d>>>0>e>>>0?d:e;while(1)if((d|0)==(y|0)){h=h+1|0;continue b}else{f=x[b>>2];e=_c(f,d);g=e+8|0;j=x[g+4>>2];x[c+120>>2]=x[g>>2];x[c+124>>2]=j;g=x[e+4>>2];x[c+112>>2]=x[e>>2];x[c+116>>2]=g;k=d+i|0;g=_c(f,k);n=C[g+8>>3];o=C[g>>3];r=d+w|0;g=_c(f,r);j=x[g+12>>2];x[c+104>>2]=x[g+8>>2];x[c+108>>2]=j;j=x[g+4>>2];x[c+96>>2]=x[g>>2];x[c+100>>2]=j;s=d+v|0;f=_c(f,s);t=C[f+8>>3];u=C[f>>3];g=c+80|0;f=c+112|0;Zk(g,f,o,n);j=c- -64|0;Yi(j,f,o,n);l=c+96|0;Zk(c+48|0,l,u,t);f=c+16|0;Yi(f,l,u,t);qi(c+32|0,0,1,C[c+16>>3],C[c+24>>3]);Zk(f,g,C[c+48>>3],C[c+56>>3]);l=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=l;l=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=l;Zk(c,j,C[c+32>>3],C[c+40>>3]);qi(f,C[c+160>>3],C[c+168>>3],C[c>>3],C[c+8>>3]);e=_c(x[b>>2],k);k=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=k;k=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=k;Yi(c,g,C[c+48>>3],C[c+56>>3]);qi(f,C[c+144>>3],C[c+152>>3],C[c>>3],C[c+8>>3]);e=_c(x[b>>2],r);g=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=g;g=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=g;Yi(c,j,C[c+32>>3],C[c+40>>3]);qi(f,C[c+128>>3],C[c+136>>3],C[c>>3],C[c+8>>3]);e=_c(x[b>>2],s);f=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=f;f=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=f;d=d+1|0;continue}}}break}c:{if(!(d&1)){break c}i=q>>>1|0;d=0;while(1){if((d|0)==(i|0)){break c}h=x[b>>2];a=_c(h,d+i|0);m=_c(h,d);n=C[a>>3];o=C[a+8>>3];Yi(c+160|0,m,n,o);h=x[c+172>>2];x[a+8>>2]=x[c+168>>2];x[a+12>>2]=h;h=x[c+164>>2];x[a>>2]=x[c+160>>2];x[a+4>>2]=h;iy(_c(x[b>>2],d),n,o);d=d+1|0;continue}}db=c+176|0}function vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=db-48|0;db=f;u=x[a+16>>2];v=cg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;o=x[a+128>>2];if(o){i=x[a+8>>2];g=x[a+12>>2];p=dg(i,g,o);q=hb;h=x[a+76>>2];Ff(x[a>>2],x[a+4>>2],bf(i,g,d),hb);n=hb>>>0>h>>>0?d:0}else{n=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}y=x[a+24>>2];z=x[a+20>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];a:while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;n=n-1|0;h=n;p=h?p:0;q=h?q:0;i=((((g&2147483647)<<1|b>>>31)&2147483646)<<1)+u|0;b=o;while(1)if((b|0)<=0){Qb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(h){b=x[f+40>>2];b=(x[f+44>>2]&2147483647)<<1|b>>>31;Md(j,(w[(b<<1|2)+i>>1]+w[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Ld(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=bg(j,v);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];r=x[a+68>>2];E=r>>31;i=x[a+64>>2];F=i>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){s=(b<<2)+f|0;e=x[s>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];k=x[g+4>>2];x[g+8>>2]=k;t=e<<8;e=t;e=yka(h,G,e,e>>31);l=hb;m=e;e=Ub(k,-16777216,16776704);e=yka(i,F,e,e>>31);k=m+e|0;m=hb+l|0;m=e>>>0>k>>>0?m+1|0:m;e=Ub(H,-16777216,16776704);l=yka(r,E,e,e>>31);k=l+k|0;e=hb+m|0;e=k>>>0<l>>>0?e+1|0:e;l=k+8388608|0;e=l>>>0<8388608?e+1|0:e;e=Lc(l,e,24);x[g+4>>2]=e-(t&C);x[s>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],z);x[c+4>>2]=x[c+4>>2]+D(y,x[f+4>>2]);Qb(f+8|0,A,B);c=c+8|0;continue a}else{g=x[f+40>>2];g=(x[f+44>>2]&2147483647)<<1|g>>>31;Md(j,(w[(g<<1|2)+i>>1]+w[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Ld(j,4);Qb(f+40|0,p,q);b=b-1|0;continue}}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}db=f+48|0}function W$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=db-16|0;db=j;k=Nw(x[g>>2]);o=ww(x[g>>2]);Mg(j+4|0,o);x[f>>2]=d;a:{b:{c:{i=a;g=y[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[23549]=0;g=O(1132,k|0,g<<24>>24)|0;i=x[23549];x[23549]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[23549]=0;g=O(1132,k|0,48)|0;h=x[23549];x[23549]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=g;g=v[i+1|0];x[23549]=0;g=O(1132,k|0,g|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];yd();if(!tH(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];yd();if(!Kj(h)){break d}g=g+1|0;continue}}e:{if(xd(x[j+8>>2],y[j+15|0])){h=x[f>>2];x[23549]=0;V(1126,k|0,i|0,g|0,h|0);h=x[23549];x[23549]=0;if((h|0)==1){break a}x[f>>2]=x[f>>2]+(g-i<<2);break e}Nl(i,g);x[23549]=0;r=R(1124,o|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){Qr((i-a<<2)+d|0,x[f>>2]);break e}f:{if(v[uc(j+4|0,l)|0]<=0){break f}if(v[uc(j+4|0,l)|0]!=(m|0)){break f}m=x[f>>2];x[f>>2]=m+4;x[m>>2]=r;l=(Bb(x[j+8>>2],y[j+15|0])-1>>>0>l>>>0)+l|0;m=0}q=v[h|0];x[23549]=0;q=O(1132,k|0,q|0)|0;n=x[23549];x[23549]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+4;x[n>>2]=q;h=h+1|0;m=m+1|0;continue}break}break a}g:{while(1){if(c>>>0>g>>>0){i=y[g|0];if((i|0)==46){x[23549]=0;i=R(1127,o|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break a}l=x[f>>2];h=l+4|0;x[f>>2]=h;x[l>>2]=i;g=g+1|0;break g}x[23549]=0;i=O(1132,k|0,i<<24>>24)|0;h=x[23549];x[23549]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=i;g=g+1|0;continue}break}h=x[f>>2]}x[23549]=0;V(1126,k|0,g|0,c|0,h|0);i=x[23549];x[23549]=0;if((i|0)==1){break a}i=f;f=x[f>>2]+(c-g<<2)|0;x[i>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;tb(j+4|0);db=j+16|0;return}a=N()|0;tb(j+4|0);Q(a|0);p()}function li(a,b,c,d,e,f){var g=0,h=0,i=0,j=E(0),k=E(0),l=0,m=0,n=E(0),o=E(0),p=E(0),q=0,r=E(0);m=ib[x[x[a>>2]+136>>2]](a)|0;g=x[a+20>>2];h=m?h:y[g+25|0];j=B[g+144>>2];k=E(1);if(!(ib[x[x[a>>2]+136>>2]](a)|0)){k=B[x[a+20>>2]+144>>2]}j=E(E(1)-j);a:{if((ib[x[x[a>>2]+152>>2]](a)|0)<=0){break a}if(!zL(y[x[a+20>>2]+24|0])){break a}j=E(E(j+j)+E(-1));k=E(-j)}n=B[a+4196>>2];k=E(k*n);j=E(j*n);g=0;l=x[a+44>>2];m=Ac(l,0);l=Ac(l,1);b:{c:{d:{e:{f:{g:{h:{h=h&255;switch(h|0){case 0:break h;case 5:break c;case 4:break d;case 3:break e;case 2:break f;case 1:break g;default:break b}}while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;B[i>>2]=B[i>>2]+E(E(B[d+g>>2]*j)+E(k*B[g+m>>2]));i=c+g|0;B[i>>2]=B[i>>2]+E(E(B[e+g>>2]*j)+E(k*B[g+l>>2]));h=h+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]+E(B[h+m>>2]-E(B[d+h>>2]*j));i=c+h|0;B[i>>2]=B[i>>2]+E(B[h+l>>2]-E(B[e+h>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]+E(B[d+h>>2]-E(B[h+m>>2]*k));i=c+h|0;B[i>>2]=B[i>>2]+E(B[e+h>>2]-E(B[h+l>>2]*k));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]-E(B[d+h>>2]-E(B[h+m>>2]*j));i=c+h|0;B[i>>2]=B[i>>2]-E(B[e+h>>2]-E(B[h+l>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;k=B[i>>2];q=i;r=k;n=B[h+m>>2];i=c+h|0;o=B[i>>2];p=B[h+l>>2];k=E(E(E(E(k+n)+o)+p)*E(.5));B[q>>2]=r-E(E(k+E(k-E(B[d+h>>2]*j)))-n);B[i>>2]=o-E(E(k+E(k-E(B[e+h>>2]*j)))-p);g=g+1|0;continue}}g=zL(y[x[a+20>>2]+24|0]);j=g?E(j*E(.5)):j;k=g?E(k*E(.5)):k;h=0;while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;n=E(B[d+g>>2]-B[g+m>>2]);o=E(B[g+l>>2]-B[e+g>>2]);B[i>>2]=B[i>>2]+E(E(j*n)+E(k*o));g=c+g|0;B[g>>2]=B[g>>2]+E(E(k*n)+E(j*o));h=h+1|0;continue}}i:{if(!((y[x[a+20>>2]+24|0]&4)>>>2|0)){break i}if(ib[x[x[a>>2]+136>>2]](a)|0){break i}g=0;while(1){if((f|0)==(g|0)){break i}a=g<<2;d=a+b|0;B[d>>2]=B[a+m>>2]+B[d>>2];d=a+c|0;B[d>>2]=B[a+l>>2]+B[d>>2];g=g+1|0;continue}}}function hH(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=x[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!d){break l}g=x[d>>2];if(!g){break l}if(!a){d=c;break j}x[d>>2]=0;d=c;break k}m:{if(!x[x[116055]>>2]){if(!a){break m}if(!c){break a}g=c;while(1){d=v[e|0];if(d){x[a>>2]=d&57343;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}x[a>>2]=0;x[b>>2]=0;return c-g|0}d=c;if(!a){break i}break g}return Pf(e)}f=1;break g}f=0;break h}f=1}while(1){if(!f){f=y[e|0]>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}f=e+1|0;n:{if(!(g&33554432)){break n}if((y[f|0]&192)!=128){e=e-1|0;break d}f=e+2|0;if(!(g&524288)){break n}if((y[f|0]&192)!=128){e=e-1|0;break d}f=e+3|0}e=f;d=d-1|0;f=1;continue}while(1){g=y[e|0];o:{if(e&3|g-1>>>0>126){break o}g=x[e>>2];if((g|g-16843009)&-2139062144){break o}while(1){d=d-4|0;g=x[e+4>>2];e=e+4|0;if(!((g-16843009|g)&-2139062144)){continue}break}}f=g&255;if(f-1>>>0<=126){d=d-1|0;e=e+1|0;continue}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=x[(f<<2)+81584>>2];f=0;continue}}while(1){if(!f){if(!d){break a}while(1){p:{f=y[e|0];h=f-1|0;q:{r:{if(h>>>0>126){g=f;break r}if(e&3|d>>>0<5){break q}s:{while(1){g=x[e>>2];if((g|g-16843009)&-2139062144){break s}x[a>>2]=g&255;x[a+4>>2]=y[e+1|0];x[a+8>>2]=y[e+2|0];x[a+12>>2]=y[e+3|0];a=a+16|0;e=e+4|0;d=d-4|0;if(d>>>0>4){continue}break}g=y[e|0]}f=g&255;h=f-1|0}if(h>>>0>126){break p}}x[a>>2]=f;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=x[(f<<2)+81584>>2];f=1;continue}i=y[e|0];f=i>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}t:{u:{h=e+1|0;f=i-128|g<<6;v:{if((f|0)>=0){break v}i=y[h|0]-128|0;if(i>>>0>63){break u}h=e+2|0;f=i|f<<6;if((f|0)>=0){break v}h=y[h|0]-128|0;if(h>>>0>63){break u}f=h|f<<6;h=e+3|0}e=h;x[a>>2]=f;d=d-1|0;a=a+4|0;break t}x[23424]=25;e=e-1|0;break c}f=0;continue}}e=e-1|0;if(g){break d}g=y[e|0]}if(g&255){break d}if(a){x[a>>2]=0;x[b>>2]=0}return c-d|0}x[23424]=25;if(!a){break b}}x[b>>2]=e}return-1}x[b>>2]=e;return c}function me(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=db-16|0;db=i;d=x[a>>2];a:{if(qc(d,x[a+4>>2])){break a}f=x[b+4>>2];if(f>>>0>=A[a+12>>2]){break a}g=z[b+8>>1];j=x[x[a+48>>2]+12>>2];e=z[j+480188>>1];if(g>>>0>=e>>>0&(g|0)!=65535){break a}c=e-1|0;e=(g|0)==65535;l=e?c:g;e=e?0:g;d=$c(d,j,f,e);h=y[b+12|0];k=h&4;b:{c:{if(h&2){break c}g=y[b+10|0];f=d;c=e;while(1){if((c&65535)>>>0>(l&65535)>>>0){break c}d:{if(!k){if((g|0)!=y[f+3|0]){break d}break b}if((g|0)==y[f+2|0]){break b}}f=f+6|0;c=c+1|0;continue}}g=l&65535;c=d;f=e;while(1){if(g>>>0>=(f&65535)>>>0){e:{if(!k){if(y[c+3|0]){break e}v[c+3|0]=y[b+10|0];v[c+5|0]=y[b+11|0];break b}if(y[c+2|0]){break e}v[c+2|0]=y[b+10|0];v[c+4|0]=y[b+11|0];break b}c=c+6|0;f=f+1|0;continue}break}f:{if(!(h&1)){break f}c=x[j+480180>>2]&2;g=b;g:{h:{i:{if(!k){while(1){if((e&65535)>>>0<=(l&65535)>>>0){j:{k:{switch(y[d+3|0]-9|0){case 4:if(!BU(x[x[j+8>>2]+88>>2])){break j}c=1;v[d+2|0]=1;v[d+4|0]=y[d+5|0];v[d+3|0]=y[b+10|0];v[d+5|0]=y[b+11|0];break a;case 0:break k;default:break j}}l:{if(c){f=y[d+5|0];if(f>>>0>128){break j}v[d+2|0]=2;v[d+3|0]=y[b+10|0];a=1;break l}v[d+2|0]=2;v[d+3|0]=y[b+10|0];f=y[d+5|0];a=2}v[d+4|0]=a+(f&255)>>>a;v[d+5|0]=y[b+11|0];break b}d=d+6|0;e=e+1|0;continue}break}if(!k){break i}}f=y[b+11|0];e=13;m:{switch(y[b+10|0]-1|0){case 1:e=9;f=Km(f<<(c?1:2));break;case 0:break m;default:break g}}v[b+11|0]=f;v[b+10|0]=e;d=h&254;break h}f=y[b+11|0];v[i+14|0]=f;e=y[b+10|0];n:{if(!(!c|(e|0)!=9)){if(f>>>0>128){break g}c=2;d=(f&254)>>>1|0;break n}v[i+15|0]=e;if(!Lq(i+15|0,i+14|0,1)){break g}c=y[i+15|0];if(!c){break g}d=y[i+14|0]}v[b+11|0]=d;v[b+10|0]=c;d=h&254}h=d;v[g+12|0]=h}c=1;if(h&1){break f}v[b+12|0]=h^4;if(me(a,b)){break a}}c=0;o:{p:{switch(x[b>>2]-1|0){case 0:e=x[b+4>>2]+1|0;if(e>>>0>=A[a+12>>2]){break a}x[b+4>>2]=e;break o;case 1:break p;default:break a}}e=x[b+4>>2];if(!e){break a}x[b+4>>2]=e-1}v[b+12|0]=y[b+12|0]|1;c=me(a,b);break a}c=1}db=i+16|0;return c}function lka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=db-32|0;db=l;d=b;b=x[a>>2];b=(Fo(d,yb(b))<<1)+b|0;e=x[a+4>>2];a:{b:{if(e>>>0<A[wb(a)>>2]){if((b|0)!=(e|0)){break b}d=db-16|0;db=d;a=Ei(d+4|0,a,1);Eo(x[a+4>>2],y[c|0]|y[c+1|0]<<8);x[a+4>>2]=x[a+4>>2]+2;fc(a);db=d+16|0;break a}d=wb(a);f=uj(l+12|0,vj(a,Ic(x[a>>2],e)+1|0),b-x[a>>2]>>1,d);x[23549]=0;P(281,f|0,c|0);c=x[23549];x[23549]=0;if((c|0)!=1){g=db-16|0;db=g;c=x[f+4>>2];i=wb(a);d=vb(g+12|0,b);h=vb(g+8|0,x[a>>2]);j=vb(g+4|0,x[f+4>>2]);e=x[d>>2];m=x[h>>2];d=db+-64|0;db=d;h=x[j>>2];x[d+56>>2]=h;x[d+60>>2]=e;x[d+52>>2]=h;h=rd(d+24|0,i,d+52|0,d+56|0);x[d+16>>2]=x[h+8>>2];j=x[h+4>>2];x[d+8>>2]=x[h>>2];x[d+12>>2]=j;Ke(d+36|0,d+8|0);while(1){if(sd(e,m)){k=Om(x[d+56>>2]);e=Om(e);Eo(k,y[e|0]|y[e+1|0]<<8);e=qk(d+60|0);qk(d+56|0);e=x[e>>2];continue}break}e=d+36|0;Je(e);h=x[d+56>>2];ik(e);db=d- -64|0;x[f+4>>2]=h;h=x[a+4>>2];d=db-48|0;db=d;e=x[f+8>>2];x[d+44>>2]=e;x[d+40>>2]=e;e=rd(d+12|0,i,d+40|0,d+44|0);x[d+8>>2]=x[e+8>>2];i=x[e+4>>2];x[d>>2]=x[e>>2];x[d+4>>2]=i;Ke(d+24|0,d);while(1){if((b|0)!=(h|0)){Eo(x[d+44>>2],y[b|0]|y[b+1|0]<<8);x[d+44>>2]=x[d+44>>2]+2;b=b+2|0;continue}break}b=d+24|0;Je(b);e=x[d+44>>2];ik(b);db=d+48|0;x[f+8>>2]=e;Pb(a,f+4|0);Pb(a+4|0,f+8|0);Pb(wb(a),kc(f));x[f>>2]=x[f+4>>2];db=g+16|0;b=c;Di(f);break a}a=N()|0;Di(f);Q(a|0);p()}h=db-16|0;db=h;g=x[a+4>>2];f=(g-(b+2|0)|0)+b|0;j=Ei(h+4|0,a,e-f>>1);i=x[j+4>>2];d=f;while(1){if(d>>>0>=e>>>0){fc(j);i=db-16|0;db=i;j=i+8|0;d=g;g=db-32|0;db=g;Od(g+24|0,b,f);m=g+16|0;n=x[g+24>>2];f=db-16|0;db=f;k=x[g+28>>2];e=k;while(1){if((e|0)!=(n|0)){e=e-2|0;d=SV(d-2|0,e);continue}break}x[f+12>>2]=d;vc(m,k,f+12|0);db=f+16|0;d=x[g+16>>2];x[g+12>>2]=x[g+20>>2];vc(j,d,g+12|0);db=g+32|0;db=i+16|0;db=h+16|0}else{Eo(i,y[d|0]|y[d+1|0]<<8);i=i+2|0;x[j+4>>2]=i;d=d+2|0;continue}break}a=((b>>>0<=c>>>0&A[a+4>>2]>c>>>0)<<1)+c|0;c=y[a|0];v[b+1|0]=y[a+1|0];v[b|0]=c}yb(b);db=l+32|0}function cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;i=db-16|0;db=i;c=jf(a,c);ae(i,x[a+28>>2]);j=a;a:{if(!c){e=0;if(ed(a,5)){break a}}e=db-208|0;db=e;g=Pl(e+104|0,x[a+28>>2]);x[23549]=0;f=O(403,e+92|0,27864)|0;a=x[23549];x[23549]=0;b:{c:{d:{e:{if((a|0)!=1){x[23549]=0;x[e+72>>2]=19927555;x[e+76>>2]=0;S(404,g|0,f|0,e+72|0);a=x[23549];x[23549]=0;if((a|0)==1){break e}Ab(f);if(!(y[g+3|0]&64)){break d}break b}b=N()|0;break c}b=N()|0;Ab(f);break c}v[e+91|0]=0;x[23549]=0;f=O(403,e+72|0,5446)|0;a=x[23549];x[23549]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[23549]=0;S(405,g|0,e+91|0,f|0);a=x[23549];x[23549]=0;if((a|0)==1){break q}Ab(f);f=Gb(e+60|0);x[23549]=0;a=O(403,e+48|0,9977)|0;h=x[23549];x[23549]=0;if((h|0)==1){break p}x[23549]=0;S(727,g|0,f|0,a|0);h=x[23549];x[23549]=0;if((h|0)==1){break o}Ab(a);x[23549]=0;S(11,e+36|0,(y[e+91|0]?0:d)|0,f|0);d=x[23549];x[23549]=0;if((d|0)==1){break n}x[23549]=0;P(262,b|0,e+36|0);d=x[23549];x[23549]=0;if((d|0)==1){break m}d=e+36|0;tb(d);w[e+34>>1]=0;x[23549]=0;d=O(403,d|0,10637)|0;a=x[23549];x[23549]=0;if((a|0)==1){break g}x[23549]=0;U(433,g|0,e+34|0,d|0)|0;a=x[23549];x[23549]=0;if((a|0)==1){break l}Ab(d);Wf(e+34|0,4e3);x[23549]=0;d=O(403,e+20|0,13254)|0;a=x[23549];x[23549]=0;if((a|0)==1){break k}h=z[e+34>>1];a=x[vb(e+16|0,h)>>2];x[23549]=0;V(728,g|0,b|0,d|0,a|0);a=x[23549];x[23549]=0;if((a|0)==1){break j}Ab(d);w[e+14>>1]=65535;x[23549]=0;d=O(403,e|0,8862)|0;a=x[23549];x[23549]=0;if((a|0)==1){break i}x[23549]=0;k=U(433,g|0,e+14|0,d|0)|0;a=x[23549];x[23549]=0;if((a|0)==1){break h}a=z[e+14>>1];Ab(d);if(!(a>>>0>=h>>>0|k)){$e(b,a)}tb(f);break b}b=N()|0;break c}b=N()|0;Ab(f);break c}b=N()|0;break f}b=N()|0;Ab(a);break f}b=N()|0;break f}b=N()|0;tb(e+36|0);break f}b=N()|0;Ab(d);break f}b=N()|0;break f}b=N()|0;Ab(d);break f}b=N()|0;break f}b=N()|0;Ab(d);break f}b=N()|0}tb(f)}Zg(g);Q(b|0);p()}Zg(g);db=e+208|0;e=c}cf(j,e);db=i+16|0}function e0(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=db-16|0;db=j;k=Zu(x[g>>2]);o=Cw(x[g>>2]);Mg(j+4|0,o);x[f>>2]=d;a:{b:{c:{i=a;g=y[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[23549]=0;g=O(19,k|0,g<<24>>24)|0;i=x[23549];x[23549]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+1;v[i|0]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[23549]=0;g=O(19,k|0,48)|0;h=x[23549];x[23549]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=g;g=v[i+1|0];x[23549]=0;g=O(19,k|0,g|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];yd();if(!tH(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];yd();if(!Kj(h)){break d}g=g+1|0;continue}}e:{if(xd(x[j+8>>2],y[j+15|0])){h=x[f>>2];x[23549]=0;V(1113,k|0,i|0,g|0,h|0);h=x[23549];x[23549]=0;if((h|0)==1){break a}x[f>>2]=x[f>>2]+(g-i|0);break e}Nl(i,g);x[23549]=0;r=R(1111,o|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){Nl((i-a|0)+d|0,x[f>>2]);break e}f:{if(v[uc(j+4|0,m)|0]<=0){break f}if(v[uc(j+4|0,m)|0]!=(l|0)){break f}l=x[f>>2];x[f>>2]=l+1;v[l|0]=r;m=(Bb(x[j+8>>2],y[j+15|0])-1>>>0>m>>>0)+m|0;l=0}q=v[h|0];x[23549]=0;q=O(19,k|0,q|0)|0;n=x[23549];x[23549]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+1;v[n|0]=q;h=h+1|0;l=l+1|0;continue}break}break a}while(1){g:{if(c>>>0>g>>>0){i=y[g|0];if((i|0)!=46){break g}x[23549]=0;i=R(1114,o|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=i;g=g+1|0}i=x[f>>2];x[23549]=0;V(1113,k|0,g|0,c|0,i|0);i=x[23549];x[23549]=0;if((i|0)==1){break a}i=f;f=x[f>>2]+(c-g|0)|0;x[i>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;tb(j+4|0);db=j+16|0;return}x[23549]=0;i=O(19,k|0,i<<24>>24)|0;h=x[23549];x[23549]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=i;g=g+1|0;continue}}a=N()|0;tb(j+4|0);Q(a|0);p()}function x6(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;j=db-80|0;db=j;a:{b:{c:{k=_p(1,32);d:{e:{if(!k){a=_l(ac(4));x[23549]=0;S(105,a|0,92296,25);a=x[23549];x[23549]=0;if((a|0)!=1){break a}i=T(0)|0;break e}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;f=c?c:908;x[k>>2]=f;c=ig(j+68|0);f:{g:{h:{if(!i){break h}while(1){e=x[i>>2];if(!e){break h}l=x[i+4>>2];i:{if(l){x[23549]=0;e=O(54,j+56|0,e|0)|0;m=x[23549];x[23549]=0;j:{if((m|0)!=1){x[23549]=0;m=O(919,c|0,e|0)|0;n=x[23549];x[23549]=0;if((n|0)==1){break j}x[23549]=0;P(259,m|0,l|0);l=x[23549];x[23549]=0;if((l|0)==1){break j}break i}i=T(0)|0;break f}i=T(0)|0;tb(e);break f}x[23549]=0;e=O(54,j+44|0,e|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break g}Ds(c,e)}tb(e);i=i+8|0;continue}}e=x[a+8>>2];i=x[a+4>>2];l=x[a>>2];x[23549]=0;a=R(789,96)|0;m=x[23549];x[23549]=0;k:{l:{m:{if((m|0)!=1){x[j+40>>2]=e;x[j+36>>2]=i;x[j+32>>2]=l;x[j+28>>2]=b;x[23549]=0;b=O(920,f|0,d|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break m}x[j+20>>2]=b;b=x[Vf(j+24|0,j+20|0)>>2];d=x[j+40>>2];x[j+8>>2]=x[j+36>>2];x[j+12>>2]=d;x[23549]=0;d=x[j+32>>2];x[j>>2]=x[j+28>>2];x[j+4>>2]=d;b=ba(950,a|0,j|0,b|0,c|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){break k}i=T(0)|0;xe(j+20|0);break l}i=T(0)|0;break f}i=T(0)|0}Eb(a);break f}x[k+28>>2]=b;xe(j+20|0);x[k+24>>2]=b+8;dl(c);break d}i=T(0)|0}dl(c);Y(i|0)|0;x[23549]=0;V(914,11198,k|0,g|0,h|0);a=x[23549];x[23549]=0;if((a|0)!=1){x[23549]=0;X(17);a=x[23549];x[23549]=0;if((a|0)!=1){a=x[k+28>>2];if(a){ib[x[x[a>>2]+4>>2]](a)}x[k+24>>2]=0;x[k+28>>2]=0;a=x[k+20>>2];if(a){Eb(a);x[k+20>>2]=0}Eb(k);k=0;break d}i=T(0)|0;break e}i=T(0)|0;x[23549]=0;X(17);a=x[23549];x[23549]=0;if((a|0)==1){break b}}Y(i|0)|0;k=0;x[23549]=0;V(914,11198,0,g|0,h|0);a=x[23549];x[23549]=0;if((a|0)==1){break c}Z()}db=j+80|0;return k|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Rb()}p()}function $ca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=db-48|0;db=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}s=b+196648|0;break a}s=b+131112|0;break a}s=b+262184|0}y=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+28|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}z=x[a+24>>2];A=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;B=x[a+72>>2];v=x[a+68>>2];C=v>>31;l=x[a+64>>2];E=l>>31;j=x[a+60>>2];F=j>>31;while(1){if(d){b=x[f+16>>2];t=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+y|0;b=(b>>>16&65520)+s|0;m=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];u=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];o=0;p=0;while(1){if((p|0)!=2){k=t+(p<<1)|0;x[(f+8|0)+(p<<2)>>2]=(((((((D(w[k-8>>1],e)+D(w[k-12>>1],b)|0)+D(w[k-4>>1],i)|0)+D(w[k>>1],g)|0)+D(w[k+4>>1],u)|0)+D(w[k+8>>1],r)|0)+D(q,w[k+12>>1])|0)+D(m,w[k+16>>1])|0)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){r=(f+8|0)+(o<<2)|0;e=x[r>>2];b=(f+28|0)+(o<<3)|0;u=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;q=e<<8;e=q;e=yka(j,F,e,e>>31);i=hb;t=e;e=Ub(g,-16777216,16776704);e=yka(l,E,e,e>>31);g=t+e|0;m=hb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Ub(u,-16777216,16776704);i=yka(v,C,e,e>>31);g=i+g|0;e=hb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Lc(i,e,24);x[b+4>>2]=e-(q&B);x[r>>2]=(e|0)/256;o=o+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],A);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],z);Qb(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}db=f+48|0}function Qt(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return Nd(b)}if(b>>>0>=4294967232){x[23424]=48;return 0}f=b>>>0<11?16:b+11&-8;e=a-8|0;i=x[e+4>>2];d=i&-8;a:{if(!(i&3)){if(f>>>0<256){break a}if(d>>>0>=f+4>>>0){c=e;if(d-f>>>0<=x[23545]<<1>>>0){break a}}c=0;break a}g=d+e|0;b:{if(d>>>0>=f>>>0){c=d-f|0;if(c>>>0<16){break b}x[e+4>>2]=i&1|f|2;d=e+f|0;x[d+4>>2]=c|3;x[g+4>>2]=x[g+4>>2]|1;Ht(d,c);break b}if(x[23431]==(g|0)){d=d+x[23428]|0;if(d>>>0<=f>>>0){break a}x[e+4>>2]=i&1|f|2;c=e+f|0;d=d-f|0;x[c+4>>2]=d|1;x[23428]=d;x[23431]=c;break b}if(x[23430]==(g|0)){d=d+x[23427]|0;if(d>>>0<f>>>0){break a}c=d-f|0;c:{if(c>>>0>=16){x[e+4>>2]=i&1|f|2;h=e+f|0;x[h+4>>2]=c|1;d=d+e|0;x[d>>2]=c;x[d+4>>2]=x[d+4>>2]&-2;break c}x[e+4>>2]=d|i&1|2;c=d+e|0;x[c+4>>2]=x[c+4>>2]|1;c=0}x[23430]=h;x[23427]=c;break b}h=x[g+4>>2];if(h&2){break a}j=d+(h&-8)|0;if(j>>>0<f>>>0){break a}l=j-f|0;d:{if(h>>>0<=255){c=x[g+12>>2];d=x[g+8>>2];if((c|0)==(d|0)){n=93700,o=x[23425]&Cka(-2,h>>>3|0),x[n>>2]=o;break d}x[d+12>>2]=c;x[c+8>>2]=d;break d}k=x[g+24>>2];d=x[g+12>>2];e:{if((g|0)!=(d|0)){c=x[g+8>>2];x[c+12>>2]=d;x[d+8>>2]=c;break e}f:{c=g+20|0;h=x[c>>2];if(!h){h=x[g+16>>2];if(!h){break f}c=g+16|0}while(1){m=c;d=h;c=d+20|0;h=x[c>>2];if(h){continue}c=d+16|0;h=x[d+16>>2];if(h){continue}break}x[m>>2]=0;break e}d=0}if(!k){break d}c=x[g+28>>2];h=(c<<2)+94004|0;g:{if(x[h>>2]==(g|0)){x[h>>2]=d;if(d){break g}n=93704,o=x[23426]&Cka(-2,c),x[n>>2]=o;break d}x[(x[k+16>>2]==(g|0)?16:20)+k>>2]=d;if(!d){break d}}x[d+24>>2]=k;c=x[g+16>>2];if(c){x[d+16>>2]=c;x[c+24>>2]=d}c=x[g+20>>2];if(!c){break d}x[d+20>>2]=c;x[c+24>>2]=d}if(l>>>0<=15){x[e+4>>2]=i&1|j|2;c=e+j|0;x[c+4>>2]=x[c+4>>2]|1;break b}x[e+4>>2]=i&1|f|2;c=e+f|0;x[c+4>>2]=l|3;d=e+j|0;x[d+4>>2]=x[d+4>>2]|1;Ht(c,l)}c=e}if(c){return c+8|0}c=Nd(b);if(!c){return 0}e=x[a-4>>2];e=(e&3?-4:-8)+(e&-8)|0;rc(c,a,b>>>0>e>>>0?e:b);Eb(a);return c}function GK(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;j=db-80|0;db=j;a:{b:{c:{d:{e:{f:{k=_p(1,28);if(!k){a=_l(ac(4));x[23549]=0;S(105,a|0,92296,25);a=x[23549];x[23549]=0;if((a|0)!=1){break a}break f}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;f=c?c:908;x[k>>2]=f;c=ig(j+68|0);g:{h:{i:{if(!i){break i}while(1){e=x[i>>2];if(!e){break i}l=x[i+4>>2];j:{if(l){x[23549]=0;e=O(54,j+56|0,e|0)|0;m=x[23549];x[23549]=0;k:{if((m|0)!=1){x[23549]=0;m=O(919,c|0,e|0)|0;n=x[23549];x[23549]=0;if((n|0)==1){break k}x[23549]=0;P(259,m|0,l|0);l=x[23549];x[23549]=0;if((l|0)==1){break k}break j}i=T(0)|0;break g}i=T(0)|0;tb(e);break g}x[23549]=0;e=O(54,j+44|0,e|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break h}Ds(c,e)}tb(e);i=i+8|0;continue}}e=x[a+8>>2];i=x[a+4>>2];l=x[a>>2];x[23549]=0;a=R(789,80)|0;m=x[23549];x[23549]=0;l:{m:{n:{if((m|0)!=1){x[j+40>>2]=e;x[j+36>>2]=i;x[j+32>>2]=l;x[j+28>>2]=b;x[23549]=0;b=O(920,f|0,d|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break n}x[j+20>>2]=b;b=x[Vf(j+24|0,j+20|0)>>2];d=x[j+40>>2];x[j+8>>2]=x[j+36>>2];x[j+12>>2]=d;x[23549]=0;d=x[j+32>>2];x[j>>2]=x[j+28>>2];x[j+4>>2]=d;b=ba(921,a|0,j|0,b|0,c|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){break l}i=T(0)|0;xe(j+20|0);break m}i=T(0)|0;break g}i=T(0)|0}Eb(a);break g}x[k+24>>2]=b;xe(j+20|0);dl(c);i=k;break d}i=T(0)|0}dl(c);Y(i|0)|0;x[23549]=0;V(914,14795,k|0,g|0,h|0);a=x[23549];x[23549]=0;if((a|0)!=1){x[23549]=0;X(17);a=x[23549];x[23549]=0;if((a|0)==1){break f}a=x[k+24>>2];if(a){Eb(Cs(a))}i=0;x[k+24>>2]=0;a=x[k+20>>2];if(a){Eb(a);x[k+20>>2]=0}Eb(k);break d}i=T(0)|0;x[23549]=0;X(17);a=x[23549];x[23549]=0;if((a|0)!=1){break e}break b}i=T(0)|0}Y(i|0)|0;i=0;x[23549]=0;V(914,14795,0,g|0,h|0);a=x[23549];x[23549]=0;if((a|0)==1){break c}Z()}db=j+80|0;return i|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Rb()}p()}function ada(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0;f=db-48|0;db=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}s=b+196648|0;break a}s=b+131112|0;break a}s=b+262184|0}z=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+28|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}A=x[a+24>>2];B=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;C=x[a+72>>2];y=x[a+68>>2];E=y>>31;l=x[a+64>>2];F=l>>31;j=x[a+60>>2];G=j>>31;while(1){if(d){b=x[f+16>>2];t=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+z|0;b=(b>>>16&65520)+s|0;m=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];u=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];o=0;p=0;while(1){if((p|0)!=2){k=p+t|0;x[(f+8|0)+(p<<2)>>2]=(((((((D(v[k-4|0],e)+D(v[k-6|0],b)|0)+D(v[k-2|0],i)|0)+D(v[k|0],g)|0)+D(v[k+2|0],u)|0)+D(v[k+4|0],r)|0)+D(q,v[k+6|0])|0)+D(m,v[k+8|0])<<8)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){r=(f+8|0)+(o<<2)|0;e=x[r>>2];b=(f+28|0)+(o<<3)|0;u=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;q=e<<8;e=q;e=yka(j,G,e,e>>31);i=hb;t=e;e=Ub(g,-16777216,16776704);e=yka(l,F,e,e>>31);g=t+e|0;m=hb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Ub(u,-16777216,16776704);i=yka(y,E,e,e>>31);g=i+g|0;e=hb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Lc(i,e,24);x[b+4>>2]=e-(q&C);x[r>>2]=(e|0)/256;o=o+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],B);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],A);Qb(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}db=f+48|0}function Gja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=db-1104|0;db=d;x[d+1100>>2]=c;i=zB(d+40|0,b);r=zq(i);e=Nb(a);x[23549]=0;a=R(188,b|0)|0;c=x[23549];x[23549]=0;a:{if((c|0)!=1){x[d+12>>2]=a;x[d+36>>2]=85899345;t=d,u=D(x[Cb(d+12|0,d+36|0)>>2],50),x[t+24>>2]=u;a=x[Cb(d+1100|0,d+24|0)>>2];x[23549]=0;P(313,e|0,a|0);a=x[23549];x[23549]=0;if((a|0)!=1){x[23549]=0;h=R(324,d+24|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){x[23549]=0;f=O(325,d+12|0,8192)|0;a=x[23549];x[23549]=0;b:{if((a|0)!=1){a=x[h>>2];c=0;while(1){if((c|0)!=256){g=xb(a,c);v[g+2|0]=c;w[g>>1]=8192;c=c+1|0;continue}break}m=9;c:{d:while(1){g=0;n=257;while(1){s=m&255;e:{while(1){j=n&65535;while(1){x[23549]=0;o=O(150,i|0,s|0)|0;a=x[23549];x[23549]=0;if((a|0)==1){break c}k=o&65535;if((k|0)==257|j>>>0<k>>>0){break e}if(Pc(x[e>>2],x[e+4>>2])>>>0>=A[d+1100>>2]){break e}if((k|0)==256){m=9;continue d}c=j>>>0>k>>>0?o:g;a=x[h>>2];l=8192;while(1){c=c&65535;a=xb(a,c);l=l-1|0;q=l&65535;t=Db(x[f>>2],q),u=y[a+2|0],v[t|0]=u;a=x[h>>2];c=z[xb(a,c)>>1];if(c>>>0<8192){continue}break}a=vb(d+8|0,yb(x[e+4>>2]));c=Ie(yb(x[f>>2]),q);l=yb(x[f+4>>2]);a=x[a>>2];x[23549]=0;V(314,e|0,a|0,c|0,l|0);a=x[23549];x[23549]=0;if((a|0)==1){break c}f:{if((j|0)!=(k|0)){break f}a=x[f>>2];x[23549]=0;P(326,e|0,Db(a,q)|0);a=x[23549];x[23549]=0;if((a|0)!=1){break f}break c}if(j>>>0>=8192){g=o;continue}if(Pc(x[e>>2],x[e+4>>2])>>>0>=A[d+1100>>2]){continue}break}a=y[Db(x[f>>2],q)|0];c=xb(x[h>>2],j);w[c>>1]=g;v[c+2|0]=a;a=n+1|0;n=8192;g=o;c=a&65535;if((c|0)==8192){continue}break}m=((c|0)==1<<s)+m|0;n=a;continue}break}break}a=zq(i);x[23549]=0;O(141,b|0,((a-r|0)+3&-4)+r|0)|0;a=x[23549];x[23549]=0;if((a|0)==1){break c}bc(f);sc(h);ub(i);db=d+1104|0;return}c=N()|0;bc(f);break b}c=N()|0}sc(h);break a}c=N()|0;break a}c=N()|0;break a}c=N()|0}bc(e);ub(i);Q(c|0);p()}function rP(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;c=db-176|0;db=c;e=x[a+12>>2];j=1<<e;a:{if(!(e&1)){h=j>>>2|0;l=1;break a}l=j>>>1|0;e=0;while(1){if((e|0)==(l|0)){h=j>>>3|0;l=2;e=x[a+12>>2]}else{i=x[b>>2];h=_c(i,e+l|0);d=_c(i,e);o=C[h>>3];p=C[h+8>>3];Yi(c+160|0,d,o,p);i=x[c+172>>2];x[h+8>>2]=x[c+168>>2];x[h+12>>2]=i;i=x[c+164>>2];x[h>>2]=x[c+160>>2];x[h+4>>2]=i;iy(_c(x[b>>2],e),o,p);e=e+1|0;continue}break}}i=e&-2;b:while(1){if(i){w=D(h,3);y=h<<1;j=0;c:while(1){if((j|0)==(l|0)){i=i-2|0;h=h>>>2|0;l=l<<2;continue b}d=x[a>>2];e=_c(d,j<<1);d=_c(d,j);o=C[d>>3];p=C[d+8>>3];r=C[e>>3];s=C[e+8>>3];qi(c+160|0,o,p,r,s);e=j<<i;d=h+e|0;z=d>>>0<e>>>0?e:d;while(1)if((e|0)==(z|0)){j=j+1|0;continue c}else{f=x[b>>2];d=_c(f,e);g=x[d+12>>2];x[c+152>>2]=x[d+8>>2];x[c+156>>2]=g;g=x[d+4>>2];x[c+144>>2]=x[d>>2];x[c+148>>2]=g;g=c+128|0;t=e+h|0;k=_c(f,t);qi(g,r,s,C[k>>3],C[k+8>>3]);u=e+y|0;k=_c(f,u);qi(c+112|0,o,p,C[k>>3],C[k+8>>3]);m=C[c+160>>3];n=C[c+168>>3];v=e+w|0;f=_c(f,v);qi(c+96|0,m,n,C[f>>3],C[f+8>>3]);k=c+80|0;f=c+144|0;m=C[c+112>>3];n=C[c+120>>3];Zk(k,f,m,n);q=c- -64|0;Yi(q,f,m,n);m=C[c+96>>3];n=C[c+104>>3];Zk(c+48|0,g,m,n);f=c+16|0;fl(f,-0,-1);Yi(c,g,m,n);qi(c+32|0,C[c+16>>3],C[c+24>>3],C[c>>3],C[c+8>>3]);Zk(f,k,C[c+48>>3],C[c+56>>3]);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Yi(f,k,C[c+48>>3],C[c+56>>3]);d=_c(x[b>>2],t);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Zk(f,q,C[c+32>>3],C[c+40>>3]);d=_c(x[b>>2],u);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Yi(f,q,C[c+32>>3],C[c+40>>3]);d=_c(x[b>>2],v);f=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=f;f=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=f;e=e+1|0;continue}}}break}db=c+176|0}function L6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=db-96|0;db=d;e=x[b+4>>2];a:{if(!e){break a}f=x[b>>2];g=y[Sk(f,e)|0];if((g|0)==33){c=1}else{if((g|0)!=63){break a}c=0}cl(d+72|0,f,e,e-1|0);e=x[d+76>>2];x[b>>2]=x[d+72>>2];x[b+4>>2]=e}f=d+72|0;Rd(f);e=x[d+72>>2];Rd(d+60|0);e=Rk(e,x[d+64>>2],b);Rd(f);b:{c:{d:{e:{if((e|0)==x[d+76>>2]){a=x[b+4>>2];e=x[b>>2];f=mc(d+88|0,21204);g=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=g;if(Gc(e,a,d)){a=ac(8);x[23549]=0;c=O(54,d+72|0,10365)|0;b=x[23549];x[23549]=0;if((b|0)==1){break d}a=pc(a,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}e=0;f=0;if(!c){break e}c=ac(8);a=x[b+4>>2];b=x[b>>2];x[23549]=0;e=Ch(d+60|0,b,a);a=x[23549];x[23549]=0;f:{g:{h:{if((a|0)!=1){x[23549]=0;S(942,d+72|0,17247,e|0);a=x[23549];x[23549]=0;if((a|0)==1){break h}a=0;b=pc(c,d+72|0);x[23549]=0;S(105,b|0,61816,931);b=x[23549];x[23549]=0;if((b|0)!=1){break b}b=N()|0;tb(d+72|0);break g}b=N()|0;break f}b=N()|0;a=1}tb(e);if(!a){break c}}jc(c);break c}if(x[e+4>>2]!=1){a=ac(8);x[23549]=0;c=O(54,d+72|0,11442)|0;b=x[23549];x[23549]=0;if((b|0)!=1){a=pc(a,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}c=x[b+4>>2];b=x[b>>2];e=mc(d+52|0,21204);f=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=f;if(Gc(b,c,d+24|0)){a=ac(8);x[23549]=0;c=O(54,d+72|0,10365)|0;b=x[23549];x[23549]=0;if((b|0)!=1){a=pc(a,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}e=mc(d+44|0,10824);f=x[e+4>>2];x[d+16>>2]=x[e>>2];x[d+20>>2]=f;if(Gc(b,c,d+16|0)){e=x[a+8>>2];f=e>>31;break e}e=mc(d+36|0,8525);f=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=f;e=0;f=0;if(!Gc(b,c,d+8|0)){break e}e=Lj(y[x[a+32>>2]+140|0]);f=0}db=d+96|0;hb=f;return e|0}b=N()|0;jc(a)}Q(b|0)}p()}function b5(a,b,c){a=a|0;b=E(b);c=c|0;var d=0,e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),k=E(0),m=0,n=0,o=0;d=db-16|0;db=d;a:{b:{c:{d:{switch(c-1|0){case 0:a=(q(b),j(2));e:{f:{g:{if((a|0)<=8388607){e=E(E(-1)/E(b*b));if(!(a&2147483647)){break e}e=E(E(b-b)/E(0));if((a|0)<0){break e}a=(q(E(b*E(33554432))),j(2));c=-152;break g}if(a>>>0>2139095039){break f}c=-127;b=E(0);if((a|0)==1065353216){break f}}a=a+4913933|0;k=E((a>>>23|0)+c|0);b=E((l(2,(a&8388607)+1060439283|0),r())+E(-1));f=E(b*E(b*E(.5)));g=E(b/E(b+E(2)));h=E(g*g);i=E(h*h);e=b;b=(l(2,(q(E(b-f)),j(2))&-4096),r());f=E(E(g*E(f+E(E(h*E(E(i*E(.2849878668785095))+E(.6666666269302368)))+E(i*E(E(i*E(.24279078841209412))+E(.40000972151756287))))))+E(E(e-b)-f));b=E(E(k*E(.3010292053222656))+E(E(b*E(.434326171875))+E(E(f*E(.434326171875))+E(E(k*E(7.903415166765626e-7))+E(E(f+b)*E(-3168997136526741e-20))))))}e=b}b=E(e*E(2e3));if(!(E(F(b))<E(2147483648))){break c}a=~~b;break b;case 1:a=(D(x[a+24604>>2],100)|0)/128|0;break b;case 2:c=db-16|0;db=c;h:{i:{j:{k:{a=y[a+24648|0];if(a>>>0>=6){a=ac(8);x[23549]=0;c=O(54,c+4|0,5064)|0;d=x[23549];x[23549]=0;if((d|0)==1){break k}a=pc(a,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break i}d=N()|0;tb(c);break j}db=c+16|0;a=x[(a<<2)+61560>>2];break h}d=N()|0;jc(a)}Q(d|0)}p()}break b;case 3:x[d+4>>2]=0;m=x[a+24640>>2];c=db-80|0;db=c;a=x[a+24636>>2];x[c+40>>2]=a;x[c>>2]=m;n=c+40|0;o=x[Re(n,c)>>2];l:{if((a|0)==x[Zp(n)+32>>2]){a=-1;if(x[Zp(c)+36>>2]==(m|0)){break l}}a=0;if((o|0)<=0){break l}a=(o+500>>>0)/1e3|0}x[d+4>>2]=a;db=c+80|0;a=x[d+4>>2];break b;default:break d}}c=ac(8);x[23549]=0;d=O(54,d+4|0,10268)|0;a=x[23549];x[23549]=0;m:{if((a|0)!=1){a=pc(c,d);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break m}a=N()|0;jc(c)}Q(a|0);p()}a=-2147483648}db=d+16|0;return a|0}p()}function J6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=db-96|0;db=e;f=x[c+4>>2];a:{if(!f){break a}g=x[c>>2];h=y[Sk(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}cl(e+72|0,g,f,f-1|0);f=x[e+76>>2];x[c>>2]=x[e+72>>2];x[c+4>>2]=f}f=e+72|0;Rd(f);g=x[e+72>>2];Rd(e+60|0);h=Rk(g,x[e+64>>2],c);Rd(f);f=x[c+4>>2];g=x[c>>2];b:{c:{d:{e:{if((h|0)==x[e+76>>2]){b=mc(e+88|0,21204);h=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=h;if(Gc(g,f,e)){a=ac(8);x[23549]=0;b=O(54,e+72|0,10365)|0;c=x[23549];x[23549]=0;if((c|0)==1){break d}a=pc(a,b);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}if(d){a=ac(8);b=x[c+4>>2];c=x[c>>2];x[23549]=0;b=Ch(e+60|0,c,b);c=x[23549];x[23549]=0;f:{g:{h:{if((c|0)!=1){x[23549]=0;S(942,e+72|0,17247,b|0);c=x[23549];x[23549]=0;if((c|0)==1){break h}d=0;c=pc(a,e+72|0);x[23549]=0;S(105,c|0,61816,931);c=x[23549];x[23549]=0;if((c|0)!=1){break b}c=N()|0;tb(e+72|0);break g}c=N()|0;break f}c=N()|0;d=1}tb(b);if(!d){break c}}jc(a);break c}Gb(a);break e}c=mc(e+52|0,21204);d=x[c+4>>2];x[e+24>>2]=x[c>>2];x[e+28>>2]=d;if(Gc(g,f,e+24|0)){a=ac(8);x[23549]=0;b=O(54,e+72|0,10365)|0;c=x[23549];x[23549]=0;if((c|0)!=1){a=pc(a,b);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}c=N()|0;jc(a);break c}c=mc(e+44|0,12211);d=x[c+4>>2];x[e+16>>2]=x[c>>2];x[e+20>>2]=d;if(Gc(g,f,e+16|0)){i:{switch(x[b+52>>2]){case 0:Tb(a,5542);break e;case 1:Tb(a,11143);break e;case 2:Tb(a,9104);break e;default:break i}}Gb(a);break e}c=mc(e+36|0,11380);d=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=d;if(Gc(g,f,e+8|0)){j:{switch(x[b+56>>2]){case 0:Tb(a,15205);break e;case 1:Tb(a,15210);break e;case 2:Tb(a,12485);break e;case 3:Tb(a,9168);break e;default:break j}}Gb(a);break e}Gb(a)}db=e+96|0;return}c=N()|0;jc(a)}Q(c|0)}p()}function n$(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a=db-1056|0;db=a;x[a+16>>2]=f;x[a+20>>2]=g;x[a+24>>2]=h;x[a+28>>2]=i;j=a+944|0;x[a+940>>2]=j;j=Fw(j,100,11028,a+16|0);x[a+48>>2]=1103;k=a+48|0;o=pe(a+520|0,0,k);x[a+48>>2]=1103;k=pe(a+512|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+528|0;f=a+944|0;break d}j=yd();x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;j=Oi(a+940|0,j,11028,a);if((j|0)!=-1){f=x[a+940>>2];Me(o,f);Me(k,Nd(j<<2));h=x[k>>2];if(!Sj(h)){break d}}x[23549]=0;X(1104);a=x[23549];x[23549]=0;if((a|0)!=1){break a}j=N()|0;break c}Nc(a+508|0,x[d+28>>2]);x[23549]=0;r=R(1115,x[a+508>>2])|0;g=x[23549];x[23549]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}x[23549]=0;V(1126,r|0,f|0,f+j|0,h|0);g=x[23549];x[23549]=0;if((g|0)==1){break j}q=(j|0)>0?y[f|0]==45:q;i=Gb(a+484|0);f=Gb(a+472|0);g=Gb(a+460|0);x[23549]=0;ha(1154,c|0,q|0,x[a+508>>2],a+504|0,a+500|0,a+496|0,i|0,f|0,g|0,a+456|0);c=x[23549];x[23549]=0;if((c|0)==1){break i}x[a+36>>2]=1103;c=pe(a+40|0,0,a+36|0);m=a+48|0;n=x[a+456>>2];k:{if((n|0)<(j|0)){l=((Bb(x[g+4>>2],y[g+11|0])+(j-n<<1)|0)+Bb(x[f+4>>2],y[f+11|0])|0)+1|0;break k}l=(Bb(x[g+4>>2],y[g+11|0])+Bb(x[f+4>>2],y[f+11|0])|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Me(c,Nd(l<<2));m=x[c>>2];if(m){break h}x[23549]=0;X(1104);b=x[23549];x[23549]=0;if((b|0)!=1){break a}break g}j=N()|0;break e}j=N()|0;break f}l=x[d+4>>2];x[23549]=0;ka(1155,m|0,a+36|0,a+32|0,l|0,h|0,(j<<2)+h|0,r|0,q|0,a+504|0,x[a+500>>2],x[a+496>>2],i|0,f|0,g|0,n|0);h=x[23549];x[23549]=0;if((h|0)!=1){x[23549]=0;b=ga(1135,b|0,m|0,x[a+36>>2],x[a+32>>2],d|0,e|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){break b}}}j=N()|0;Kc(c)}Ec(g);Ec(f);tb(i)}Xb(a+508|0)}Kc(k);Kc(o);Q(j|0);p()}Kc(c);Ec(g);Ec(f);tb(i);Xb(a+508|0);Kc(k);Kc(o);db=a+1056|0;return b|0}p()}function aR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=x[a>>2];e=ph(c,x[a+4>>2]);if(e>>>0<b>>>0){h=db-32|0;db=h;g=b-e|0;b=x[wb(a)>>2];c=x[a+4>>2];a:{if(g>>>0<=b-c>>8>>>0){e=db-16|0;db=e;b=e+4|0;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+(g<<8);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){fc(b);db=e+16|0}else{Nz(a);a=a+256|0;x[b+4>>2]=a;continue}break}break a}i=wb(a);b=h+12|0;e=a;f=ph(x[a>>2],c)+g|0;c=db-16|0;db=c;x[c+12>>2]=f;d=db-16|0;db=d;x[d+12>>2]=16777215;x[d+8>>2]=2147483647;a=x[Cb(d+12|0,d+8|0)>>2];db=d+16|0;b:{if(a>>>0>=f>>>0){d=Oz(e);if(d>>>0<a>>>1>>>0){x[c+8>>2]=d<<1;a=x[Yc(c+8|0,c+12|0)>>2]}db=c+16|0;break b}Rc();p()}f=ph(x[e>>2],x[e+4>>2]);d=db-16|0;db=d;Hf(b+12|0,i);c:{if(!a){c=0;a=0;break c}if(a>>>0>=16777216){wi();p()}c=Hc(a<<8);x[d+12>>2]=a;x[d+8>>2]=c;c=x[d+8>>2];a=x[d+12>>2]}x[b>>2]=c;f=c+(f<<8)|0;x[b+8>>2]=f;x[b+4>>2]=f;l=kc(b),m=c+(a<<8)|0,x[l>>2]=m;db=d+16|0;d=db-16|0;db=d;c=d+4|0;a=b;x[c>>2]=x[a+8>>2];b=x[a+8>>2];x[c+8>>2]=a+8;x[c+4>>2]=b+(g<<8);b=x[c>>2];while(1){if(x[c+4>>2]!=(b|0)){Nz(b);b=x[c>>2]+256|0;x[c>>2]=b;continue}break}Kd(c);db=d+16|0;g=db-16|0;db=g;c=vb(g+12|0,x[e+4>>2]);d=vb(g+8|0,x[e>>2]);i=x[vb(g+4|0,x[a+4>>2])>>2];f=db-16|0;db=f;b=db-32|0;db=b;Od(b+24|0,x[c>>2],x[d>>2]);j=b+16|0;d=x[b+24>>2];k=x[b+28>>2];c=db-16|0;db=c;x[c+8>>2]=i;x[c+12>>2]=d;while(1){if(sd(d,k)){d=KQ(d);rc(KQ(x[c+8>>2]),d,256);d=JQ(c+12|0);JQ(c+8|0);d=x[d>>2];continue}break}vc(j,d,c+8|0);db=c+16|0;c=x[b+16>>2];x[b+12>>2]=x[b+20>>2];vc(f+8|0,c,b+12|0);db=b+32|0;db=f+16|0;x[a+4>>2]=x[f+12>>2];Pb(e,a+4|0);Pb(e+4|0,a+8|0);Pb(wb(e),kc(a));x[a>>2]=x[a+4>>2];db=g+16|0;e=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(e|0)){b=b-256|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){kc(a);Eb(b)}}db=h+32|0;return}if(b>>>0<e>>>0){Dd(a,c+(b<<8)|0)}}function Q6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=db-96|0;db=d;f=1;g=x[c+4>>2];h=y[c+11|0];a:{if(xd(g,h)){break a}e=y[eK(c)|0];if((e|0)!=33){if((e|0)!=63){break a}f=0}e=d+84|0;yr(e,c,0,Oc(g,h)-1|0);zb(c,e);tb(e)}e=d+84|0;Rd(e);g=x[d+84>>2];Rd(d+72|0);g=dK(g,x[d+76>>2],c);Rd(e);b:{c:{d:{e:{f:{if((g|0)==x[d+88>>2]){if(ie(c,21204)){a=ac(8);x[23549]=0;b=O(54,d+84|0,10365)|0;c=x[23549];x[23549]=0;if((c|0)==1){break d}a=pc(a,b);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}if(!f){break f}a=ac(8);x[23549]=0;S(933,d+84|0,17247,c|0);b=x[23549];x[23549]=0;if((b|0)!=1){a=pc(a,d+84|0);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break b}c=N()|0;tb(d+84|0);break c}c=N()|0;jc(a);break c}e=Gb(d+84|0);g:{h:{i:{j:{switch(x[g+4>>2]){case 0:ze(d- -64|0,c);x[23549]=0;c=x[d+68>>2];x[d+8>>2]=x[d+64>>2];x[d+12>>2]=c;b=U(934,b|0,d+8|0,f|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){x[23549]=0;v[d+72|0]=b;P(935,a|0,d+72|0);a=x[23549];x[23549]=0;if((a|0)!=1){break g}}break i;case 1:ze(d+56|0,c);x[23549]=0;c=x[d+60>>2];x[d+16>>2]=x[d+56>>2];x[d+20>>2]=c;b=EF(b,d+16|0,f);c=hb;f=x[23549];x[23549]=0;if((f|0)!=1){x[23549]=0;x[d+72>>2]=b;x[d+76>>2]=c;P(937,a|0,d+72|0);a=x[23549];x[23549]=0;if((a|0)!=1){break g}}break i;case 2:ze(d+48|0,c);x[23549]=0;c=x[d+52>>2];x[d+24>>2]=x[d+48>>2];x[d+28>>2]=c;i=+ma(938,b|0,d+24|0,f|0);b=x[23549];x[23549]=0;if((b|0)!=1){x[23549]=0;C[d+72>>3]=i;P(939,a|0,d+72|0);a=x[23549];x[23549]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}ze(d+40|0,c);x[23549]=0;c=x[d+44>>2];x[d+32>>2]=x[d+40>>2];x[d+36>>2]=c;V(940,a|0,b|0,d+32|0,f|0);a=x[23549];x[23549]=0;if((a|0)!=1){break g}}c=N()|0;tb(e);break c}ad(a,e)}tb(e);break e}Gb(a)}db=d+96|0;return}c=N()|0;jc(a)}Q(c|0)}p()}function Nha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=x[a>>2];c=eu(e,x[a+4>>2]);if(c>>>0<=63){h=db-32|0;db=h;g=64-c|0;e=x[wb(a)>>2];b=x[a+4>>2];a:{if(g>>>0<=(e-b|0)/33>>>0){e=db-16|0;db=e;c=e+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+D(g,33);a=x[c+4>>2];b=x[c+8>>2];while(1){if((a|0)==(b|0)){fc(c);db=e+16|0}else{RA(a);a=a+33|0;x[c+4>>2]=a;continue}break}break a}i=wb(a);c=h+12|0;e=a;f=eu(x[a>>2],b)+g|0;b=db-16|0;db=b;x[b+12>>2]=f;d=db-16|0;db=d;x[d+12>>2]=130150524;x[d+8>>2]=2147483647;a=x[Cb(d+12|0,d+8|0)>>2];db=d+16|0;b:{if(a>>>0>=f>>>0){d=zT(e);if(d>>>0<a>>>1>>>0){x[b+8>>2]=d<<1;a=x[Yc(b+8|0,b+12|0)>>2]}db=b+16|0;break b}Rc();p()}f=eu(x[e>>2],x[e+4>>2]);d=db-16|0;db=d;Hf(c+12|0,i);c:{if(!a){b=0;a=0;break c}if(a>>>0>=130150525){wi();p()}b=Hc(D(a,33));x[d+12>>2]=a;x[d+8>>2]=b;b=x[d+8>>2];a=x[d+12>>2]}x[c>>2]=b;f=b+D(f,33)|0;x[c+8>>2]=f;x[c+4>>2]=f;l=kc(c),m=b+D(a,33)|0,x[l>>2]=m;db=d+16|0;d=db-16|0;db=d;b=d+4|0;x[b>>2]=x[c+8>>2];a=x[c+8>>2];x[b+8>>2]=c+8;x[b+4>>2]=a+D(g,33);a=x[b>>2];while(1){if(x[b+4>>2]!=(a|0)){RA(a);a=x[b>>2]+33|0;x[b>>2]=a;continue}break}Kd(b);db=d+16|0;g=db-16|0;db=g;b=vb(g+12|0,x[e+4>>2]);d=vb(g+8|0,x[e>>2]);i=x[vb(g+4|0,x[c+4>>2])>>2];f=db-16|0;db=f;a=db-32|0;db=a;Od(a+24|0,x[b>>2],x[d>>2]);j=a+16|0;d=x[a+24>>2];k=x[a+28>>2];b=db-16|0;db=b;x[b+8>>2]=i;x[b+12>>2]=d;while(1){if(sd(d,k)){d=yT(d);rc(yT(x[b+8>>2]),d,33);d=xT(b+12|0);xT(b+8|0);d=x[d>>2];continue}break}vc(j,d,b+8|0);db=b+16|0;b=x[a+16>>2];x[a+12>>2]=x[a+20>>2];vc(f+8|0,b,a+12|0);db=a+32|0;db=f+16|0;x[c+4>>2]=x[f+12>>2];Pb(e,c+4|0);Pb(e+4|0,c+8|0);Pb(wb(e),kc(c));x[c>>2]=x[c+4>>2];db=g+16|0;e=x[c+4>>2];a=x[c+8>>2];while(1){if((a|0)!=(e|0)){a=a-33|0;x[c+8>>2]=a;continue}break}a=x[c>>2];if(a){kc(c);Eb(a)}}db=h+32|0;return}if((c|0)!=64){Dd(a,e+2112|0)}}function Hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=db-48|0;db=f;v=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;y=b+24|0;z=x[a+32>>2];A=x[a+28>>2];B=x[a+72>>2];t=x[a+68>>2];C=t>>31;u=x[a+64>>2];E=u>>31;m=x[a+60>>2];F=m>>31;j=x[a+8>>2];G=x[a+12>>2];while(1){if(d){b=x[f+16>>2];H=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+v|0;b=(((b>>>16|0)+4&131064)<<1)+y|0;l=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;p=0;while(1){if((p|0)!=2){i=H+(p<<1)|0;x[(f+8|0)+(p<<2)>>2]=(((((D(w[i+8>>1],r)+D(w[i+4>>1],s)|0)+D(q,w[i+12>>1])|0)+D(l,w[i+16>>1])|0)/2|0)+((((D(w[i-8>>1],e)+D(w[i-12>>1],b)|0)+D(w[i-4>>1],k)|0)+D(w[i>>1],h)|0)/2|0)|0)/16384;p=p+1|0;continue}break}while(1){if((g|0)!=2){r=(f+8|0)+(g<<2)|0;e=x[r>>2];b=(f+28|0)+(g<<3)|0;s=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;q=e<<8;e=q;e=yka(m,F,e,e>>31);k=hb;i=e;e=Ub(h,-16777216,16776704);e=yka(u,E,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Ub(s,-16777216,16776704);k=yka(t,C,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Lc(k,e,24);x[b+4>>2]=e-(q&B);x[r>>2]=(e|0)/256;g=g+1|0;continue}break}o=o+A|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],o>>12);n=n+z|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],n>>12);Qb(f+16|0,j,G);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}db=f+48|0}function r$(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a=db-448|0;db=a;x[a+16>>2]=f;x[a+20>>2]=g;x[a+24>>2]=h;x[a+28>>2]=i;j=a+336|0;x[a+332>>2]=j;j=Fw(j,100,11028,a+16|0);x[a+48>>2]=1103;k=a+48|0;o=pe(a+216|0,0,k);x[a+48>>2]=1103;k=pe(a+208|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+224|0;f=a+336|0;break d}j=yd();x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;j=Oi(a+332|0,j,11028,a);if((j|0)!=-1){f=x[a+332>>2];Me(o,f);Me(k,Nd(j));h=x[k>>2];if(!Sj(h)){break d}}x[23549]=0;X(1104);a=x[23549];x[23549]=0;if((a|0)!=1){break a}j=N()|0;break c}Nc(a+204|0,x[d+28>>2]);x[23549]=0;r=R(18,x[a+204>>2])|0;g=x[23549];x[23549]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}x[23549]=0;V(1113,r|0,f|0,f+j|0,h|0);g=x[23549];x[23549]=0;if((g|0)==1){break j}q=(j|0)>0?y[f|0]==45:q;i=Gb(a+184|0);f=Gb(a+172|0);g=Gb(a+160|0);x[23549]=0;ha(1152,c|0,q|0,x[a+204>>2],a+200|0,a+199|0,a+198|0,i|0,f|0,g|0,a+156|0);c=x[23549];x[23549]=0;if((c|0)==1){break i}x[a+36>>2]=1103;c=pe(a+40|0,0,a+36|0);m=a+48|0;n=x[a+156>>2];k:{if((n|0)<(j|0)){l=((Bb(x[g+4>>2],y[g+11|0])+(j-n<<1)|0)+Bb(x[f+4>>2],y[f+11|0])|0)+1|0;break k}l=(Bb(x[g+4>>2],y[g+11|0])+Bb(x[f+4>>2],y[f+11|0])|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Me(c,Nd(l));m=x[c>>2];if(m){break h}x[23549]=0;X(1104);b=x[23549];x[23549]=0;if((b|0)!=1){break a}break g}j=N()|0;break e}j=N()|0;break f}l=x[d+4>>2];x[23549]=0;ka(1153,m|0,a+36|0,a+32|0,l|0,h|0,h+j|0,r|0,q|0,a+200|0,v[a+199|0],v[a+198|0],i|0,f|0,g|0,n|0);h=x[23549];x[23549]=0;if((h|0)!=1){x[23549]=0;b=ga(14,b|0,m|0,x[a+36>>2],x[a+32>>2],d|0,e|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){break b}}}j=N()|0;Kc(c)}tb(g);tb(f);tb(i)}Xb(a+204|0)}Kc(k);Kc(o);Q(j|0);p()}Kc(c);tb(g);tb(f);tb(i);Xb(a+204|0);Kc(k);Kc(o);db=a+448|0;return b|0}p()}function wS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=db-16|0;db=f;v[a|0]=0;c=y[b|0];if(c){v[a|0]=c>>>0>96?-1:c+12|0}v[a+1|0]=y[b+1|0];c=y[b+2|0];d=c-16|0;a:{b:{if((d&255)>>>0<=128){v[a+2|0]=1;c=(d&254)>>>1|0;break b}c:{switch(((c&240)+96&240)>>>4|0){case 0:v[a+2|0]=4;c=c&15;break b;case 1:v[a+2|0]=3;c=c&15;break b;case 2:v[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}v[a+2|0]=5;c=c&15}v[a+4|0]=c}c=y[b+6|0];e=y[b+4|0];d=y[b+5|0];d:{if(!(c|(e|d))){break d}e:{f:{g:{h:{i:{j:{switch(e|0){default:k:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break k}}if((e|0)==128){break e}if((e|0)!=157){break d}v[a+2|0]=15;v[a+3|0]=20;v[a+4|0]=c>>>3;v[f+15|0]=15;h=a,i=y[Sb(b+5|0,f+15|0)|0]|208,v[h+5|0]=i;break d;case 0:v[a+5|0]=d;v[a+3|0]=c;Qf(a);g=y[b+6|0]==15;break d;case 1:v[a+3|0]=2;h=a,i=xi(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 2:v[a+3|0]=3;h=a,i=xi(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 3:v[a+3|0]=4;h=a,i=xi(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 4:v[a+3|0]=5;v[a+5|0]=c&240|(d&240)>>>4;break d;case 8:if(d){v[a+5|0]=d;v[a+3|0]=9;break d}if((c-1&255)>>>0>1){break d}v[a+5|0]=145;v[a+3|0]=20;break d;case 12:v[a+3|0]=13;v[a+5|0]=c>>>1;break d;case 15:if(c){v[a+5|0]=c;v[a+3|0]=17;break d}v[a+3|0]=16;v[a+5|0]=d&15;break d;case 16:break j;case 5:case 6:case 7:case 9:case 10:case 11:case 13:case 14:break d}}v[a+5|0]=d;v[a+3|0]=c;eB(a,1);g=(y[a+3|0]&254)==16;break d}v[a+5|0]=d;v[a+3|0]=18;break d}v[a+3|0]=31;v[a+5|0]=c>>>1;break d}v[a+3|0]=31;v[a+5|0]=c>>>1&120;break d}v[a+5|0]=159;v[a+3|0]=20;break d}v[a+3|0]=21;v[a+5|0]=c>>>2}b=y[b+3|0];l:{if(!b){break l}if(!y[a+3|0]){v[a+5|0]=b;v[a+3|0]=9;break l}if(y[a+2|0]){break l}v[a+2|0]=2;v[a+4|0]=b>>>2}db=f+16|0;return g}function Ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;f=db-48|0;db=f;y=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;z=b+24|0;A=x[a+32>>2];B=x[a+28>>2];C=x[a+72>>2];t=x[a+68>>2];E=t>>31;u=x[a+64>>2];F=u>>31;m=x[a+60>>2];G=m>>31;j=x[a+8>>2];H=x[a+12>>2];while(1){if(d){b=x[f+16>>2];I=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+y|0;b=(((b>>>16|0)+4&131064)<<1)+z|0;l=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;p=0;while(1){if((p|0)!=2){i=p+I|0;x[(f+8|0)+(p<<2)>>2]=((((D(v[i+4|0],r)+D(v[i+2|0],s)|0)+D(q,v[i+6|0])|0)+D(l,v[i+8|0])<<8>>1)+(((D(v[i-4|0],e)+D(v[i-6|0],b)|0)+D(v[i-2|0],k)|0)+D(v[i|0],h)<<8>>1)|0)/16384;p=p+1|0;continue}break}while(1){if((g|0)!=2){r=(f+8|0)+(g<<2)|0;e=x[r>>2];b=(f+28|0)+(g<<3)|0;s=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;q=e<<8;e=q;e=yka(m,G,e,e>>31);k=hb;i=e;e=Ub(h,-16777216,16776704);e=yka(u,F,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Ub(s,-16777216,16776704);k=yka(t,E,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Lc(k,e,24);x[b+4>>2]=e-(q&C);x[r>>2]=(e|0)/256;g=g+1|0;continue}break}o=o+B|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],o>>12);n=n+A|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],n>>12);Qb(f+16|0,j,H);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}db=f+48|0}function u6(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;k=db-48|0;db=k;a:{b:{c:{j=_p(1,32);d:{e:{if(!j){a=_l(ac(4));x[23549]=0;S(105,a|0,92296,25);a=x[23549];x[23549]=0;if((a|0)!=1){break a}i=T(0)|0;break e}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;f=c?c:908;x[j>>2]=f;c=ig(k+36|0);f:{g:{h:{if(!i){break h}while(1){e=x[i>>2];if(!e){break h}l=x[i+4>>2];i:{if(l){x[23549]=0;e=O(54,k+24|0,e|0)|0;m=x[23549];x[23549]=0;j:{if((m|0)!=1){x[23549]=0;m=O(919,c|0,e|0)|0;n=x[23549];x[23549]=0;if((n|0)==1){break j}x[23549]=0;P(259,m|0,l|0);l=x[23549];x[23549]=0;if((l|0)==1){break j}break i}i=T(0)|0;break f}i=T(0)|0;tb(e);break f}x[23549]=0;e=O(54,k+12|0,e|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break g}Ds(c,e)}tb(e);i=i+8|0;continue}}x[23549]=0;e=R(789,96)|0;i=x[23549];x[23549]=0;k:{l:{m:{if((i|0)!=1){x[23549]=0;d=O(920,f|0,d|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break m}x[k+4>>2]=d;d=x[Vf(k+8|0,k+4|0)>>2];x[23549]=0;a=fa(951,e|0,a|0,b|0,d|0,c|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break k}i=T(0)|0;xe(k+4|0);break l}i=T(0)|0;break f}i=T(0)|0}Eb(e);break f}x[j+28>>2]=a;xe(k+4|0);x[j+24>>2]=a+8;dl(c);break d}i=T(0)|0}dl(c);Y(i|0)|0;x[23549]=0;V(914,4914,j|0,g|0,h|0);a=x[23549];x[23549]=0;if((a|0)!=1){x[23549]=0;X(17);a=x[23549];x[23549]=0;if((a|0)!=1){a=x[j+28>>2];if(a){ib[x[x[a>>2]+4>>2]](a)}x[j+24>>2]=0;x[j+28>>2]=0;a=x[j+20>>2];if(a){Eb(a);x[j+20>>2]=0}Eb(j);j=0;break d}i=T(0)|0;break e}i=T(0)|0;x[23549]=0;X(17);a=x[23549];x[23549]=0;if((a|0)==1){break b}}Y(i|0)|0;j=0;x[23549]=0;V(914,4914,0,g|0,h|0);a=x[23549];x[23549]=0;if((a|0)==1){break c}Z()}db=k+48|0;return j|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Rb()}p()}function NZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;r=db-16|0;db=r;j=c;while(1){a:{if((d|0)==(j|0)){j=d;break a}if(!y[j|0]){break a}j=j+1|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}i=x[b+4>>2];x[r+8>>2]=x[b>>2];x[r+12>>2]=i;s=db-16|0;db=s;v=ei(s+12|0,x[a+8>>2]);m=j-c|0;k=0;n=0;o=db-1040|0;db=o;q=x[e>>2];x[o+12>>2]=q;p=f?f:o+16|0;l=f?g-f>>2:256;e:{f:{g:{if(!(!q|!l)){while(1){i=m>>>2|0;if(!(m>>>0>131|i>>>0>=l>>>0)){i=q;break f}t=hH(p,o+12|0,i>>>0<l>>>0?i:l,b);i=x[o+12>>2];if((t|0)==-1){l=0;k=-1;break g}u=(o+16|0)!=(p|0)?t:0;l=l-u|0;p=(u<<2)+p|0;m=i?(m+q|0)-i|0:0;k=k+t|0;if(!i){break g}q=i;if(l){continue}break}break g}i=q}if(!i){break e}}if(!(!l|!m)){n=i;i=k;while(1){h:{k=Vr(p,n,m,b);i:{if(k+2>>>0<=2){j:{switch(k+1|0){case 1:n=0;break i;case 0:break e;default:break j}}x[b>>2]=0;break i}n=k+n|0;x[o+12>>2]=n;i=i+1|0;l=l-1|0;if(l){break h}}k=i;break e}p=p+4|0;m=m-k|0;k=i;if(m){continue}break}break e}n=i}if(f){x[e>>2]=n}db=o+1040|0;di(v);db=s+16|0;k:{l:{m:{n:{if((k|0)==-1){while(1){o:{x[h>>2]=f;if(x[e>>2]==(c|0)){break o}g=1;p:{q:{r:{b=UF(f,c,j-c|0,r+8|0,x[a+8>>2]);switch(b+2|0){case 0:break l;case 2:break p;case 1:break r;default:break q}}x[e>>2]=c;break n}g=b}c=c+g|0;f=x[h>>2]+4|0;continue}break}x[e>>2]=c;break d}f=x[h>>2]+(k<<2)|0;x[h>>2]=f;if((f|0)==(g|0)){break k}c=x[e>>2];if((d|0)==(j|0)){j=d;continue}if(!UF(f,c,1,b,x[a+8>>2])){break m}}a=2;break c}x[h>>2]=x[h>>2]+4;c=x[e>>2]+1|0;x[e>>2]=c;j=c;while(1){if((d|0)==(j|0)){j=d;break b}if(!y[j|0]){break b}j=j+1|0;continue}}x[e>>2]=c;a=1;break c}c=x[e>>2]}a=(c|0)!=(d|0)}db=r+16|0;return a|0}f=x[h>>2];continue}}function LM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=db-16|0;db=f;e=D(b,872)+a|0;j=e+1074992|0;a:{b:{i=x[e+1075080>>2];if(i&131072){e=x[a+480180>>2];i=1;c:{d:{e:{h=x[a+480208>>2];if(h&4096){if(!(e&16777248)){break e}i=!(h&4)}if((e|0)!=64){break d}break b}if((e|0)==64){break b}h=a+480180|0;i=0;break c}h=a+480180|0;if(!i){break c}Fb(f+8|0,a+1074312|0,21);if(!Ib(x[x[f+8>>2]>>2],x[f+12>>2])){break c}e=D(b,872)+a|0;g=e+1075811|0;v[g|0]=y[g|0]+(y[e+1075815|0]<<2)}g=D(b,872)+a|0;k=g+1075814|0;l=g+1075811|0;e=sy(a,y[k|0],y[l|0]);f:{if(gj(x[j+656>>2])){B[d>>2]=B[d>>2]+E(E(E(D(y[g+1075816|0],e)|0)*E(.05000000074505806))/E(7680));c=g+1075843|0;d=y[c|0];v[c|0]=d&159|64;if(x[a+1074416>>2]!=(x[a+1074392>>2]+1|0)){break f}v[c|0]=d|96;break f}d=x[a+480208>>2];if((d&2101248)==2101248){break a}g=x[h>>2];if(d&4096?g&67633152:0){break a}e=g&5?(y[k|0]&3)==1?0-e|0:e:e;k=a+1074312|0;Fb(f+8|0,k,21);g=x[a+480208>>2];g:{if(Ib(x[x[f+8>>2]>>2],x[f+12>>2])){d=g&4;e=d?e:0-e|0;d=d?5:6;break g}d=5;h:{if(g&131072){break h}h=x[h>>2];d=8;if((h|0)==1024){break h}d=7;if(h&524304){break h}d=h&16777248?g&4?6:7:6}Fb(f+8|0,k,80);if(!Ib(x[x[f+8>>2]>>2],x[f+12>>2])){break g}d=y[(D(b,872)+a|0)+1075783|0]==26?d+2|0:d}d=0-((D(y[(D(b,872)+a|0)+1075816|0],e)|0)/(1<<d)|0)|0;Oj(a,j,c,d,0);e=x[j+656>>2];c=at(a,x[j+88>>2],e);if(!c){break f}ib[x[x[c>>2]+88>>2]](c,d,(e?v[e+33|0]:2)<<24>>24,b)}if(!i){break a}Fb(f+8|0,a+1074312|0,21);if(Ib(x[x[f+8>>2]>>2],x[f+12>>2])){break a}v[l|0]=y[l|0]+y[(D(b,872)+a|0)+1075815|0];break a}if(!(y[e+1075662|0]&2)){break a}a=at(a,i,x[j+656>>2]);if(!a){break a}ib[x[x[a>>2]+88>>2]](a,0,0,b);break a}a=D(b,872)+a|0;b=a+1075811|0;d=y[b|0];if(d&1){x[c>>2]=x[c>>2]+D(y[a+1075816|0],167)}v[b|0]=d+1}db=f+16|0}function Lea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=db-16|0;db=j;e=x[b>>2];d=fh(e,x[b+4>>2]);a:{if(d>>>0<c>>>0){n=db-32|0;db=n;d=c-d|0;f=x[wb(b)>>2];e=x[b+4>>2];b:{if(d>>>0<=f-e>>4>>>0){g=db-16|0;db=g;e=fp(g+4|0,b,d);d=x[e+4>>2];f=x[e+8>>2];while(1){if((d|0)==(f|0)){fc(e);db=g+16|0}else{uu(d);d=d+16|0;x[e+4>>2]=d;continue}break}break b}g=wb(b);g=Wv(n+12|0,Yv(b,fh(x[b>>2],e)+d|0),fh(x[b>>2],x[b+4>>2]),g);f=db-16|0;db=f;d=BE(f+4|0,g+8|0,d);e=x[d>>2];while(1){if(x[d+4>>2]!=(e|0)){uu(e);e=x[d>>2]+16|0;x[d>>2]=e;continue}break}Kd(d);db=f+16|0;k=db-16|0;db=k;d=vb(k+12|0,x[b+4>>2]);e=vb(k+8|0,x[b>>2]);h=x[vb(k+4|0,x[g+4>>2])>>2];l=db-16|0;db=l;o=l+8|0;f=db-32|0;db=f;Od(f+24|0,x[d>>2],x[e>>2]);p=f+16|0;d=x[f+24>>2];q=x[f+28>>2];i=db-16|0;db=i;x[i+8>>2]=h;x[i+12>>2]=d;while(1){if(sd(d,q)){e=wk(d);d=wk(x[i+8>>2]);h=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);m=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);v[d+8|0]=m;v[d+9|0]=m>>>8;v[d+10|0]=m>>>16;v[d+11|0]=m>>>24;v[d+12|0]=h;v[d+13|0]=h>>>8;v[d+14|0]=h>>>16;v[d+15|0]=h>>>24;h=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);v[d|0]=e;v[d+1|0]=e>>>8;v[d+2|0]=e>>>16;v[d+3|0]=e>>>24;v[d+4|0]=h;v[d+5|0]=h>>>8;v[d+6|0]=h>>>16;v[d+7|0]=h>>>24;d=Jl(i+12|0);Jl(i+8|0);d=x[d>>2];continue}break}vc(p,d,i+8|0);db=i+16|0;d=x[f+16>>2];x[f+12>>2]=x[f+20>>2];vc(o,d,f+12|0);db=f+32|0;db=l+16|0;x[g+4>>2]=x[l+12>>2];Pb(b,g+4|0);Pb(b+4|0,g+8|0);Pb(wb(b),kc(g));x[g>>2]=x[g+4>>2];db=k+16|0;JE(g)}db=n+32|0;break a}if(c>>>0<d>>>0){Dd(b,e+(c<<4)|0)}}if(Lb(x[a>>2],x[a+8>>2],c<<4)){c=x[b>>2];dc(j+8|0,c,fh(c,x[b+4>>2])<<4);pd(j,a,x[j+8>>2],x[j+12>>2])}db=j+16|0}function FK(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;k=db-48|0;db=k;a:{b:{c:{d:{e:{f:{j=_p(1,28);if(!j){a=_l(ac(4));x[23549]=0;S(105,a|0,92296,25);a=x[23549];x[23549]=0;if((a|0)!=1){break a}break f}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;f=c?c:908;x[j>>2]=f;c=ig(k+36|0);g:{h:{i:{if(!i){break i}while(1){e=x[i>>2];if(!e){break i}l=x[i+4>>2];j:{if(l){x[23549]=0;e=O(54,k+24|0,e|0)|0;m=x[23549];x[23549]=0;k:{if((m|0)!=1){x[23549]=0;m=O(919,c|0,e|0)|0;n=x[23549];x[23549]=0;if((n|0)==1){break k}x[23549]=0;P(259,m|0,l|0);l=x[23549];x[23549]=0;if((l|0)==1){break k}break j}i=T(0)|0;break g}i=T(0)|0;tb(e);break g}x[23549]=0;e=O(54,k+12|0,e|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break h}Ds(c,e)}tb(e);i=i+8|0;continue}}x[23549]=0;e=R(789,80)|0;i=x[23549];x[23549]=0;l:{m:{n:{if((i|0)!=1){x[23549]=0;d=O(920,f|0,d|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break n}x[k+4>>2]=d;d=x[Vf(k+8|0,k+4|0)>>2];x[23549]=0;a=fa(925,e|0,a|0,b|0,d|0,c|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break l}i=T(0)|0;xe(k+4|0);break m}i=T(0)|0;break g}i=T(0)|0}Eb(e);break g}x[j+24>>2]=a;xe(k+4|0);dl(c);i=j;break d}i=T(0)|0}dl(c);Y(i|0)|0;x[23549]=0;V(914,14738,j|0,g|0,h|0);a=x[23549];x[23549]=0;if((a|0)!=1){x[23549]=0;X(17);a=x[23549];x[23549]=0;if((a|0)==1){break f}a=x[j+24>>2];if(a){Eb(Cs(a))}i=0;x[j+24>>2]=0;a=x[j+20>>2];if(a){Eb(a);x[j+20>>2]=0}Eb(j);break d}i=T(0)|0;x[23549]=0;X(17);a=x[23549];x[23549]=0;if((a|0)!=1){break e}break b}i=T(0)|0}Y(i|0)|0;i=0;x[23549]=0;V(914,14738,0,g|0,h|0);a=x[23549];x[23549]=0;if((a|0)==1){break c}Z()}db=k+48|0;return i|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Rb()}p()}function VR(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=db-16|0;db=l;g=x[b>>2];h=x[b+4>>2];a:{if((h|0)==(f|0)){j=ec(l+8|0,e,f);b=db-16|0;db=b;c=sm(c,d,g,f);x[b+12>>2]=c;e=x[j>>2];b:{if((c|0)<=0){break b}if(f){d=32-f|0;x[b+8>>2]=d;h=c;c=x[qd(b+8|0,b+12|0)>>2];x[b+12>>2]=h-c;d=-1<<f&-1>>>d-c;x[e>>2]=x[e>>2]&(d^-1)|d&x[g>>2];c=c+x[j+4>>2]|0;x[j+4>>2]=c&31;e=(c>>>3&536870908)+e|0;x[j>>2]=e;g=g+4|0;c=x[b+12>>2]}d=(c|0)/32|0;TR(g,d,e);c=c-(d<<5)|0;x[b+12>>2]=c;d=d<<2;e=d+x[j>>2]|0;x[j>>2]=e;if((c|0)<=0){break b}c=-1>>>32-c|0;x[e>>2]=x[e>>2]&(c^-1)|c&x[d+g>>2];x[j+4>>2]=x[b+12>>2]}ec(a,e,x[j+4>>2]);db=b+16|0;break a}j=a;i=ec(l,e,f);f=db-16|0;db=f;e=sm(c,d,g,h);x[f+12>>2]=e;c:{if((e|0)<=0){a=x[i+4>>2];b=x[i>>2];break c}d:{if(!h){a=x[i+4>>2];break d}k=32-h|0;x[f+8>>2]=k;c=f+8|0;b=x[qd(c,f+12|0)>>2];x[f+12>>2]=e-b;a=x[i+4>>2];e=x[g>>2];x[f+8>>2]=b;m=32-a|0;x[f+4>>2]=m;d=x[i>>2];n=x[d>>2];c=x[Cb(c,f+4|0)>>2];e=e&(-1<<h&-1>>>k-b);x[d>>2]=(-1<<a&-1>>>m-c^-1)&n|(a>>>0>h>>>0?e<<a-h:e>>>h-a|0);k=a+c|0;a=k&31;x[i+4>>2]=a;d=d+(k>>>3&536870908)|0;x[i>>2]=d;b=b-c|0;if((b|0)>0){x[d>>2]=x[d>>2]&(-1>>>32-b^-1)|e>>>c+h;x[i+4>>2]=b;a=b}g=g+4|0;e=x[f+12>>2]}c=32-a|0;d=-1<<a;h=d^-1;while(1){if((e|0)>=32){b=x[i>>2];e=x[g>>2];x[b>>2]=h&x[b>>2]|e<<a;x[i>>2]=b+4;x[b+4>>2]=d&x[b+4>>2]|e>>>c;e=x[f+12>>2]-32|0;x[f+12>>2]=e;g=g+4|0;continue}break}b=x[i>>2];if((e|0)<=0){break c}g=x[g>>2];x[f+8>>2]=c;k=x[b>>2];h=c;c=x[qd(f+12|0,f+8|0)>>2];e=g&-1>>>32-e;x[b>>2]=k&(d&-1>>>h-c^-1)|e<<a;d=a+c|0;a=d&31;x[i+4>>2]=a;b=(d>>>3&536870908)+b|0;x[i>>2]=b;d=x[f+12>>2]-c|0;x[f+12>>2]=d;if((d|0)<=0){break c}x[b>>2]=x[b>>2]&(-1>>>32-d^-1)|e>>>c;a=x[f+12>>2];x[i+4>>2]=a}ec(j,b,a);db=f+16|0}db=l+16|0}function rX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=db+-64|0;db=d;wc(b);ap(a);a:{if(!$h(b,d+56|0)){break a}if(!BD(d+56|0)){break a}if(!c){k=1;break a}if(!Lb(x[b>>2],x[b+8>>2],4)){break a}Iv(a);q=d,r=Hv(),x[q+36>>2]=r;c=d+36|0;Gv(yh(x[a+4>>2])+32|0,c);or(c);j=x[yh(x[a+4>>2])+32>>2];c=Ig(x[b>>2]);if(c&1){break a}f=c-4|0;Vc(b,f);g=db-16|0;db=g;c=g+13|0;uv(c,b);h=y[Db(c,0)|0];e=y[Db(c,1)|0];c=y[Db(c,2)|0];db=g+16|0;h=c|(e<<8|h<<16);if(!h){break a}x[23549]=0;P(161,j|0,h|0);c=x[23549];x[23549]=0;k=1;if((c|0)==1){a=T(92296)|0;if((eb|0)==($(92296)|0)){Y(a|0)|0;Z();k=0;break a}Q(a|0);p()}Vc(b,4);m=d+36|0;zD(m,b);l=x[j>>2];e=db-32|0;db=e;b=x[d+36>>2];v[e+28|0]=y[b|0];v[e+29|0]=y[b+1|0];v[e+30|0]=y[b+2|0];v[e+31|0]=y[b+3|0];g=dr(e+12|0);c=b+f|0;x[g+12>>2]=c-4;x[g+8>>2]=b;yj(g,y[c-1|0]);c=h;b:while(1){c:{d:{e:{if(!c){break e}if(yj(g,1)){break d}b=1;while(1){f=yj(g,2);b=f+b|0;if((f|0)==3){continue}break}x[e+8>>2]=b;tc(e+8|0,c);b=0;f=x[e+8>>2];while(1)if((b|0)==(f|0)){if(!c){break e}break d}else{c=c-1|0;q=l+c|0,r=yj(g,8),v[q|0]=r;b=b+1|0;continue}}db=e+32|0;break c}f=yj(g,2);b=f+2|0;x[e+8>>2]=b;f:{if((f|0)==3){g:{if(!yj(g,1)){b=5;f=7;break g}f=y[Db(e+28|0,3)|0]}f=yj(g,f);while(1){i=yj(g,3);b=i+b|0;if((i|0)==7){continue}break}x[e+8>>2]=b;break f}f=yj(g,y[Db(e+28|0,f)|0])}tc(e+8|0,c);b=0;o=x[e+8>>2];while(1){if((b|0)==(o|0)){continue b}i=0;n=c+f|0;if(h>>>0>n>>>0){i=y[l+n|0]}c=c-1|0;v[l+c|0]=i;b=b+1|0;continue}}break}ge(d+16|0,x[j>>2],x[j+4>>2]);Ng(d+24|0,x[d+16>>2],x[d+20>>2]);b=Xd(d+8|0);c=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=c;b=mr(m,x[d+24>>2],x[d+28>>2],d);Zc(yh(x[a+4>>2])+12|0,b);ub(b)}db=d- -64|0;return k|0}function ag(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;h=x[a+8>>2]+(D(z[a+14>>1],(y[a+80|0]?c:0)+b|0)>>>1|0)|0;x[a+8>>2]=h;g=y[a+79|0]?z[x[a>>2]+3836>>1]:g;c=z[a+20>>1];j=z[a+22>>1];k=z[a+70>>1];a:{b:{c:{d:{switch(x[a+16>>2]){case 1:b=z[x[a>>2]+3832>>1];f=c+(b&z[a+46>>1]?0:z[a+26>>1]?z[a+48>>1]>>>z[x[a+52>>2]+((b>>>z[a+44>>1]&7)<<1)>>1]|0:0)|0;w[a+20>>1]=f;b=2;i=z[a+28>>1];if((i|0)<=f<<16>>16){break c}break b;case 2:if(y[a+78|0]){break b}case 3:b=0;f=z[x[a>>2]+3832>>1];f=c+(f&z[a+58>>1]?0:z[a+30>>1]?z[a+60>>1]>>>z[x[a+64>>2]+((f>>>z[a+56>>1]&7)<<1)>>1]|0:0)|0;w[a+20>>1]=f;if(f<<16>>16<511){break b}x[a+16>>2]=-1;w[a+20>>1]=511;x[a+72>>2]=0;break a;default:b=0;x[a+72>>2]=0;break a;case 0:break d}}b=1;f=z[x[a>>2]+3832>>1];f=c+(f&z[a+34>>1]?0:z[a+24>>1]?D((c^-1)<<16>>16,z[a+36>>1]>>>z[x[a+40>>2]+((f>>>z[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0)|0;w[a+20>>1]=f;if(f<<16>>16>0){break b}}x[a+16>>2]=b;w[a+20>>1]=i}g=((c+j|0)+k|0)+g<<3;if(e){d=(w[a+74>>1]+w[a+72>>1]>>e)+d|0}d=(h>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(z[a+12>>1]){case 0:d=(b&512)>>>9|0;b=z[((b&256?c^255:c)<<1)+28464>>1];break e;case 1:d=0;b=z[((b&512?0:b&256?c^255:c)<<1)+28464>>1];break e;case 2:d=0;b=z[((b&256?c^255:c)<<1)+28464>>1];break e;case 3:d=0;b=z[((b&256?0:c)<<1)+28464>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=z[(e<<1)+28464>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=z[(b<<1)+28464>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}w[a+74>>1]=z[a+72>>1];c=a;a=b+g&65535;a=a>>>0>=8191?8191:a;b=0-d^z[((a&255)<<1)+27952>>1]+1024>>>(a>>>8)<<1;w[c+72>>1]=b}return b<<16>>16}function Lca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=db-48|0;db=f;t=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}u=x[a+24>>2];v=x[a+20>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;y=b+24|0;z=x[a+72>>2];r=x[a+68>>2];A=r>>31;s=x[a+64>>2];B=s>>31;m=x[a+60>>2];C=m>>31;j=x[a+8>>2];E=x[a+12>>2];while(1){if(d){b=x[f+16>>2];F=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=(((b>>>16|0)+4&131064)<<1)+y|0;l=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;n=0;while(1){if((n|0)!=2){i=F+(n<<1)|0;x[(f+8|0)+(n<<2)>>2]=(((((D(w[i+8>>1],p)+D(w[i+4>>1],q)|0)+D(o,w[i+12>>1])|0)+D(l,w[i+16>>1])|0)/2|0)+((((D(w[i-8>>1],e)+D(w[i-12>>1],b)|0)+D(w[i-4>>1],k)|0)+D(w[i>>1],h)|0)/2|0)|0)/16384;n=n+1|0;continue}break}while(1){if((g|0)!=2){p=(f+8|0)+(g<<2)|0;e=x[p>>2];b=(f+28|0)+(g<<3)|0;q=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;o=e<<8;e=o;e=yka(m,C,e,e>>31);k=hb;i=e;e=Ub(h,-16777216,16776704);e=yka(s,B,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Ub(q,-16777216,16776704);k=yka(r,A,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Lc(k,e,24);x[b+4>>2]=e-(o&z);x[p>>2]=(e|0)/256;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],v);x[c+4>>2]=x[c+4>>2]+D(u,x[f+12>>2]);Qb(f+16|0,j,E);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}db=f+48|0}function Rr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=db-128|0;db=i;x[i+124>>2]=b;k=dH(c,d);x[i+4>>2]=1103;n=cH(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Nd(k);if(!j){x[23549]=0;X(1104);a=x[23549];x[23549]=0;if((a|0)!=1){break a}break b}Me(n,j)}h=j;b=c;c:{d:{while(1){if((b|0)==(d|0)){e:while(1){f:{x[23549]=0;h=O(1105,a|0,i+124|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break f}if((h|!k)==1){x[23549]=0;b=O(1105,a|0,i+124|0)|0;a=x[23549];x[23549]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}b=x[a>>2];x[23549]=0;o=R(1106,b|0)|0;b=x[23549];x[23549]=0;g:{if((b|0)!=1){if(g){break g}x[23549]=0;o=O(1107,e|0,o|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break g}}break b}l=q+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=l;if(!s){continue e}x[23549]=0;R(1108,a|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){h=j;b=c;if(k+m>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Bb(x[b+4>>2],y[b+11|0])|0)==(q|0)){break h}v[h|0]=0;m=m-1|0}h=h+1|0;b=b+12|0;continue}}break b}i:{if(y[h|0]!=1){break i}r=v[uc(b,q)|0];j:{if(g){break j}x[23549]=0;r=O(1107,e|0,r<<24>>24)|0;t=x[23549];x[23549]=0;if((t|0)!=1){break j}break b}k:{if((o&255)==(r&255)){s=1;if((Bb(x[b+4>>2],y[b+11|0])|0)!=(l|0)){break i}v[h|0]=2;m=m+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}}else{l=xd(x[b+4>>2],y[b+11|0]);v[h|0]=l?2:1;m=m+l|0;k=k-l|0;h=h+1|0;b=b+12|0;continue}break}break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Kc(n);db=i+128|0;return d|0}}a=N()|0;Kc(n);Q(a|0)}p()}function Pr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=db-128|0;db=i;x[i+124>>2]=b;k=dH(c,d);x[i+4>>2]=1103;n=cH(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Nd(k);if(!j){x[23549]=0;X(1104);a=x[23549];x[23549]=0;if((a|0)!=1){break a}break b}Me(n,j)}h=j;b=c;c:{d:{while(1){if((b|0)==(d|0)){e:while(1){f:{x[23549]=0;h=O(1120,a|0,i+124|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break f}if((h|!k)==1){x[23549]=0;b=O(1120,a|0,i+124|0)|0;a=x[23549];x[23549]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}b=x[a>>2];x[23549]=0;o=R(1121,b|0)|0;b=x[23549];x[23549]=0;g:{if((b|0)!=1){if(g){break g}x[23549]=0;o=O(1122,e|0,o|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break g}}break b}l=q+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=l;if(!s){continue e}x[23549]=0;R(1123,a|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){h=j;b=c;if(k+m>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Bb(x[b+4>>2],y[b+11|0])|0)==(q|0)){break h}v[h|0]=0;m=m-1|0}h=h+1|0;b=b+12|0;continue}}break b}i:{if(y[h|0]!=1){break i}r=x[_i(b,q)>>2];j:{if(g){break j}x[23549]=0;r=O(1122,e|0,r|0)|0;t=x[23549];x[23549]=0;if((t|0)!=1){break j}break b}k:{if((o|0)==(r|0)){s=1;if((Bb(x[b+4>>2],y[b+11|0])|0)!=(l|0)){break i}v[h|0]=2;m=m+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}}else{l=xd(x[b+4>>2],y[b+11|0]);v[h|0]=l?2:1;m=m+l|0;k=k-l|0;h=h+1|0;b=b+12|0;continue}break}break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Kc(n);db=i+128|0;return d|0}}a=N()|0;Kc(n);Q(a|0)}p()}function Yba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;g=db-32|0;db=g;f=tP(g+20|0,1<<x[b+12>>2]);e=x[f>>2];while(1){c=x[a>>2];if(Hg(c,x[a+4>>2])>>>0>d>>>0){c=Qe(c,d);sP(_c(e,d),C[c>>3]);d=d+1|0;continue}break}rP(b,f);w=g,y=yb(x[f>>2]),x[w>>2]=y;u=yb(x[f+4>>2]);while(1){d=x[g>>2];if(Kb(d,u)){m=C[d+8>>3];k=db-32|0;db=k;o(+C[d>>3]);e=j(1)|0;r=j(0)|0;o(+m);c=j(1)|0;s=j(0)|0;e=e&2147483647;q=c&2147483647;c=(e|0)==(q|0)&r>>>0<s>>>0|e>>>0<q>>>0;h=c?r:s;c=c?e:q;v=c;l(0,h|0);l(1,c|0);p=+n();t=c>>>20|0;i=p;a:{if((t|0)==2047){break a}c=(e|0)==(q|0)&r>>>0>s>>>0|e>>>0>q>>>0;l(0,(c?r:s)|0);c=c?e:q;l(1,c|0);m=+n();b:{if(!(h|v)){break b}c=c>>>20|0;if((c|0)==2047){break b}i=m+p;if((c-t|0)>=65){break a}c:{if(c>>>0>=1534){p=p*190109156629516e-225;m=m*190109156629516e-225;i=5.260135901548374e210;break c}i=1;if(t>>>0>572){break c}p=p*5.260135901548374e210;m=m*5.260135901548374e210;i=190109156629516e-225}pI(k+24|0,k+16|0,m);pI(k+8|0,k,p);i=i*M(C[k>>3]+C[k+16>>3]+C[k+8>>3]+C[k+24>>3]);break a}i=m}p=i;db=k+32|0;sP(d,lp(p));jl(g);continue}break}qP(b,f);pP(f);h=x[f>>2];e=fh(h,x[f+4>>2])>>>1|0;c=e>>>0<=1?1:e;d=1;while(1){if((c|0)!=(d|0)){qz(_c(h,d),2);qz(_c(h,d+e|0),0);d=d+1|0;continue}break}rP(b,f);w=g,y=yb(x[f>>2]),x[w+16>>2]=y;e=yb(x[f+4>>2]);while(1){h=x[g+16>>2];if(Kb(h,e)){oP(g,C[h>>3],C[h+8>>3]);c=x[g+12>>2];x[h+8>>2]=x[g+8>>2];x[h+12>>2]=c;c=x[g+4>>2];x[h>>2]=x[g>>2];x[h+4>>2]=c;jl(g+16|0);continue}break}qP(b,f);pP(f);e=x[a>>2];c=Hg(e,x[a+4>>2]);b=x[f>>2];d=0;while(1){if((c|0)==(d|0)){ql(f);db=g+32|0}else{a=_c(b,d);w=Qe(e,d),z=C[a>>3],C[w>>3]=z;d=d+1|0;continue}break}}function uea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=db-48|0;db=h;j=c+484344|0;mg(j,y[b+70|0]|y[b+71|0]<<8);a:{b:{while(1){if((y[b+70|0]|y[b+71|0]<<8)>>>0<=i>>>0){break b}g=x[a+8>>2];d=pg(a);Zb(a,1);c:{if((y[b+58|0]|y[b+59|0]<<8)==258){c=ee(a)+1|0;break c}c=Fg(a)}e=Fg(a);Vc(a,d+g|0);d=h+8|0;Wd(d,a,e);g=hc(h+28|0,d);ub(d);x[23549]=0;c=U(212,j|0,i&65535,(c?c>>>0>=1024?1024:c:64)|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){d:{if(!(c&(e|0)!=0)){break d}c=Yb(x[j>>2],i);m=h,n=yb(x[c>>2]),x[m+8>>2]=n;k=yb(x[c+4>>2]);while(1){c=x[h+8>>2];if(!Kb(c,k)){break d}x[23549]=0;e=R(192,g|0)|0;d=x[23549];x[23549]=0;e:{f:{g:{if((d|0)!=1){d=e<<24>>24;if((d|0)>=0){break g}if(d&1){x[23549]=0;e=R(192,g|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break a}v[c|0]=e}e=d&255;if(d&2){break f}break e}break a}v[c|0]=d;e=255}x[23549]=0;d=R(192,g|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break a}v[c+1|0]=d}d=0;if(e&4){x[23549]=0;d=R(192,g|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break a}}if(e&8){x[23549]=0;f=R(192,g|0)|0;l=x[23549];x[23549]=0;if((l|0)==1){break a}v[c+3|0]=f}if(e&16){x[23549]=0;e=R(192,g|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break a}v[c+5|0]=e}h:{i:{e=y[c|0];if(!e){break i}f=255;if((e|0)==97){break h}if(e>>>0>96){break i}f=e+12|0;break h}f=0}v[c|0]=f;j:{if(y[c+5|0]|y[c+3|0]){Qf(c);break j}v[c+3|0]=0}if(y[c+1|0]==255){v[c+1|0]=0}e=d-16|0;k:{if((e&255)>>>0<=64){v[c+4|0]=e;v[c+2|0]=1;break k}if(d>>>0<96){break k}e=d&15;v[c+4|0]=e;d=d-96>>>4|0;v[c+2|0]=y[d+27198|0];if((d|0)!=6){break k}v[c+4|0]=e<<2}lk(h+8|0);continue}}ub(g);i=i+1|0;continue}break}break a}db=h+48|0;return}a=N()|0;ub(g);Q(a|0);p()}function Mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0;f=db-48|0;db=f;t=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}u=x[a+24>>2];y=x[a+20>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;z=b+24|0;A=x[a+72>>2];r=x[a+68>>2];B=r>>31;s=x[a+64>>2];C=s>>31;m=x[a+60>>2];E=m>>31;j=x[a+8>>2];F=x[a+12>>2];while(1){if(d){b=x[f+16>>2];G=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=(((b>>>16|0)+4&131064)<<1)+z|0;l=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;n=0;while(1){if((n|0)!=2){i=n+G|0;x[(f+8|0)+(n<<2)>>2]=((((D(v[i+4|0],p)+D(v[i+2|0],q)|0)+D(o,v[i+6|0])|0)+D(l,v[i+8|0])<<8>>1)+(((D(v[i-4|0],e)+D(v[i-6|0],b)|0)+D(v[i-2|0],k)|0)+D(v[i|0],h)<<8>>1)|0)/16384;n=n+1|0;continue}break}while(1){if((g|0)!=2){p=(f+8|0)+(g<<2)|0;e=x[p>>2];b=(f+28|0)+(g<<3)|0;q=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;o=e<<8;e=o;e=yka(m,E,e,e>>31);k=hb;i=e;e=Ub(h,-16777216,16776704);e=yka(s,C,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Ub(q,-16777216,16776704);k=yka(r,B,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Lc(k,e,24);x[b+4>>2]=e-(o&A);x[p>>2]=(e|0)/256;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],y);x[c+4>>2]=x[c+4>>2]+D(u,x[f+12>>2]);Qb(f+16|0,j,F);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}db=f+48|0}function naa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=db-192|0;db=c;e=Pl(c+88|0,a);x[23549]=0;d=O(403,c+76|0,44030)|0;a=x[23549];x[23549]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){x[23549]=0;x[c+64>>2]=19927555;x[c+68>>2]=0;S(404,e|0,d|0,c- -64|0);a=x[23549];x[23549]=0;if((a|0)==1){break n}Ab(d);if(y[e+3|0]&64){break e}x[23549]=0;d=O(403,c- -64|0,13188)|0;a=x[23549];x[23549]=0;if((a|0)==1){break m}x[23549]=0;V(435,e|0,b|0,d|0,849);a=x[23549];x[23549]=0;if((a|0)==1){break l}Ab(d);x[c+60>>2]=0;x[c+56>>2]=0;x[23549]=0;d=O(403,c+44|0,16338)|0;a=x[23549];x[23549]=0;if((a|0)==1){break k}x[23549]=0;S(850,e|0,c+60|0,d|0);a=x[23549];x[23549]=0;if((a|0)==1){break j}Ab(d);x[23549]=0;d=O(403,c+32|0,16328)|0;a=x[23549];x[23549]=0;if((a|0)==1){break i}x[23549]=0;S(850,e|0,c+56|0,d|0);a=x[23549];x[23549]=0;if((a|0)==1){break h}Ab(d);a=x[c+60>>2];d=x[c+56>>2];o:{if(!a|d>>>0<a>>>0){break o}f=x[x[x[x[b+48>>2]+12>>2]+8>>2]+40>>2];if(f>>>0<a>>>0|d>>>0>f>>>0){break o}x[b+20>>2]=d;x[b+16>>2]=a}d=Nb(c+20|0);x[23549]=0;f=O(403,c+8|0,13842)|0;a=x[23549];x[23549]=0;if((a|0)==1){break d}x[23549]=0;S(851,e|0,d|0,f|0);a=x[23549];x[23549]=0;if((a|0)==1){break g}Ab(f);if(qc(x[d>>2],x[d+4>>2])){break f}a=x[b+16>>2];x[23549]=0;P(803,d|0,a|0);a=x[23549];x[23549]=0;if((a|0)!=1){break f}break c}a=N()|0;break a}a=N()|0;Ab(d);break a}a=N()|0;break a}a=N()|0;Ab(d);break a}a=N()|0;break a}a=N()|0;Ab(d);break a}a=N()|0;break a}a=N()|0;Ab(d);break a}a=N()|0;Ab(f);break b}x[23549]=0;P(852,b|0,d|0);a=x[23549];x[23549]=0;if((a|0)==1){break c}sc(d)}Zg(e);db=c+192|0;return}a=N()|0;break b}a=N()|0}sc(d)}Zg(e);Q(a|0);p()}function lda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;f=db-48|0;db=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;o=g+(f+28|0)|0;g=a+g|0;x[o+4>>2]=x[g+44>>2];x[o+8>>2]=x[g+48>>2];b=b+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];q=x[a+68>>2];z=q>>31;r=x[a+64>>2];A=r>>31;s=x[a+60>>2];B=s>>31;o=x[a+8>>2];C=x[a+12>>2];while(1){if(d){b=x[f+16>>2];p=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=b>>>21&2040;h=w[b+39942>>1];i=w[b+39940>>1];e=w[b+39938>>1];g=w[b+39936>>1];b=0;j=0;while(1){if((j|0)!=2){k=p+(j<<1)|0;x[(f+8|0)+(j<<2)>>2]=(((D(w[k>>1],e)+D(w[k-4>>1],g)|0)+D(i,w[k+4>>1])|0)+D(h,w[k+8>>1])|0)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+28|0)+(b<<3)|0;p=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=yka(s,B,e,e>>31);i=hb;l=e;e=Ub(h,-16777216,16776704);e=yka(r,A,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Ub(p,-16777216,16776704);i=yka(q,z,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Lc(i,e,24);x[g+4>>2]=e-(j&y);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}n=n+v|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],n>>12);m=m+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],m>>12);Qb(f+16|0,o,C);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}db=f+48|0}function mda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0;f=db-48|0;db=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;o=g+(f+28|0)|0;g=a+g|0;x[o+4>>2]=x[g+44>>2];x[o+8>>2]=x[g+48>>2];b=b+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];y=x[a+28>>2];z=x[a+72>>2];q=x[a+68>>2];A=q>>31;r=x[a+64>>2];B=r>>31;s=x[a+60>>2];C=s>>31;o=x[a+8>>2];E=x[a+12>>2];while(1){if(d){b=x[f+16>>2];p=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=b>>>21&2040;h=w[b+39942>>1];i=w[b+39940>>1];e=w[b+39938>>1];g=w[b+39936>>1];b=0;j=0;while(1){if((j|0)!=2){k=j+p|0;x[(f+8|0)+(j<<2)>>2]=(((D(v[k|0],e)+D(v[k-2|0],g)|0)+D(i,v[k+2|0])|0)+D(h,v[k+4|0])<<8)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+28|0)+(b<<3)|0;p=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=yka(s,C,e,e>>31);i=hb;l=e;e=Ub(h,-16777216,16776704);e=yka(r,B,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Ub(p,-16777216,16776704);i=yka(q,A,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Lc(i,e,24);x[g+4>>2]=e-(j&z);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}n=n+y|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],n>>12);m=m+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],m>>12);Qb(f+16|0,o,E);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}db=f+48|0}function Zn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;x[b+88>>2]=x[b+88>>2]|524288;a:{b:{if(!(y[a+480208|0]&8)){if(Ob(a+1074312|0,15)|x[a+480180>>2]==268435456){break b}break a}if(x[a+480180>>2]!=268435456){break a}}c=c?c:y[b+811|0];v[b+812|0]=c;v[b+811|0]=c}if(c){w[b+768>>1]=c}c:{d=x[b+656>>2];d:{if(gj(d)){c=z[b+768>>1];if(!c){break d}e=x[b+856>>2];f=x[a+1074392>>2];h=0-c|0;i=c;c=x[b+708>>2];g=(+(f>>>0)+1)*+(((c|0)<0?h:i)|0)/+A[a+1074416>>2];e:{if(F(g)<2147483648){a=~~g;break e}a=-2147483648}x[b+856>>2]=a;if(y[b+90|0]&16){a=D(x[x[d+44>>2]+36>>2]+1|0,a);x[b+856>>2]=a}a=a-(f?e:0)|0;d=a>>31;e=c>>31;if((e^c)-e>>>0<=(a^d)-d>>>0){if(!c){break d}x[b+708>>2]=0;x[b+852>>2]=c+x[b+852>>2];break c}x[b+708>>2]=c-a;x[b+852>>2]=a+x[b+852>>2];break c}c=1;f:{if(!(v[b+851|0]&1)){break f}d=x[a+480180>>2];if(d&524352){break f}if(x[a+1074416>>2]==1){if(Ob(a+1074312|0,6)){break f}d=x[a+480180>>2]}c=0;if((d|0)!=8){break f}c=(y[a+480208|0]&2)>>>1|0}g:{if(!x[b+700>>2]|!x[b+708>>2]){break g}e=x[a+480180>>2];d=z[b+768>>1];f=(e|0)==268435456&d>>>0>239;if(!((f?y[b+851|0]:c)&1)){break g}c=b+700|0;d=(f?d-240|0:d)<<((e|0)==64?1:2);d=Zi(a)?d:0-d|0;e=x[b+700>>2];f=x[b+708>>2];if(!(!(y[b+851|0]&16)&(e|0)>=(f|0))){Oj(a,b,c,d,1);d=x[b+708>>2];if((d|0)>=x[b+700>>2]){break g}x[c>>2]=d;break g}if((e|0)<=(f|0)){break g}Oj(a,b,c,0-d|0,1);e=x[b+700>>2];d=x[b+708>>2];h:{if((e|0)<(d|0)){x[c>>2]=d;break h}if((d|0)!=(e|0)){break g}}if(!Ob(a+1074312|0,112)){break g}v[b+851|0]=y[b+851|0]|16}if(x[b+700>>2]!=x[b+708>>2]){break d}if(!Ob(a+1074312|0,25)&x[a+480180>>2]!=1){break d}x[b+708>>2]=0}return}v[b+851|0]=y[b+851|0]|64}function Gga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=db-32|0;db=d;a:{b:{c:{d:{e:{f:{if(ud(x[a+24>>2])){break f}j=Oc(x[a+8>>2],y[a+15|0]);f=db-16|0;db=f;h=f+8|0;x[h>>2]=-1;x[h+4>>2]=-1;x[23549]=0;g=BF(38);c=x[23549];x[23549]=0;b=hb;if((c|0)==1){T(0)|0;Rb();p()}e=db-16|0;db=e;c=Ph(e+8|0,yka(g,b,1e3,0),hb);b=x[c>>2];db=e+16|0;k=f,l=bA(b,x[c+4>>2]),x[k>>2]=l;x[f+4>>2]=hb;e=HR(h,f,wb(f));x[23549]=0;g=BF(39);c=x[23549];x[23549]=0;b=hb;if((c|0)==1){T(0)|0;Rb();p()}i=a+24|0;h=db-16|0;db=h;c=Ph(h+8|0,g,b);b=x[c>>2];db=h+16|0;k=f,l=bA(b,x[c+4>>2]),x[k>>2]=l;x[f+4>>2]=hb;b=HR(e,f,wb(f));c=x[b>>2];b=x[b+4>>2];db=f+16|0;if(j){e=Nb(d+20|0);x[23549]=0;x[d+8>>2]=b;P(32,e|0,d+8|0);b=x[23549];x[23549]=0;if((b|0)==1){break c}x[23549]=0;x[d+8>>2]=c;P(32,e|0,d+8|0);b=x[23549];x[23549]=0;if((b|0)==1){break d}c=a+4|0;g=0;g:{while(1){if(Oc(x[a+8>>2],y[a+15|0])>>>0<=g>>>0){b=yb(x[e>>2]);a=yb(x[e+4>>2]);x[23549]=0;c=U(33,d+8|0,b|0,a|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){break g}a=N()|0;break b}b=y[uc(c,g)|0];x[23549]=0;x[d+8>>2]=b;P(32,e|0,d+8|0);b=x[23549];x[23549]=0;if((b|0)!=1){g=g+1|0;continue}break}a=N()|0;break b}x[23549]=0;b=R(34,c|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){x[d+4>>2]=b;a=d+4|0;gA(i,a);ij(a);um(c);sc(e);break f}a=N()|0;um(c);break b}hb=c;x[d+8>>2]=b;x[d+12>>2]=hb;b=Nb(d+20|0);x[23549]=0;S(37,b|0,d+8|0,d+16|0);a=x[23549];x[23549]=0;if((a|0)==1){a=N()|0;sc(b);Q(a|0);p()}x[23549]=0;c=R(34,b|0)|0;a=x[23549];x[23549]=0;if((a|0)==1){break e}x[d+4>>2]=c;a=d+4|0;gA(i,a);ij(a);um(b)}db=d+32|0;return}a=N()|0;um(b);break a}a=N()|0;break b}a=N()|0}sc(e)}Q(a|0);p()}function Lq(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=db-16|0;db=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=y[a|0];switch(d|0){case 1:case 6:case 7:case 8:case 10:case 12:case 14:case 15:case 16:case 17:case 18:case 19:break a;case 2:break j;case 13:break k;case 0:break l;case 5:break c;case 9:break e;case 11:break f;case 20:break g;case 4:break h;case 3:break i;default:break d}}v[a|0]=0;break b}e=1;v[a|0]=1;v[f+15|0]=64;h=b,i=y[Sb(b,f+15|0)|0],v[h|0]=i;break a}d=c;c=y[b|0];if(!(c&3|c>>>0>223?d:1)){break a}v[b|0]=(c&252)>>>2;v[a|0]=12;break b}d=c;c=y[b|0];if(!(c&3|c>>>0>223?d:1)){break a}v[b|0]=(c&252)>>>2;v[a|0]=13;break b}d=y[b|0];if(d>>>0<240){while(1){if((e|0)==10){e=0;break a}g=y[e+43968|0];m:{n:{if(c){if(d>>>0<=g>>>0){break n}break m}if((d|0)!=(g|0)){break m}}v[a|0]=11;v[b|0]=e;e=e>>>0<10;break a}e=e+1|0;continue}}v[a|0]=11;v[b|0]=9;break b}o:{p:{q:{d=y[b|0]>>>4|0;switch(d|0){case 3:case 4:case 5:case 6:case 7:break a;case 8:break o;case 0:case 1:case 2:break p;default:break q}}if((d|0)!=15){break a}}if(!c){break a}v[b|0]=0;v[a|0]=0;break b}v[a|0]=2;v[b|0]=y[b|0]<<2&60|2;break b}c=y[b|0];if(!c){break a}d=c&15;if(!d){v[b|0]=c>>>4;v[a|0]=3;break b}g=c&240;if(!g){v[a|0]=4;break b}if((d|0)==15){v[b|0]=c>>>4;v[a|0]=5;break b}if((g|0)!=240){break a}v[b|0]=d;v[a|0]=6;break b}c=b;b=y[b|0];v[c|0]=(b|0)==255?64:b>>>2|0;v[a|0]=2;break b}if((d|0)!=26){break a}r:{if(c){v[b|0]=0;break r}if(y[b|0]){break a}}v[a|0]=8;break b}s:{if(c){v[f+14|0]=y[b|0]&15;v[f+13|0]=9;c=y[Sb(f+14|0,f+13|0)|0];break s}c=y[b|0];if(c>>>0>15|(c&14)>>>0>9){break a}}v[b|0]=c&15;v[a|0]=8}e=1}db=f+16|0;return e}function dQ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{d=b;e=x[b>>2];if(e){if(!x[b+4>>2]){break b}g=x[b+4>>2];c:{if(!g){while(1){g=qh(d);d=x[d+8>>2];if(!g){continue}break}break c}d=jT(g)}e=x[d>>2];if(e){break b}}e=x[d+4>>2];if(e){break b}e=0;g=1;break a}x[e+8>>2]=x[d+8>>2];g=0}d:{e:{if(qh(d)){c=x[d+8>>2];x[c>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=c+4|0;break e}c=x[d+8>>2];x[c+4>>2]=e}c=x[c>>2]}h=!y[d+12|0];if((b|0)!=(d|0)){f=x[b+8>>2];x[d+8>>2]=f;i=f+(qh(b)?0:4)|0,j=d,x[i>>2]=j;f=x[b>>2];x[d>>2]=f;Zl(f,d);f=x[b+4>>2];x[d+4>>2]=f;if(f){Zl(f,d)}v[d+12|0]=y[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=y[c+12|0];f:{g:{if(!qh(c)){if(!b){v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;pq(b);b=x[c>>2];a=(b|0)==(a|0)?c:a;c=x[b+4>>2]}b=x[c>>2];h:{if(!(y[b+12|0]?0:b)){b=x[c+4>>2];if(y[b+12|0]?0:b){break h}v[c+12|0]=0;i:{b=x[c+8>>2];if((b|0)!=(a|0)){if(y[b+12|0]){break i}a=b}v[a+12|0]=1;return}if(!qh(b)){break g}b=x[b+8>>2]+4|0;break f}a=x[c+4>>2];if(y[a+12|0]?0:a){break h}v[b+12|0]=1;v[c+12|0]=0;oq(c);c=x[c+8>>2]}a=x[c+8>>2];v[c+12|0]=y[a+12|0];v[a+12|0]=1;v[x[c+4>>2]+12|0]=1;pq(a);return}if(!b){v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;oq(b);b=x[c+4>>2];a=(b|0)==(a|0)?c:a;c=x[b>>2]}d=x[c>>2];j:{if(y[d+12|0]?0:d){break j}b=x[c+4>>2];if(!(y[b+12|0]?0:b)){v[c+12|0]=0;b=x[c+8>>2];if(!((a|0)!=(b|0)?y[b+12|0]:0)){v[b+12|0]=1;return}if(qh(b)){b=x[b+8>>2]+4|0;break f}b=x[b+8>>2];break f}if(y[d+12|0]?0:d){break j}v[b+12|0]=1;v[c+12|0]=0;pq(c);c=x[c+8>>2];d=x[c>>2]}a=x[c+8>>2];v[c+12|0]=y[a+12|0];v[a+12|0]=1;v[d+12|0]=1;oq(a);return}b=x[b+8>>2]}c=x[b>>2];continue}}v[e+12|0]=1}}function y$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=db-624|0;db=a;x[a+616>>2]=c;x[a+620>>2]=b;x[a+16>>2]=1136;h=pe(a+200|0,a+208|0,a+16|0);Nc(a+192|0,x[e+28>>2]);x[23549]=0;i=R(1115,x[a+192>>2])|0;b=x[23549];x[23549]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){v[a+191|0]=0;b=x[e+4>>2];x[23549]=0;b=la(1145,a+620|0,c|0,d|0,a+192|0,b|0,f|0,a+191|0,i|0,h|0,a+196|0,a+608|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break d}if(!b){break e}b=y[14313]|y[14314]<<8|(y[14315]<<16|y[14316]<<24);v[a+183|0]=b;v[a+184|0]=b>>>8;v[a+185|0]=b>>>16;v[a+186|0]=b>>>24;b=y[14310]|y[14311]<<8|(y[14312]<<16|y[14313]<<24);x[a+176>>2]=y[14306]|y[14307]<<8|(y[14308]<<16|y[14309]<<24);x[a+180>>2]=b;x[23549]=0;V(1126,i|0,a+176|0,a+186|0,a+128|0);b=x[23549];x[23549]=0;if((b|0)==1){break g}x[a+4>>2]=1103;d=pe(a+8|0,0,a+4|0);e=a+16|0;b=x[a+196>>2];c=b-x[h>>2]|0;if((c|0)<393){break f}Me(d,Nd((c>>2)+2|0));e=x[d>>2];if(e){break f}x[23549]=0;X(1104);b=x[23549];x[23549]=0;if((b|0)==1){break c}break a}c=N()|0;break b}c=N()|0;break b}if(y[a+191|0]){v[e|0]=45;e=e+1|0}c=x[h>>2];while(1){if(b>>>0<=c>>>0){v[e|0]=0;x[a>>2]=g;if((mH(a+16|0,a)|0)!=1){x[23549]=0;W(1138,7898);b=x[23549];x[23549]=0;if((b|0)!=1){break a}break c}Kc(d)}else{b=a+128|0;j=e,k=y[(a+176|0)+(vw(b,b+40|0,x[c>>2])-b>>2)|0],v[j|0]=k;e=e+1|0;c=c+4|0;b=x[a+196>>2];continue}break}}x[23549]=0;b=O(1120,a+620|0,a+616|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break d}if(b){x[f>>2]=x[f>>2]|2}b=x[a+620>>2];Xb(a+192|0);Kc(h);db=a+624|0;return b|0}c=N()|0;break b}c=N()|0;Kc(d)}Xb(a+192|0);Kc(h);Q(c|0);p()}p()}function ZQ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;m=db-16|0;db=m;a:{if((b|0)==(c|0)){break a}x[m+12>>2]=-1953789045;Uz(b,c,m+12|0);k=c-b|0;c=k>>2;x[m+8>>2]=c;e=oc(x[a>>2],x[a+4>>2]);d=11;b:{if(k>>>0>2488){break b}d=7;if(k>>>0>268){break b}d=5;if(k>>>0>152){break b}d=3;if(k>>>0>24){break b}d=c-1>>>1|0}i=e+1|0;x[m+4>>2]=i;k=x[Yc(m+4|0,m+8|0)>>2];h=c-d>>>1|0;f=(h<<2)+b|0;l=x[f>>2];g=c-1|0;j=D(At(l^(x[b>>2]^x[(g<<2)+b>>2])),1664525);x[f>>2]=j+l;f=d+h|0;d=(f<<2)+b|0;l=d;n=x[d>>2];d=e+j|0;x[l>>2]=n+d;x[b>>2]=d;l=i>>>0<=1?1:i;d=(h>>>0)%(c>>>0)|0;e=(f>>>0)%(c>>>0)|0;f=x[a>>2];h=1;a=0;while(1)if((h|0)==(l|0)){while(1)if(k>>>0<=i>>>0){i=c+k|0;h=k>>>0>i>>>0?k:i;while(1){if((h|0)==(k|0)){break a}g=g+1|0;g=(c|0)!=(g|0)?g:0;d=d+1|0;d=(c|0)!=(d|0)?d:0;f=(d<<2)+b|0;l=x[f>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;j=(a<<2)+b|0;i=D(At(x[(g<<2)+b>>2]+(l+x[j>>2]|0)|0),1566083941);x[f>>2]=i^l;e=e+1|0;e=(c|0)!=(e|0)?e:0;f=(e<<2)+b|0;i=i-a|0;x[f>>2]=i^x[f>>2];x[j>>2]=i;k=k+1|0;continue}}else{d=d+1|0;d=(c|0)!=(d|0)?d:0;f=(d<<2)+b|0;l=x[f>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;j=(a<<2)+b|0;g=g+1|0;g=(c|0)!=(g|0)?g:0;h=D(At(l^(x[j>>2]^x[(g<<2)+b>>2])),1664525);x[f>>2]=h+l;e=e+1|0;e=(c|0)!=(e|0)?e:0;f=(e<<2)+b|0;h=a+h|0;x[f>>2]=h+x[f>>2];x[j>>2]=h;i=i+1|0;continue}}else{d=d+1|0;d=(c|0)!=(d|0)?d:0;n=(d<<2)+b|0;o=x[n>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;p=(a<<2)+b|0;g=g+1|0;g=(c|0)!=(g|0)?g:0;j=D(At(o^(x[p>>2]^x[(g<<2)+b>>2])),1664525);x[n>>2]=j+o;j=x[xb(f,h-1|0)>>2]+(a+j|0)|0;e=e+1|0;e=(c|0)!=(e|0)?e:0;n=(e<<2)+b|0;x[n>>2]=j+x[n>>2];x[p>>2]=j;h=h+1|0;continue}}db=m+16|0}function F$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=db-272|0;db=a;x[a+264>>2]=c;x[a+268>>2]=b;x[a+16>>2]=1136;h=pe(a+152|0,a+160|0,a+16|0);Nc(a+144|0,x[e+28>>2]);x[23549]=0;i=R(18,x[a+144>>2])|0;b=x[23549];x[23549]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){v[a+143|0]=0;b=x[e+4>>2];x[23549]=0;b=la(1137,a+268|0,c|0,d|0,a+144|0,b|0,f|0,a+143|0,i|0,h|0,a+148|0,a+260|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break d}if(!b){break e}b=y[14313]|y[14314]<<8|(y[14315]<<16|y[14316]<<24);v[a+135|0]=b;v[a+136|0]=b>>>8;v[a+137|0]=b>>>16;v[a+138|0]=b>>>24;b=y[14310]|y[14311]<<8|(y[14312]<<16|y[14313]<<24);x[a+128>>2]=y[14306]|y[14307]<<8|(y[14308]<<16|y[14309]<<24);x[a+132>>2]=b;x[23549]=0;V(1113,i|0,a+128|0,a+138|0,a+118|0);b=x[23549];x[23549]=0;if((b|0)==1){break g}x[a+4>>2]=1103;d=pe(a+8|0,0,a+4|0);e=a+16|0;b=x[a+148>>2];c=b-x[h>>2]|0;if((c|0)<99){break f}Me(d,Nd(c+2|0));e=x[d>>2];if(e){break f}x[23549]=0;X(1104);b=x[23549];x[23549]=0;if((b|0)==1){break c}break a}c=N()|0;break b}c=N()|0;break b}if(y[a+143|0]){v[e|0]=45;e=e+1|0}c=x[h>>2];while(1){if(b>>>0<=c>>>0){v[e|0]=0;x[a>>2]=g;if((mH(a+16|0,a)|0)!=1){x[23549]=0;W(1138,7898);b=x[23549];x[23549]=0;if((b|0)!=1){break a}break c}Kc(d)}else{b=a+118|0;j=e,k=y[((oi(b,b+10|0,y[c|0])-a|0)+a|0)+10|0],v[j|0]=k;e=e+1|0;c=c+1|0;b=x[a+148>>2];continue}break}}x[23549]=0;b=O(1105,a+268|0,a+264|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break d}if(b){x[f>>2]=x[f>>2]|2}b=x[a+268>>2];Xb(a+144|0);Kc(h);db=a+272|0;return b|0}c=N()|0;break b}c=N()|0;Kc(d)}Xb(a+144|0);Kc(h);Q(c|0);p()}p()}function jea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=db-32|0;db=e;w[e+30>>1]=254;d=cj(a);c=db-16|0;db=c;f=e+16|0;x[f>>2]=0;x[f+4>>2]=0;xc(f+8|0);Id(c+8|0,x[vb(c+4|0,f)>>2]);a:{b:{if(d){x[23549]=0;P(581,f|0,d|0);g=x[23549];x[23549]=0;if((g|0)==1){break b}uC(f,d)}g=c+8|0;Hd(g);ll(g);db=c+16|0;break a}a=N()|0;ll(c+8|0);Q(a|0);p()}c:{d:{while(1){e:{if((b|0)==(d|0)){if(!(h&65535)){break c}b=yb(x[a>>2]);d=yb(x[a+4>>2]);c=db-16|0;db=c;b=rA(b,d,z[e+30>>1]);x[c+12>>2]=b;if(Kb(b,d)){x[c+8>>2]=b;while(1){b=x[Se(c+8|0)>>2];if(Kb(b,d)){b=z[b>>1];if((b|0)==z[e+30>>1]){continue}w[x[c+12>>2]>>1]=b;Se(c+12|0);continue}break}b=x[c+12>>2]}db=c+16|0;b=vb(e+12|0,b);c=x[vb(e+8|0,yb(x[a+4>>2]))>>2];d=x[b>>2];b=x[a>>2];b=(Fo(d,yb(b))<<1)+b|0;if(Kb(d,c)){Dd(a,_g(b+(Fo(c,d)<<1)|0,x[a+4>>2],b))}yb(b);k=e,l=yb(x[a>>2]),x[k+4>>2]=l;d=yb(x[a+4>>2]);break e}k=_b(x[f>>2],b),l=b-h|0,w[k>>1]=l;c=x[a+4>>2];g=x[a>>2];x[23549]=0;c=U(719,g|0,c|0,b|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}b=b+1|0;h=(z[c>>1]==254)+h|0;continue}break}while(1){b=x[e+4>>2];if(Kb(b,d)){f:{c=x[a+24>>2];h=x[c+484344>>2];b=z[b>>1];if(!se(h,x[c+484348>>2],b)){break f}b=Yb(h,b);k=e,l=yb(x[b>>2]),x[k>>2]=l;h=yb(x[b+4>>2]);g=x[f+4>>2];c=x[f>>2];while(1){b=x[e>>2];if(!Kb(b,h)){break f}g:{if(y[b+3|0]!=12){break g}j=Ic(c,g);i=y[b+5|0];if(j>>>0<=i>>>0){break g}k=b,l=y[_b(c,i)|0],v[k+5|0]=l}lk(e);continue}}Se(e+4|0);continue}else{b=x[f>>2];d=Ic(b,x[f+4>>2]);c=z[a+28>>1];if(d>>>0<=c>>>0){break c}k=a,l=z[_b(b,c)>>1],w[k+28>>1]=l;break c}}}a=N()|0;id(f);Q(a|0);p()}id(f);db=e+32|0}function eaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=x[a>>2];d=kk(e,x[a+4>>2]);if(d>>>0<b>>>0){i=db-32|0;db=i;a:{b:{g=b-d|0;b=x[wb(a)>>2];e=x[a+4>>2];c:{if(g>>>0<=(b-e|0)/52>>>0){cy(a,g,c);break c}f=wb(a);d=jM(a,kk(x[a>>2],e)+g|0);j=kk(x[a>>2],x[a+4>>2]);h=db-16|0;db=h;b=i+12|0;Hf(b+12|0,f);d:{if(!d){e=0;d=0;break d}iM(h+8|0,d);e=x[h+12>>2];d=x[h+8>>2]}x[b>>2]=d;f=d+D(j,52)|0;x[b+8>>2]=f;x[b+4>>2]=f;l=kc(b),m=d+D(e,52)|0,x[l>>2]=m;db=h+16|0;x[23549]=0;S(859,b|0,g|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}h=db-16|0;db=h;c=wb(a);d=vb(h+12|0,x[a+4>>2]);g=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[b+4>>2]);e=x[d>>2];g=x[g>>2];d=db+-64|0;db=d;f=x[f>>2];x[d+56>>2]=f;x[d+60>>2]=e;x[d+52>>2]=f;c=rd(d+24|0,c,d+52|0,d+56|0);x[d+16>>2]=x[c+8>>2];f=x[c+4>>2];x[d+8>>2]=x[c>>2];x[d+12>>2]=f;Ke(d+36|0,d+8|0);while(1){if(sd(e,g)){k=by(x[d+56>>2]);c=by(e);e=Zj(k,c);x[e+20>>2]=x[c+20>>2];f=x[c+16>>2];x[e+12>>2]=x[c+12>>2];x[e+16>>2]=f;Zj(e+24|0,c+24|0);ad(e+36|0,c+36|0);x[e+48>>2]=x[c+48>>2];c=fM(d+60|0);fM(d+56|0);e=x[c>>2];continue}break}Je(d+36|0);j=x[d+56>>2];if(!y[d+48|0]){e=db-16|0;db=e;c=vb(e+12|0,x[x[d+44>>2]>>2]);k=x[vb(e+8|0,x[x[d+40>>2]>>2])>>2];g=db-16|0;db=g;c=x[c>>2];x[g+12>>2]=c;while(1){if(ai(c,k)){f=db-16|0;db=f;x[f+12>>2]=c;c=by(x[so(f+12|0)>>2]);db=f+16|0;Nj(c);c=x[so(g+12|0)>>2];continue}break}db=g+16|0;db=e+16|0}db=d- -64|0;x[b+4>>2]=j;Pb(a,b+4|0);Pb(a+4|0,b+8|0);Pb(wb(a),kc(b));x[b>>2]=x[b+4>>2];db=h+16|0;hM(b)}db=i+32|0;break a}a=N()|0;hM(b);Q(a|0);p()}return}if(b>>>0<d>>>0){kM(a,e+D(b,52)|0)}}function mia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=db-16|0;db=g;i=jf(a,c);ae(g,x[a+28>>2]);j=a;a:{if(!i){c=0;if(ed(a,5)){break a}}e=db-176|0;db=e;f=Pl(e+72|0,x[a+28>>2]);x[23549]=0;a=O(403,e+60|0,27871)|0;c=x[23549];x[23549]=0;b:{c:{d:{e:{if((c|0)!=1){x[23549]=0;x[e>>2]=19927555;x[e+4>>2]=0;S(404,f|0,a|0,e|0);c=x[23549];x[23549]=0;if((c|0)==1){break e}Ab(a);if(!(y[f+3|0]&64)){break d}break b}c=N()|0;break c}c=N()|0;Ab(a);break c}v[e+59|0]=0;v[e+58|0]=0;x[23549]=0;a=O(403,e+44|0,9977)|0;c=x[23549];x[23549]=0;f:{g:{h:{i:{if((c|0)!=1){x[23549]=0;S(443,f|0,e+59|0,a|0);c=x[23549];x[23549]=0;if((c|0)==1){break i}Ab(a);if(!y[e+59|0]){break b}pf(e+59|0,50);x[23549]=0;a=O(403,e+32|0,13078)|0;c=x[23549];x[23549]=0;if((c|0)==1){break f}x[23549]=0;S(443,f|0,e+58|0,a|0);c=x[23549];x[23549]=0;if((c|0)==1){break g}Ab(a);a=x[b>>2];c=bj(a,x[b+4>>2]);h=y[e+59|0];if(c>>>0<h>>>0){a=Dz(e,x[b+12>>2]);x[23549]=0;S(444,b|0,h|0,a|0);c=x[23549];x[23549]=0;if((c|0)==1){break h}Tj(a);a=x[b>>2]}k=z[jj(a,0)+28>>1];c=0;j:{while(1){a=c&255;if(a>>>0>=h>>>0){a=y[e+58|0];n=b,o=bj(x[b>>2],x[b+4>>2])>>>0>a>>>0?a:0,v[n+16|0]=o;break b}$e(jj(x[b>>2],a),k);l=x[b>>2];x[23549]=0;P(445,e|0,c|0);m=x[23549];x[23549]=0;if((m|0)!=1){x[23549]=0;V(446,f|0,jj(l,a)|0,e|0,d|0);a=x[23549];x[23549]=0;if((a|0)==1){break j}c=c+1|0;Ab(e);continue}break}c=N()|0;break c}c=N()|0;Ab(e);break c}c=N()|0;break c}c=N()|0;Ab(a);break c}c=N()|0;Tj(a);break c}c=N()|0;Ab(a);break c}c=N()|0}Zg(f);Q(c|0);p()}Zg(f);db=e+176|0;c=i}cf(j,c);db=g+16|0}function l$(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0;x[c>>2]=a;w=d&512;z=h<<2;while(1){if((u|0)==4){if(Bb(x[n+4>>2],y[n+11|0])>>>0>1){B=c,C=rG(Yj(od(n),1),Hk(n),x[c>>2]),x[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}}else{a:{b:{switch(v[i+u|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];h=Yr(g,32);p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 3:if(xd(x[n+4>>2],y[n+11|0])){break a}h=x[_i(n,0)>>2];p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 2:if(xd(x[m+4>>2],y[m+11|0])|!w){break a}B=c,C=rG(od(m),Hk(m),x[c>>2]),x[B>>2]=C;break a;case 4:break b;default:break a}}A=x[c>>2];e=e+z|0;h=e;while(1){c:{if(f>>>0<=h>>>0){break c}if(!Jk(g,64,x[h>>2])){break c}h=h+4|0;continue}break}if((o|0)>0){p=x[c>>2];q=o;while(1){if(!(!q|e>>>0>=h>>>0)){q=q-1|0;h=h-4|0;s=x[h>>2];r=p+4|0;x[c>>2]=r;x[p>>2]=s;p=r;continue}break}d:{if(!q){s=0;break d}s=Yr(g,48);p=x[c>>2]}while(1){r=p+4|0;if((q|0)>0){x[p>>2]=s;q=q-1|0;p=r;continue}break}x[c>>2]=r;x[p>>2]=j}e:{if((e|0)==(h|0)){p=Yr(g,48);q=x[c>>2];h=q+4|0;x[c>>2]=h;x[q>>2]=p;break e}s=-1;if(!xd(x[l+4>>2],y[l+11|0])){s=v[uc(l,0)|0]}q=0;t=0;while(1){if((e|0)!=(h|0)){r=x[c>>2];f:{if((q|0)!=(s|0)){p=r;r=q;break f}p=r+4|0;x[c>>2]=p;x[r>>2]=k;r=0;t=t+1|0;if(Bb(x[l+4>>2],y[l+11|0])>>>0<=t>>>0){s=q;break f}s=-1;if(y[uc(l,t)|0]==127){break f}s=v[uc(l,t)|0]}h=h-4|0;q=x[h>>2];x[c>>2]=p+4;x[p>>2]=q;q=r+1|0;continue}break}h=x[c>>2]}Qr(A,h)}u=u+1|0;continue}break}}function X4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=db-32|0;db=c;f=Nb(a);a:{b:{c:{a=x[b+36>>2];d=x[b+40>>2];d:{if(Kb(a,d)){xc(c+28|0);break d}x[23549]=0;P(1002,c+16|0,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break b}x[23549]=0;a=R(986,c+16|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break c}x[c+28>>2]=a;Yf(c+16|0);d=x[b+40>>2];a=x[b+36>>2]}e:{if(Kb(a,d)){d=b+36|0;break e}d=x[c+28>>2];a=x[d>>2]}g=x[d+4>>2];x[23549]=0;P(167,f|0,Mn(a,g)|0);a=x[23549];x[23549]=0;f:{if((a|0)!=1){i=c,j=yb(x[d>>2]),x[i+12>>2]=j;g=yb(x[d+4>>2]);g:{h:{i:{j:{k:{l:{while(1){a=x[c+12>>2];if(!Kb(a,g)){Qk(c+28|0);db=c+32|0;return}d=y[a+16|0];e=x[x[b+24>>2]+484360>>2];x[23549]=0;d=jj(e,d);P(1003,c|0,d|0);e=x[23549];x[23549]=0;if((e|0)!=1){x[23549]=0;P(989,c+16|0,c|0);e=x[23549];x[23549]=0;if((e|0)==1){break l}x[23549]=0;P(169,f|0,c+16|0);e=x[23549];x[23549]=0;if((e|0)==1){break k}tb(c+16|0);tb(c);e=dh(x[f+4>>2]);m:{if(!xd(x[e+4>>2],y[e+11|0])){break m}e=y[a+12|0];x[23549]=0;e=O(299,d|0,e|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break g}if(!e){break m}e=x[b+24>>2];h=x[e+1298404>>2];a=z[_b(x[d>>2],x[a+12>>2])>>1];d=x[e+484344>>2];x[23549]=0;P(996,c|0,Yb(d,a)|0);a=x[23549];x[23549]=0;if((a|0)==1){break i}x[23549]=0;V(224,c+16|0,0,h|0,c|0);a=x[23549];x[23549]=0;if((a|0)==1){break h}a=c+16|0;zb(dh(x[f+4>>2]),a);tb(a);tb(c)}qJ(c+12|0);continue}break}a=N()|0;break f}a=N()|0;break j}a=N()|0;tb(c+16|0)}tb(c);break f}a=N()|0;break f}a=N()|0;tb(c);break f}a=N()|0;break f}a=N()|0}Qk(c+28|0);break a}a=N()|0;Yf(c+16|0);break a}a=N()|0}Yd(f);Q(a|0);p()}function Ws(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=db-128|0;db=f;a:{b:{c:{d:{e:{f:{g:{h:{if(!c){break h}d=x[c+4>>2];if(!d&A[c>>2]>=A[b+4>>2]|d){break h}a=ac(8);x[23549]=0;b=O(26,a|0,21204)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break g}b=N()|0;jc(a);break a}if(!x[b>>2]){a=ac(8);x[23549]=0;b=R(792,a|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break f}b=N()|0;jc(a);break a}d=x[b>>2];j=x[b+4>>2];b=db-16|0;db=b;Ng(b+8|0,d,j);h=x[b+8>>2];g=f+108|0;YD(g,h,x[b+12>>2]);x[g+12>>2]=0;db=b+16|0;i:{j:{if(a&2){b=Um(f+88|0,g);x[23549]=0;b=R(793,b|0)|0;e=x[23549];x[23549]=0;d=1;if((e|0)==1){break i}if((b|0)==1){break j}d=Um(f+68|0,g);x[23549]=0;e=R(794,d|0)|0;h=x[23549];x[23549]=0;d=1;if((h|0)==1){break e}k=(e|0)==1;if(k){break j}d=Um(f+48|0,g);x[23549]=0;h=O(795,d|0,c|0)|0;i=x[23549];x[23549]=0;d=1;if((i|0)==1){break d}l=(h|0)==1;if(l){break j}d=Um(f+28|0,g);x[23549]=0;i=O(796,d|0,c|0)|0;m=x[23549];x[23549]=0;d=1;if((m|0)==1){break c}if((i|0)==1){break j}b=(b|0)==-1?-1:0;b=k?b:(e|0)==-1?-1:b;e=(i|0)==-1?-1:l?b:(h|0)==-1?-1:b}k:{if(!(a&1)){break k}b=31616;while(1){if((b|0)==32132){break k}a=x[b>>2];if(a){d=Um(f+8|0,g);x[23549]=0;a=O(a|0,d|0,c|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break b}d=1;if((a|0)==1){break j}e=(a|0)==-1?-1:e}b=b+12|0;continue}}a=j;if(c){d=0;if((e|0)!=-1){break j}d=Qc(x[c>>2],x[c+4>>2])>>>0>a>>>0?-1:0;break j}d=0;if((e|0)!=-1){break j}d=a>>>0>2047?1:-1}db=f+128|0;return d}b=N()|0;break a}da(b|0,92588,24);p()}da(b|0,92484,24);p()}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}b=N()|0}Q(b|0);p()}function HN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=db-16|0;db=c;d=a+1074376|0;e=D(b,872);a:{if(x[(d+e|0)+704>>2]&134218752){break a}g=x[(a+e|0)+1075648>>2];if(!Pj(g)|y[g+15|0]&2){break a}d=Dl(a,d,b,2,1);if((d-1&255)>>>0>249){break a}h=x[(D(d,160)+a|0)+906140>>2];if(!h){break a}f=D(b,872)+a|0;d=y[f+1075780|0];b:{if(y[f+1075782|0]==1){v[c+8|0]=64;e=y[Sb(f+1075784|0,c+8|0)|0];break b}e=255;if(y[f+1075783|0]!=13){break b}v[c+8|0]=64;e=y[Sb((D(b,872)+a|0)+1075785|0,c+8|0)|0]}i=a+1074312|0;Fb(c+8|0,i,2);if(Ib(x[x[c+8>>2]>>2],x[c+12>>2])){if(d){if(Tc(d)){d=y[Db(g+108|0,d-1|0)|0]}fm(a,b,d&255,z[(D(b,872)+a|0)+1075680>>1]);break a}if((e|0)==255){break a}ib[x[x[h>>2]+76>>2]](h,39,e,b);break a}j=x[g+4>>2];if(d){f=y[g+35|0]?j<<2:x[(D(b,872)+a|0)+1075680>>2];k=w[(D(b,872)+a|0)+1075768>>1];Fb(c+8|0,i,28);l=c,m=f+(Ib(x[x[c+8>>2]>>2],x[c+12>>2])?k<<2:k)|0,x[l+4>>2]=m;ke(c+4|0,0,256);f=a;if(Tc(d)){a=y[Db(g+108|0,d-1|0)|0]}else{a=d}fm(f,b,a&255,z[c+4>>1])}a=y[g+35|0];Fb(c+8|0,i,101);a=(a|0)==1;f=(e|0)!=255;if(!Ib(x[x[c+8>>2]>>2],x[c+12>>2])){d=Tc(d)}if(((d?a:f)|0)!=1){break a}c:{switch(y[g+36|0]){case 1:a=x[h+20>>2];if((e|0)!=255){bt(a,E(E(E(e<<1)/E(-127))+E(1)));break a}bt(a,E(E(E(j<<1>>>0)/E(-127))+E(1)));break a;case 0:break c;default:break a}}if((e|0)!=255){v[c+8|0]=127;v[c+4|0]=e<<1;m=h,n=7,o=y[Sb(c+8|0,c+4|0)|0],p=b,l=x[x[h>>2]+76>>2],ib[l](m|0,n|0,o|0,p|0);break a}x[c+8>>2]=127;x[c+4>>2]=j<<1;p=h,o=7,n=y[Cb(c+8|0,c+4|0)|0],m=b,l=x[x[h>>2]+76>>2],ib[l](p|0,o|0,n|0,m|0)}db=c+16|0}function gL(a){var b=E(0),c=0,d=0,e=0,f=0,g=E(0),h=0,i=0,k=0,l=E(0),m=0,n=E(0);c=db-16|0;db=c;e=a+4208|0;b=Fx(B[xb(e,2)>>2]);f=x[a+16>>2]+24620|0;B[c+12>>2]=b/E(A[f>>2]);x[c+8>>2]=1056964608;b=zp(E(B[$l(c+12|0,c+8|0)>>2]*E(6.2831854820251465)));b=E(M(E(E(E(b+b)+E(3))/E(5))));B[a+4236>>2]=b;B[a+4240>>2]=M(E(E(1)-E(b*b)));b=E(E(B[xb(e,1)>>2]*E(29))+E(2));a:{if(b<E(4294967296)&b>=E(0)){i=~~b>>>0;break a}i=0}v[a+4272|0]=i;d=i;while(1){if(d&255){k=k+1|0;d=(d&254)>>>1|0;continue}break}v[a+4273|0]=k;l=qe(E(10),E(E(E(B[a+4208>>2]*E(60))+E(-60))/E(20)));m=c,n=E(Fx(B[xb(e,3)>>2])/E(A[f>>2])),B[m+12>>2]=n;x[c+8>>2]=1056964608;g=B[$l(c+12|0,c+8|0)>>2];m=c,n=E(Fx(B[xb(e,4)>>2])/E(A[f>>2])),B[m+12>>2]=n;x[c+8>>2]=1056964608;b=E(E(B[$l(c+12|0,c+8|0)>>2]*E(6.2831854820251465))*E(.5));f=db-16|0;db=f;e=(q(b),j(2));d=e&2147483647;b:{if(d>>>0<=1061752794){if(d>>>0<964689920){break b}b=En(+b,0);break b}if(d>>>0<=1081824209){h=+b;if(d>>>0<=1075235811){b=En(((e|0)<0?1.5707963267948966:-1.5707963267948966)+h,1);break b}b=En(((e|0)<0?3.141592653589793:-3.141592653589793)+h,0);break b}if(d>>>0<=1088565717){h=+b;if(d>>>0<=1085271519){b=En(((e|0)<0?4.71238898038469:-4.71238898038469)+h,1);break b}b=En(((e|0)<0?6.283185307179586:-6.283185307179586)+h,0);break b}if(d>>>0>=2139095040){b=E(b-b);break b}d=Xw(b,f+8|0);b=En(C[f+8>>3],d&1)}db=f+16|0;b=E(E(E(1)-b)/E(b+E(1)));B[a+4268>>2]=b;g=zp(E(g*E(6.2831854820251465)));B[a+4264>>2]=-g;B[a+4260>>2]=E(E(l*E(M(E(E(1)-E(g*g)))))*E(M(E(E(1)-E(b*b)))))*B[(i<<2)+45792>>2];db=c+16|0}function Bda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;f=db-48|0;db=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;n=g+(f+28|0)|0;g=a+g|0;x[n+4>>2]=x[g+44>>2];x[n+8>>2]=x[g+48>>2];b=b+1|0;continue}break}l=x[a+40>>2];m=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];o=x[a+68>>2];z=o>>31;p=x[a+64>>2];A=p>>31;q=x[a+60>>2];B=q>>31;n=x[a+8>>2];C=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>18|0;e=((((x[f+20>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+t|0;b=0;j=0;while(1){if((j|0)!=2){g=e+(j<<1)|0;h=w[g>>1];x[(f+8|0)+(j<<2)>>2]=h+((D(i,w[g+4>>1]-h|0)|0)/16384|0);j=j+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+28|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;s=e<<8;e=s;e=yka(q,B,e,e>>31);i=hb;k=e;e=Ub(h,-16777216,16776704);e=yka(p,A,e,e>>31);h=k+e|0;k=hb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Ub(j,-16777216,16776704);i=yka(o,z,e,e>>31);h=i+h|0;e=hb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Lc(i,e,24);x[g+4>>2]=e-(s&y);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}m=m+v|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],m>>12);l=l+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],l>>12);Qb(f+16|0,n,C);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+24>>2]=l>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}db=f+48|0}function Rp(a,b,c,d){var e=E(0),f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=db-16|0;db=i;x[i+12>>2]=w[b+780>>1]+y[b+837|0];x[i+8>>2]=w[b+782>>1]+(y[b+838|0]&127);ke(i+12|0,0,127);ke(i+8|0,0,127);k=a+1074312|0;j=Ob(k,1);h=x[i+8>>2];l=x[i+12>>2];if(!j){v[b+838|0]=h;v[b+837|0]=l;x[b+780>>2]=0}m=D(l,d+256|0);j=(m|0)/256|0;a:{if(!(h|!Ob(k,36)|(m|0)<65024)){j=-1;if(!(y[b+851|0]&2)){break a}x[b+88>>2]=x[b+88>>2]&-32769;break a}x[b+88>>2]=x[b+88>>2]|32768;e=qe(E(10),E(E(0-h|0)*E(.00937500037252903)));h=db-16|0;db=h;g=E(D(l,d+256|0)>>>0);b:{if(x[a+480180>>2]!=33554432){f=E(110);g=E(E(g/(y[a+480209|0]&128?E(10240):E(12288)))+E(.25));break b}f=E(125);g=E(E(g*E(6))/E(65024))}n=h,o=Oh(E(qe(E(2),g)*f)),x[n+12>>2]=o;ke(h+12|0,120,2e4);db=h+16|0;d=x[a+24620>>2];h=x[h+12>>2];g=E(E(((d|0)<h<<1?d>>>1|0:h)>>>0)*E(6.2831854820251465));c:{if(!(!Ob(k,36)|y[a+480209|0]&128)){f=E(E(A[a+24620>>2])/g);g=E(E(E(e*f)+e)+E(-1));e=E(f*f);break c}f=E(e+e);e=E(g/E(A[a+24620>>2]));B[i+4>>2]=E(E(1)-f)*e;DO(i+4|0,E(2));g=E(E(f-B[i+4>>2])/e);e=E(E(1)/E(e*e))}f=E(e+E(g+E(1)));g=E(E(e+E(e+g))/f);e=E(E(-e)/f);f=E(E(1)/f);d:{if(y[b+845|0]==1){n=b,o=Oh(E(E(E(1)-f)*E(16777216))),x[n+60>>2]=o;n=b,o=Oh(E(g*E(16777216))),x[n+64>>2]=o;n=b,o=Oh(E(e*E(16777216))),x[n+68>>2]=o;a=-1;break d}d=Oh(E(f*E(16777216)));x[b+60>>2]=d;n=b,o=Oh(E(g*E(16777216))),x[n+64>>2]=o;n=b,o=Oh(E(e*E(16777216))),x[n+68>>2]=o;a=0;if(d){break d}x[b+60>>2]=1}x[b+72>>2]=a;if(!c){break a}x[b+44>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;x[b+56>>2]=0}db=i+16|0;return j}function Cda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;f=db-48|0;db=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;n=g+(f+28|0)|0;g=a+g|0;x[n+4>>2]=x[g+44>>2];x[n+8>>2]=x[g+48>>2];b=b+1|0;continue}break}l=x[a+40>>2];m=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];w=x[a+28>>2];y=x[a+72>>2];o=x[a+68>>2];z=o>>31;p=x[a+64>>2];A=p>>31;q=x[a+60>>2];B=q>>31;n=x[a+8>>2];C=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>10&4194048;e=(((x[f+20>>2]&2147483647)<<1|g>>>31)&-2)+t|0;b=0;j=0;while(1){if((j|0)!=2){g=e+j|0;h=v[g|0];x[(f+8|0)+(j<<2)>>2]=((D(i,v[g+2|0]-h|0)|0)/16384|0)+(h<<8);j=j+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+28|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;s=e<<8;e=s;e=yka(q,B,e,e>>31);i=hb;k=e;e=Ub(h,-16777216,16776704);e=yka(p,A,e,e>>31);h=k+e|0;k=hb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Ub(j,-16777216,16776704);i=yka(o,z,e,e>>31);h=i+h|0;e=hb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Lc(i,e,24);x[g+4>>2]=e-(s&y);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}m=m+w|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],m>>12);l=l+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],l>>12);Qb(f+16|0,n,C);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+24>>2]=l>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}db=f+48|0}function p$(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0;x[c>>2]=a;z=d&512;while(1){if((u|0)==4){if(Bb(x[n+4>>2],y[n+11|0])>>>0>1){B=c,C=sG(Ie(od(n),1),tf(n),x[c>>2]),x[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}}else{a:{b:{switch(v[i+u|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];p=yl(g,32);q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break a;case 3:if(xd(x[n+4>>2],y[n+11|0])){break a}p=y[uc(n,0)|0];q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break a;case 2:if(xd(x[m+4>>2],y[m+11|0])|!z){break a}B=c,C=sG(od(m),tf(m),x[c>>2]),x[B>>2]=C;break a;case 4:break b;default:break a}}p=x[g+8>>2];A=x[c>>2];e=e+h|0;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!ih(p,64,v[r|0])){break c}r=r+1|0;continue}break}p=o;if((p|0)>0){while(1){if(!(!p|e>>>0>=r>>>0)){p=p-1|0;r=r-1|0;q=y[r|0];s=x[c>>2];x[c>>2]=s+1;v[s|0]=q;continue}break}if(p){q=yl(g,48)}else{q=0}while(1){s=x[c>>2];x[c>>2]=s+1;if((p|0)>0){v[s|0]=q;p=p-1|0;continue}break}v[s|0]=j}d:{if((e|0)==(r|0)){p=yl(g,48);q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break d}q=-1;if(!xd(x[l+4>>2],y[l+11|0])){q=v[uc(l,0)|0]}p=0;t=0;while(1){if((e|0)==(r|0)){break d}e:{if((p|0)!=(q|0)){s=p;break e}q=x[c>>2];x[c>>2]=q+1;v[q|0]=k;s=0;t=t+1|0;if(Bb(x[l+4>>2],y[l+11|0])>>>0<=t>>>0){q=p;break e}q=-1;if(y[uc(l,t)|0]==127){break e}q=v[uc(l,t)|0]}r=r-1|0;p=y[r|0];w=x[c>>2];x[c>>2]=w+1;v[w|0]=p;p=s+1|0;continue}}Nl(A,x[c>>2])}u=u+1|0;continue}break}}function Vea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=db-16|0;db=f;k=f,l=$j(b),x[k+4>>2]=l;e=db-16|0;db=e;h=a;c=Ud(a);a:{if(c){g=gc(h);while(1){a=c;c=a+14|0;if(yt(b,c)){g=a;c=x[a>>2];if(c){continue}break a}if(!yt(c,b)){break a}g=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=gc(h);g=a}x[e+12>>2]=a;b=x[g>>2];if(!b){i=db-16|0;db=i;a=gc(h);j=rh(e,Hc(48),Ag(i+8|0,a));a=x[j>>2];b=x[f+4>>2];c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);d=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a+14|0]=d;v[a+15|0]=d>>>8;v[a+16|0]=d>>>16;v[a+17|0]=d>>>24;v[a+18|0]=c;v[a+19|0]=c>>>8;v[a+20|0]=c>>>16;v[a+21|0]=c>>>24;c=y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24);d=y[b+24|0]|y[b+25|0]<<8|(y[b+26|0]<<16|y[b+27|0]<<24);v[a+38|0]=d;v[a+39|0]=d>>>8;v[a+40|0]=d>>>16;v[a+41|0]=d>>>24;v[a+42|0]=c;v[a+43|0]=c>>>8;v[a+44|0]=c>>>16;v[a+45|0]=c>>>24;c=y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24);d=y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24);v[a+30|0]=d;v[a+31|0]=d>>>8;v[a+32|0]=d>>>16;v[a+33|0]=d>>>24;v[a+34|0]=c;v[a+35|0]=c>>>8;v[a+36|0]=c>>>16;v[a+37|0]=c>>>24;c=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);b=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[a+22|0]=b;v[a+23|0]=b>>>8;v[a+24|0]=b>>>16;v[a+25|0]=b>>>24;v[a+26|0]=c;v[a+27|0]=c>>>8;v[a+28|0]=c>>>16;v[a+29|0]=c>>>24;w[a+46>>1]=0;k=gc(j),l=1,v[k+4|0]=l;db=i+16|0;Yg(h,x[e+12>>2],g,x[e>>2]);b=Zd(e);ol(e);d=1}Xg(f+8|0,x[vb(e,b)>>2],d);db=e+16|0;a=iq(x[f+8>>2]);db=f+16|0;return a+32|0}function mX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=db-48|0;db=f;g=pi(b)^-1;a:{if(oc(x[d>>2],x[d+4>>2])>>>0<=g>>>0){Us(a);break a}pi(b);if((y[c+4|0]|y[c+5|0]<<8)>>>0>=60){Zb(b,4)}j=f,k=pi(b),x[j+44>>2]=k;Zb(b,4);h=pi(b);i=pi(b);if(!((h|0)>0&(i|0)>36)){Us(a);break a}if(lu($d(x[e>>2],x[xb(x[d>>2],g)>>2]),12955)){Us(a);break a}e=f+4|0;Fv(e,b,i,h);d=hc(f+24|0,e);ub(e);b=x[d>>2];x[23549]=0;b=R(164,b|0)|0;e=x[23549];x[23549]=0;b:{if((e|0)==1){break b}c:{d:{if(!b){x[23549]=0;R(173,a|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){break d}break b}b=y[c+4|0]|y[c+5|0]<<8;if(b>>>0<=39){x[23549]=0;O(174,d|0,8)|0;b=x[23549];x[23549]=0;if((b|0)==1){break b}b=y[c+4|0]|y[c+5|0]<<8}if((b&65535)>>>0<=59){x[23549]=0;O(174,d|0,16)|0;b=x[23549];x[23549]=0;if((b|0)==1){break b}}x[23549]=0;R(175,d|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break b}e:{f:{b=y[c+4|0]|y[c+5|0]<<8;g:{if(b>>>0>=120){x[23549]=0;R(175,d|0)|0;c=x[23549];x[23549]=0;b=8;break g}h:{if(b>>>0>=100){x[23549]=0;O(174,d|0,4)|0;b=x[23549];x[23549]=0;if((b|0)==1){break b}break h}if(b>>>0<62){break f}}x[23549]=0;R(175,d|0)|0;c=x[23549];x[23549]=0;b=4}if((c|0)==1){break b}x[23549]=0;O(174,d|0,b|0)|0;break e}x[23549]=0;R(175,d|0)|0}b=x[23549];x[23549]=0;if((b|0)==1){break b}x[23549]=0;b=R(175,d|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break c}x[23549]=0;S(176,f+4|0,d|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break c}b=a;a=f+4|0;j=hc(b,a),k=x[f+44>>2],x[j+20>>2]=k;ub(a)}ub(d);break a}}a=N()|0;ub(d);Q(a|0);p()}db=f+48|0}function pda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;f=db-48|0;db=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];o=x[a+68>>2];v=o>>31;p=x[a+64>>2];y=p>>31;q=x[a+60>>2];z=q>>31;m=x[a+8>>2];A=x[a+12>>2];while(1){if(d){b=x[f+16>>2];n=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+r|0;b=b>>>21&2040;h=w[b+39942>>1];i=w[b+39940>>1];e=w[b+39938>>1];g=w[b+39936>>1];b=0;j=0;while(1){if((j|0)!=2){k=n+(j<<1)|0;x[(f+8|0)+(j<<2)>>2]=(((D(w[k>>1],e)+D(w[k-4>>1],g)|0)+D(i,w[k+4>>1])|0)+D(h,w[k+8>>1])|0)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+28|0)+(b<<3)|0;n=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=yka(q,z,e,e>>31);i=hb;l=e;e=Ub(h,-16777216,16776704);e=yka(p,y,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Ub(n,-16777216,16776704);i=yka(o,v,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Lc(i,e,24);x[g+4>>2]=e-(j&u);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],s);Qb(f+16|0,m,A);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}db=f+48|0}function U3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(A[a+4>>2]<A[wb(a)>>2]){c=db-16|0;db=c;d=c+4|0;x[d>>2]=a;a=x[a+4>>2];x[d+4>>2]=a;x[d+8>>2]=a+24;lK(x[d+4>>2],b);x[d+4>>2]=x[d+4>>2]+24;fc(d);db=c+16|0;return}i=db-32|0;db=i;g=wb(a);d=i+12|0;f=Mn(x[a>>2],x[a+4>>2])+1|0;e=db-16|0;db=e;x[e+12>>2]=f;a:{c=eh(178956970);if(f>>>0<=c>>>0){f=Xt(a);if(f>>>0<c>>>1>>>0){x[e+8>>2]=f<<1;c=x[Yc(e+8|0,e+12|0)>>2]}db=e+16|0;break a}Rc();p()}f=Mn(x[a>>2],x[a+4>>2]);e=db-16|0;db=e;Hf(d+12|0,g);b:{if(!c){c=0;g=0;break b}if(c>>>0>=178956971){wi();p()}g=Hc(D(c,24));x[e+12>>2]=c;x[e+8>>2]=g;c=x[e+8>>2];g=x[e+12>>2]}x[d>>2]=c;f=c+D(f,24)|0;x[d+8>>2]=f;x[d+4>>2]=f;m=kc(d),n=c+D(g,24)|0,x[m>>2]=n;db=e+16|0;lK(x[d+8>>2],b);x[d+8>>2]=x[d+8>>2]+24;f=db-16|0;db=f;c=vb(f+12|0,x[a+4>>2]);e=vb(f+8|0,x[a>>2]);g=x[vb(f+4|0,x[d+4>>2])>>2];h=db-16|0;db=h;b=db-32|0;db=b;Od(b+24|0,x[c>>2],x[e>>2]);k=b+16|0;c=x[b+24>>2];l=x[b+28>>2];e=db-16|0;db=e;x[e+8>>2]=g;x[e+12>>2]=c;while(1){if(sd(c,l)){c=Ln(c);g=Ln(x[e+8>>2]);x[g+16>>2]=x[c+16>>2];j=x[c+12>>2];x[g+8>>2]=x[c+8>>2];x[g+12>>2]=j;j=x[c+4>>2];x[g>>2]=x[c>>2];x[g+4>>2]=j;c=kK(e+12|0);kK(e+8|0);c=x[c>>2];continue}break}vc(k,c,e+8|0);db=e+16|0;c=x[b+16>>2];x[b+12>>2]=x[b+20>>2];vc(h+8|0,c,b+12|0);db=b+32|0;db=h+16|0;x[d+4>>2]=x[h+12>>2];Pb(a,d+4|0);Pb(a+4|0,d+8|0);Pb(wb(a),kc(d));x[d>>2]=x[d+4>>2];db=f+16|0;b=x[d+4>>2];a=x[d+8>>2];while(1){if((a|0)!=(b|0)){a=a-24|0;x[d+8>>2]=a;continue}break}a=x[d>>2];if(a){kc(d);Eb(a)}db=i+32|0}function Tg(a,b,c,d,e){var f=0,g=0,h=0;if(!b){c=db-16|0;db=c;a:{if((d|0)==189){v[a+3843|0]=e>>>7;v[a+3844|0]=e>>>6&1;break a}b=d&224;if(!b){if((d|0)!=260){break a}b=0;d=1;while(1){if((b|0)==6){break a}f=D(b>>>0<3?b:b+6|0,44)+a|0;g=f+148|0;f=f+16|0;h=d&e;b:{if(h){io(f,g);break b}io(f,0)}v[g+40|0]=!h;b=b+1|0;d=d<<1&510;continue}}if(b-160>>>0<=32){b=d&15;if(b>>>0>8){break a}a=D(d&256?b+9|0:b,44)+a|0;x[c+8>>2]=a+16;b=x[a+52>>2];x[c+12>>2]=b;g=b?2:1;c:{b=d&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}f=e&3;h=e>>>2&7;b=0;d=(e&32)!=0;while(1){if((b|0)==(g|0)){break a}a=x[(c+8|0)+(b<<2)>>2];HP(x[a>>2],d);HP(x[a+4>>2],d);w[a+22>>1]=h;wz(a);JP(a);v[a+21|0]=f;wz(a);JP(a);b=b+1|0;continue}}b=0;while(1){if((b|0)==(g|0)){break a}a=x[(c+8|0)+(b<<2)>>2];w[a+20>>1]=z[a+20>>1]&768|e&255;wz(a);b=b+1|0;continue}}v[a+58|0]=(e&32)>>>5;v[a+57|0]=(e&16)>>>4;b=e>>>1&7;w[a+46>>1]=b?9-b|0:0;w[a+48>>1]=e&1;break a}if((b|0)!=224&b>>>0>=129|-4144960>>>d&1){break a}f=a;a=v[(d&31)+29056|0];a=(f+D(d&256?a+18|0:a,84)|0)+808|0;d:{switch(b-32>>>5|0){case 0:v[a+79|0]=e>>>7;v[a+80|0]=(e&64)>>>6;v[a+78|0]=(e&32)>>>5;v[a+77|0]=(e&16)>>>4;jo(a);w[a+14>>1]=z[((e&15)<<1)+29088>>1];break a;case 1:w[a+68>>1]=y[(e>>>6|0)+21189|0];IP(a);w[a+22>>1]=(e&63)<<2;break a;case 2:w[a+24>>1]=e>>>4;jo(a);w[a+26>>1]=e&15;jo(a);break a;case 3:b=e>>>4|0;w[a+28>>1]=b>>>0>=15?496:b<<4;w[a+30>>1]=e&15;jo(a);break a;case 6:break d;default:break a}}w[a+12>>1]=e&7}db=c+16|0;return}ib[x[x[b>>2]>>2]](b,c,d,e)}function Zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0;g=db-16|0;db=g;e=x[a+12>>2];h=e;a:{b:{c:{i=x[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}t=x[a+16>>2];e=x[a+48>>2];j=x[a+40>>2];k=x[a+36>>2];b=x[a+44>>2];l=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=l;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];q=x[a+68>>2];z=q>>31;r=x[a+64>>2];A=r>>31;s=x[a+60>>2];B=s>>31;while(1){l=b;if(d){b=Ub(l,-16777216,16776704);m=yka(r,A,b,b>>31);n=hb;b=x[g+8>>2];f=(x[g+12>>2]<<1)+t|0;b=(b>>>16&65520)+p|0;f=(((((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+4>>1],w[b+10>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/32768<<8;b=f;b=yka(b,b>>31,s,B);m=b+m|0;o=hb+n|0;o=b>>>0>m>>>0?o+1|0:o;b=Ub(e,-16777216,16776704);e=yka(q,z,b,b>>31);n=e+m|0;b=hb+o|0;b=e>>>0>n>>>0?b+1|0:b;e=n+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Lc(e,b,24);b=(e|0)/256|0;k=k+v|0;x[c>>2]=D(b,k>>12)+x[c>>2];j=j+u|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Qb(g+8|0,i,h);b=e-(f&y)|0;c=c+8|0;d=d-1|0;e=l;continue}break}b=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+48>>2]=e;x[a+44>>2]=l;x[a+24>>2]=j>>12;db=g+16|0}function qda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;f=db-48|0;db=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];o=x[a+68>>2];y=o>>31;p=x[a+64>>2];z=p>>31;q=x[a+60>>2];A=q>>31;m=x[a+8>>2];B=x[a+12>>2];while(1){if(d){b=x[f+16>>2];n=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+r|0;b=b>>>21&2040;h=w[b+39942>>1];i=w[b+39940>>1];e=w[b+39938>>1];g=w[b+39936>>1];b=0;j=0;while(1){if((j|0)!=2){k=j+n|0;x[(f+8|0)+(j<<2)>>2]=(((D(v[k|0],e)+D(v[k-2|0],g)|0)+D(i,v[k+2|0])|0)+D(h,v[k+4|0])<<8)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+28|0)+(b<<3)|0;n=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=yka(q,A,e,e>>31);i=hb;l=e;e=Ub(h,-16777216,16776704);e=yka(p,z,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Ub(n,-16777216,16776704);i=yka(o,y,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Lc(i,e,24);x[g+4>>2]=e-(j&u);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],s);Qb(f+16|0,m,B);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}db=f+48|0}function tK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0);e=db-48|0;db=e;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;d=x[a+24>>2];if((b|0)==x[d+24604>>2]){break d}a=e+8|0;rc(a,d+24604|0,40);x[e+8>>2]=b;vy(d,a);break d;case 2:f=x[a+24>>2];d=f+24664|0;b=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=b;d=f+24656|0;b=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=b;b=x[f+24652>>2];x[e+8>>2]=x[f+24648>>2];x[e+12>>2]=b;d=db-16|0;db=d;b=3;f:{g:{h:{if(!c|(c|0)>7){break h}b=2;if((c|0)>2){break h}b=1;if((c|0)==2){break h}b=0;if((c|0)>0){break h}c=ac(8);x[23549]=0;b=O(54,d+4|0,10680)|0;a=x[23549];x[23549]=0;i:{if((a|0)!=1){a=pc(c,b);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break g}a=N()|0;tb(b);break i}a=N()|0;jc(c)}Q(a|0);p()}db=d+16|0;break f}p()}v[e+8|0]=b;a=x[a+24>>2];if(!wx(e+8|0,a+24648|0)){break d}ty(a,e+8|0);break d;case 3:f=e+8|0;d=x[a+24>>2];rc(f,d+24604|0,40);b=db-48|0;db=b;j:{if((c|0)==-1){vs(f,x[Zp(b+8|0)+32>>2]);io(f,x[Zp(b+8|0)+36>>2]);break j}if((c|0)<=0){vs(f,0);io(f,0);break j}a=D(c,1e3);vs(f,a);io(f,a)}db=b+48|0;if(x[d+24636>>2]==x[e+40>>2]&x[d+24640>>2]==x[e+44>>2]){break d}vy(d,e+8|0);break d;default:d=ac(8);x[23549]=0;c=O(54,e+8|0,10268)|0;a=x[23549];x[23549]=0;if((a|0)==1){break c}a=pc(d,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b;case 0:break e}}g=a,h=qe(E(10),E(E(E(c|0)*E(.0010000000474974513))*E(.5))),B[g+48>>2]=h}db=e+48|0;return}b=N()|0;jc(d)}Q(b|0)}p()}function _ca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;g=db-16|0;db=g;e=x[a+12>>2];h=e;a:{b:{c:{i=x[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}s=x[a+16>>2];b=x[a+48>>2];j=x[a+40>>2];k=x[a+36>>2];e=x[a+44>>2];l=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=l;t=x[a+32>>2];u=x[a+28>>2];y=x[a+72>>2];o=x[a+68>>2];z=o>>31;p=x[a+64>>2];A=p>>31;q=x[a+60>>2];B=q>>31;while(1){l=e;if(d){e=Ub(l,-16777216,16776704);f=yka(p,A,e,e>>31);e=hb;b=Ub(b,-16777216,16776704);b=yka(o,z,b,b>>31);f=b+f|0;e=hb+e|0;e=b>>>0>f>>>0?e+1|0:e;b=x[g+8>>2];m=f;f=x[g+12>>2]+s|0;b=(b>>>16&65520)+n|0;r=(((((((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])|0)+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+2|0],w[b+10>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8)/32768<<8;b=r;f=yka(b,b>>31,q,B);m=m+f|0;b=hb+e|0;b=f>>>0>m>>>0?b+1|0:b;e=m+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Lc(e,b,24);b=(e|0)/256|0;k=k+u|0;x[c>>2]=D(b,k>>12)+x[c>>2];j=j+t|0;x[c+4>>2]=x[c+4>>2]+D(j>>12,b);Qb(g+8|0,i,h);e=e-(y&r)|0;c=c+8|0;d=d-1|0;b=l;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+48>>2]=b;x[a+44>>2]=l;x[a+24>>2]=j>>12;db=g+16|0}function Oj(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;i=db-16|0;db=i;a:{if(!d){break a}g=x[c>>2];if(!g){break a}b:{c:{d:{e:{f=x[a+480180>>2];if((f|0)!=512){if((f|0)!=64){break e}f=D(d,20)+g|0;break d}f=((D(d,36318)|0)/1024|0)+g|0;break d}f:{g:{if(y[a+480208|0]&16){if((f|0)==4){break g}f=d>>31;x[i+12>>2]=(f^d)-f;tc(i+12|0,1020);h=x[i+12>>2];f=c;h:{if((d|0)>0){if(h>>>0<=15){h=x[(h<<2)+(Ob(a+1074312|0,7)?37232:37296)>>2];break h}h=x[(h&-4)+(Ob(a+1074312|0,7)?37360:38384)>>2];break h}if(h>>>0<=15){h=x[(h<<2)+(Ob(a+1074312|0,7)?37296:37232)>>2];break h}h=x[(h&-4)+(Ob(a+1074312|0,7)?38384:37360)>>2]}j=yka(h,h>>31,g,g>>31);h=hb;j=j+32768|0;h=j>>>0<32768?h+1|0:h;k=f;f=Cc(zka(j,h,65536,0),hb);x[k>>2]=f;if((g|0)!=(f|0)){break c}f=Ob(a+1074312|0,7);g=x[c>>2];if(!(f^(d|0)>0)){f=2147483647;d=1;if((g|0)==2147483647){break c}break f}d=-1;if((g|0)>=2){break f}f=g;break c}f=Ob(a+1074312|0,7);g=x[c>>2];if(!f){break g}if((d|0)<0){f=yka(g,0,14317456,0);h=hb;g=yka(g,0,0-d|0,0);d=hb;g=g+14317456|0;d=g>>>0<14317456?d+1|0:d;f=SN(Bka(f,h,g,d),hb);break d}d=yka(g,g>>31,d,0);f=hb;if((f|0)>=0&d>>>0>=14317456|(f|0)>0){if(e){x[c>>2]=2147483647;break a}x[c>>2]=0;x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248;break a}d=SN(Bka(yka(g,0,14317456,0),hb,14317456-d|0,0-(f+(d>>>0>14317456)|0)|0),hb);x[c>>2]=d;if((d|0)<=0){break b}break a}f=g-d|0;break d}f=d+g|0}x[c>>2]=f}if((f|0)>0){break a}}x[c>>2]=1;if(x[a+480180>>2]!=2|e){break a}x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248}db=i+16|0}function Rda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;f=db-48|0;db=f;s=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}k=x[a+40>>2];l=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;t=x[a+32>>2];u=x[a+28>>2];v=x[a+72>>2];n=x[a+68>>2];y=n>>31;o=x[a+64>>2];z=o>>31;p=x[a+60>>2];A=p>>31;m=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+s|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=w[g+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){q=(f+8|0)+(b<<2)|0;e=x[q>>2];g=(f+28|0)+(b<<3)|0;C=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;r=e<<8;e=r;e=yka(p,A,e,e>>31);i=hb;j=e;e=Ub(h,-16777216,16776704);e=yka(o,z,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Ub(C,-16777216,16776704);i=yka(n,y,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Lc(i,e,24);x[g+4>>2]=e-(r&v);x[q>>2]=(e|0)/256;b=b+1|0;continue}break}l=l+u|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],l>>12);k=k+t|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],k>>12);Qb(f+16|0,m,B);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}db=f+48|0}function LW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=db-16|0;db=f;wc(c);while(1){a:{if(!Lb(x[c>>2],x[c+8>>2],3)){break a}d=f+13|0;Sq(d,c);i=fd(d);h=Ue(d);d=y[f+13|0];if(d>>>0>=A[a+12>>2]){break a}g=$c(x[a>>2],x[x[a+48>>2]+12>>2],d,b);d=y[i|0];if(d>>>0<=126){if(!(d|y[h|0])){v[g|0]=254;continue}v[g|0]=d+1;if(y[h|0]==255){continue}v[g+2|0]=1;v[g+4|0]=y[h|0];continue}b:{switch(d-127|0){case 1:v[g+1|0]=y[h|0]+1;continue;case 0:continue;default:break b}}e=v[h|0];v[f+12|0]=e;h=0;d=d&127;if(d>>>0<=23){h=y[d+26272|0]}c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{j=y[i|0];switch((j&127)-2|0){case 21:break g;case 18:break h;case 17:break i;case 16:case 20:break j;case 15:break k;case 2:break l;case 1:break m;case 0:case 8:case 9:break n;default:break d}}if((e|0)>=0){break f}d=0-e&15;break e}v[f+8|0]=64;e=y[Sb(f+12|0,f+8|0)|0];if(y[g+2|0]>1){break d}v[g+4|0]=e;v[g+2|0]=1;continue}d=3;if((e|0)>=0){break c}d=0-e&127;break e}if(!e){continue}d=0-e|-16;if((e|0)<0){break e}d=e<<4|15;break e}if(!e){continue}d=(e|0)>=0;if(!d){e=0-e&15;v[f+12|0]=e;j=y[i|0]}d=d?3:2;e=((j|0)==22?-32:-16)|e;v[f+12|0]=e;break c}d=e&15|-48;break e}d=e&15|-64;break e}d=164;if((e|0)==100){break e}x[f+8>>2]=e- -64;x[f+4>>2]=0;x[f>>2]=128;e=x[sj(f+8|0,f+4|0,f)>>2];if(!y[g+3|0]){break d}o:{switch(y[g+2|0]){case 0:case 2:break o;default:continue}}v[g+2|0]=2;v[g+4|0]=(e&254)>>>1;continue}d=e<<4}e=d;v[f+12|0]=e}d=h;if(!d){continue}}v[g+5|0]=e;v[g+3|0]=d;continue}break}db=f+16|0}function gW(){var a=0,b=0,c=0;if(!y[467376]){a=db-16|0;db=a;ws(467024);x[116768]=-1;x[116766]=467080;x[116764]=93384;x[116756]=77260;v[467076]=0;b=a+12|0;Nc(b,x[116757]);c=x[x[116756]+8>>2];x[23549]=0;P(c|0,467024,b|0);b=x[23549];x[23549]=0;a:{if((b|0)!=1){Xb(a+12|0);db=a+16|0;break a}b=N()|0;Xb(a+12|0);Pn(467024);Q(b|0);p()}Bs(466352);x[116588]=77392;x[116586]=77372;x[116587]=0;On(466352,467024);DH(467088,93528,467136);Iw(466520,467088);DH(467144,93232,467192);Iw(466688,467144);Iw(466856,x[x[x[116672]-12>>2]+466712>>2]);BH(x[x[116586]-12>>2]+466344|0);vJ(x[x[116672]-12>>2]+466688|0);BH(x[x[116672]-12>>2]+466688|0);a=db-16|0;db=a;PH(467200);x[116812]=-1;x[116810]=467256;x[116808]=93384;x[116800]=77652;v[467252]=0;b=a+12|0;Nc(b,x[116801]);c=x[x[116800]+8>>2];x[23549]=0;P(c|0,467200,b|0);b=x[23549];x[23549]=0;b:{if((b|0)!=1){Xb(a+12|0);db=a+16|0;break b}b=N()|0;Xb(a+12|0);$r(467200);Q(b|0);p()}yH(466440);x[116610]=77784;x[116608]=77764;x[116609]=0;On(466440,467200);AH(467264,93528,467312);Hw(466604,467264);AH(467320,93232,467368);Hw(466772,467320);Hw(466940,x[x[x[116693]-12>>2]+466796>>2]);zH(x[x[116608]-12>>2]+466432|0);vJ(x[x[116693]-12>>2]+466772|0);zH(x[x[116693]-12>>2]+466772|0);v[467376]=1}a=db-16|0;db=a;c:{if($a(a+12|0,a+8|0)|0){break c}b=Nd((x[a+12>>2]<<2)+4|0);x[116846]=b;if(!b){break c}b=Nd(x[a+8>>2]);if(b){c=x[116846];x[c+(x[a+12>>2]<<2)>>2]=0;if(!(_a(c|0,b|0)|0)){break c}}x[116846]=0}db=a+16|0;x[116037]=42;x[116055]=467476}function Sda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;f=db-48|0;db=f;s=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}k=x[a+40>>2];l=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;t=x[a+32>>2];u=x[a+28>>2];w=x[a+72>>2];n=x[a+68>>2];y=n>>31;o=x[a+64>>2];z=o>>31;p=x[a+60>>2];A=p>>31;m=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+s|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=v[e+g|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){q=(f+8|0)+(b<<2)|0;e=x[q>>2];g=(f+28|0)+(b<<3)|0;C=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;r=e<<8;e=r;e=yka(p,A,e,e>>31);i=hb;j=e;e=Ub(h,-16777216,16776704);e=yka(o,z,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Ub(C,-16777216,16776704);i=yka(n,y,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Lc(i,e,24);x[g+4>>2]=e-(r&w);x[q>>2]=(e|0)/256;b=b+1|0;continue}break}l=l+u|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],l>>12);k=k+t|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],k>>12);Qb(f+16|0,m,B);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}db=f+48|0}function Mba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,B=0;f=db-48|0;db=f;a:{b:{c:{d:{e:{f:{g:{if(!a){break g}l=e<<2;if(l>>>0>d>>>0){break g}t=l-4|0;o=D(b,e);u=o-8|0;h:while(1){b=x[c+8>>2];h=x[c>>2];x[23549]=0;b=U(142,h|0,b|0,l|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break b}if(!(b&n>>>0<o>>>0)){break g}x[23549]=0;S(176,f+8|0,c|0,d|0);b=x[23549];x[23549]=0;if((b|0)==1){break c}b=f+8|0;h=hc(f+28|0,b);ub(b);x[23549]=0;P(519,b|0,h|0);b=x[23549];x[23549]=0;if((b|0)==1){break e}z=Ee(f+8|0);q=x[f+8>>2];A=q-4|0;k=0;while(1){if((e|0)==(k|0)){Jc(f+8|0);ub(h);n=(q-l<<1)+n|0;continue h}x[23549]=0;g=R(512,h|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){x[23549]=0;b=R(192,h|0)|0;j=x[23549];x[23549]=0;if((j|0)==1){break f}x[f>>2]=b;ke(f,0,89);x[23549]=0;O(174,h|0,1)|0;b=x[23549];x[23549]=0;if((b|0)==1){break f}j=k+n|0;b=e+k<<2;i:while(1){j:{if(j>>>0>u>>>0){break j}m=0;if(b>>>0>A>>>0){break j}while(1)if((m|0)==8){b=b+t|0;continue i}else{r=x[f>>2];i=y[b+z|0];s=m&1;i=s?i>>>4|0:i&15;x[f>>2]=r+v[(i&7)+30328|0];B=g;g=w[(r<<1)+30336>>1];g=(((0-(i&1)&g>>2)+(g>>3)|0)+(i<<30>>31&g>>1)|0)+(g&i<<29>>31)|0;x[f+4>>2]=B+(i>>>0<8?g:0-g|0);ke(f,0,88);ke(f+4|0,-32768,32767);g=x[f+4>>2];w[(j<<1)+a>>1]=g;m=m+1|0;j=e+j|0;b=b+s|0;continue}}break}k=k+1|0;continue}break}break}break f}ub(c);db=f+48|0;return}b=N()|0;Jc(f+8|0);break d}b=N()|0}ub(h);break a}b=N()|0;break a}b=N()|0}ub(c);Q(b|0);p()}function Laa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-96|0;db=c;mj(c+76|0,b,1413829443);x[23549]=0;b=R(164,x[c+76>>2])|0;d=x[23549];x[23549]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){x[23549]=0;S(748,c+56|0,a+140|0,1413894985);a=x[23549];x[23549]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){x[23549]=0;a=O(826,c+56|0,13404)|0;b=x[23549];x[23549]=0;if((b|0)==1){break e}b=28591;if(a){b=Gb(c+44|0);x[23549]=0;a=R(188,c+56|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break m}x[23549]=0;S(257,c+56|0,b|0,a|0);a=x[23549];x[23549]=0;if((a|0)==1){break m}x[23549]=0;d=O(53,c+20|0,b|0)|0;a=x[23549];x[23549]=0;if((a|0)==1){break l}x[23549]=0;W(827,c+8|0);a=x[23549];x[23549]=0;if((a|0)==1){break k}x[23549]=0;S(828,c+32|0,d|0,c+8|0);a=x[23549];x[23549]=0;if((a|0)==1){break j}a=c+32|0;e=zb(b,a);tb(a);tb(c+8|0);tb(d);x[23549]=0;S(11,a|0,2,e|0);a=x[23549];x[23549]=0;if((a|0)==1){break h}x[23549]=0;a=R(713,c+32|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break g}tb(c+32|0);tb(e);b=a-1>>>0<19398657?1252:28591}ub(c+56|0);break a}a=N()|0;break b}a=N()|0;break f}a=N()|0;break f}a=N()|0;break i}a=N()|0;tb(c+8|0)}tb(d);break f}a=N()|0;break f}a=N()|0;tb(c+32|0)}tb(b);break d}a=N()|0}ub(c+56|0);break b}x[23549]=0;a=U(142,x[c+76>>2],x[c+84>>2],2)|0;b=x[23549];x[23549]=0;if((b|0)==1){break c}b=28591;if(!a){break a}x[23549]=0;b=R(180,c+76|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;break b}a=N()|0}ub(c+76|0);Q(a|0);p()}ub(c+76|0);db=c+96|0;return b|0}function n0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;d=x[d+28>>2];a=db-384|0;db=a;x[a+376>>2]=c;x[a+380>>2]=b;uw(a+220|0,d,a+240|0,a+236|0,a+232|0);d=Gb(a+208|0);b=Mc(d);x[23549]=0;P(59,d|0,b|0);b=x[23549];x[23549]=0;a:{b:{c:{if((b|0)!=1){c=uc(d,0);x[a+204>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;h=x[a+232>>2];i=x[a+236>>2];while(1){d:{x[23549]=0;b=O(1120,a+380|0,a+376|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}if(b){break c}g=x[a+204>>2];b=Bb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[23549]=0;P(59,d|0,b<<1);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=uc(d,0);x[a+204>>2]=b+c}x[23549]=0;b=R(1121,x[a+380>>2])|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}if(tw(b,a+23|0,a+22|0,c,a+204|0,i,h,a+220|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}x[23549]=0;R(1123,a+380|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+224>>2],y[a+231|0])|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}SG(a,c,x[a+204>>2],e);b=x[a>>2];c=x[a+4>>2];h=x[a+12>>2];x[f+8>>2]=x[a+8>>2];x[f+12>>2]=h;x[f>>2]=b;x[f+4>>2]=c;vf(a+220|0,a+32|0,x[a+28>>2],e);x[23549]=0;b=O(1120,a+380|0,a+376|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+380>>2];tb(d);tb(a+220|0);db=a+384|0;break a}}b=N()|0;tb(d);tb(a+220|0);Q(b|0);p()}return b|0}function w0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;d=x[d+28>>2];a=db-272|0;db=a;x[a+264>>2]=c;x[a+268>>2]=b;yw(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Gb(a+196|0);b=Mc(d);x[23549]=0;P(59,d|0,b|0);b=x[23549];x[23549]=0;a:{b:{c:{if((b|0)!=1){c=uc(d,0);x[a+192>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;h=v[a+222|0];i=v[a+223|0];while(1){d:{x[23549]=0;b=O(1105,a+268|0,a+264|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}if(b){break c}g=x[a+192>>2];b=Bb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[23549]=0;P(59,d|0,b<<1);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=uc(d,0);x[a+192>>2]=b+c}x[23549]=0;b=R(1106,x[a+268>>2])|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}if(xw(b,a+23|0,a+22|0,c,a+192|0,i,h,a+208|0,a+32|0,a+28|0,a+24|0,a+224|0)){break c}x[23549]=0;R(1108,a+268|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+212>>2],y[a+219|0])|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}SG(a,c,x[a+192>>2],e);b=x[a>>2];c=x[a+4>>2];h=x[a+12>>2];x[f+8>>2]=x[a+8>>2];x[f+12>>2]=h;x[f>>2]=b;x[f+4>>2]=c;vf(a+208|0,a+32|0,x[a+28>>2],e);x[23549]=0;b=O(1105,a+268|0,a+264|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+268>>2];tb(d);tb(a+208|0);db=a+272|0;break a}}b=N()|0;tb(d);tb(a+208|0);Q(b|0);p()}return b|0}function lfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=x[a>>2];d=Cd(c,x[a+4>>2]);if(d>>>0<b>>>0){i=db-32|0;db=i;b=b-d|0;d=x[wb(a)>>2];c=x[a+4>>2];a:{if(b>>>0<=(d-c|0)/12>>>0){d=db-16|0;db=d;b=It(d+4|0,a,b);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){fc(b);db=d+16|0}else{dR(a);a=a+12|0;x[b+4>>2]=a;continue}break}break a}d=wb(a);d=Hl(i+12|0,ep(a,Cd(x[a>>2],c)+b|0),Cd(x[a>>2],x[a+4>>2]),d);f=db-16|0;db=f;b=eR(f+4|0,d+8|0,b);c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){dR(c);c=x[b>>2]+12|0;x[b>>2]=c;continue}break}Kd(b);db=f+16|0;f=db-16|0;db=f;e=wb(a);b=vb(f+12|0,x[a+4>>2]);g=vb(f+8|0,x[a>>2]);h=vb(f+4|0,x[d+4>>2]);c=x[b>>2];g=x[g>>2];b=db+-64|0;db=b;h=x[h>>2];x[b+56>>2]=h;x[b+60>>2]=c;x[b+52>>2]=h;e=rd(b+24|0,e,b+52|0,b+56|0);x[b+16>>2]=x[e+8>>2];h=x[e+4>>2];x[b+8>>2]=x[e>>2];x[b+12>>2]=h;Ke(b+36|0,b+8|0);while(1){if(sd(c,g)){Zj(dh(x[b+56>>2]),dh(c));c=Cj(b+60|0);Cj(b+56|0);c=x[c>>2];continue}break}Je(b+36|0);h=x[b+56>>2];if(!y[b+48|0]){e=db-16|0;db=e;c=vb(e+12|0,x[x[b+44>>2]>>2]);j=x[vb(e+8|0,x[x[b+40>>2]>>2])>>2];g=db-16|0;db=g;c=x[c>>2];x[g+12>>2]=c;while(1){if(ai(c,j)){Zz(Mv(c));c=x[Bj(g+12|0)>>2];continue}break}db=g+16|0;db=e+16|0}db=b- -64|0;x[d+4>>2]=h;Pb(a,d+4|0);Pb(a+4|0,d+8|0);Pb(wb(a),kc(d));x[d>>2]=x[d+4>>2];db=f+16|0;a=x[d+4>>2];while(1){b=x[d+8>>2];if((b|0)!=(a|0)){b=b-12|0;x[d+8>>2]=b;Zz(b);continue}break}a=x[d>>2];if(a){vr(d);Eb(a)}}db=i+32|0;return}if(b>>>0<d>>>0){fR(a,c+D(b,12)|0)}}function tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=db-16|0;db=g;t=x[a+16>>2];u=cg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);m=x[a+8>>2];n=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];o=x[a+128>>2];if(o){p=dg(m,n,o);q=hb;b=x[a+76>>2];Ff(h,e,bf(m,n,d),hb);r=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;a:while(1){b:{s=b;if(!d){break b}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;r=r-1|0;b=r;p=b?p:0;q=b?q:0;h=(e<<1)+t|0;b=o;while(1)if((b|0)<=0){Qb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Md(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);Ld(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=bg(i,u);v=x[a+72>>2];y=x[a+32>>2];l=x[a+28>>2]+l|0;h=b<<8;b=h;e=x[a+60>>2];b=yka(e,e>>31,b,b>>31);z=hb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Ub(s,-16777216,16776704);j=yka(j,A,b,b>>31);e=e+j|0;b=hb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Ub(f,-16777216,16776704);e=yka(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Lc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(l>>12,f)+x[c>>2];k=k+y|0;x[c+4>>2]=x[c+4>>2]+D(k>>12,f);Qb(g,m,n);b=b-(h&v)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=s;continue a}else{Md(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);Ld(i,4);Qb(g+8|0,p,q);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=f;x[a+44>>2]=s;x[a+24>>2]=k>>12;db=g+16|0}function tz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{e=255;b:{c:{g=a+62|0;d=y[Db(g,b)|0];if((d|0)==255){break c}if(v[Db(g,b)|0]>=0){break b}f=a+26|0;d=d&127;if(z[_b(f,d)>>1]!=65535){if(z[_b(f,d)>>1]!=(b|0)){break c}}j=_b(f,d),k=b,w[j>>1]=k;j=Db(g,b),k=d,v[j|0]=k;break b}i=a+8|0;f=a+26|0;d=0;h=255;d:{while(1){if((d|0)==18){break d}if(z[_b(f,d)>>1]!=65535){if(!(y[Db(i,d)|0]&32)){h=v[Db(g,z[_b(f,d)>>1])|0]<0?d:h;e=d}d=d+1|0;continue}break}j=_b(f,d),k=b,w[j>>1]=k;j=Db(g,b),k=d,v[j|0]=k;break b}if((e&255)!=255){d=(h&255)==255?e:h;e=d&255;j=Db(g,z[_b(f,e)>>1]),k=255,v[j|0]=k;j=_b(f,e),k=b,w[j>>1]=k;j=Db(g,b),k=d,v[j|0]=k}d=gl(a,b)}g=d&255;if((g|0)==255){break a}if(Sj(x[a>>2])){break a}e=$d(a+318|0,g);d=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[e+8|0]=d;v[e+9|0]=d>>>8;v[e+10|0]=d>>>16;v[e+11|0]=d>>>24;d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[e|0]=f;v[e+1|0]=f>>>8;v[e+2|0]=f>>>16;v[e+3|0]=f>>>24;v[e+4|0]=d;v[e+5|0]=d>>>8;v[e+6|0]=d>>>16;v[e+7|0]=d>>>24;f=DP(g);h=f+3|0;d=0;while(1){if((d|0)==2){Tg(x[a>>2],x[a+4>>2],b,qt(g)|192,y[Db(c,10)|0])}else{e=d?h:f;Tg(x[a>>2],x[a+4>>2],b,e|32,y[Db(c,d)|0]);Tg(x[a>>2],x[a+4>>2],b,e|64,y[Db(c,d+2|0)|0]);Tg(x[a>>2],x[a+4>>2],b,e|96,y[Db(c,d+4|0)|0]);Tg(x[a>>2],x[a+4>>2],b,e|128,y[Db(c,d+6|0)|0]);Tg(x[a>>2],x[a+4>>2],b,e|224,y[Db(c,d+8|0)|0]);d=d+1|0;continue}break}}}function m0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=db-320|0;db=a;x[a+312>>2]=c;x[a+316>>2]=b;h=Gb(a+196|0);Nc(a+16|0,x[d+28>>2]);x[23549]=0;b=R(1115,x[a+16>>2])|0;c=x[23549];x[23549]=0;a:{b:{if((c|0)==1){break b}x[23549]=0;V(1126,b|0,81792,81818,a+208|0);b=x[23549];x[23549]=0;if((b|0)==1){break b}Xb(a+16|0);c=Gb(a+184|0);b=Mc(c);x[23549]=0;P(59,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){c:{b=uc(c,0);x[a+180>>2]=b;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[23549]=0;g=O(1120,a+316|0,a+312|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break d}d=x[a+180>>2];e:{if(!g){g=d;d=Bb(x[c+4>>2],y[c+11|0]);if((g|0)==(d+b|0)){x[23549]=0;P(59,c|0,d<<1);b=x[23549];x[23549]=0;if((b|0)==1){break c}b=Mc(c);x[23549]=0;P(59,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break c}b=uc(c,0);x[a+180>>2]=d+b}x[23549]=0;d=R(1121,x[a+316>>2])|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}if(!on(d,16,b,a+180|0,a+8|0,0,x[h+4>>2],y[h+11|0],a+16|0,a+12|0,a+208|0)){break e}d=x[a+180>>2]}x[23549]=0;P(59,c|0,d-b|0);b=x[23549];x[23549]=0;if((b|0)==1){break d}b=Mb(c);d=yd();x[a>>2]=f;if((RG(b,d,a)|0)!=1){x[e>>2]=4}x[23549]=0;b=O(1120,a+316|0,a+312|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break d}if(b){x[e>>2]=x[e>>2]|2}b=x[a+316>>2];tb(c);tb(h);db=a+320|0;return b|0}x[23549]=0;R(1123,a+316|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){continue}}break}}}b=N()|0;tb(c);break a}b=N()|0;Xb(a+16|0)}tb(h);Q(b|0);p()}function V$(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;m=b;i=db-416|0;db=i;x[i+408>>2]=37;x[i+412>>2]=0;l=Nr(i+408|1,13623,x[c+4>>2]);x[i+364>>2]=i+368;a=yd();a:{if(l){b=x[c+8>>2];j=i- -64|0;x[j>>2]=g;x[j+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=b;j=Lg(i+368|0,30,a,i+408|0,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;j=Lg(i+368|0,30,a,i+408|0,i+80|0)}x[i+128>>2]=1103;k=pe(i+356|0,0,i+128|0);b=i+368|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=yd();f:{if(l){j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i+8>>2]=e;x[i+12>>2]=f;x[i>>2]=j;j=Oi(i+364|0,a,i+408|0,i);break f}x[i+32>>2]=e;x[i+36>>2]=f;x[i+40>>2]=g;x[i+44>>2]=h;j=Oi(i+364|0,a,i+408|0,i+32|0)}if((j|0)==-1){x[23549]=0;X(1104);a=x[23549];x[23549]=0;if((a|0)==1){break d}break e}a=x[i+364>>2];Me(k,a)}f=a+j|0;g=Pi(a,f,x[c+4>>2]);x[i+116>>2]=1103;e=pe(i+120|0,0,i+116|0);g:{h:{if((i+368|0)==(a|0)){j=i+128|0;break h}j=Nd(j<<3);if(!j){x[23549]=0;X(1104);a=x[23549];x[23549]=0;if((a|0)!=1){break e}a=N()|0;break g}Me(e,j);b=a}a=i+108|0;Nc(a,x[c+28>>2]);x[23549]=0;ea(1134,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=x[23549];x[23549]=0;i:{if((a|0)!=1){Xb(i+108|0);x[23549]=0;a=ga(1135,m|0,j|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break i}Kc(e);Kc(k);db=i+416|0;break b}a=N()|0;Xb(i+108|0);break g}a=N()|0}Kc(e);break c}p()}a=N()|0}Kc(k);Q(a|0);p()}return a|0}function v0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=db-256|0;db=a;x[a+248>>2]=c;x[a+252>>2]=b;h=Gb(a+196|0);Nc(a+16|0,x[d+28>>2]);x[23549]=0;b=R(18,x[a+16>>2])|0;c=x[23549];x[23549]=0;a:{b:{if((c|0)==1){break b}x[23549]=0;V(1113,b|0,81792,81818,a+208|0);b=x[23549];x[23549]=0;if((b|0)==1){break b}Xb(a+16|0);c=Gb(a+184|0);b=Mc(c);x[23549]=0;P(59,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){c:{b=uc(c,0);x[a+180>>2]=b;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[23549]=0;g=O(1105,a+252|0,a+248|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break d}d=x[a+180>>2];e:{if(!g){g=d;d=Bb(x[c+4>>2],y[c+11|0]);if((g|0)==(d+b|0)){x[23549]=0;P(59,c|0,d<<1);b=x[23549];x[23549]=0;if((b|0)==1){break c}b=Mc(c);x[23549]=0;P(59,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break c}b=uc(c,0);x[a+180>>2]=d+b}x[23549]=0;d=R(1106,x[a+252>>2])|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}if(!rn(d,16,b,a+180|0,a+8|0,0,x[h+4>>2],y[h+11|0],a+16|0,a+12|0,a+208|0)){break e}d=x[a+180>>2]}x[23549]=0;P(59,c|0,d-b|0);b=x[23549];x[23549]=0;if((b|0)==1){break d}b=Mb(c);d=yd();x[a>>2]=f;if((RG(b,d,a)|0)!=1){x[e>>2]=4}x[23549]=0;b=O(1105,a+252|0,a+248|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break d}if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];tb(c);tb(h);db=a+256|0;return b|0}x[23549]=0;R(1108,a+252|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){continue}}break}}}b=N()|0;tb(c);break a}b=N()|0;Xb(a+16|0)}tb(h);Q(b|0);p()}function d0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;m=b;i=db-256|0;db=i;x[i+248>>2]=37;x[i+252>>2]=0;l=Nr(i+248|1,13623,x[c+4>>2]);x[i+204>>2]=i+208;a=yd();a:{if(l){b=x[c+8>>2];j=i- -64|0;x[j>>2]=g;x[j+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=b;j=Lg(i+208|0,30,a,i+248|0,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;j=Lg(i+208|0,30,a,i+248|0,i+80|0)}x[i+128>>2]=1103;k=pe(i+196|0,0,i+128|0);b=i+208|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=yd();f:{if(l){j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i+8>>2]=e;x[i+12>>2]=f;x[i>>2]=j;j=Oi(i+204|0,a,i+248|0,i);break f}x[i+32>>2]=e;x[i+36>>2]=f;x[i+40>>2]=g;x[i+44>>2]=h;j=Oi(i+204|0,a,i+248|0,i+32|0)}if((j|0)==-1){x[23549]=0;X(1104);a=x[23549];x[23549]=0;if((a|0)==1){break d}break e}a=x[i+204>>2];Me(k,a)}f=a+j|0;g=Pi(a,f,x[c+4>>2]);x[i+116>>2]=1103;e=pe(i+120|0,0,i+116|0);g:{h:{if((i+208|0)==(a|0)){j=i+128|0;break h}j=Nd(j<<1);if(!j){x[23549]=0;X(1104);a=x[23549];x[23549]=0;if((a|0)!=1){break e}a=N()|0;break g}Me(e,j);b=a}a=i+108|0;Nc(a,x[c+28>>2]);x[23549]=0;ea(1129,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=x[23549];x[23549]=0;i:{if((a|0)!=1){Xb(i+108|0);x[23549]=0;a=ga(14,m|0,j|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break i}Kc(e);Kc(k);db=i+256|0;break b}a=N()|0;Xb(i+108|0);break g}a=N()|0}Kc(e);break c}p()}a=N()|0}Kc(k);Q(a|0);p()}return a|0}function Fda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;f=db-48|0;db=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;l=g+(f+28|0)|0;g=a+g|0;x[l+4>>2]=x[g+44>>2];x[l+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];m=x[a+68>>2];v=m>>31;n=x[a+64>>2];y=n>>31;o=x[a+60>>2];z=o>>31;l=x[a+8>>2];A=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>18|0;e=((((x[f+20>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+r|0;b=0;j=0;while(1){if((j|0)!=2){g=e+(j<<1)|0;h=w[g>>1];x[(f+8|0)+(j<<2)>>2]=h+((D(i,w[g+4>>1]-h|0)|0)/16384|0);j=j+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+28|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;q=e<<8;e=q;e=yka(o,z,e,e>>31);i=hb;k=e;e=Ub(h,-16777216,16776704);e=yka(n,y,e,e>>31);h=k+e|0;k=hb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Ub(j,-16777216,16776704);i=yka(m,v,e,e>>31);h=i+h|0;e=hb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Lc(i,e,24);x[g+4>>2]=e-(q&u);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(s,x[f+12>>2]);Qb(f+16|0,l,A);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}db=f+48|0}function uca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=db-16|0;db=g;t=x[a+16>>2];u=cg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);m=x[a+8>>2];n=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];o=x[a+128>>2];if(o){p=dg(m,n,o);q=hb;b=x[a+76>>2];Ff(h,e,bf(m,n,d),hb);r=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;a:while(1){b:{s=b;if(!d){break b}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;r=r-1|0;b=r;p=b?p:0;q=b?q:0;h=e+t|0;b=o;while(1)if((b|0)<=0){Qb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Md(i,v[h+x[g+12>>2]|0]<<6);Ld(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=bg(i,u);w=x[a+72>>2];y=x[a+32>>2];l=x[a+28>>2]+l|0;h=b<<8;b=h;e=x[a+60>>2];b=yka(e,e>>31,b,b>>31);z=hb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Ub(s,-16777216,16776704);j=yka(j,A,b,b>>31);e=e+j|0;b=hb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Ub(f,-16777216,16776704);e=yka(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Lc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(l>>12,f)+x[c>>2];k=k+y|0;x[c+4>>2]=x[c+4>>2]+D(k>>12,f);Qb(g,m,n);b=b-(h&w)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=s;continue a}else{Md(i,v[h+x[g+12>>2]|0]<<6);Ld(i,4);Qb(g+8|0,p,q);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=f;x[a+44>>2]=s;x[a+24>>2]=k>>12;db=g+16|0}function Gda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;f=db-48|0;db=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;l=g+(f+28|0)|0;g=a+g|0;x[l+4>>2]=x[g+44>>2];x[l+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];m=x[a+68>>2];w=m>>31;n=x[a+64>>2];y=n>>31;o=x[a+60>>2];z=o>>31;l=x[a+8>>2];A=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>10&4194048;e=(((x[f+20>>2]&2147483647)<<1|g>>>31)&-2)+r|0;b=0;j=0;while(1){if((j|0)!=2){g=e+j|0;h=v[g|0];x[(f+8|0)+(j<<2)>>2]=((D(i,v[g+2|0]-h|0)|0)/16384|0)+(h<<8);j=j+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+28|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;q=e<<8;e=q;e=yka(o,z,e,e>>31);i=hb;k=e;e=Ub(h,-16777216,16776704);e=yka(n,y,e,e>>31);h=k+e|0;k=hb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Ub(j,-16777216,16776704);i=yka(m,w,e,e>>31);h=i+h|0;e=hb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Lc(i,e,24);x[g+4>>2]=e-(q&u);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(s,x[f+12>>2]);Qb(f+16|0,l,A);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}db=f+48|0}function hB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=db-16|0;db=i;a:{if(b&4){break a}d=y[a+14|0];b:{if(d>>>0>=y[a+15|0]){break b}c=y[a+12|0];if(!(c&2)){break b}v[a+12|0]=c&251}if(!(y[a+12|0]&2)|d>>>0<=y[a+13|0]){break a}f=x[a>>2];c=x[a+4>>2];if(ne(f,c)>>>0<=d>>>0){break a}f=z[Fc(f,c,d)>>1];c=Fc(x[a>>2],x[a+4>>2],y[a+14|0]-1|0);d=y[a+14|0];if(z[c>>1]<(f-1|0)){d=z[Fc(x[a>>2],x[a+4>>2],d)>>1]-1&65535;f=Xp(a,d,64,64);c=vb(i+12|0,Yj(yb(x[a>>2]),y[a+14|0]));j=vo(i+8|0,d,f&255);m=db-32|0;db=m;g=x[c>>2];c=x[a>>2];g=(bu(g,yb(c))<<2)+c|0;c=x[a+4>>2];c:{d:{if(c>>>0<A[wb(a)>>2]){if((c|0)!=(g|0)){break d}AT(a,j);break c}f=wb(a);e=Jf(m+12|0,eg(a,oc(x[a>>2],c)+1|0),g-x[a>>2]>>2,f);x[23549]=0;P(721,e|0,j|0);c=x[23549];x[23549]=0;if((c|0)!=1){h=db-16|0;db=h;c=x[e+4>>2];k=vb(h+12|0,g);d=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[e+4>>2]);n=e,o=gD(x[k>>2],x[d>>2],x[f>>2]),x[n+4>>2]=o;n=e,o=xq(g,x[a+4>>2],x[e+8>>2]),x[n+8>>2]=o;Pb(a,e+4|0);Pb(a+4|0,e+8|0);Pb(wb(a),kc(e));x[e>>2]=x[e+4>>2];db=h+16|0;g=c;If(e);break c}a=N()|0;If(e);Q(a|0);p()}e=db-16|0;db=e;k=x[a+4>>2];f=(k-(g+4|0)|0)+g|0;h=oh(e+4|0,a,c-f>>2);l=x[h+4>>2];d=f;while(1){if(c>>>0<=d>>>0){fc(h);tB(g,f,k);db=e+16|0}else{kq(l,z[d>>1]|z[d+2>>1]<<16);l=l+4|0;x[h+4>>2]=l;d=d+4|0;continue}break}v[g+2|0]=y[j+2|0];w[g>>1]=z[j>>1]}yb(g);db=m+32|0;break a}v[a+14|0]=d-1}if((b|0)!=16777216){v[a+17|0]=255}db=i+16|0}function Fz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=db-32|0;db=e;if(b&5){if((b|0)==1){d=yka(x[a+24>>2],0,8363,0);c=hb;d=d+4143|0;c=d>>>0<4143?c+1|0:c;h=a,i=Qc(Bka(d,c,8287,0),hb),x[h+24>>2]=i}d=db-16|0;db=d;f=d+14|0;c=db-16|0;db=c;g=x[a+24>>2];a:{if(!g){v[f|0]=0;v[f+1|0]=0;break a}CB(c+8|0,Ub(pm(lp(+(g>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);g=x[c+8>>2];v[c+7|0]=x[c+12>>2];st(f,g,c+7|0)}db=c+16|0;vb(vb(d+4|0,a+36|0)+4|0,a+37|0);v[x[d+4>>2]]=y[f|0];v[x[d+8>>2]]=y[f+1|0];db=d+16|0}if(b&3){w[a+38>>1]=0;w[a+40>>1]=0;v[a+36|0]=0;w[a+34>>1]=z[a+34>>1]&65499}if(b&7){w[a+32>>1]=64;c=z[a+34>>1];if(c&8){d=x[a+16>>2];x[a+4>>2]=x[a+12>>2];x[a+8>>2]=d;c=c&16?c|6:c&65529|2}x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=c&65511}b:{if(!(b&4)){break b}c=z[a+34>>1];if(!(c&32)){w[a+28>>1]=128;w[a+34>>1]=c|32}pf(a+40|0,15);pf(a+41|0,63);if(!y[a+41|0]){break b}d=y[a+40|0];if(!d){break b}c=y[a+39|0];if(c){c=Km(Qc(((d<<8|c>>>1)>>>0)/(c>>>0)|0,0))}else{c=255}v[a+39|0]=c}c:{d:{if((b|0)!=4){if((b|0)==16777216){break c}if((b|0)!=32|y[a+38|0]!=2){break d}v[a+38|0]=3;break d}if(y[a+38|0]!=4){break d}v[a+38|0]=0}w[a+34>>1]=z[a+34>>1]&49151}e:{if(!(!(y[a+35|0]&2)|b&16777218)){x[e+24>>2]=0;x[e+8>>2]=0;x[e+16>>2]=0;x[e+20>>2]=0;x[e>>2]=0;x[e+4>>2]=0;xl(a,0,e);break e}if(!(y[a+35|0]&2)|(b|0)!=2){break e}a=a+68|0;b=Db(a,8);v[b|0]=y[b|0]&3;a=Db(a,9);v[a|0]=y[a|0]&3}db=e+32|0}function j5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=db+-64|0;db=e;f=Nb(a);a=0;c=x[b+24>>2];g=cj(Wb(x[c+484360>>2],y[c+484376|0]));x[23549]=0;P(167,f|0,g|0);c=x[23549];x[23549]=0;a:{if((c|0)!=1){while(1){b:{if((a|0)!=(g|0)){c=x[b+24>>2];d=x[c+484344>>2];h=x[c+484348>>2];c=z[_b(x[Wb(x[c+484360>>2],y[c+484376|0])>>2],a)>>1];if(Gm(d,h,c)){x[23549]=0;P(996,e+40|0,Yb(d,c)|0);c=x[23549];x[23549]=0;c:{d:{e:{if((c|0)!=1){c=x[b+24>>2];x[23549]=0;S(983,e+52|0,c|0,e+40|0);c=x[23549];x[23549]=0;if((c|0)==1){break e}x[23549]=0;P(169,f|0,e+52|0);c=x[23549];x[23549]=0;if((c|0)==1){break d}tb(e+52|0);tb(e+40|0);break b}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(e+52|0)}tb(e+40|0);break a}f:{switch(c-65534|0){case 0:x[23549]=0;c=O(54,e+28|0,9138)|0;d=x[23549];x[23549]=0;g:{if((d|0)!=1){x[23549]=0;P(169,f|0,c|0);d=x[23549];x[23549]=0;if((d|0)==1){break g}tb(c);break b}a=N()|0;break a}a=N()|0;tb(c);break a;case 1:x[23549]=0;c=O(54,e+16|0,9100)|0;d=x[23549];x[23549]=0;h:{if((d|0)!=1){x[23549]=0;P(169,f|0,c|0);d=x[23549];x[23549]=0;if((d|0)==1){break h}tb(c);break b}a=N()|0;break a}a=N()|0;tb(c);break a;default:break f}}x[23549]=0;c=O(54,e+4|0,14275)|0;d=x[23549];x[23549]=0;i:{if((d|0)!=1){x[23549]=0;P(169,f|0,c|0);d=x[23549];x[23549]=0;if((d|0)==1){break i}tb(c);break b}a=N()|0;break a}a=N()|0;tb(c);break a}db=e- -64|0;return}a=a+1|0;continue}}a=N()|0}Yd(f);Q(a|0);p()}function paa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;m=db-32|0;db=m;e=b;b=x[a>>2];g=D(Ts(e,yb(b)),6)+b|0;a:{if(!c){break a}b=x[wb(a)>>2];i=x[a+4>>2];if((b-i|0)/6>>>0>=c>>>0){b=c;e=(i-g|0)/6|0;if(e>>>0<c>>>0){aB(a,c-e|0,d);b=e;if((g|0)==(i|0)){break a}}n=db-16|0;db=n;o=x[a+4>>2];h=D((o-(D(c,6)+g|0)|0)/6|0,6)+g|0;f=Bq(n+4|0,a,(i-h|0)/6|0);k=x[f+4>>2];e=h;while(1){if(e>>>0>=i>>>0){fc(f);i=db-16|0;db=i;j=db-32|0;db=j;Od(j+24|0,g,h);l=db-16|0;db=l;k=x[j+28>>2];f=x[j+24>>2];h=k-f|0;e=D((h|0)/-6|0,6)+o|0;x[l+12>>2]=e;uk(e,f,h);vc(j+16|0,k,l+12|0);db=l+16|0;e=oM(g,x[j+16>>2]);p=j,q=ey(o,x[j+20>>2]),x[p+12>>2]=q;vc(i+8|0,e,j+12|0);db=j+32|0;db=i+16|0;db=n+16|0}else{hu(k,e);k=k+6|0;x[f+4>>2]=k;e=e+6|0;continue}break}e=g;c=D(e>>>0<=d>>>0?A[a+4>>2]>d>>>0?c:0:0,6)+d|0;while(1){if(b){a=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[e|0]=a;v[e+1|0]=a>>>8;v[e+2|0]=a>>>16;v[e+3|0]=a>>>24;a=y[c+4|0]|y[c+5|0]<<8;v[e+4|0]=a;v[e+5|0]=a>>>8;b=b-1|0;e=e+6|0;continue}break}break a}b=wb(a);f=ZT(m+12|0,XA(a,bk(x[a>>2],i)+c|0),(g-x[a>>2]|0)/6|0,b);YT(f,c,d);h=db-16|0;db=h;b=x[f+4>>2];e=vb(h+12|0,g);d=vb(h+8|0,x[a>>2]);c=vb(h+4|0,x[f+4>>2]);p=f,q=VT(x[e>>2],x[d>>2],x[c>>2]),x[p+4>>2]=q;p=f,q=fy(g,x[a+4>>2],x[f+8>>2]),x[p+8>>2]=q;Pb(a,f+4|0);Pb(a+4|0,f+8|0);Pb(wb(a),kc(f));x[f>>2]=x[f+4>>2];db=h+16|0;g=b;XT(f)}yb(g);db=m+32|0}function bda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;g=db-16|0;db=g;e=x[a+12>>2];h=e;a:{b:{c:{i=x[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}r=x[a+16>>2];e=x[a+48>>2];s=x[a+24>>2];t=x[a+20>>2];b=x[a+44>>2];j=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=j;u=x[a+72>>2];o=x[a+68>>2];v=o>>31;p=x[a+64>>2];y=p>>31;q=x[a+60>>2];z=q>>31;while(1){j=b;if(d){b=Ub(j,-16777216,16776704);k=yka(p,y,b,b>>31);l=hb;b=x[g+8>>2];f=(x[g+12>>2]<<1)+r|0;b=(b>>>16&65520)+n|0;f=(((((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+4>>1],w[b+10>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/32768<<8;b=f;b=yka(b,b>>31,q,z);k=b+k|0;m=hb+l|0;m=b>>>0>k>>>0?m+1|0:m;b=Ub(e,-16777216,16776704);e=yka(o,v,b,b>>31);l=e+k|0;b=hb+m|0;b=e>>>0>l>>>0?b+1|0:b;e=l+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Lc(e,b,24);b=(e|0)/256|0;x[c>>2]=D(b,t)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(b,s);Qb(g+8|0,i,h);b=e-(f&u)|0;c=c+8|0;d=d-1|0;e=j;continue}break}b=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=b;x[a+48>>2]=e;x[a+44>>2]=j;db=g+16|0}function p0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=E(0);d=x[d+28>>2];a=db-368|0;db=a;x[a+360>>2]=c;x[a+364>>2]=b;uw(a+204|0,d,a+224|0,a+220|0,a+216|0);d=Gb(a+192|0);b=Mc(d);x[23549]=0;P(59,d|0,b|0);b=x[23549];x[23549]=0;a:{b:{c:{if((b|0)!=1){c=uc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=x[a+216>>2];i=x[a+220>>2];while(1){d:{x[23549]=0;b=O(1120,a+364|0,a+360|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}if(b){break c}g=x[a+188>>2];b=Bb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[23549]=0;P(59,d|0,b<<1);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=uc(d,0);x[a+188>>2]=b+c}x[23549]=0;b=R(1121,x[a+364>>2])|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}if(tw(b,a+7|0,a+6|0,c,a+188|0,i,h,a+204|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[23549]=0;R(1123,a+364|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+208>>2],y[a+215|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=VG(c,x[a+188>>2],e),B[j>>2]=k;vf(a+204|0,a+16|0,x[a+12>>2],e);x[23549]=0;b=O(1120,a+364|0,a+360|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+364>>2];tb(d);tb(a+204|0);db=a+368|0;break a}}b=N()|0;tb(d);tb(a+204|0);Q(b|0);p()}return b|0}function y0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=E(0);d=x[d+28>>2];a=db-256|0;db=a;x[a+248>>2]=c;x[a+252>>2]=b;yw(a+192|0,d,a+208|0,a+207|0,a+206|0);d=Gb(a+180|0);b=Mc(d);x[23549]=0;P(59,d|0,b|0);b=x[23549];x[23549]=0;a:{b:{c:{if((b|0)!=1){c=uc(d,0);x[a+176>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=v[a+206|0];i=v[a+207|0];while(1){d:{x[23549]=0;b=O(1105,a+252|0,a+248|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}if(b){break c}g=x[a+176>>2];b=Bb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[23549]=0;P(59,d|0,b<<1);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=uc(d,0);x[a+176>>2]=b+c}x[23549]=0;b=R(1106,x[a+252>>2])|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}if(xw(b,a+7|0,a+6|0,c,a+176|0,i,h,a+192|0,a+16|0,a+12|0,a+8|0,a+208|0)){break c}x[23549]=0;R(1108,a+252|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+196>>2],y[a+203|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=VG(c,x[a+176>>2],e),B[j>>2]=k;vf(a+192|0,a+16|0,x[a+12>>2],e);x[23549]=0;b=O(1105,a+252|0,a+248|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];tb(d);tb(a+192|0);db=a+256|0;break a}}b=N()|0;tb(d);tb(a+192|0);Q(b|0);p()}return b|0}function o0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;d=x[d+28>>2];a=db-368|0;db=a;x[a+360>>2]=c;x[a+364>>2]=b;uw(a+204|0,d,a+224|0,a+220|0,a+216|0);d=Gb(a+192|0);b=Mc(d);x[23549]=0;P(59,d|0,b|0);b=x[23549];x[23549]=0;a:{b:{c:{if((b|0)!=1){c=uc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=x[a+216>>2];i=x[a+220>>2];while(1){d:{x[23549]=0;b=O(1120,a+364|0,a+360|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}if(b){break c}g=x[a+188>>2];b=Bb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[23549]=0;P(59,d|0,b<<1);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=uc(d,0);x[a+188>>2]=b+c}x[23549]=0;b=R(1121,x[a+364>>2])|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}if(tw(b,a+7|0,a+6|0,c,a+188|0,i,h,a+204|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[23549]=0;R(1123,a+364|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+208>>2],y[a+215|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=TG(c,x[a+188>>2],e),C[j>>3]=k;vf(a+204|0,a+16|0,x[a+12>>2],e);x[23549]=0;b=O(1120,a+364|0,a+360|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+364>>2];tb(d);tb(a+204|0);db=a+368|0;break a}}b=N()|0;tb(d);tb(a+204|0);Q(b|0);p()}return b|0}function zy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=89;i=88;j=92;k=91;l=85;m=84;n=83;o=5;p=113;q=111;r=107;s=106;t=96;u=82;v=80;w=78;x=79;y=77;z=57;A=47;d=10;e=8;f=7;c=dr(a);a:{b:{c:{d:{switch(b-1|0){default:a=(b|0)==16777216;if(!a&(b|0)!=32){break c}Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(c,0,1),7,1),8,1),9,1),10,1),11,1),12,1),13,1),14,1),15,1),16,1),17,1),18,1),19,1),20,1),21,1),22,1),23,1),24,1),25,1),26,1),27,1),28,1),29,1),30,1),31,1),32,1),33,1),34,1),35,1),36,1),37,1),38,1),39,1),40,1),41,1),42,1),43,1),44,1),45,1),46,1),47,1),48,1),103,1),50,1),87,1),88,1),100,1),102,1),104,1),115,1),119,1);if(!a){break a}d=111;e=105;f=99;break b;case 3:Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(c,0,1),4,1),8,1),9,1),10,1),17,1),40,1),51,1),52,1),53,1),54,1),55,1),56,1),57,1),58,1),59,1),60,1),61,1),62,1),63,1),64,1),65,1),66,1),67,1);p=112;q=98;r=93;s=90;t=89;u=86;v=76;w=75;x=74;y=73;z=72;A=71;d=70;e=69;g=68;case 1:Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(c,g,1),e,1),d,1),A,1),z,1),y,1),x,1),w,1);m=88;o=v;n=u;l=t;k=s;j=r;i=q;h=p;break;case 2:break c;case 0:break d}}Jb(Jb(Jb(Jb(c,o,1),n,1),m,1),l,1);g=k;f=j;e=i;d=h}Jb(c,g,1)}Jb(Jb(Jb(c,f,1),e,1),d,1)}}function x0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;d=x[d+28>>2];a=db-256|0;db=a;x[a+248>>2]=c;x[a+252>>2]=b;yw(a+192|0,d,a+208|0,a+207|0,a+206|0);d=Gb(a+180|0);b=Mc(d);x[23549]=0;P(59,d|0,b|0);b=x[23549];x[23549]=0;a:{b:{c:{if((b|0)!=1){c=uc(d,0);x[a+176>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=v[a+206|0];i=v[a+207|0];while(1){d:{x[23549]=0;b=O(1105,a+252|0,a+248|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}if(b){break c}g=x[a+176>>2];b=Bb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[23549]=0;P(59,d|0,b<<1);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=uc(d,0);x[a+176>>2]=b+c}x[23549]=0;b=R(1106,x[a+252>>2])|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}if(xw(b,a+7|0,a+6|0,c,a+176|0,i,h,a+192|0,a+16|0,a+12|0,a+8|0,a+208|0)){break c}x[23549]=0;R(1108,a+252|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+196>>2],y[a+203|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=TG(c,x[a+176>>2],e),C[j>>3]=k;vf(a+192|0,a+16|0,x[a+12>>2],e);x[23549]=0;b=O(1105,a+252|0,a+248|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];tb(d);tb(a+192|0);db=a+256|0;break a}}b=N()|0;tb(d);tb(a+192|0);Q(b|0);p()}return b|0}function PD(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=x[a>>2];e=Hg(c,x[a+4>>2]);if(e>>>0<b>>>0){j=db-32|0;db=j;c=b-e|0;b=x[wb(a)>>2];d=x[a+4>>2];a:{if(c>>>0<=b-d>>3>>>0){e=db-16|0;db=e;b=gr(e+4|0,a,c);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){fc(b);db=e+16|0}else{El(a);a=a+8|0;x[b+4>>2]=a;continue}break}break a}b=wb(a);e=ir(j+12|0,jr(a,Hg(x[a>>2],d)+c|0),Hg(x[a>>2],x[a+4>>2]),b);d=db-16|0;db=d;b=d+4|0;x[b>>2]=x[e+8>>2];f=x[e+8>>2];x[b+8>>2]=e+8;x[b+4>>2]=f+(c<<3);c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){El(c);c=x[b>>2]+8|0;x[b>>2]=c;continue}break}Kd(b);db=d+16|0;h=db-16|0;db=h;b=vb(h+12|0,x[a+4>>2]);d=vb(h+8|0,x[a>>2]);g=x[vb(h+4|0,x[e+4>>2])>>2];i=db-16|0;db=i;c=db-32|0;db=c;Od(c+24|0,x[b>>2],x[d>>2]);k=c+16|0;b=x[c+24>>2];l=x[c+28>>2];f=db-16|0;db=f;x[f+8>>2]=g;x[f+12>>2]=b;while(1){if(sd(b,l)){d=Xo(b);g=Xo(x[f+8>>2]);b=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[g|0]=d;v[g+1|0]=d>>>8;v[g+2|0]=d>>>16;v[g+3|0]=d>>>24;v[g+4|0]=b;v[g+5|0]=b>>>8;v[g+6|0]=b>>>16;v[g+7|0]=b>>>24;b=fr(f+12|0);fr(f+8|0);b=x[b>>2];continue}break}vc(k,b,f+8|0);db=f+16|0;b=x[c+16>>2];x[c+12>>2]=x[c+20>>2];vc(i+8|0,b,c+12|0);db=c+32|0;db=i+16|0;x[e+4>>2]=x[i+12>>2];Pb(a,e+4|0);Pb(a+4|0,e+8|0);Pb(wb(a),kc(e));x[e>>2]=x[e+4>>2];db=h+16|0;hr(e)}db=j+32|0;return}if(b>>>0<e>>>0){Dd(a,c+(b<<3)|0)}}function k$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=db-480|0;db=a;Nc(a+476|0,x[d+28>>2]);x[23549]=0;n=R(1115,x[a+476>>2])|0;g=x[23549];x[23549]=0;a:{b:{c:{d:{e:{if((g|0)!=1){if(Bb(x[f+4>>2],y[f+11|0])){g=x[_i(f,0)>>2];x[23549]=0;h=O(1132,n|0,45)|0;j=x[23549];x[23549]=0;if((j|0)==1){break e}o=(g|0)==(h|0)}j=Gb(a+452|0);g=Gb(a+440|0);h=Gb(a+428|0);x[23549]=0;ha(1154,c|0,o|0,x[a+476>>2],a+472|0,a+468|0,a+464|0,j|0,g|0,h|0,a+424|0);c=x[23549];x[23549]=0;if((c|0)==1){break d}x[a+4>>2]=1103;c=pe(a+8|0,0,a+4|0);k=a+16|0;l=Bb(x[f+4>>2],y[f+11|0]);m=x[a+424>>2];f:{if((l|0)>(m|0)){i=((Bb(x[h+4>>2],y[h+11|0])+(l-m<<1)|0)+Bb(x[g+4>>2],y[g+11|0])|0)+1|0;break f}i=(Bb(x[h+4>>2],y[h+11|0])+Bb(x[g+4>>2],y[g+11|0])|0)+2|0}g:{i=i+m|0;if(i>>>0>=101){Me(c,Nd(i<<2));k=x[c>>2];if(!k){break g}l=Bb(x[f+4>>2],y[f+11|0])}i=x[d+4>>2];f=Mb(f);x[23549]=0;ka(1155,k|0,a+4|0,a|0,i|0,f|0,f+(l<<2)|0,n|0,o|0,a+472|0,x[a+468>>2],x[a+464>>2],j|0,g|0,h|0,m|0);f=x[23549];x[23549]=0;if((f|0)==1){break c}x[23549]=0;b=ga(1135,b|0,k|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break c}Kc(c);Ec(h);Ec(g);tb(j);Xb(a+476|0);db=a+480|0;return b|0}x[23549]=0;X(1104);b=x[23549];x[23549]=0;if((b|0)==1){break c}p()}f=N()|0;break a}f=N()|0;break a}f=N()|0;break b}f=N()|0;Kc(c)}Ec(h);Ec(g);tb(j)}Xb(a+476|0);Q(f|0);p()}function cda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;g=db-16|0;db=g;e=x[a+12>>2];h=e;a:{b:{c:{i=x[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}p=b;q=x[a+16>>2];b=x[a+48>>2];r=x[a+24>>2];s=x[a+20>>2];e=x[a+44>>2];j=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=j;t=x[a+72>>2];l=x[a+68>>2];u=l>>31;m=x[a+64>>2];y=m>>31;n=x[a+60>>2];z=n>>31;while(1){j=e;if(d){e=Ub(j,-16777216,16776704);f=yka(m,y,e,e>>31);e=hb;b=Ub(b,-16777216,16776704);b=yka(l,u,b,b>>31);f=b+f|0;e=hb+e|0;e=b>>>0>f>>>0?e+1|0:e;b=x[g+8>>2];k=f;f=x[g+12>>2]+q|0;b=(b>>>16&65520)+p|0;o=(((((((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])|0)+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+2|0],w[b+10>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8)/32768<<8;b=o;f=yka(b,b>>31,n,z);k=k+f|0;b=hb+e|0;b=f>>>0>k>>>0?b+1|0:b;e=k+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Lc(e,b,24);b=(e|0)/256|0;x[c>>2]=D(b,s)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(b,r);Qb(g+8|0,i,h);e=e-(t&o)|0;c=c+8|0;d=d-1|0;b=j;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=b;x[a+44>>2]=j;db=g+16|0}function OZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;n=db-16|0;db=n;b=c;while(1){a:{if((b|0)==(d|0)){b=d;break a}if(!x[b>>2]){break a}b=b+4|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){q=1;r=db-16|0;db=r;s=ei(r+12|0,x[a+8>>2]);i=f;j=g-f|0;m=0;o=db-16|0;db=o;k=x[e>>2];p=b-c>>2;d:{if(!k|!p){break d}j=i?j:0;while(1){l=Ww(j>>>0<4?o+12|0:i,x[k>>2]);if((l|0)==-1){m=-1;break d}if(i){if(j>>>0<=3){if(j>>>0<l>>>0){break d}rc(i,o+12|0,l)}j=j-l|0;i=i+l|0}else{i=0}if(!x[k>>2]){k=0;break d}m=m+l|0;k=k+4|0;p=p-1|0;if(p){continue}break}}if(i){x[e>>2]=k}db=o+16|0;di(s);db=r+16|0;e:{f:{g:{h:{switch(m+1|0){case 0:x[h>>2]=f;while(1){i:{if(x[e>>2]==(c|0)){break i}b=ow(f,x[c>>2],x[a+8>>2]);if((b|0)==-1){break i}f=b+x[h>>2]|0;x[h>>2]=f;c=c+4|0;continue}break};x[e>>2]=c;break g;case 1:break c;default:break h}}f=x[h>>2]+m|0;x[h>>2]=f;if((f|0)==(g|0)){break e}if((b|0)==(d|0)){c=x[e>>2];b=d;continue}b=ow(n+12|0,0,x[a+8>>2]);if((b|0)!=-1){break f}}q=2;break c}c=n+12|0;if(g-x[h>>2]>>>0<b>>>0){break c}while(1){if(b){f=y[c|0];i=x[h>>2];x[h>>2]=i+1;v[i|0]=f;b=b-1|0;c=c+1|0;continue}break}c=x[e>>2]+4|0;x[e>>2]=c;b=c;while(1){if((b|0)==(d|0)){b=d;break b}if(!x[b>>2]){break b}b=b+4|0;continue}}c=x[e>>2]}q=(c|0)!=(d|0)}db=n+16|0;return q|0}f=x[h>>2];continue}}function kha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=db-16|0;db=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){if((d|0)==120){break a}f=(d<<2)+a|0;i=y[f+4|0];j=Db(h,d),k=i+1|0,v[j|0]=k;f=y[f+6|0]|y[f+7|0]<<8;j=_b(g,d),k=f+1|0,w[j>>1]=k;d=d+1|0;continue}}f=b+236|0;while(1){if((d|0)==96){break a}g=(d<<2)+a|0;g=y[g+6|0]|y[g+7|0]<<8;j=_b(f,d+12|0),k=g+1|0,w[j>>1]=k;d=d+1|0;continue}}BA(a+484|0,b+48|0,0,c);BA(a+590|0,b+68|0,0,c);BA(a+696|0,b+88|0,5,c);x[b>>2]=y[a+806|0]|y[a+807|0]<<8;d=v[a+808|0];b:{if((d|0)<0){v[b+34|0]=d-127;break b}if(d>>>0>16){break b}if(v[a|0]&1){v[b+31|0]=d+1;break b}if(!d){break b}v[b+31|0]=d+1}if(y[b+31|0]){c:{d:{if((c|0)==4){d=y[a+810|0];break d}d=v[a+809|0];if((d|0)>=0){w[b+28>>1]=(d&255)+1}d=v[a+810|0];if((d|0)<0){break c}}v[b+30|0]=d+1}v[b+33|0]=y[a+811|0]}if((c|0)==32){v[e+15|0]=y[a+812|0];v[e+14|0]=128;j=b,k=y[Sb(e+15|0,e+14|0)|0]>>>1|0,x[j+4>>2]=k}c=y[a+813|0]|y[a+814|0]<<8;if(c>>>0<=256){x[b+8>>2]=c;v[b+15|0]=y[b+15|0]|1}v[b+16|0]=y[a+815|0];v[b+26|0]=y[a+816|0];v[b+27|0]=y[a+817|0];v[b+17|0]=y[a+818|0];v[b+18|0]=y[a+819|0];w[e+12>>1]=y[a+820|0]|y[a+821|0]<<8;w[e+10>>1]=100;j=b,k=y[Uc(e+12|0,e+10|0)|0],v[j+20|0]=k;w[e+8>>1]=y[a+822|0]|y[a+823|0]<<8;w[e+6>>1]=256;j=b,k=z[Uc(e+8|0,e+6|0)>>1]>>>2|0,v[j+19|0]=k;c=y[a+824|0];Mm(b,c&127,c>>>7|0);a=y[a+825|0];Lm(b,a&127,a>>>7|0);db=e+16|0}function Vda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;f=db-48|0;db=f;q=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;k=g+(f+28|0)|0;g=a+g|0;x[k+4>>2]=x[g+44>>2];x[k+8>>2]=x[g+48>>2];b=b+1|0;continue}break}r=x[a+24>>2];s=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;t=x[a+72>>2];l=x[a+68>>2];u=l>>31;m=x[a+64>>2];v=m>>31;n=x[a+60>>2];y=n>>31;k=x[a+8>>2];z=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+q|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=w[g+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){o=(f+8|0)+(b<<2)|0;e=x[o>>2];g=(f+28|0)+(b<<3)|0;A=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;p=e<<8;e=p;e=yka(n,y,e,e>>31);i=hb;j=e;e=Ub(h,-16777216,16776704);e=yka(m,v,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Ub(A,-16777216,16776704);i=yka(l,u,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Lc(i,e,24);x[g+4>>2]=e-(p&t);x[o>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],s);x[c+4>>2]=x[c+4>>2]+D(r,x[f+12>>2]);Qb(f+16|0,k,z);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}db=f+48|0}function s0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=db-336|0;db=a;x[a+328>>2]=c;x[a+332>>2]=b;b=Si(x[d+4>>2]);i=op(x[d+28>>2],a+208|0);np(a+196|0,x[d+28>>2],a+324|0);d=Gb(a+184|0);c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;a:{b:{c:{if((c|0)!=1){c=uc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[23549]=0;g=O(1120,a+332|0,a+328|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[23549]=0;P(59,d|0,g<<1);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=uc(d,0);x[a+180>>2]=g+c}x[23549]=0;g=R(1121,x[a+332>>2])|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}if(on(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[23549]=0;R(1123,a+332|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=_G(c,x[a+180>>2],e,b),x[j>>2]=k;x[f+4>>2]=hb;vf(a+196|0,a+16|0,x[a+12>>2],e);x[23549]=0;b=O(1120,a+332|0,a+328|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);db=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function q0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=db-336|0;db=a;x[a+328>>2]=c;x[a+332>>2]=b;b=Si(x[d+4>>2]);i=op(x[d+28>>2],a+208|0);np(a+196|0,x[d+28>>2],a+324|0);d=Gb(a+184|0);c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;a:{b:{c:{if((c|0)!=1){c=uc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[23549]=0;g=O(1120,a+332|0,a+328|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[23549]=0;P(59,d|0,g<<1);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=uc(d,0);x[a+180>>2]=g+c}x[23549]=0;g=R(1121,x[a+332>>2])|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}if(on(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[23549]=0;R(1123,a+332|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=WG(c,x[a+180>>2],e,b),x[j>>2]=k;x[f+4>>2]=hb;vf(a+196|0,a+16|0,x[a+12>>2],e);x[23549]=0;b=O(1120,a+332|0,a+328|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);db=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function o$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=db-176|0;db=a;Nc(a+172|0,x[d+28>>2]);x[23549]=0;n=R(18,x[a+172>>2])|0;g=x[23549];x[23549]=0;a:{b:{c:{d:{e:{if((g|0)!=1){if(Bb(x[f+4>>2],y[f+11|0])){g=y[uc(f,0)|0];x[23549]=0;h=O(19,n|0,45)|0;j=x[23549];x[23549]=0;if((j|0)==1){break e}o=(g|0)==(h&255)}j=Gb(a+152|0);g=Gb(a+140|0);h=Gb(a+128|0);x[23549]=0;ha(1152,c|0,o|0,x[a+172>>2],a+168|0,a+167|0,a+166|0,j|0,g|0,h|0,a+124|0);c=x[23549];x[23549]=0;if((c|0)==1){break d}x[a+4>>2]=1103;c=pe(a+8|0,0,a+4|0);k=a+16|0;l=Bb(x[f+4>>2],y[f+11|0]);m=x[a+124>>2];f:{if((l|0)>(m|0)){i=((Bb(x[h+4>>2],y[h+11|0])+(l-m<<1)|0)+Bb(x[g+4>>2],y[g+11|0])|0)+1|0;break f}i=(Bb(x[h+4>>2],y[h+11|0])+Bb(x[g+4>>2],y[g+11|0])|0)+2|0}g:{i=i+m|0;if(i>>>0>=101){Me(c,Nd(i));k=x[c>>2];if(!k){break g}l=Bb(x[f+4>>2],y[f+11|0])}i=x[d+4>>2];f=Mb(f);x[23549]=0;ka(1153,k|0,a+4|0,a|0,i|0,f|0,f+l|0,n|0,o|0,a+168|0,v[a+167|0],v[a+166|0],j|0,g|0,h|0,m|0);f=x[23549];x[23549]=0;if((f|0)==1){break c}x[23549]=0;b=ga(14,b|0,k|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break c}Kc(c);tb(h);tb(g);tb(j);Xb(a+172|0);db=a+176|0;return b|0}x[23549]=0;X(1104);b=x[23549];x[23549]=0;if((b|0)==1){break c}p()}f=N()|0;break a}f=N()|0;break a}f=N()|0;break b}f=N()|0;Kc(c)}tb(h);tb(g);tb(j)}Xb(a+172|0);Q(f|0);p()}function Yea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=db-16|0;db=i;nd(d,32);h=i+8|0;VQ(h,y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24),y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24),x[b>>2]);h=gc(h);VQ(i,y[a+40|0]|y[a+41|0]<<8|(y[a+42|0]<<16|y[a+43|0]<<24),y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24),x[c>>2]);a=0;a:{h=x[h>>2];if(h-838861>>>0<4294128436){break a}e=x[gc(i)>>2];x[d>>2]=D(h,320);w[d+34>>1]=1;if(!zg(d)){break a}k=h<<2;f=+(k>>>0);o=+(e>>>0)/f;p=+(h>>>0)/f;q=1/+A[d>>2];r=+A[i>>2];s=+A[i+8>>2];h=0;b:while(1){if((h|0)==(k|0)){a=1;break a}l=+(h>>>0);m=0;n=0;a=x[b+20>>2];if(Sd(x[b>>2],a)){f=l*p+s;c:{if(f<4294967296&f>=0){g=~~f>>>0;break c}g=0}e=g;f=f-+(e>>>0);e=z[b+34>>1];j=Jd(e);g=D(g,j);d:{if(e&1){e=w[a+(g<<1)>>1];a=z[a+(g+j<<1)>>1];break d}e=y[a+g|0]<<8;a=y[a+(g+j|0)|0]<<8}n=+(e<<16>>16)*(1-f)+f*+(a<<16>>16)}a=x[c+20>>2];if(Sd(x[c>>2],a)){f=l*o+r;e:{if(f<4294967296&f>=0){g=~~f>>>0;break e}g=0}e=g;f=f-+(e>>>0);e=z[c+34>>1];j=Jd(e);g=D(g,j);f:{if(e&1){e=w[a+(g<<1)>>1];a=z[a+(g+j<<1)>>1];break f}e=y[a+g|0]<<8;a=y[a+(g+j|0)|0]<<8}m=+(e<<16>>16)*(1-f)+f*+(a<<16>>16)}e=0;a=h;while(1)if((e|0)==80){h=h+1|0;continue b}else{f=q*+(a>>>0);t=x[d+20>>2]+(a<<1)|0,u=Tz(n*(1-f)+m*f),w[t>>1]=u;a=a+k|0;e=e+1|0;continue}}}db=i+16|0;return a|0}function xfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=db-48|0;db=e;nd(b,2);f=e+24|0;ck(f,2,a+1|0);d=e+36|0;Bc(d,f);Ce(b+43|0,d);tb(d);a:{b:{c:{d:{switch(y[a|0]){case 0:f=x[b+4>>2];d=x[b+8>>2];break c;case 2:break b;case 1:break d;default:break a}}d=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);x[b>>2]=d;x[e+36>>2]=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);x[e+24>>2]=d-1;d=e+36|0;f=x[Cb(d,e+24|0)>>2];x[b+4>>2]=f;x[e+36>>2]=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);d=x[Cb(d,b)>>2];x[b+8>>2]=d;w[b+34>>1]=z[b+34>>1]&65533|y[a+31|0]<<1&2}if(d>>>0>f>>>0&d>>>0>=2){break a}w[b+34>>1]=0;x[b+4>>2]=0;x[b+8>>2]=0;break a}f=e+24|0;Bh(f,a+16|0);d=x[e+24>>2];x[e+36>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);Bh(f,a+20|0);d=x[e+24>>2];x[e+40>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);Bh(f,a+24|0);d=x[e+24>>2];d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[e+44>>2]=d;x[e+16>>2]=d;d=x[e+40>>2];x[e+8>>2]=x[e+36>>2];x[e+12>>2]=d;xl(b,1,e+8|0)}v[e+36|0]=y[a+28|0];v[e+24|0]=64;g=b,h=y[Sb(e+36|0,e+24|0)|0]<<2,w[g+30>>1]=h;d=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);x[b+24>>2]=d;b=b+24|0;e:{if(!c){break e}if(y[a|0]==2){d=d&65535;x[b>>2]=d;break e}if(A[b>>2]>=65536){x[b>>2]=65535}d=x[b>>2]}f:{g:{if(!d){a=8363;break g}a=1024;if(d>>>0>1023){break f}}x[b>>2]=a}db=e+48|0}function t0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=db-336|0;db=a;x[a+328>>2]=c;x[a+332>>2]=b;b=Si(x[d+4>>2]);i=op(x[d+28>>2],a+208|0);np(a+196|0,x[d+28>>2],a+324|0);d=Gb(a+184|0);c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;a:{b:{c:{if((c|0)!=1){c=uc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[23549]=0;g=O(1120,a+332|0,a+328|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[23549]=0;P(59,d|0,g<<1);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=uc(d,0);x[a+180>>2]=g+c}x[23549]=0;g=R(1121,x[a+332>>2])|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}if(on(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[23549]=0;R(1123,a+332|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=aH(c,x[a+180>>2],e,b),x[j>>2]=k;vf(a+196|0,a+16|0,x[a+12>>2],e);x[23549]=0;b=O(1120,a+332|0,a+328|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);db=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function r0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=db-336|0;db=a;x[a+328>>2]=c;x[a+332>>2]=b;b=Si(x[d+4>>2]);i=op(x[d+28>>2],a+208|0);np(a+196|0,x[d+28>>2],a+324|0);d=Gb(a+184|0);c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;a:{b:{c:{if((c|0)!=1){c=uc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[23549]=0;g=O(1120,a+332|0,a+328|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[23549]=0;P(59,d|0,g<<1);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=uc(d,0);x[a+180>>2]=g+c}x[23549]=0;g=R(1121,x[a+332>>2])|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}if(on(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[23549]=0;R(1123,a+332|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=ZG(c,x[a+180>>2],e,b),w[j>>1]=k;vf(a+196|0,a+16|0,x[a+12>>2],e);x[23549]=0;b=O(1120,a+332|0,a+328|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);db=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function PG(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=db-336|0;db=a;x[a+328>>2]=c;x[a+332>>2]=b;b=Si(x[d+4>>2]);i=op(x[d+28>>2],a+208|0);np(a+196|0,x[d+28>>2],a+324|0);d=Gb(a+184|0);c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;a:{b:{c:{if((c|0)!=1){c=uc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[23549]=0;g=O(1120,a+332|0,a+328|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[23549]=0;P(59,d|0,g<<1);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=uc(d,0);x[a+180>>2]=g+c}x[23549]=0;g=R(1121,x[a+332>>2])|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}if(on(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[23549]=0;R(1123,a+332|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=XG(c,x[a+180>>2],e,b),x[j>>2]=k;vf(a+196|0,a+16|0,x[a+12>>2],e);x[23549]=0;b=O(1120,a+332|0,a+328|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);db=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function XF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;a=db-16|0;db=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{c:{while(1){c=x[a+12>>2];if(!(c>>>0>=d>>>0|f>>>0>=g>>>0)){i=v[c|0];j=i&255;d:{if((i|0)>=0){w[f>>1]=j;b=c+1|0;break d}b=2;if(i>>>0<4294967234){break b}if(i>>>0<=4294967263){if((d-c|0)<2){break c}i=y[c+1|0];if((i&192)!=128){break a}w[f>>1]=i&63|j<<6&1984;b=c+2|0;break d}if(i>>>0<=4294967279){if((d-c|0)<3){break c}k=y[c+2|0];i=y[c+1|0];e:{f:{if((j|0)!=237){if((j|0)!=224){break f}if((i&224)==160){break e}break a}if((i&224)==128){break e}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}w[f>>1]=k&63|((i&63)<<6|j<<12);b=c+3|0;break d}if(i>>>0>4294967284){break b}b=1;if((d-c|0)<4){break a}k=y[c+3|0];i=y[c+2|0];c=y[c+1|0];g:{h:{switch(j-240|0){case 0:if((c+112&255)>>>0>=48){break b}break g;case 4:if((c&240)!=128){break b}break g;default:break h}}if((c&192)!=128){break b}}if((i&192)!=128|(k&192)!=128){break b}if((g-f|0)<4){break a}b=2;j=j&7;if((c<<12&196608|j<<18)>>>0>1114111){break a}b=c<<2;w[f>>1]=(i>>>4&3|(b&192|j<<8|b&60))+16320|55296;x[a+8>>2]=f+2;w[f+2>>1]=i<<6&960|k&63|56320;b=x[a+12>>2]+4|0}x[a+12>>2]=b;f=x[a+8>>2]+2|0;x[a+8>>2]=f;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];db=a+16|0;return b|0}function Wda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;f=db-48|0;db=f;q=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;k=g+(f+28|0)|0;g=a+g|0;x[k+4>>2]=x[g+44>>2];x[k+8>>2]=x[g+48>>2];b=b+1|0;continue}break}r=x[a+24>>2];s=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;t=x[a+72>>2];l=x[a+68>>2];u=l>>31;m=x[a+64>>2];w=m>>31;n=x[a+60>>2];y=n>>31;k=x[a+8>>2];z=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+q|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=v[e+g|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){o=(f+8|0)+(b<<2)|0;e=x[o>>2];g=(f+28|0)+(b<<3)|0;A=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;p=e<<8;e=p;e=yka(n,y,e,e>>31);i=hb;j=e;e=Ub(h,-16777216,16776704);e=yka(m,w,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Ub(A,-16777216,16776704);i=yka(l,u,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Lc(i,e,24);x[g+4>>2]=e-(p&t);x[o>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],s);x[c+4>>2]=x[c+4>>2]+D(r,x[f+12>>2]);Qb(f+16|0,k,z);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}db=f+48|0}function UI(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=db-16|0;db=h;g=x[a+32>>2];f=ys(g);if(!f){f=xs(g)}a:{b:{c:{if(b>>>0>=f>>>0){b=ac(8);x[23549]=0;c=O(54,h+4|0,5941)|0;a=x[23549];x[23549]=0;if((a|0)==1){break c}a=pc(b,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}if(c>>>0>=120){b=ac(8);x[23549]=0;c=O(54,h+4|0,11176)|0;a=x[23549];x[23549]=0;if((a|0)!=1){a=pc(b,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=N()|0;jc(b);break b}f=Ly(g,65535);j=(f|0)==65535?255:f;w[h+4>>1]=j;f=g+D(j,872)|0;i=f+1074992|0;ko(i,g,65535,1024);c=c+1|0;v[f+1075794|0]=c;v[f+1075791|0]=c;w[f+1075778>>1]=0;hm(i);Pp(x[a+32>>2],i,b+1|0,0,1,1);x[f+1075688>>2]=65536;ht(x[a+32>>2],i,c,0,1,1,65535);l=f+1075684|0,m=pm(bz(e*128,-128,128)+128),x[l>>2]=m;l=f+1075680|0,m=pm(bz(d*256,0,256)),x[l>>2]=m;c=x[a+32>>2];i=c+1074478|0;b=i;c=b+(z[c+480212>>1]<<1)|0;g=z[h+4>>1];f=g;while(1){d:{e:{if((b|0)!=(c|0)){if((f|0)!=z[b>>1]){break e}}else{b=c}break d}b=b+2|0;continue}break}f:{if((b|0)==(c|0)){break f}f=b;while(1){f=f+2|0;if((f|0)==(c|0)){c=b;break f}k=z[f>>1];if((k|0)==(g|0)){continue}w[b>>1]=k;b=b+2|0;g=z[h+4>>1];continue}}l=x[a+32>>2],m=jz(i,c),w[l+480212>>1]=m;db=h+16|0;return j|0}a=N()|0;jc(b)}Q(a|0)}p()}function z0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=db-224|0;db=a;x[a+216>>2]=c;x[a+220>>2]=b;b=Si(g);pp(a+200|0,d,a+215|0);d=Gb(a+188|0);c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;a:{b:{c:{if((c|0)!=1){c=uc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[23549]=0;g=O(1105,a+220|0,a+216|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[23549]=0;P(59,d|0,g<<1);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=uc(d,0);x[a+184>>2]=g+c}x[23549]=0;g=R(1106,x[a+220>>2])|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}if(rn(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,81792)){break c}x[23549]=0;R(1108,a+220|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=WG(c,x[a+184>>2],e,b),x[i>>2]=j;x[f+4>>2]=hb;vf(a+200|0,a+16|0,x[a+12>>2],e);x[23549]=0;b=O(1105,a+220|0,a+216|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);db=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function B0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=db-224|0;db=a;x[a+216>>2]=c;x[a+220>>2]=b;b=Si(g);pp(a+200|0,d,a+215|0);d=Gb(a+188|0);c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;a:{b:{c:{if((c|0)!=1){c=uc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[23549]=0;g=O(1105,a+220|0,a+216|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[23549]=0;P(59,d|0,g<<1);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=uc(d,0);x[a+184>>2]=g+c}x[23549]=0;g=R(1106,x[a+220>>2])|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}if(rn(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,81792)){break c}x[23549]=0;R(1108,a+220|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=_G(c,x[a+184>>2],e,b),x[i>>2]=j;x[f+4>>2]=hb;vf(a+200|0,a+16|0,x[a+12>>2],e);x[23549]=0;b=O(1105,a+220|0,a+216|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);db=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function FE(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=Gb(a);a=y[b+11|0];h=x[b+4>>2];x[23549]=0;m=Oc(h,a);P(g|0,k|0,m|0);a=x[23549];x[23549]=0;a:{b:{if((a|0)!=1){g=0;a=0;while(1){c:{if((a|0)==(m|0)){a=!i;if(!(n?a&(o^-1):a)){break c}return}h=v[uc(b,a)|0];j=h&255;d:{e:{f:{g:{switch(i+1|0){case 1:i=1;h:{switch(j-123|0){case 2:break h;case 0:break d;default:break f}}i=3;break d;case 2:i:{switch(j-123|0){case 2:o=1;h=g+1|0;i=0;if(d>>>0<=g>>>0){g=h;break d}x[23549]=0;O(f|0,k|0,$d(c,g)|0)|0;j=x[23549];x[23549]=0;g=h;if((j|0)!=1){break d}a=N()|0;break b;case 0:break f;default:break i}}i=-1;h=h-48|0;if((h&255)>>>0>9){break d}n=1;i=2;l=h;break d;case 3:i=-1;j:{switch(j-123|0){case 2:i=0;if(d>>>0<=l>>>0){break d}x[23549]=0;O(f|0,k|0,$d(c,l)|0)|0;h=x[23549];x[23549]=0;if((h|0)!=1){break d}a=N()|0;break b;case 0:break d;default:break j}}if((h-48&255)>>>0>9){break d}l=(D(l,10)+h|0)-48|0;n=1;i=2;break d;case 4:break g;case 0:break e;default:break d}}j=(h|0)!=125;i=-1;h=125;if(j){break d}}i=0;x[23549]=0;O(e|0,k|0,h|0)|0;h=x[23549];x[23549]=0;if((h|0)!=1){break d}a=N()|0;break b}i=-1}a=a+1|0;continue}break}b=ac(8);x[23549]=0;a=R(104,b|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){x[23549]=0;S(105,a|0,42036,24);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;break b}a=N()|0;jc(b);break b}a=N()|0}tb(k);Q(a|0)}p()}function xE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=db-80|0;db=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!b){Tb(a,9633);break j}d=b>>>24|0;if(!(b&65535)){e=db-16|0;db=e;f=Tb(e+4|0,4340);ad(c+68|0,f);tb(f);db=e+16|0;x[23549]=0;x[c+24>>2]=d;P(95,c+56|0,c+24|0);d=x[23549];x[23549]=0;k:{l:{m:{n:{if((d|0)!=1){x[23549]=0;x[c+8>>2]=b>>>16&255;P(96,c+44|0,c+8|0);b=x[23549];x[23549]=0;if((b|0)==1){break n}x[23549]=0;V(97,a|0,c+68|0,c+56|0,c+44|0);a=x[23549];x[23549]=0;if((a|0)==1){break m}tb(c+44|0);tb(c+56|0);Ab(c+68|0);break j}b=N()|0;break k}b=N()|0;break l}b=N()|0;tb(c+44|0)}tb(c+56|0)}break a}e=db-16|0;db=e;f=Tb(e+4|0,4064);ad(c+68|0,f);tb(f);db=e+16|0;x[23549]=0;x[c+40>>2]=d;P(95,c+56|0,c+40|0);d=x[23549];x[23549]=0;if((d|0)==1){break i}x[23549]=0;x[c+36>>2]=b>>>16&255;P(96,c+44|0,c+36|0);d=x[23549];x[23549]=0;if((d|0)==1){break h}x[23549]=0;x[c+20>>2]=b>>>8&255;P(96,c+24|0,c+20|0);d=x[23549];x[23549]=0;if((d|0)==1){break g}x[23549]=0;x[c+4>>2]=b&255;P(96,c+8|0,c+4|0);b=x[23549];x[23549]=0;if((b|0)==1){break f}x[23549]=0;ia(98,a|0,c+68|0,c+56|0,c+44|0,c+24|0,c+8|0);a=x[23549];x[23549]=0;if((a|0)==1){break e}tb(c+8|0);tb(c+24|0);tb(c+44|0);tb(c+56|0);Ab(c+68|0)}db=c+80|0;return}b=N()|0;break a}b=N()|0;break b}b=N()|0;break c}b=N()|0;break d}b=N()|0;tb(c+8|0)}tb(c+24|0)}tb(c+44|0)}tb(c+56|0)}Ab(c+68|0);Q(b|0);p()}function xca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;g=db-16|0;db=g;r=x[a+16>>2];s=cg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);k=x[a+8>>2];l=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];m=x[a+128>>2];if(m){n=dg(k,l,m);o=hb;b=x[a+76>>2];Ff(h,e,bf(k,l,d),hb);p=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];t=x[a+24>>2];u=x[a+20>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;a:while(1){b:{q=b;if(!d){break b}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;p=p-1|0;b=p;n=b?n:0;o=b?o:0;h=(e<<1)+r|0;b=m;while(1)if((b|0)<=0){Qb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Md(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);Ld(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=bg(i,s);v=x[a+72>>2];h=b<<8;b=h;e=x[a+60>>2];b=yka(e,e>>31,b,b>>31);y=hb;e=b;b=x[a+64>>2];j=b;z=b>>31;b=Ub(q,-16777216,16776704);j=yka(j,z,b,b>>31);e=e+j|0;b=hb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Ub(f,-16777216,16776704);e=yka(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Lc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(f,u)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,t);Qb(g,k,l);b=b-(h&v)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=q;continue a}else{Md(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);Ld(i,4);Qb(g+8|0,n,o);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+48>>2]=f;x[a+44>>2]=q;db=g+16|0}function FP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;h=db-16|0;db=h;c=x[a>>2];a:{if(Sj(c)){i=db-16|0;db=i;e=Hc(3848);d=e+808|0;c=e+16|0;while(1){x[c+16>>2]=0;x[c+20>>2]=0;x[c+36>>2]=0;v[c+42|0]=1;w[c+40>>1]=257;x[c+24>>2]=0;x[c+28>>2]=0;w[c+32>>1]=0;c=c+44|0;if((c|0)!=(d|0)){continue}break}c=e+3832|0;while(1){x[d>>2]=0;x[d+4>>2]=0;x[d+68>>2]=0;x[d+72>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;w[d+20>>1]=511;x[d+16>>2]=-1;w[d+14>>1]=1;w[d+6>>1]=0;w[d+8>>1]=0;w[d+10>>1]=0;w[d+12>>1]=0;v[d+73|0]=0;v[d+74|0]=0;v[d+75|0]=0;v[d+76|0]=0;v[d+77|0]=0;v[d+78|0]=0;v[d+79|0]=0;v[d+80|0]=0;d=d+84|0;if((c|0)!=(d|0)){continue}break}x[e+3832>>2]=0;x[e+3836>>2]=0;c=e+3837|0;v[c|0]=0;v[c+1|0]=0;v[c+2|0]=0;v[c+3|0]=0;v[c+4|0]=0;v[c+5|0]=0;v[c+6|0]=0;v[c+7|0]=0;while(1){if((g|0)==36){while(1){if((f|0)==18){b:{f=0;g=0;while(1)if((f|0)==18){while(1){if((g|0)==36){break b}jo((e+D(g,84)|0)+808|0);g=g+1|0;continue}}else{d=(e+D(f,44)|0)+16|0;c=x[(f<<2)+28976>>2];c:{if(!(!(1<<f&3591)|f>>>0>11)){c=e+D(c,84)|0;LP(d,c+808|0,c+1060|0,c+1312|0,c+1564|0);break c}c=e+D(c,84)|0;LP(d,c+808|0,c+1060|0,0,0)}f=f+1|0;continue}}}else{x[(e+D(f,44)|0)+32>>2]=e;f=f+1|0;continue}break}KP(e,b)}else{zd((e+D(g,84)|0)+808|0,e);g=g+1|0;continue}break}b=x[of(i+12|0,e)>>2];db=i+16|0;x[h+12>>2]=b;b=h+12|0;gA(a,b);ij(b);break a}KP(c,b)}EP(a);db=h+16|0}function EI(a){var b=0,c=0,d=0,e=0;ve(x[a+80>>2],x[a+20>>2]);while(1){c=x[a+28>>2];if((b|0)<x[a+24>>2]){ve(x[a+80>>2],x[c+(b<<2)>>2]);b=b+1|0;continue}break}ve(x[a+80>>2],c);a:{if(!x[a+396>>2]){break a}c=0;while(1){if(x[a+264>>2]<=(c|0)){break a}e=x[a+396>>2]+D(c,24)|0;d=x[e+16>>2];if(d){b=0;while(1){if((b|0)<x[(x[a+124>>2]+D(y[e+13|0],2096)|0)+4>>2]){ve(x[a+80>>2],x[(b<<2)+d>>2]);b=b+1|0;d=x[e+16>>2];continue}break}ve(x[a+80>>2],d)}ve(x[a+80>>2],x[e+20>>2]);c=c+1|0;continue}}d=x[a+124>>2];if(d){c=0;while(1){if((c|0)<x[a+120>>2]){b=D(c,2096)+d|0;ve(x[a+80>>2],x[b+8>>2]);ve(x[a+80>>2],x[b+28>>2]);ve(x[a+80>>2],x[b+32>>2]);ve(x[a+80>>2],x[b+2084>>2]);b=x[b+2088>>2];ve(x[a+80>>2],b?b-4|0:0);c=c+1|0;d=x[a+124>>2];continue}break}ve(x[a+80>>2],d)}ve(x[a+80>>2],x[a+260>>2]);ve(x[a+80>>2],x[a+396>>2]);c=x[a+404>>2];if(c){b=0;while(1){if((b|0)<x[a+400>>2]){ve(x[a+80>>2],x[(D(b,40)+c|0)+4>>2]);b=b+1|0;c=x[a+404>>2];continue}break}ve(x[a+80>>2],c)}c=0;b=0;while(1){if(!(x[a+4>>2]<=(b|0)|b>>>0>15)){d=(b<<2)+a|0;ve(x[a+80>>2],x[d+800>>2]);ve(x[a+80>>2],x[d+928>>2]);ve(x[a+80>>2],x[d+996>>2]);b=b+1|0;continue}break}while(1){if((c|0)!=2){b=(c<<2)+a|0;ve(x[a+80>>2],x[b+1068>>2]);ve(x[a+80>>2],x[b+1076>>2]);ve(x[a+80>>2],x[b+1084>>2]);ve(x[a+80>>2],x[b+1092>>2]);ve(x[a+80>>2],x[b+1100>>2]);c=c+1|0;continue}break}}function $$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=db-16|0;db=k;l=Nw(x[g>>2]);g=ww(x[g>>2]);Mg(k+4|0,g);a:{b:{if(xd(x[k+8>>2],y[k+15|0])){x[23549]=0;V(1126,l|0,a|0,c|0,d|0);g=x[23549];x[23549]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[23549]=0;j=O(1132,l|0,h<<24>>24)|0;h=x[23549];x[23549]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[23549]=0;h=O(1132,l|0,48)|0;i=x[23549];x[23549]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;h=v[j+1|0];x[23549]=0;h=O(1132,l|0,h|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;j=j+2|0}Nl(j,c);i=0;x[23549]=0;o=R(1124,g|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){Qr((j-a<<2)+d|0,x[f>>2]);g=x[f>>2];break a}e:{if(!y[uc(k+4|0,h)|0]){break e}if(v[uc(k+4|0,h)|0]!=(i|0)){break e}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=o;h=(Bb(x[k+8>>2],y[k+15|0])-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[23549]=0;n=O(1132,l|0,n|0)|0;m=x[23549];x[23549]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+4;x[m>>2]=n;g=g+1|0;i=i+1|0;continue}break}}a=N()|0;tb(k+4|0);Q(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;tb(k+4|0);db=k+16|0}function CC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=db-16|0;db=h;d=x[b>>2];e=Ic(d,x[b+4>>2]);a:{if(e>>>0<c>>>0){l=db-32|0;db=l;d=c-e|0;e=x[wb(b)>>2];f=x[b+4>>2];b:{if(d>>>0<=e-f>>1>>>0){f=db-16|0;db=f;d=Ei(f+4|0,b,d);e=x[d+4>>2];g=x[d+8>>2];while(1){if((e|0)==(g|0)){fc(d);db=f+16|0}else{Pq(e);e=e+2|0;x[d+4>>2]=e;continue}break}break b}e=wb(b);e=uj(l+12|0,vj(b,Ic(x[b>>2],f)+d|0),Ic(x[b>>2],x[b+4>>2]),e);g=db-16|0;db=g;d=So(g+4|0,e+8|0,d);f=x[d>>2];while(1){if(x[d+4>>2]!=(f|0)){Pq(f);f=x[d>>2]+2|0;x[d>>2]=f;continue}break}Kd(d);db=g+16|0;i=db-16|0;db=i;f=vb(i+12|0,x[b+4>>2]);g=vb(i+8|0,x[b>>2]);j=x[vb(i+4|0,x[e+4>>2])>>2];k=db-16|0;db=k;m=k+8|0;d=db-32|0;db=d;Od(d+24|0,x[f>>2],x[g>>2]);n=d+16|0;g=x[d+24>>2];o=x[d+28>>2];f=db-16|0;db=f;x[f+8>>2]=j;x[f+12>>2]=g;while(1){if(sd(g,o)){g=Om(g);j=Om(x[f+8>>2]);g=y[g|0]|y[g+1|0]<<8;v[j|0]=g;v[j+1|0]=g>>>8;g=qk(f+12|0);qk(f+8|0);g=x[g>>2];continue}break}vc(n,g,f+8|0);db=f+16|0;f=x[d+16>>2];x[d+12>>2]=x[d+20>>2];vc(m,f,d+12|0);db=d+32|0;db=k+16|0;x[e+4>>2]=x[k+12>>2];Pb(b,e+4|0);Pb(b+4|0,e+8|0);Pb(wb(b),kc(e));x[e>>2]=x[e+4>>2];db=i+16|0;Di(e)}db=l+32|0;break a}if(c>>>0<e>>>0){Dd(b,d+(c<<1)|0)}}c=Lb(x[a>>2],x[a+8>>2],c<<1);if(c){e=x[b>>2];dc(h+8|0,e,Ic(e,x[b+4>>2])<<1);pd(h,a,x[h+8>>2],x[h+12>>2])}db=h+16|0;return c|0}function YG(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=db-224|0;db=a;x[a+216>>2]=c;x[a+220>>2]=b;b=Si(g);pp(a+200|0,d,a+215|0);d=Gb(a+188|0);c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;a:{b:{c:{if((c|0)!=1){c=uc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[23549]=0;g=O(1105,a+220|0,a+216|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[23549]=0;P(59,d|0,g<<1);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=uc(d,0);x[a+184>>2]=g+c}x[23549]=0;g=R(1106,x[a+220>>2])|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}if(rn(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,81792)){break c}x[23549]=0;R(1108,a+220|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=XG(c,x[a+184>>2],e,b),x[i>>2]=j;vf(a+200|0,a+16|0,x[a+12>>2],e);x[23549]=0;b=O(1105,a+220|0,a+216|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);db=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function C0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=db-224|0;db=a;x[a+216>>2]=c;x[a+220>>2]=b;b=Si(g);pp(a+200|0,d,a+215|0);d=Gb(a+188|0);c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;a:{b:{c:{if((c|0)!=1){c=uc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[23549]=0;g=O(1105,a+220|0,a+216|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[23549]=0;P(59,d|0,g<<1);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=uc(d,0);x[a+184>>2]=g+c}x[23549]=0;g=R(1106,x[a+220>>2])|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}if(rn(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,81792)){break c}x[23549]=0;R(1108,a+220|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=aH(c,x[a+184>>2],e,b),x[i>>2]=j;vf(a+200|0,a+16|0,x[a+12>>2],e);x[23549]=0;b=O(1105,a+220|0,a+216|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);db=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function A0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=db-224|0;db=a;x[a+216>>2]=c;x[a+220>>2]=b;b=Si(g);pp(a+200|0,d,a+215|0);d=Gb(a+188|0);c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;a:{b:{c:{if((c|0)!=1){c=uc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[23549]=0;g=O(1105,a+220|0,a+216|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[23549]=0;P(59,d|0,g<<1);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=Mc(d);x[23549]=0;P(59,d|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=uc(d,0);x[a+184>>2]=g+c}x[23549]=0;g=R(1106,x[a+220>>2])|0;h=x[23549];x[23549]=0;if((h|0)==1){break d}if(rn(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,81792)){break c}x[23549]=0;R(1108,a+220|0)|0;g=x[23549];x[23549]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=ZG(c,x[a+184>>2],e,b),w[i>>1]=j;vf(a+200|0,a+16|0,x[a+12>>2],e);x[23549]=0;b=O(1105,a+220|0,a+216|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);db=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function JJ(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{b:{switch(e<<31|e-2>>>1){case 4:Kx(a,b,c,d);return;case 0:e=32-G(d|1)|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<17){while(1){b=b-1|0;v[b|0]=y[(d&1)+14993|0];e=d>>>0>1;d=d>>>1|0;if(e){continue}break}}else{b=b-4|0;Gs((d<<2&60)+25328|0,4,b);d=d>>>4|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;case 3:e=(34-G(d|1)>>>0)/3|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<65){while(1){b=b-1|0;v[b|0]=y[(d&7)+14424|0];e=d>>>0>7;d=d>>>3|0;if(e){continue}break}}else{b=b-2|0;Gs((d<<1&126)+25392|0,2,b);d=d>>>6|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;case 7:e=35-G(d|1)>>>2|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<257){while(1){b=b-1|0;v[b|0]=y[(d&15)+11011|0];e=d>>>0>15;d=d>>>4|0;if(e){continue}break}}else{b=b-2|0;Gs((d<<1&510)+25520|0,2,b);d=d>>>8|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;default:break b}}g=d;i=D(e,e);k=D(i,e);j=D(i,i);c:{while(1){h=f|1;if(e>>>0>g>>>0){break c}h=f|2;if(g>>>0<i>>>0){break c}h=f|3;if(g>>>0<k>>>0){break c}if(g>>>0<j>>>0){h=f+4|0}else{f=f+4|0;g=(g>>>0)/(j>>>0)|0;continue}break}}f=h;if((f|0)>(c-b|0)){x[a+4>>2]=61;break a}f=b+f|0;c=f;while(1){c=c-1|0;b=(d>>>0)/(e>>>0)|0;v[c|0]=y[(d-D(b,e)|0)+4836|0];g=d>>>0>=e>>>0;d=b;if(g){continue}break}x[a+4>>2]=0;x[a>>2]=f;return}x[a>>2]=c}function _ia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=db+-64|0;db=d;b=b&4095;w[d+62>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=db-16|0;db=e;f=Tb(e+4|0,4392);ad(d+48|0,f);tb(f);db=e+16|0;x[23549]=0;e=((b|0)==4095?c:b-80|0)+734016|0;c=yka(e,e>>31,1e4,0);b=hb;c=c+14780|0;b=c>>>0<14780?b+1|0:b;b=zka(c,b,3652425,0);c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<0){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}g=b;b=(D(c,100)+52|0)/3060|0;e=b+2|0;f=(e|0)/12|0;x[d+32>>2]=g+f;P(86,d+36|0,d+32|0);g=x[23549];x[23549]=0;e:{f:{g:{h:{i:{j:{if((g|0)!=1){x[23549]=0;x[d+16>>2]=(e+D(f,-12)|0)+1;P(88,d+20|0,d+16|0);e=x[23549];x[23549]=0;if((e|0)==1){break j}x[23549]=0;x[d>>2]=(((D(b,306)+5|0)/-10|0)+c|0)+1;P(88,d+4|0,d|0);b=x[23549];x[23549]=0;if((b|0)==1){break i}x[23549]=0;aa(355,a|0,d+48|0,d+36|0,d+20|0,d+4|0);a=x[23549];x[23549]=0;if((a|0)==1){break h}tb(d+4|0);tb(d+20|0);break d}b=N()|0;break e}b=N()|0;break f}b=N()|0;break g}b=N()|0;tb(d+4|0)}tb(d+20|0)}tb(d+36|0)}break a}hf(d+48|0,4372);x[23549]=0;P(356,d+36|0,d+62|0);b=x[23549];x[23549]=0;if((b|0)==1){break c}x[23549]=0;S(131,a|0,d+48|0,d+36|0);a=x[23549];x[23549]=0;if((a|0)==1){break b}}tb(d+36|0);Ab(d+48|0);db=d- -64|0;return}b=N()|0;break a}b=N()|0;tb(d+36|0)}Ab(d+48|0);Q(b|0);p()}
function Zy(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=db-16|0;db=h;f=x[c+656>>2];a:{if(!gj(f)){i=x[c+704>>2];f=db-16|0;db=f;x[f+12>>2]=d;g=0;b:{if(!d){break b}j=x[b+480180>>2];if(j&20){e=b+1074312|0;d=Ob(e,73)?d&65535:d;if(y[b+480208|0]&16){e=Ob(e,73)?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0;g=x[((d>>>0)%768<<2)+34160>>2]<<6>>>e|0;break b}g=229079296/((d>>>0<=1?1:d)>>>0)|0;break b}g=227001280/(d>>>0)|0;if(ym(j)){break b}g=(d+i<<4)-133808|0;if((j|0)==64){break b}tc(f+12|0,16777215);if(j&17408){g=Qc(Bka(yka(i?i:8363,0,3506176,0),hb,(x[f+12>>2]<<8)+e|0,0),hb);break b}if(Zi(b)){d=x[f+12>>2];i=d>>>24|0;j=d<<8;d=j+e|0;e=i+(e>>31)|0;g=((d>>>0<j>>>0?e+1|0:e)&15)<<28|d>>>4;break b}if(y[b+480208|0]&16){g=Qc(Bka(yka(i?i:8363,0,7012352,0),hb,(x[f+12>>2]<<8)+e|0,0),hb);break b}g=Qc(Bka(-1485242368,13,(x[f+12>>2]<<8)+e|0,0),hb)}e=g;db=f+16|0;f=x[c+656>>2];break a}e=x[c+700>>2]}x[h+12>>2]=e;c=w[c+774>>1];c:{if(!c){break c}c=f?D(v[f+33|0],c):c;if(!c){break c}e=Le(Dj(+(c|0)/393216)*+(e>>>0));x[h+12>>2]=e}d:{if(!f){break d}c=x[f+40>>2];if(!c){break d}d=(c|0)/2|0;f=x[b+1074420>>2];e=yka(f,f>>31,e,e>>31);f=d+e|0;d=hb+(d>>31)|0;k=h,l=Cc(zka(f,e>>>0>f>>>0?d+1|0:d,c,c>>31),hb),x[k+12>>2]=l}tc(h+12|0,2147483647);c=x[h+12>>2];b=zka(0,c,x[b+24620>>2]<<4,0);x[a+8>>2]=c;x[a>>2]=b;x[a+4>>2]=hb;db=h+16|0}function j0(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=db-16|0;db=k;l=Zu(x[g>>2]);g=Cw(x[g>>2]);Mg(k+4|0,g);a:{b:{if(xd(x[k+8>>2],y[k+15|0])){x[23549]=0;V(1113,l|0,a|0,c|0,d|0);g=x[23549];x[23549]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[23549]=0;j=O(19,l|0,h<<24>>24)|0;h=x[23549];x[23549]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+1;v[h|0]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[23549]=0;h=O(19,l|0,48)|0;i=x[23549];x[23549]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;h=v[j+1|0];x[23549]=0;h=O(19,l|0,h|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;j=j+2|0}Nl(j,c);i=0;x[23549]=0;o=R(1111,g|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){Nl((j-a|0)+d|0,x[f>>2]);g=x[f>>2];break a}e:{if(!y[uc(k+4|0,h)|0]){break e}if(v[uc(k+4|0,h)|0]!=(i|0)){break e}i=x[f>>2];x[f>>2]=i+1;v[i|0]=o;h=(Bb(x[k+8>>2],y[k+15|0])-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[23549]=0;n=O(19,l|0,n|0)|0;m=x[23549];x[23549]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+1;v[m|0]=n;g=g+1|0;i=i+1|0;continue}break}}a=N()|0;tb(k+4|0);Q(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;tb(k+4|0);db=k+16|0}function MP(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=db-240|0;db=e;if(!y[94360]){if(!y[94232]){b=db-16|0;db=b;Gb(94208);x[23555]=0;v[94224]=0;x[23557]=0;x[23549]=0;a=ca(28)|0;c=x[23549];x[23549]=0;a:{b:{c:{d:{e:{f:{if((c|0)!=1){x[b+12>>2]=a;a=b+12|0;oA(94220,Zd(a));ij(a);v[94224]=0;break f}a=wa(92296,92880)|0;c=eb;if(($(92296)|0)==(c|0)){Y(a|0)|0;x[23549]=0;X(29);b=x[23549];x[23549]=0;if((b|0)==1){break d}p()}if(($(92880)|0)!=(c|0)){break c}Y(a|0)|0;x[23549]=0;v[94224]=0;X(17);a=x[23549];x[23549]=0;if((a|0)==1){a=N()|0;break c}if(y[94224]){break e}}x[23549]=0;W(30,94204);a=x[23549];x[23549]=0;if((a|0)!=1){break e}a=N()|0;break c}db=b+16|0;break a}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)==1){break b}}ij(94228);ij(94220);tb(94208);Q(a|0);p()}T(0)|0;Rb();p()}v[94232]=1}c=db+-64|0;db=c;b=c+16|0;g=db-16|0;db=g;h=uP(g+8|0);j=e+120|0;l=c+4|0;while(1){if((i|0)==12){db=g+16|0}else{f=db-48|0;db=f;a=x[h+4>>2];d=x[h>>2];g:{if((a|0)==(d|0)){break g}a=(a-d|0)+1|0;if(!a){a=gP(lP(f+12|0,32));break g}d=G(a);d=lP(f+12|0,(a<<d&2147483647?32:31)-d|0);while(1){k=gP(d);if(a>>>0<=k>>>0){continue}break}a=x[h>>2]+k|0}db=f+48|0;m=xb(b,i),n=a,x[m>>2]=n;i=i+1|0;continue}break}b=CP(l,b,GP(b));yP(j,b);um(b);db=c- -64|0;rc(94240,rc(e,j,120),116);v[94360]=1}db=e+240|0}function ac(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=eH(a+24|0);a=h;i=a>>>0<=1?1:a;a=i;b=a+15&-16;d=a>>>0<b>>>0?b:a;b=0;f=db-16|0;db=f;if(!(d&15)){if(d>>>0>4294967216){a=48}else{a:{if(d>>>0>=4294967216){x[23424]=48;a=0;break a}d=d>>>0<11?16:d+11&-8;c=Nd(d+28|0);a=0;if(!c){break a}b=c-8|0;b:{if(!(c&15)){a=b;break b}g=c-4|0;j=x[g>>2];a=(c+15&-16)-8|0;a=(a-b>>>0<=15?16:0)+a|0;c=a-b|0;e=(j&-8)-c|0;if(!(j&3)){b=x[b>>2];x[a+4>>2]=e;x[a>>2]=b+c;break b}x[a+4>>2]=e|x[a+4>>2]&1|2;e=a+e|0;x[e+4>>2]=x[e+4>>2]|1;x[g>>2]=c|x[g>>2]&1|2;e=b+c|0;x[e+4>>2]=x[e+4>>2]|1;Ht(b,c)}b=x[a+4>>2];c:{if(!(b&3)){break c}c=b&-8;if(c>>>0<=d+16>>>0){break c}x[a+4>>2]=d|b&1|2;b=a+d|0;d=c-d|0;x[b+4>>2]=d|3;c=a+c|0;x[c+4>>2]=x[c+4>>2]|1;Ht(b,d)}a=a+8|0}if(a){x[f+12>>2]=a;a=0}else{a=48}}b=a?0:x[f+12>>2]}db=f+16|0;a=b;if(!a){d:{b=0;a=x[117374];if(!a){x[117374]=469516;w[234759]=125;k=469516,l=kw(470016),w[k>>1]=l;a=x[117374]}d=(i+3>>>2|0)+1|0;while(1){e:{if(!a|(a|0)==470016){a=0}else{c=z[a+2>>1];f=d+(d>>>0<c>>>0?c-d&3:0)|0;if(c>>>0>f>>>0){b=c-f|0;w[a+2>>1]=b;a=((b&65535)<<2)+a|0;w[a+2>>1]=f;w[a>>1]=0;a=a+4|0;break d}if(d>>>0>c>>>0){break e}d=z[a>>1];f:{if(!b){k=469496,l=lw(d),x[k>>2]=l;break f}w[b>>1]=d}w[a>>1]=0;a=a+4|0}break d}b=a;a=lw(z[a>>1]);continue}}}if(!a){Rb();p()}return QM(Vb(a,0,h))}function ry(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=KM(b,c);a:{if(!x[b+656>>2]|!(v[h+6|0]&1)){break a}e=x[h>>2];i=a+1074312|0;f=Ob(i,31);d=bv(x[b+656>>2],c);if(qc(x[d>>2],x[d+4>>2])){break a}f=e+(f^1)|0;g=Ob(i,31);e=y[d+12|0];b:{c:{if(!g){d:{if(!(e&2)){break d}j=y[d+14|0];k=!(x[a+480180>>2]&1048580)+z[xb(x[d>>2],j)>>1]|0;g=0;if(!(!(y[b+89|0]&8)|(!(e&4)|(j|0)!=y[d+16|0]))){g=Ob(i,70)}if(g|(f|0)!=(k|0)){break d}f=z[xb(x[d>>2],y[d+13|0])>>1]}if(!(!(y[d+12|0]&4)|y[b+89|0]&8)){a=x[d>>2];if((z[xb(a,y[d+16|0])>>1]+1|0)!=(f|0)){break b}f=z[xb(a,y[d+15|0])>>1];if(!Ob(i,93)|(c|0)!=1|y[b+89|0]&8){break b}v[h+6|0]=y[h+6|0]&254;break b}j=1;e=z[Gf(x[d+4>>2])>>1];if(f>>>0>e>>>0){break c}break b}e:{f:{if(!(!(e&4)|y[b+669|0]&8)){if(z[h+4>>1]==65535){break f}if(Ob(i,97)){break f}e=y[d+12|0]}if(e&2){g=x[d>>2];e=z[xb(g,y[d+13|0])>>1];g=z[xb(g,y[d+14|0])>>1]+1|0;break e}e=z[Gf(x[d+4>>2])>>1];j=f>>>0>e>>>0;g=e;break e}g=x[d>>2];e=z[xb(g,y[d+15|0])>>1];g=z[xb(g,y[d+16|0])>>1]+1|0}e=f>>>0<g>>>0?f:e}g:{if(!j|c){break g}f=x[a+480180>>2];c=x[b+88>>2];if(!(!(f&16777248)&(!(c&2048)|(f|0)==16384))){c=c|4096;x[b+88>>2]=c}if(y[Gf(x[d+4>>2])+2|0]|!(z[b+786>>1]|x[a+480180>>2]&16777248)){break g}x[b+696>>2]=0;x[b+720>>2]=0;x[b+680>>2]=0;x[b+88>>2]=c|4096}f=e}l=h,m=Ob(i,31)+f|0,x[l>>2]=m}}function yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0;g=db-16|0;db=g;r=x[a+16>>2];s=cg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);k=x[a+8>>2];l=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];m=x[a+128>>2];if(m){n=dg(k,l,m);o=hb;b=x[a+76>>2];Ff(h,e,bf(k,l,d),hb);p=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];t=x[a+24>>2];u=x[a+20>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;a:while(1){b:{q=b;if(!d){break b}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;p=p-1|0;b=p;n=b?n:0;o=b?o:0;h=e+r|0;b=m;while(1)if((b|0)<=0){Qb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Md(i,v[h+x[g+12>>2]|0]<<6);Ld(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=bg(i,s);w=x[a+72>>2];h=b<<8;b=h;e=x[a+60>>2];b=yka(e,e>>31,b,b>>31);y=hb;e=b;b=x[a+64>>2];j=b;z=b>>31;b=Ub(q,-16777216,16776704);j=yka(j,z,b,b>>31);e=e+j|0;b=hb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Ub(f,-16777216,16776704);e=yka(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Lc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(f,u)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,t);Qb(g,k,l);b=b-(h&w)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=q;continue a}else{Md(i,v[h+x[g+12>>2]|0]<<6);Ld(i,4);Qb(g+8|0,n,o);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+48>>2]=f;x[a+44>>2]=q;db=g+16|0}function s5(a){a=a|0;var b=0,c=0,d=0,e=0;e=db-160|0;db=e;d=Tb(e+4|0,11458);x[23549]=0;b=d+12|0;O(54,b|0,10855)|0;c=x[23549];x[23549]=0;a:{if((c|0)==1){break a}x[23549]=0;b=d+24|0;O(54,b|0,11288)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}x[23549]=0;b=d+36|0;O(54,b|0,10847)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}x[23549]=0;b=d+48|0;O(54,b|0,8141)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}x[23549]=0;b=d+60|0;O(54,b|0,10832)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}x[23549]=0;b=d+72|0;O(54,b|0,8207)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}x[23549]=0;b=d+84|0;O(54,b|0,5561)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}x[23549]=0;b=d+96|0;O(54,b|0,11862)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}x[23549]=0;b=d+108|0;O(54,b|0,11231)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}x[23549]=0;b=d+120|0;O(54,b|0,12063)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}x[23549]=0;b=d+132|0;O(54,b|0,5413)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}x[23549]=0;b=d+144|0;O(54,b|0,7233)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}x[23549]=0;U(993,a|0,d|0,13)|0;a=x[23549];x[23549]=0;if((a|0)!=1){b=d+156|0;while(1){b=tb(b-12|0);if((d|0)!=(b|0)){continue}break}db=e+160|0;return}b=d+156|0}a=N()|0;while(1){b=tb(b-12|0);if((d|0)!=(b|0)){continue}break}Q(a|0);p()}function iea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=db-32|0;db=d;c=z[a+480190>>1];v[d+20|0]=0;dP(b,c+1|0,d+20|0);if(z[a+480192>>1]){h=Nb(d+20|0);m=d,n=yb(x[a+484344>>2]),x[m+16>>2]=n;l=yb(x[a+484348>>2]);while(1){i=x[d+16>>2];if(Kb(i,l)){a:{if(!Kb(x[i>>2],x[i+4>>2])){break a}c=z[a+480188>>1];x[23549]=0;v[d+4|0]=0;S(720,h|0,c|0,d+4|0);c=x[23549];x[23549]=0;if((c|0)!=1){m=d,n=yb(x[i>>2]),x[m+12>>2]=n;j=0;b:while(1){f=0;if(A[i+12>>2]<=j>>>0){break a}while(1)if(z[a+480188>>1]<=f>>>0){j=j+1|0;continue b}else{c:{c=x[d+12>>2];if(!Tc(y[c|0])){break c}d:{e:{c=y[c+1|0];if(c){g=z[a+480192>>1];break e}g=z[a+480192>>1];c=y[Db(x[h>>2],f)|0];if(c){break e}c=1;break d}m=Db(x[h>>2],f),n=c,v[m|0]=n;g=g&65535;e=g>>>0<c>>>0;g=e?g:c;c=e?1:c}while(1){e=c&65535;if(e>>>0>(g&65535)>>>0){break c}e=x[((e<<2)+a|0)+900380>>2];f:{if(!e){break f}e=z[_b(e+236|0,y[x[d+12>>2]]-1|0)>>1];if(e>>>0>z[a+480190>>1]){break f}k=d+4|0;Fb(k,x[b>>2],e);Dh(k,1)}c=c+1|0;continue}}f=f+1|0;qA(d+12|0);continue}}}a=N()|0;bc(h);Q(a|0);p()}so(d+16|0);continue}else{c=z[a+480190>>1];while(1){if(c){Fb(d+4|0,x[b>>2],c);if(!Ib(x[x[d+4>>2]>>2],x[d+8>>2])){e=f;f=D(c,104)+a|0;f=e+Sd(x[f+484380>>2],x[f+484400>>2])|0}c=c-1|0;continue}else{bc(h)}break}}break}}db=d+32|0;return f&65535}function YF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=db-16|0;db=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;c=x[a+12>>2];a:{while(1){if(c>>>0>=d>>>0){f=0;break a}b:{b=z[c>>1];c:{if(b>>>0<=127){f=1;c=x[a+8>>2];if((g-c|0)<=0){break a}x[a+8>>2]=c+1;v[c|0]=b;break c}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}if(b>>>0<=55295){c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=z[c+2>>1];if((i&64512)!=56320){break e}if((g-x[a+8>>2]|0)<4){break a}x[a+12>>2]=c+2;c=x[a+8>>2];x[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;v[f|0]=c>>>2|240;f=x[a+8>>2];x[a+8>>2]=f+1;v[f|0]=c<<4&48|b>>>2&15|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=i>>>6&15|b<<4&48|128;b=x[a+8>>2];x[a+8>>2]=b+1;v[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}c=x[a+12>>2]+2|0;x[a+12>>2]=c;continue}break}f=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];db=a+16|0;return f|0}function Jca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;h=db-16|0;db=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];q=x[a+16>>2];l=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=l;r=b+24|0;s=x[a+32>>2];t=x[a+28>>2];u=x[a+72>>2];m=x[a+68>>2];v=m>>31;n=x[a+64>>2];y=n>>31;o=x[a+60>>2];z=o>>31;l=x[a+8>>2];A=x[a+12>>2];while(1){b=f;if(d){f=Ub(b,-16777216,16776704);g=yka(n,y,f,f>>31);f=hb;e=Ub(e,-16777216,16776704);e=yka(m,v,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];k=g;g=(x[h+12>>2]<<1)+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;p=(((((D(w[g+4>>1],w[e+10>>1])+D(w[g+2>>1],w[e+8>>1])|0)+D(w[g+6>>1],w[e+12>>1])|0)+D(w[g+8>>1],w[e+14>>1])|0)/2|0)+((((D(w[g-4>>1],w[e+2>>1])+D(w[g-6>>1],w[e>>1])|0)+D(w[g-2>>1],w[e+4>>1])|0)+D(w[g>>1],w[e+6>>1])|0)/2|0)|0)/16384<<8;e=p;g=yka(e,e>>31,o,z);k=k+g|0;e=hb+f|0;e=g>>>0>k>>>0?e+1|0:e;f=k+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Lc(f,e,24);e=(f|0)/256|0;j=j+t|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+s|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Qb(h+8|0,l,A);f=f-(u&p)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;db=h+16|0}function uI(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=E(0);d=(b<<2)+a|0;h=d+1068|0;k=c<<1&-4;p=h,q=be(a,k),x[p>>2]=q;g=d+1076|0;p=g,q=be(a,k),x[p>>2]=q;i=be(a,c&-4);x[d+1084>>2]=i;a:{h=x[h>>2];if(!h){break a}g=x[g>>2];if(!g|!i){break a}d=c>>2;o=(d|0)>0?d:0;j=E(c|0);d=0;while(1){if((e|0)==(o|0)){d=0;e=c>>3;h=(e|0)>0?e:0;e=0;while(1){if((d|0)!=(h|0)){g=e|1;f=+E(E(E(g<<1)*E(3.1415927410125732))/j);p=i+(e<<2)|0,r=E(Pe(f)),B[p>>2]=r;p=i+(g<<2)|0,r=E(-E(ui(f))),B[p>>2]=r;e=e+2|0;d=d+1|0;continue}break}}else{l=d<<2;f=+E(E(E(e<<2)*E(3.1415927410125732))/j);p=h+l|0,r=E(Pe(f)),B[p>>2]=r;m=d|1;n=m<<2;p=h+n|0,r=E(-E(ui(f))),B[p>>2]=r;f=+E(E(E(E(m|0)*E(3.1415927410125732))/j)*E(.5));p=g+l|0,r=E(E(Pe(f))*E(.5)),B[p>>2]=r;p=g+n|0,r=E(E(ui(f))*E(.5)),B[p>>2]=r;d=d+2|0;e=e+1|0;continue}break}i=(b<<2)+a|0;d=be(a,k);x[i+1092>>2]=d;if(!d){break a}b=0;e=c>>1;k=(e|0)>0?e:0;f=+(e|0);while(1){if((b|0)!=(k|0)){j=E(ui((+(b|0)+.5)/f*.5*3.1415927410125732));p=d+(b<<2)|0,r=E(ui(+E(j*j)*1.5707963705062866)),B[p>>2]=r;b=b+1|0;continue}break}b=be(a,c>>2&-2);x[i+1100>>2]=b;if(!b){break a}a=0;d=c>>3;d=(d|0)>0?d:0;c=36-Wl(c)|0;while(1){if((a|0)!=(d|0)){p=b+(a<<1)|0,q=Ul(a)>>>c<<2,w[p>>1]=q;a=a+1|0;continue}break}return 1}cc(a,3);return 0}function qe(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0),i=0,k=0;d=(q(b),j(2));c=GF(d);a:{b:{c:{d:{e=(q(a),j(2));e:{if(e-2139095040>>>0>=2164260864){if(c){break e}break c}if(!c){break d}}h=E(1);if((e|0)==1065353216){break b}c=d<<1;if(!c){break b}i=c>>>0<4278190081;c=e<<1;a=E(a+b);if(!(i&c>>>0<=4278190080)){break a}if((c|0)==2130706432){break b}a=c>>>0>2130706431^(d|0)>=0?E(0):E(b*b);break a}if(GF(e)){h=E(a*a);if((e|0)<0){h=(FF(d)|0)==1?E(-h):h}if((d|0)>=0){break b}a=Nv(E(E(1)/h));break a}if((e|0)<0){c=FF(d);if(!c){a=wE(a);break a}e=e&2147483647;i=((c|0)==1)<<16}if(e>>>0>8388607){break c}e=((q(E(a*E(8388608))),j(2))&2147483647)-192937984|0}d=e-1060306944|0;c=d>>>15&240;f=+(l(2,e-(d&-8388608)|0),r())*C[c+92920>>3]+-1;g=f*f;f=((f*.288457581109214+-.36092606229713164)*(g*g)+((f*.480898481472577+-.7213474675006291)*g+(f*1.4426950408774342+(C[c+92928>>3]+ +(d>>23)))))*+b;o(+f);c=j(1)|0;j(0)|0;f:{c=c&2147450880;if((c|0)==1079967744|c>>>0<1079967744){break f}if(f>127.99999995700433){a=mD(i);break a}if(!(f<=-150)){break f}a=TC(i);break a}k=f;g=C[160];f=g+f;g=k-(f-g);g=(C[161]*g+C[162])*(g*g)+(C[163]*g+1);o(+f);j(1)|0;e=j(0)|0;d=i+e|0;i=d<<15;d=((e&31)<<3)+1024|0;c=x[d>>2];d=x[d+4>>2]+i|0;l(0,c|0);l(1,(c>>>0>c>>>0?d+1|0:d)|0);h=E(g*+n())}a=h}return a}function RS(a,b){var c=0,d=0;a:{b:{c:{d:{if(de(a,16333)){break d}if(de(a,17084)){break d}if(de(a,13394)){break d}if(de(a,13479)){break d}if(!de(a,13929)){break c}}w[b+10>>1]=4;x[b>>2]=11894;break b}e:{f:{if(de(a,17079)){break f}if(de(a,13399)){break f}if(!de(a,16323)){break e}}v[b+15|0]=1;v[b+12|0]=1;x[b>>2]=8289;w[b+10>>1]=4;return 1}g:{if(!de(a,13964)){if(!de(a,13969)){break g}}w[b+10>>1]=8;x[b>>2]=8067;break b}h:{if(!de(a,14946)){if(!de(a,14951)){break h}}x[b>>2]=16687;w[b+10>>1]=v[a+2|0]-48;break b}i:{if(!de(a,26938)){if(!de(a,26943)){break i}}x[b+4>>2]=1;x[b>>2]=16493;w[b+10>>1]=y[a|0]==56?8:4;return 1}if(!(cd(a,15051,3)|(y[a+3|0]-52&255)>>>0>4)){x[b>>2]=8407;a=v[a+3|0];w[b+8>>1]=1088;w[b+10>>1]=a-48;break b}j:{if(cd(a,13412,3)){if(cd(a,13536,3)){break j}}if((y[a+3|0]-52&255)>>>0>5){break j}v[b+15|0]=1;v[b+13|0]=1;x[b>>2]=8166;w[b+10>>1]=v[a+3|0]-48;return 1}k:{if((y[a|0]-49&255)>>>0>8){break k}if(!cd(a+1|0,13557,3)){v[b+14|0]=1;x[b>>2]=8471;w[b+10>>1]=v[a|0]-48;return 1}c=y[a+2|0]|y[a+3|0]<<8;if((c|0)!=18499&(c|0)!=20035|(y[a+1|0]-48&255)>>>0>9){break k}v[b+14|0]=1;x[b>>2]=8471;w[b+10>>1]=(v[a+1|0]+D(v[a|0],10)|0)-528;return 1}if(cd(a,13285,3)|(y[a+3|0]-49&255)>>>0>8){break a}x[b>>2]=8316;w[b+10>>1]=v[a+3|0]-48}d=1}return d}function fX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=db-1088|0;db=g;e=xh(a);Vb(e+20|0,0,1040);x[e+1064>>2]=0;x[e+1068>>2]=0;x[e+1060>>2]=c;v[e+1084|0]=d;a=e+1072|0;x[a>>2]=0;x[a+4>>2]=0;x[e+1080>>2]=0;i=e+1064|0;a=c;d=0;a:{b:{c:while(1){if(Jd(z[a+34>>1])>>>0<=d>>>0){break a}x[e+1064>>2]=0;x[e+1068>>2]=0;a=0;while(1){d:{e:{f:{g:{h:{i:{j:{if(A[c>>2]<=a>>>0){break j}a=x[b+8>>2];f=x[b>>2];x[23549]=0;a=U(142,f|0,a|0,2)|0;f=x[23549];x[23549]=0;if((f|0)==1){break i}if(!a){break j}x[23549]=0;a=R(180,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break h}if(!a){break e}x[23549]=0;S(176,g+8|0,b|0,a|0);a=x[23549];x[23549]=0;if((a|0)==1){break g}h=g+8|0;a=nr(g+28|0,h);f=Zc(e,a);rc(f+20|0,a+20|0,1040);ub(a);ub(h);x[e+1076>>2]=0;x[e+1080>>2]=0;h=x[e+1060>>2];a=x[h+20>>2];if(Sm(z[h+34>>1])>>>0>=2){x[23549]=0;P(181,f|0,a+(d<<1)|0);a=x[23549];x[23549]=0;if((a|0)!=1){break e}break f}x[23549]=0;P(182,f|0,a+d|0);a=x[23549];x[23549]=0;if((a|0)==1){break f}break e}d=d+1|0;a=x[e+1060>>2];continue c}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}a=T(30544)|0;if((eb|0)!=($(30544)|0)){break b}Y(a|0)|0;x[23549]=0;X(17);a=x[23549];x[23549]=0;if((a|0)==1){break d}}a=x[i>>2];continue}break}break}a=N()|0}ub(e);Q(a|0);p()}db=g+1088|0;return e|0}function Uba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=db-16|0;db=l;k=db-32|0;db=k;h=k+28|0;f=k+24|0;g=db-16|0;db=g;a:{b:{if(!qc(b,x[vb(g+12|0,Kf(a))>>2])){e=z[c>>1];i=x[c+4>>2];j=td(b);m=z[j>>1];j=x[j+4>>2];if(!el(e,i,m,j)){break b}}x[g+12>>2]=b;e=vb(g+8|0,yb(x[a>>2]));c:{f=x[g+12>>2];if(!qc(f,x[e>>2])){f=x[nz(g+12|0)>>2];e=td(f);j=z[e>>1];m=x[e+4>>2];e=z[c>>1];i=x[c+4>>2];if(!el(j,m,e,i)){break c}}if(!x[b>>2]){x[h>>2]=b;break a}x[h>>2]=f;b=f+4|0;break a}b=mz(a,h,e,i);break a}if(el(m,j,e,i)){d:{f=lz(b);if(!qc(f,x[vb(g+12|0,Kf(a))>>2])){e=z[c>>1];i=x[c+4>>2];j=td(f);if(!el(e,i,z[j>>1],x[j+4>>2])){break d}}if(!x[b+4>>2]){x[h>>2]=b;b=b+4|0;break a}x[h>>2]=f;b=f;break a}b=mz(a,h,e,i);break a}x[h>>2]=b;x[f>>2]=b;b=f}db=g+16|0;f=b;b=x[b>>2];if(!b){b=db-16|0;db=b;g=gc(a);h=k+12|0;e=rh(h,Hc(36),Ag(b+8|0,g));g=x[e>>2]+16|0;i=x[c+4>>2];x[g>>2]=x[c>>2];x[g+4>>2]=i;Zj(g+8|0,d);o=gc(e),p=1,v[o+4|0]=p;db=b+16|0;Yg(a,x[k+28>>2],f,x[k+12>>2]);b=Zd(h);ZO(h);n=1}a=l+4|0;Xg(a,x[vb(k+12|0,b)>>2],n);db=k+32|0;if(!y[gc(a)|0]){a=td(x[l+4>>2])+8|0;YO(a);x[a>>2]=x[d>>2];x[a+4>>2]=x[d+4>>2];b=wb(d);o=wb(a),p=x[b>>2],x[o>>2]=p;x[b>>2]=0;x[d>>2]=0;x[d+4>>2]=0}a=x[vb(l+12|0,x[l+4>>2])>>2];db=l+16|0;return a|0}function Aca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=db-16|0;db=e;s=x[a+16>>2];t=cg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);k=x[a+8>>2];l=x[a+12>>2];b=x[a>>2];f=x[a+4>>2];m=x[a+128>>2];if(m){n=dg(k,l,m);o=hb;h=x[a+76>>2];Ff(b,f,bf(k,l,d),hb);p=hb>>>0>h>>>0?d:0}h=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=f;while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;p=p-1|0;g=p;n=g?n:0;o=g?o:0;r=(((f&2147483647)<<1|b>>>31)&-2)+s|0;f=m;a:{b:while(1){c:{if((f|0)<=0){Qb(h,x[a+120>>2],x[a+124>>2]);f=x[a+116>>2];if(!f){break a}g=x[e+8>>2];q=((x[e+12>>2]&2147483647)<<1|g>>>31)&-2;g=0;b=0;break c}g=x[e+8>>2];q=((x[e+12>>2]&2147483647)<<1|g>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Md(h,g>>>3<<16>>16);Ld(h,4);Qb(e+8|0,n,o);f=f-1|0;continue b}else{g=(v[(b+q|0)+r|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(v[(b+q|0)+r|0]<<8)+g|0;b=b+1|0;continue}break}Md(h,g>>>3<<16>>16);Ld(h,f);x[h>>2]=x[h>>2];x[h+4>>2]=0}b=bg(h,t);f=x[a+32>>2];j=x[a+28>>2]+j|0;x[c>>2]=x[c>>2]+D(b,j>>12);i=f+i|0;x[c+4>>2]=x[c+4>>2]+D(b,i>>12);Qb(e,k,l);c=c+8|0;b=x[e>>2];f=x[e+4>>2];continue}break}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;db=e+16|0}function DT(a,b){var c=0,d=0,e=0,f=0;c=db-16|0;db=c;d=y[a|0];a:{if(d>>>0>21){break a}v[a|0]=y[d+26736|0];b:{switch(d-8|0){case 0:v[b|0]=y[b|0]<<1;break a;case 4:v[b|0]=y[b|0]+1>>>1;break a;case 5:a=y[b|0];v[b|0]=D(a>>>4|0,10)+(a&15);break a;case 6:c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{d=y[b|0];switch((d>>>4|0)-1|0){case 11:case 12:case 13:break a;case 9:break e;case 8:break f;case 6:break g;case 5:break h;case 4:break i;case 3:break j;case 1:break k;case 0:break l;case 14:break c;case 10:break d;default:break m}}v[a|0]=0;break a}v[a|0]=29;v[c+15|0]=y[b|0]&15;v[c+14|0]=14;e=b,f=y[Sb(c+15|0,c+14|0)|0]<<4|15,v[e|0]=f;break a}v[a|0]=29;v[c+13|0]=y[b|0]&15;v[c+12|0]=14;e=b,f=y[Sb(c+13|0,c+12|0)|0]|240,v[e|0]=f;break a}v[b|0]=d&15|48;break a}v[a|0]=35;v[b|0]=y[b|0]<<4^128;break a}v[b|0]=d&15|176;break a}v[b|0]=d&15|64;break a}v[a|0]=15;v[b|0]=y[b|0]&15;break a}v[a|0]=24;v[b|0]=(y[b|0]<<3&120)+8&240;break a}v[a|0]=24;v[b|0]=(y[b|0]&15)+1>>>1;break a}v[a|0]=10;break a;case 8:a=y[b|0];if(a>>>0<=223){v[b|0]=a>>>0>63?-16:a<<2&240;break a}if(a>>>0<=239){v[b|0]=a<<2&48|15;break a}v[b|0]=a<<4|15;break a;case 9:break b;default:break a}}a=y[b|0];if(a>>>0<=223){v[b|0]=a>>>0>63?15:a>>>2|0;break a}if(a>>>0>239){break a}v[b|0]=a>>>2&3|240}db=c+16|0}function Nia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=db-48|0;db=c;i=a+484344|0;j=a+480280|0;while(1){a:{if(Lb(x[b>>2],x[b+8>>2],9)){zo(b,c+44|0);d=pg(b);e=y[c+44|0]|y[c+45|0]<<8|(y[c+46|0]<<16|y[c+47|0]<<24);b:{if((e|0)==1229999433|(e|0)==1397771593){break b}e=y[c+44|0]|y[c+45|0]<<8|(y[c+46|0]<<16|y[c+47|0]<<24);if((e|0)==1297110104|(e|0)==1297110099){break b}if(Lb(x[b>>2],x[b+8>>2],d)){break a}}ng(b,8)}db=c+48|0;return k|0}e=c+4|0;Wd(e,b,d);g=hc(c+24|0,e);ub(e);d=j;c:{d:{e:{if((y[c+44|0]|y[c+45|0]<<8|(y[c+46|0]<<16|y[c+47|0]<<24))==1481001027){while(1){if((d|0)==(i|0)){break c}x[23549]=0;e=R(143,g|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break e}v[d+8|0]=e;d=d+32|0;continue}}if(y[c+44|0]!=70){break d}e=y[c+45|0];h=(e|0)==88;f:{if(!h){if((e-48&255)>>>0>9){break d}d=v[c+46|0];if((d|0)>47){break f}break d}d=v[c+46|0];if((d|0)<48){break d}}if(d>>>0>57){break d}f=v[c+47|0];if((f|0)<48|(f|0)>57){break d}d=((f&255)+(h?-528:D(e,100)-5328|0)|0)+D(d&255,10)&65535;if(d>>>0>249){break c}x[23549]=0;P(392,g|0,(D(d,160)+a|0)+906300|0);d=x[23549];x[23549]=0;if((d|0)!=1){break c}}a=N()|0;ub(g);Q(a|0);p()}if((y[c+44|0]|y[c+45|0]<<8|(y[c+46|0]<<16|y[c+47|0]<<24))!=1430540109){break c}x[a+1074308>>2]=0;k=1}ub(g);continue}}function dj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!Sd(x[a>>2],x[a+20>>2])){break a}ok(a);b:{switch(Sm(z[a+34>>1])-1|0){case 1:h=db-48|0;db=h;g=x[a+20>>2];c=x[a>>2];d=Jd(z[a+34>>1]);e=g+(D(c,d)<<1)|0;while(1){c:{d:{if((f|0)!=16){i=D(d,f);j=D(d,f^-1);c=0;break d}f=e+(d<<5)|0;c=z[a+34>>1];if(c&2){e=x[a+4>>2];i=x[a+8>>2]-e|0;cQ(h+28|0,f,g+(D(d,e)<<1)|0,i,d,(c&4)>>>2|0,Ob(b+1074312|0,33));c=z[a+34>>1]}if(c&8){e=x[a+16>>2];a=x[a+12>>2];e=e-a|0;cQ(h+8|0,f+(d<<7)|0,g+(D(a,d)<<1)|0,e,d,(c&16)>>>4|0,Ob(b+1074312|0,33))}db=h+48|0;break c}while(1){if((c|0)!=(d|0)){w[e+(c+i<<1)>>1]=z[e+(c-d<<1)>>1];w[g+(c+j<<1)>>1]=z[g+(c<<1)>>1];c=c+1|0;continue}break}f=f+1|0;continue}break};return;case 0:break b;default:break a}}h=db-48|0;db=h;g=x[a+20>>2];c=x[a>>2];d=Jd(z[a+34>>1]);e=g+D(c,d)|0;while(1){e:{f:{if((f|0)!=16){i=D(d,f);j=D(d,f^-1);c=0;break f}f=e+(d<<4)|0;c=z[a+34>>1];if(c&2){e=x[a+4>>2];i=x[a+8>>2]-e|0;bQ(h+28|0,f,g+D(d,e)|0,i,d,(c&4)>>>2|0,Ob(b+1074312|0,33));c=z[a+34>>1]}if(c&8){e=x[a+16>>2];a=x[a+12>>2];e=e-a|0;bQ(h+8|0,f+(d<<6)|0,g+D(a,d)|0,e,d,(c&16)>>>4|0,Ob(b+1074312|0,33))}db=h+48|0;break e}while(1){if((c|0)!=(d|0)){v[e+(c+i|0)|0]=y[e+(c-d|0)|0];v[g+(c+j|0)|0]=y[c+g|0];c=c+1|0;continue}break}f=f+1|0;continue}break}}}function nia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=db-16|0;db=g;h=jf(a,c);ae(g,x[a+28>>2]);i=a;a:{if(!h){c=0;if(ed(a,5)){break a}}d=db-160|0;db=d;e=Pl(d+56|0,x[a+28>>2]);x[23549]=0;a=O(403,d+44|0,44035)|0;c=x[23549];x[23549]=0;b:{c:{d:{e:{if((c|0)!=1){x[23549]=0;x[d+24>>2]=19927555;x[d+28>>2]=0;S(404,e|0,a|0,d+24|0);c=x[23549];x[23549]=0;if((c|0)==1){break e}Ab(a);if(!(y[e+3|0]&64)){break d}break b}c=N()|0;break c}c=N()|0;Ab(a);break c}k=d,l=qf(x[b>>2],x[b+4>>2]),w[k+42>>1]=l;w[d+40>>1]=65535;x[23549]=0;a=O(403,d+24|0,9988)|0;c=x[23549];x[23549]=0;f:{if((c|0)!=1){x[23549]=0;c=U(433,e|0,d+40|0,a|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break f}Ab(a);if(!c){w[d+42>>1]=z[d+40>>1]}Wf(d+42|0,4e3);a=z[d+42>>1];g:{if(qf(x[b>>2],x[b+4>>2])>>>0>=a>>>0){break g}x[23549]=0;P(211,b|0,a|0);c=x[23549];x[23549]=0;if((c|0)!=1){break g}c=N()|0;break c}c=0;h:{while(1){if((a|0)==(c|0)){break b}f=x[b>>2];x[23549]=0;P(434,d+12|0,c|0);j=x[23549];x[23549]=0;if((j|0)!=1){x[23549]=0;V(435,e|0,Yb(f,c)|0,d+12|0,436);f=x[23549];x[23549]=0;if((f|0)==1){break h}c=c+1|0;Ab(d+12|0);continue}break}c=N()|0;break c}c=N()|0;Ab(d+12|0);break c}c=N()|0;break c}c=N()|0;Ab(a)}Zg(e);Q(c|0);p()}Zg(e);db=d+160|0;c=h}cf(i,c);db=g+16|0}function D7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;l=db-16|0;db=l;m=l+4|0;i=db-32|0;db=i;f=Ye(i+20|0,1,0);a:{b:{c:{while(1){e=Mb(f);g=e+Bb(x[f+4>>2],y[f+11|0])|0;c=x[b>>2];d=x[b+4>>2];if(!((d|0)>0|(d|0)>=0|(e|0)==(g|0))){v[e|0]=45;h=c;c=0-c|0;e=e+1|0;d=0-(((h|0)!=0)+d|0)|0}j=g-e|0;d:{if((j|0)<=19){h=G(d);n=D(64-((h|0)==32?G(c|1)+32|0:h)|0,1233)>>>12|0;k=(n<<3)+91328|0;h=x[k>>2];o=j;j=x[k+4>>2];k=61;if((o|0)<(((d|0)==(j|0)&c>>>0>=h>>>0|d>>>0>j>>>0)+n|0)){break d}}e:{if(!d){g=Hx(e,c);break e}if((d|0)==2&c>>>0>=1410065408|d>>>0>2){g=Bka(c,d,1410065408,2);h=yka(g,hb,-1410065408,-3);d=d+hb|0;j=c;c=c+h|0;d=j>>>0>c>>>0?d+1|0:d;e=Hx(e,g)}d=Bka(c,d,1e8,0);g=hb;e=Xk(e,d);c=yka(d,g,-1e8,0)+c|0;g=Hs(e,c)}k=0}x[i+16>>2]=k;x[i+12>>2]=g;if(!x[i+16>>2]){break c}c=$f(Bb(x[f+4>>2],y[f+11|0]));x[23549]=0;P(58,f|0,c|0);c=x[23549];x[23549]=0;if((c|0)!=1){continue}break}break b}b=x[i+12>>2];c=Mb(f);x[23549]=0;P(59,f|0,b-c|0);b=x[23549];x[23549]=0;f:{if((b|0)!=1){x[23549]=0;P(60,m|0,f|0);b=x[23549];x[23549]=0;if((b|0)!=1){break f}break b}break b}tb(f);db=i+32|0;break a}a=N()|0;tb(f);Q(a|0);p()}x[23549]=0;P(57,a|0,m|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(l+4|0);db=l+16|0;return}a=N()|0;tb(l+4|0);Q(a|0);p()}function Kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;h=db-16|0;db=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];q=x[a+16>>2];l=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=l;r=b+24|0;s=x[a+32>>2];t=x[a+28>>2];u=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;l=x[a+8>>2];B=x[a+12>>2];while(1){b=f;if(d){f=Ub(b,-16777216,16776704);g=yka(n,z,f,f>>31);f=hb;e=Ub(e,-16777216,16776704);e=yka(m,y,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];k=g;g=x[h+12>>2]+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;p=((((D(v[g+2|0],w[e+10>>1])+D(v[g+1|0],w[e+8>>1])|0)+D(v[g+3|0],w[e+12>>1])|0)+D(v[g+4|0],w[e+14>>1])<<8>>1)+(((D(v[g-2|0],w[e+2>>1])+D(v[g-3|0],w[e>>1])|0)+D(v[g-1|0],w[e+4>>1])|0)+D(v[g|0],w[e+6>>1])<<8>>1)|0)/16384<<8;e=p;g=yka(e,e>>31,o,A);k=k+g|0;e=hb+f|0;e=g>>>0>k>>>0?e+1|0:e;f=k+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Lc(f,e,24);e=(f|0)/256|0;j=j+t|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+s|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Qb(h+8|0,l,B);f=f-(u&p)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;db=h+16|0}function YM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=db-16|0;db=d;while(1){a:{c=Wb(x[a+484360>>2],y[a+484376|0]);e=b&65535;if(Ic(x[c>>2],x[c+4>>2])>>>0>e>>>0){if(!Dq(c,e)){break a}c=Wb(x[a+484360>>2],y[a+484376|0])}if(Ic(x[c>>2],x[c+4>>2])>>>0>e>>>0){e=a+1074312|0;f=a+1298224|0;c=a+1074992|0;b:{while(1){c:{if((c|0)==(f|0)){XM(a);if(b&65535){break c}b=0;while(1){if((b|0)==256){go(a+1298264|0,1);x[a+1074456>>2]=x[a+480200>>2];x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];x[a+480208>>2]=x[a+480208>>2]&-769;Uy(a+1074376|0);w[a+1074450>>1]=0;x[a+1074392>>2]=-2;b=a+1074428|0;x[b>>2]=0;x[b+4>>2]=0;b=a+1074396|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074376>>2]=0;x[a+1074380>>2]=0}else{ko((D(b,872)+a|0)+1074992|0,a,b&65535,134217728);b=b+1|0;continue}break}break b}v[c+797|0]=0;x[c+700>>2]=0;v[c+841|0]=0;v[c+805|0]=0;x[c+708>>2]=0;v[c+821|0]=0;x[c+764>>2]=0;v[c+819|0]=0;v[c+820|0]=0;Fb(d+8|0,e,23);if(Ib(x[x[d+8>>2]>>2],x[d+12>>2])){v[c+807|0]=1;v[c+808|0]=0}v[c+839|0]=0;c=c+872|0;continue}break}w[a+1074450>>1]=b;w[a+1074446>>1]=0;b=a+1074424|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074392>>2]=-2;x[a+1074432>>2]=0;b=a+1074396|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074380>>2]=0}x[a+480208>>2]=x[a+480208>>2]&-769}db=d+16|0;return}b=b+1|0;continue}}function kL(a){var b=0,c=E(0),d=0,e=0,f=0,g=E(0),h=0,i=0,k=E(0),m=0,n=0,o=E(0);d=db-16|0;db=d;b=x[x[a+16>>2]+24620>>2];e=a+4208|0;n=a,o=qe(E(10),E(E(E(B[xb(e,0)>>2]*E(120))+E(-60))/E(20))),B[n+4232>>2]=o;k=E(E(b>>>0)/E(1e3));n=a,o=qe(E(10),E(E(-1)/E(k*E(E(B[xb(e,1)>>2]*E(499.989990234375))+E(.009999999776482582))))),B[n+4236>>2]=o;n=a,o=qe(E(10),E(E(-1)/E(k*E(E(B[xb(e,2)>>2]*E(2950))+E(50))))),B[n+4240>>2]=o;x[d+12>>2]=1325400064;c=E(qe(E(10),E(E(E(B[xb(e,3)>>2]*E(60))+E(-60))/E(20)))*E(2147483648));b=(q(c),j(2));g=E(0);a:{if((b|0)==1065353216){break a}b:{if(b-2139095040>>>0<=2164260863){f=b<<1;if(!f){g=E(Nv(E(-1))/E(0));break a}if((b|0)==2139095040){break b}if(!(f>>>0<4278190080&(b|0)>=0)){g=wE(c);break a}b=(q(E(c*E(8388608))),j(2))-192937984|0}f=b-1060306944|0;h=f>>>15&240;i=+(l(2,b-(f&-8388608)|0),r())*C[h+3568>>3]+-1;m=i*i;c=E((C[479]*m+(C[480]*i+C[481]))*m+(+(f>>23)*C[478]+C[h+3576>>3]+i))}g=c}B[d+8>>2]=E(E(g*E(67108864))/E(.6931471824645996))+E(67108864);n=a,o=E(B[$l(d+12|0,d+8|0)>>2]*E(4.656612873077393e-10)),B[n+4244>>2]=o;n=a,o=E(E(E(-1)/E(E(B[xb(e,4)>>2]*E(99))+E(1)))+E(1)),B[n+4248>>2]=o;c=E(E(E(B[xb(e,5)>>2]*E(4))*k)+E(2));c:{if(E(F(c))<E(2147483648)){h=~~c;break c}h=-2147483648}x[a+4252>>2]=h;db=d+16|0}function Rg(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=db-16|0;db=f;x[f+12>>2]=d;e=0;a:{if(b-251>>>0<4294967046){break a}e=b-1|0;g=x[a+480180>>2];if(!ym(g)){if(g&17408){a=((e&255)>>>0)/12|0;e=z[((D(a,-12)+e&255)<<1)+33472>>1]<<4>>>a|0;break a}if(!d){x[f+12>>2]=8363;d=8363}if(Zi(a)){a=((e&255)>>>0)/12|0;b=yka(x[(D(a,-12)+e<<6&960)+37360>>2]<<a,0,d,0);a=hb;c=a>>>21|0;h=f,i=Qc((a&2097151)<<11|b>>>21,c),x[h+8>>2]=i;tc(f+8|0,2147483647);e=x[f+8>>2];break a}if(y[a+480208|0]&16){a=e&255;e=z[((a>>>0)%12<<1)+33472>>1]<<5>>>(a>>>0)/12|0;break a}a=((e&255)>>>0)/12|0;tc(f+12|0,-1>>>a|0);e=Qc(Bka(yka(z[((D(a,-12)+e&255)<<1)+33472>>1],0,267616,0),hb,x[f+12>>2]<<a,0),hb);break a}if(g&20){d=e>>>0>12;if((g|0)==16){b=c<<4}else{b=Ob(a+1074312|0,76)?c&-8:c}c=d?e:12;if(y[a+480208|0]&16){a=((b|0)/-2|0)-(c<<6)|0;e=((a|0)<=-8447?-8447:a)+8448|0;break a}a=c-12|0;c=((a&255)>>>0)/12|0;d=((b|0)/16|0)+(D(c,-12)+a<<3&248)|0;x[f+4>>2]=d+8;ke(f+4|0,0,103);a=b>>31;b=(a^b)-a&15;a=d+(a|1)|0;a=(a|0)<=-8?-8:a;e=D(b,z[(((a|0)>=95?95:a)<<1)+33968>>1])+D(z[(x[f+4>>2]<<1)+33952>>1],16-b|0)<<1>>>c|0;break a}if(!(!(c&240)&b-25>>>0<84)){a=((e&255)>>>0)/12|0;e=z[(D(c>>>4&15,12)+(D(a,-12)+e&255)<<1)+33072>>1]<<5>>>a|0;break a}e=z[(b<<1)+32846>>1]<<2}db=f+16|0;return e}function r4(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=db+-64|0;db=d;a:{b:{c:{d:{e=x[a+36>>2];c=x[a+40>>2];e:{if(Kb(e,c)){xc(d+60|0);break e}c=d+24|0;Nn(c,a);x[23549]=0;c=R(986,c|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break d}x[d+60>>2]=c;Yf(d+24|0);c=x[a+40>>2];e=x[a+36>>2]}c=(k=a+36|0,l=x[d+60>>2],m=Kb(e,c),m?k:l);f=x[a+8>>2];if((f|0)==-1){e=x[c+4>>2];f=Ln(e);g=x[c>>2];i=Mn(g,e);j=C[f>>3];e=0;while(1){if((e|0)==(i|0)){c=f;break c}c=nl(g,e);if(h+C[c>>3]>b){break c}e=e+1|0;h=h+j;continue}}c=nl(x[c>>2],f);break b}e=N()|0;Yf(d+24|0);break a}b=b-h}f=z[c+12>>1];e=x[a+24>>2];x[23549]=0;P(1019,e|0,f|0);f=x[23549];x[23549]=0;if((f|0)!=1){f:{f=x[a+24>>2];e=y[a+64|0];c=RM(JS(d+24|0,b),y[c+16|0],z[c+12>>1],x[c+8>>2]);x[23549]=0;g=x[c+12>>2];x[d+8>>2]=x[c+8>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d+16>>2]=x[c+16>>2];x[d+20>>2]=g;g=x[c+4>>2];x[d>>2]=x[c>>2];x[d+4>>2]=g;V(1020,d+48|0,f|0,(e?7:1)|0,d|0);c=x[23549];x[23549]=0;if((c|0)==1){break f}c=Wj(x[d+52>>2]);f=v[c+26|0]&1;e=x[(f?c+8|0:c+12|0)>>2];f=z[(f?c+20|0:c+22|0)>>1];b=C[c>>3];vi(d+48|0);c=x[a+24>>2];w[c+1074450>>1]=f;w[c+1074448>>1]=f;x[c+1074428>>2]=e;x[c+1074392>>2]=-2;b=h+b;C[a+16>>3]=b;Qk(d+60|0);db=d- -64|0;return+b}}e=N()|0;Qk(d+60|0)}Q(e|0);p()}function pH(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{f:{g:{c=x[a+4>>2];h:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break h}c=jd(a)}switch(c-43|0){case 0:case 2:break g;default:break f}}f=(c|0)==45;g=!b;c=x[a+4>>2];i:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break i}c=jd(a)}b=c-58|0;if(g|b>>>0>4294967285){break e}b=x[a+116>>2];if((b|0)>0|(b|0)>=0){break d}break a}b=c-58|0}if(b>>>0<4294967286){break c}b=c-48|0;if(b>>>0<10){while(1){e=(D(e,10)+c|0)-48|0;d=(e|0)<214748364;c=x[a+4>>2];j:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break j}c=jd(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}d=e>>31}k:{if(b>>>0>=10){break k}while(1){b=yka(e,d,10,0);d=b+c|0;c=hb;e=d-48|0;d=(b>>>0>d>>>0?c+1|0:c)-(d>>>0<48)|0;b=x[a+4>>2];l:{if((b|0)!=x[a+104>>2]){x[a+4>>2]=b+1;c=y[b|0];break l}c=jd(a)}b=c-48|0;if(b>>>0>9){break k}if(e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836){continue}break}}if(b>>>0<10){while(1){b=x[a+4>>2];m:{if((b|0)!=x[a+104>>2]){x[a+4>>2]=b+1;b=y[b|0];break m}b=jd(a)}if(b-48>>>0<10){continue}break}}b=x[a+116>>2];if((b|0)>0|(b|0)>=0){x[a+4>>2]=x[a+4>>2]-1}hb=f?0-(((e|0)!=0)+d|0)|0:d;return f?0-e|0:e}x[a+4>>2]=x[a+4>>2]-1;break b}if(x[a+116>>2]<0){break a}}x[a+4>>2]=x[a+4>>2]-1}hb=-2147483648;return 0}function aX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=db-32|0;db=d;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1397771593){nd(b,32);Po(b);c=d+8|0;Xh(c,1,a+4|0);e=d+20|0;Bc(e,c);Ce(b+43|0,e);tb(e);w[b+30>>1]=y[a+19|0]<<2;Wf(b+30|0,256);w[b+32>>1]=y[a+17|0];Wf(b+32|0,64);w[b+28>>1]=(y[a+47|0]&127)<<2;Wf(b+28|0,256);if(v[a+47|0]<0){w[b+34>>1]=z[b+34>>1]|32}c=y[a+18|0];if(c&16){w[b+34>>1]=z[b+34>>1]|2;c=y[a+18|0]}if(c&32){w[b+34>>1]=z[b+34>>1]|8;c=y[a+18|0]}if(c&64){w[b+34>>1]=z[b+34>>1]|4;c=y[a+18|0]}if(c<<24>>24<0){w[b+34>>1]=z[b+34>>1]|16}c=y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24);x[b+24>>2]=c?c>>>0<=256?256:c:8363;x[b>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[b+4>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[b+8>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);x[b+12>>2]=y[a+64|0]|y[a+65|0]<<8|(y[a+66|0]<<16|y[a+67|0]<<24);x[b+16>>2]=y[a+68|0]|y[a+69|0]<<8|(y[a+70|0]<<16|y[a+71|0]<<24);ok(b);v[b+38|0]=y[(y[a+79|0]&7)+39920|0];v[b+41|0]=y[a+76|0];v[b+40|0]=y[a+77|0]&127;v[b+39|0]=y[a+78|0];c=y[a+46|0];a:{if((c|0)==64){c=512}else{if((c|0)!=128){break a}c=16384}w[b+34>>1]=c|z[b+34>>1]}c=y[a+72|0]|y[a+73|0]<<8|(y[a+74|0]<<16|y[a+75|0]<<24)}db=d+32|0;return c|0}function Y3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(A[a+4>>2]<A[wb(a)>>2]){c=db-16|0;db=c;a=fp(c+4|0,a,1);xx(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+16;fc(a);db=c+16|0;return}i=db-32|0;db=i;c=wb(a);c=Wv(i+12|0,Yv(a,fh(x[a>>2],x[a+4>>2])+1|0),fh(x[a>>2],x[a+4>>2]),c);xx(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+16;h=db-16|0;db=h;g=wb(a);b=vb(h+12|0,x[a+4>>2]);d=vb(h+8|0,x[a>>2]);e=vb(h+4|0,x[c+4>>2]);f=x[b>>2];d=x[d>>2];b=db+-64|0;db=b;e=x[e>>2];x[b+56>>2]=e;x[b+60>>2]=f;x[b+52>>2]=e;g=rd(b+24|0,g,b+52|0,b+56|0);x[b+16>>2]=x[g+8>>2];e=x[g+4>>2];x[b+8>>2]=x[g>>2];x[b+12>>2]=e;Ke(b+36|0,b+8|0);while(1){if(sd(f,d)){xx(wk(x[b+56>>2]),wk(f));f=Jl(b+60|0);Jl(b+56|0);f=x[f>>2];continue}break}Je(b+36|0);j=x[b+56>>2];if(!y[b+48|0]){f=db-16|0;db=f;d=vb(f+12|0,x[x[b+44>>2]>>2]);k=x[vb(f+8|0,x[x[b+40>>2]>>2])>>2];g=db-16|0;db=g;d=x[d>>2];x[g+12>>2]=d;while(1){if(ai(d,k)){e=db-16|0;db=e;x[e+12>>2]=d;d=wk(x[jl(e+12|0)>>2]);db=e+16|0;lj(d);d=x[jl(g+12|0)>>2];continue}break}db=g+16|0;db=f+16|0}db=b- -64|0;x[c+4>>2]=j;Pb(a,c+4|0);Pb(a+4|0,c+8|0);Pb(wb(a),kc(c));x[c>>2]=x[c+4>>2];db=h+16|0;a=x[c+4>>2];while(1){b=x[c+8>>2];if((b|0)!=(a|0)){b=b-16|0;x[c+8>>2]=b;lj(b);continue}break}a=x[c>>2];if(a){vr(c);Eb(a)}db=i+32|0}function dda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;e=db-16|0;db=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}l=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];o=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+l|0;b=(b>>>16&65520)+g|0;p=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];t=w[b+6>>1];u=w[b+4>>1];v=w[b+2>>1];y=w[b>>1];k=0;while(1){if((k|0)!=2){b=(k<<1)+o|0;x[(k<<2)+e>>2]=(((((((D(w[b-8>>1],v)+D(w[b-12>>1],y)|0)+D(w[b-4>>1],u)|0)+D(w[b>>1],t)|0)+D(w[b+4>>1],s)|0)+D(w[b+8>>1],r)|0)+D(w[b+12>>1],q)|0)+D(w[b+16>>1],p)|0)/32768;k=k+1|0;continue}break}j=j+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],j>>12);i=i+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i>>12);Qb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;db=e+16|0}function J9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(A[a+4>>2]<A[wb(a)>>2]){c=db-16|0;db=c;a=Kz(c+4|0,a);Ux(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+4;fc(a);db=c+16|0;return}i=db-32|0;db=i;c=wb(a);c=Jf(i+12|0,eg(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);Ux(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+4;h=db-16|0;db=h;g=wb(a);b=vb(h+12|0,x[a+4>>2]);d=vb(h+8|0,x[a>>2]);e=vb(h+4|0,x[c+4>>2]);f=x[b>>2];d=x[d>>2];b=db+-64|0;db=b;e=x[e>>2];x[b+56>>2]=e;x[b+60>>2]=f;x[b+52>>2]=e;g=rd(b+24|0,g,b+52|0,b+56|0);x[b+16>>2]=x[g+8>>2];e=x[g+4>>2];x[b+8>>2]=x[g>>2];x[b+12>>2]=e;Ke(b+36|0,b+8|0);while(1){if(sd(f,d)){Ux(Gf(x[b+56>>2]),Gf(f));f=fj(b+60|0);fj(b+56|0);f=x[f>>2];continue}break}Je(b+36|0);j=x[b+56>>2];if(!y[b+48|0]){f=db-16|0;db=f;d=vb(f+12|0,x[x[b+44>>2]>>2]);k=x[vb(f+8|0,x[x[b+40>>2]>>2])>>2];g=db-16|0;db=g;d=x[d>>2];x[g+12>>2]=d;while(1){if(ai(d,k)){e=db-16|0;db=e;x[e+12>>2]=d;d=Gf(x[Ae(e+12|0)>>2]);db=e+16|0;Lf(d);d=x[Ae(g+12|0)>>2];continue}break}db=g+16|0;db=f+16|0}db=b- -64|0;x[c+4>>2]=j;Pb(a,c+4|0);Pb(a+4|0,c+8|0);Pb(wb(a),kc(c));x[c>>2]=x[c+4>>2];db=h+16|0;a=x[c+4>>2];while(1){b=x[c+8>>2];if((b|0)!=(a|0)){b=b-4|0;x[c+8>>2]=b;Lf(b);continue}break}a=x[c>>2];if(a){Iz(c);Eb(a)}db=i+32|0}function X$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=db-368|0;db=f;x[f+360>>2]=37;x[f+364>>2]=0;h=Nr(f+360|1,21204,x[c+4>>2]);x[f+316>>2]=f+320;a=yd();a:{if(h){b=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=b;g=Lg(f+320|0,30,a,f+360|0,f+32|0);break a}C[f+48>>3]=e;g=Lg(f+320|0,30,a,f+360|0,f+48|0)}x[f+80>>2]=1103;i=pe(f+308|0,0,f+80|0);b=f+320|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=yd();f:{if(h){g=x[c+8>>2];C[f+8>>3]=e;x[f>>2]=g;g=Oi(f+316|0,a,f+360|0,f);break f}C[f+16>>3]=e;g=Oi(f+316|0,a,f+360|0,f+16|0)}if((g|0)==-1){x[23549]=0;X(1104);a=x[23549];x[23549]=0;if((a|0)==1){break d}break e}a=x[f+316>>2];Me(i,a)}j=a+g|0;l=Pi(a,j,x[c+4>>2]);x[f+68>>2]=1103;h=pe(f+72|0,0,f+68|0);g:{h:{if((f+320|0)==(a|0)){g=f+80|0;break h}g=Nd(g<<3);if(!g){x[23549]=0;X(1104);a=x[23549];x[23549]=0;if((a|0)!=1){break e}a=N()|0;break g}Me(h,g);b=a}a=f+60|0;Nc(a,x[c+28>>2]);x[23549]=0;ea(1134,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);a=x[23549];x[23549]=0;i:{if((a|0)!=1){Xb(f+60|0);x[23549]=0;a=ga(1135,k|0,g|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break i}Kc(h);Kc(i);db=f+368|0;break b}a=N()|0;Xb(f+60|0);break g}a=N()|0}Kc(h);break c}p()}a=N()|0}Kc(i);Q(a|0);p()}return a|0}function f0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=db-208|0;db=f;x[f+200>>2]=37;x[f+204>>2]=0;h=Nr(f+200|1,21204,x[c+4>>2]);x[f+156>>2]=f+160;a=yd();a:{if(h){b=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=b;g=Lg(f+160|0,30,a,f+200|0,f+32|0);break a}C[f+48>>3]=e;g=Lg(f+160|0,30,a,f+200|0,f+48|0)}x[f+80>>2]=1103;i=pe(f+148|0,0,f+80|0);b=f+160|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=yd();f:{if(h){g=x[c+8>>2];C[f+8>>3]=e;x[f>>2]=g;g=Oi(f+156|0,a,f+200|0,f);break f}C[f+16>>3]=e;g=Oi(f+156|0,a,f+200|0,f+16|0)}if((g|0)==-1){x[23549]=0;X(1104);a=x[23549];x[23549]=0;if((a|0)==1){break d}break e}a=x[f+156>>2];Me(i,a)}j=a+g|0;l=Pi(a,j,x[c+4>>2]);x[f+68>>2]=1103;h=pe(f+72|0,0,f+68|0);g:{h:{if((f+160|0)==(a|0)){g=f+80|0;break h}g=Nd(g<<1);if(!g){x[23549]=0;X(1104);a=x[23549];x[23549]=0;if((a|0)!=1){break e}a=N()|0;break g}Me(h,g);b=a}a=f+60|0;Nc(a,x[c+28>>2]);x[23549]=0;ea(1129,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);a=x[23549];x[23549]=0;i:{if((a|0)!=1){Xb(f+60|0);x[23549]=0;a=ga(14,k|0,g|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break i}Kc(h);Kc(i);db=f+208|0;break b}a=N()|0;Xb(f+60|0);break g}a=N()|0}Kc(h);break c}p()}a=N()|0}Kc(i);Q(a|0);p()}return a|0}function KJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;c=db+-64|0;db=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;xf(c+48|0,c+32|0,f);a=x[d+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=db-32|0;db=a;a:{b:{c:{d:{k=x[c+4>>2];if(k>>>0>=g>>>0){if(A[c+20>>2]<g>>>0){break d}if(f>>>0>A[c+8>>2]){break c}l=x[c+28>>2];if(he(x[c+24>>2],l)>>>0<f>>>0){break b}m=b+12|0;n=x[c+16>>2];o=x[c>>2];e:while(1){d=0;if((f|0)==(h|0)){break a}while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{j=Pg(o,k,d,h);e=xb(x[b>>2],d);i=je(fg(C[j>>3])*134217728);j=e;e=(x[e>>2]>>1)+om(i)|0;q=e;e=qs(m)+e&-4096;x[j>>2]=q-e;C[a+24>>3]=+(e|0)*7.450580596923828e-9;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;i=je(C[wg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){e=~~i;break f}e=-2147483648}e=Sc(e);r=In(n,l,d,h),s=e,w[r>>1]=s;d=d+1|0;continue}}}_(7130,8943,77,8623);p()}_(7095,8943,78,8623);p()}_(5838,8943,79,8623);p()}_(5808,8943,80,8623);p()}db=a+32|0;db=c- -64|0}function WY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if(Kg(a,x[b+8>>2],e)){hw(b,c,d);return}a:{if(Kg(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;if(x[b+44>>2]!=4){f=a+16|0;h=f+(x[a+12>>2]<<3)|0;d=0;b:{c:{while(1){d:{if(f>>>0>=h>>>0){break d}w[b+52>>1]=0;ew(x[f>>2],x[f+4>>2],b,c,c,1,e);if(y[b+54|0]){break d}e:{if(!y[b+53|0]){break e}if(y[b+52|0]){d=1;if(x[b+24>>2]==1){break c}g=1;if(y[a+8|0]&2){break e}break c}g=1;if(!(v[a+8|0]&1)){break c}}f=f+8|0;continue}break}a=4;if(!g){break b}}a=3}x[b+44>>2]=a;if(d&1){break a}}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}g=x[a+12>>2];Hr(x[a+16>>2],x[a+20>>2],b,c,d,e);f=a+24|0;g=(a+16|0)+(g<<3)|0;if(f>>>0>=g>>>0){break a}a=x[a+8>>2];if(!(!(a&2)&x[b+36>>2]!=1)){while(1){if(y[b+54|0]){break a}Hr(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(y[b+54|0]|x[b+36>>2]==1){break a}Hr(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(y[b+54|0]|x[b+36>>2]==1&x[b+24>>2]==1){break a}Hr(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function lba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=db-16|0;db=l;x[l+12>>2]=b;q=Bf(a);while(1){if(xg(b,c)){b=x[vb(l+8|0,q)>>2];k=td(x[l+12>>2]);o=db-16|0;db=o;p=0;m=db-16|0;db=m;i=db-32|0;db=i;g=i+28|0;d=i+24|0;e=db-16|0;db=e;a:{b:{if(!qc(b,x[vb(e+12|0,Kf(a))>>2])){f=y[k|0];j=x[k+4>>2];h=td(b);n=y[h|0];h=x[h+4>>2];if(!Wn(f,j,n,h)){break b}}x[e+12>>2]=b;f=vb(e+8|0,yb(x[a>>2]));c:{d=x[e+12>>2];if(!qc(d,x[f>>2])){d=x[nz(e+12|0)>>2];f=td(d);h=y[f|0];n=x[f+4>>2];f=y[k|0];j=x[k+4>>2];if(!Wn(h,n,f,j)){break c}}if(!x[b>>2]){x[g>>2]=b;break a}x[g>>2]=d;b=d+4|0;break a}b=Ny(a,g,f,j);break a}if(Wn(n,h,f,j)){d:{d=lz(b);if(!qc(d,x[vb(e+12|0,Kf(a))>>2])){f=y[k|0];j=x[k+4>>2];h=td(d);if(!Wn(f,j,y[h|0],x[h+4>>2])){break d}}if(!x[b+4>>2]){x[g>>2]=b;b=b+4|0;break a}x[g>>2]=d;b=d;break a}b=Ny(a,g,f,j);break a}x[g>>2]=b;x[d>>2]=b;b=d}db=e+16|0;d=b;b=x[b>>2];if(!b){b=db-16|0;db=b;e=gc(a);g=i+12|0;e=rh(g,Hc(28),Ag(b+8|0,e));Yz(x[e>>2]+16|0,k);r=gc(e),s=1,v[r+4|0]=s;db=b+16|0;Yg(a,x[i+28>>2],d,x[i+12>>2]);b=Zd(g);ol(g);p=1}Xg(m+8|0,x[vb(i+12|0,b)>>2],p);db=i+32|0;db=m+16|0;vb(o+12|0,x[m+8>>2]);db=o+16|0;b=x[Vg(l+12|0)>>2];continue}else{db=l+16|0}break}}function wka(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{e=b;if(e){if(!c){break j}if(!d){break i}e=G(d)-G(e)|0;if(e>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;fb=a-D(b,c)|0;gb=0;hb=0;return b}if(!a){break g}if(!d){break f}f=d-1|0;if(f&d){break f}fb=a;gb=e&f;a=e>>>xka(d)|0;hb=0;return a}f=c-1|0;if(!(f&c)){break e}j=(G(c)+33|0)-G(e)|0;h=0-j|0;break c}j=e+1|0;h=63-e|0;break c}fb=0;a=(e>>>0)/(d>>>0)|0;gb=e-D(a,d)|0;hb=0;return a}e=G(d)-G(e)|0;if(e>>>0<31){break d}break b}fb=a&f;gb=0;if((c|0)==1){break a}c=xka(c);d=c&31;if((c&63)>>>0>=32){e=0;a=b>>>d|0}else{e=b>>>d|0;a=((1<<d)-1&b)<<32-d|a>>>d}hb=e;return a}j=e+1|0;h=63-e|0}f=a;e=j&63;g=e&31;if((e&63)>>>0>=32){e=0;f=b>>>g|0}else{e=b>>>g|0;f=((1<<g)-1&b)<<32-g|f>>>g}h=h&63;g=h&31;if((h&63)>>>0>=32){i=a<<g;a=0}else{i=(1<<g)-1&a>>>32-g|b<<g;a=a<<g}b=i;if(j){h=d-1|0;k=c-1|0;h=(k|0)!=-1?h+1|0:h;g=k;while(1){e=e<<1|f>>>31;f=f<<1|b>>>31;k=e;l=h-(e+(f>>>0>g>>>0)|0)|0;m=l>>31;i=m;e=f;l=c&i;f=e-l|0;e=k-((d&i)+(e>>>0<l>>>0)|0)|0;i=b<<1|a>>>31;a=n|a<<1;b=i|o;k=m&1;n=k;j=j-1|0;if(j){continue}break}}fb=f;gb=e;i=b<<1|a>>>31;a=k|a<<1;hb=i|o;return a}fb=a;gb=b;a=0;b=0}hb=b;return a}function DJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;c=db+-64|0;db=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;xf(c+48|0,c+32|0,f);a=x[d+4>>2];g=x[a+8>>2];j=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;f=c+16|0;a=db-32|0;db=a;a:{b:{c:{d:{l=x[c+4>>2];if(l>>>0>=j>>>0){if(A[f+4>>2]<j>>>0){break d}if(A[c+8>>2]<g>>>0){break c}if(he(x[f+8>>2],x[f+12>>2])>>>0<g>>>0){break b}m=b+12|0;n=x[c>>2];e:while(1){d=0;if((g|0)==(h|0)){break a}while(1)if((d|0)==(j|0)){h=h+1|0;continue e}else{k=Pg(n,l,d,h);e=xb(x[b>>2],d);i=je(fg(C[k>>3])*134217728);k=e;e=(x[e>>2]>>1)+om(i)|0;o=e;e=qs(m)+e&-4096;x[k>>2]=o-e;C[a+24>>3]=+(e|0)*7.450580596923828e-9;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;i=je(C[wg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){e=~~i;break f}e=-2147483648}e=Sc(e);q=Hn(f,d,h),r=e,w[q>>1]=r;d=d+1|0;continue}}}_(7130,8943,77,8623);p()}_(7095,8943,78,8623);p()}_(5838,8943,79,8623);p()}_(5808,8943,80,8623);p()}db=a+32|0;db=c- -64|0}function eda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;e=db-16|0;db=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}l=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];o=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+l|0;b=(b>>>16&65520)+g|0;p=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];t=w[b+6>>1];u=w[b+4>>1];y=w[b+2>>1];z=w[b>>1];k=0;while(1){if((k|0)!=2){b=k+o|0;x[(k<<2)+e>>2]=(((((((D(v[b-4|0],y)+D(v[b-6|0],z)|0)+D(v[b-2|0],u)|0)+D(v[b|0],t)|0)+D(v[b+2|0],s)|0)+D(v[b+4|0],r)|0)+D(v[b+6|0],q)|0)+D(v[b+8|0],p)<<8)/32768;k=k+1|0;continue}break}j=j+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],j>>12);i=i+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i>>12);Qb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;db=e+16|0}function $9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=E(0);g=w[d>>1];h=w[d+2>>1];a:{if((g|0)>(h|0)){break a}k=x[b>>2];i=oc(k,x[b+4>>2]);if(!i){break a}j=w[e>>1];if((j|0)<(g|0)|(h|0)<(j|0)|(i-1&65535)>>>0>(h-j&65535)>>>0|A[a+36>>2]>65535){break a}b:{while(1){if((f|0)==(i|0)){break b}j=xb(k,f);f=f+1|0;if(!(B[j>>2]<E(0))){continue}break}return 0}f=0;l=B[c>>2];if(l<=E(0)){break a}w[a+28>>1]=g;w[a>>1]=1;m=a,n=dM(i),w[m+30>>1]=n;B[a+32>>2]=F(l);Yk(a+4|0,(h-g|0)+1|0);c=yb(x[b>>2]);h=yb(x[b+4>>2]);f=Yj(yb(x[a+4>>2]),w[e>>1]-w[d>>1]|0);g=db-16|0;db=g;b=db-32|0;db=b;Od(b+24|0,c,h);rl(b+16|0,x[b+24>>2],x[b+28>>2],f);c=Zx(c,x[b+16>>2]);m=b,n=cM(f,x[b+20>>2]),x[m+12>>2]=n;vc(g+8|0,c,b+12|0);db=b+32|0;db=g+16|0;c=x[a+4>>2];g=w[a+30>>1];h=w[a+28>>1];b=w[e>>1];f=b;while(1){if((b&65535)!=32768&(f|0)>(h|0)){f=f-1|0;b=f-h|0;i=xb(c,b+g|0);m=xb(c,b),o=E(B[i>>2]/B[a+32>>2]),B[m>>2]=o;b=w[e>>1];continue}else{c=w[a+30>>1];e=w[a+28>>1];h=c+e|0;f=g;g=b<<16>>16;f=f+g|0;b=x[a+4>>2];d=w[d+2>>1];c=(g|0)<=(32767-c|0);while(1){if(c&(d|0)>=(f|0)){g=xb(b,f-h|0);m=xb(b,f-e|0),o=E(B[a+32>>2]*B[g>>2]),B[m>>2]=o;f=f+1|0;continue}else{Cp(a)}break}}break}f=1}return f|0}function _F(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=db-16|0;db=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{while(1){j=x[a+12>>2];if(!(j>>>0>=d>>>0|f>>>0>=g>>>0)){i=v[j|0];c=i&255;c:{if((i|0)>=0){i=1;break c}b=2;if(i>>>0<4294967234){break a}if(i>>>0<=4294967263){if((d-j|0)<2){break b}i=y[j+1|0];if((i&192)!=128){break a}c=i&63|c<<6&1984;i=2;break c}if(i>>>0<=4294967279){if((d-j|0)<3){break b}k=y[j+2|0];i=y[j+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}c=k&63|(c<<12&61440|(i&63)<<6);i=3;break c}if(i>>>0>4294967284){break a}if((d-j|0)<4){break b}l=y[j+3|0];m=y[j+2|0];k=y[j+1|0];f:{g:{switch(c-240|0){case 0:if((k+112&255)>>>0<48){break f}break a;case 4:if((k&240)==128){break f}break a;default:break g}}if((k&192)!=128){break a}}if((m&192)!=128|(l&192)!=128){break a}i=4;c=l&63|(m<<6&4032|(c<<18&1835008|(k&63)<<12));if(c>>>0>1114111){break a}}x[f>>2]=c;x[a+12>>2]=i+j;f=x[a+8>>2]+4|0;x[a+8>>2]=f;continue}break}b=d>>>0>j>>>0;break a}b=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];db=a+16|0;return b|0}function iha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=db-16|0;db=e;nd(b,0);Po(b);f=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);a:{if(c&34){if(d){x[b+24>>2]=f;break a}g=b,h=Le(Dj(+(f+1408|0)/1536)*8363),x[g+24>>2]=h;break a}v[b+37|0]=(c|0)==16?f:f^128;v[b+36|0]=y[a+4|0]}v[e+15|0]=y[a+5|0];v[e+14|0]=64;g=b,h=y[Sb(e+15|0,e+14|0)|0]<<2,w[g+30>>1]=h;d=y[a+6|0]|y[a+7|0]<<8;if(d>>>0<=256){w[b+28>>1]=d;w[b+34>>1]=z[b+34>>1]|32}x[b>>2]=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);x[b+4>>2]=y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24);x[b+8>>2]=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);d=y[a+20|0]|y[a+21|0]<<8;if(d&16){w[b+34>>1]=z[b+34>>1]|2;d=y[a+20|0]|y[a+21|0]<<8}if(d&32){w[b+34>>1]=z[b+34>>1]|4;d=y[a+20|0]|y[a+21|0]<<8}if(d&256){w[b+34>>1]=z[b+34>>1]|8;d=y[a+20|0]|y[a+21|0]<<8}if(d&512){w[b+34>>1]=z[b+34>>1]|16}v[b+38|0]=y[(y[a+22|0]&7)+39920|0];v[b+39|0]=y[a+23|0];v[b+40|0]=y[a+24|0];v[b+41|0]=y[a+25|0];if((c|0)==32){v[e+13|0]=y[a+26|0];v[e+12|0]=64;g=b,h=y[Sb(e+13|0,e+12|0)|0],w[g+32>>1]=h}x[b+12>>2]=y[a+27|0]|y[a+28|0]<<8|(y[a+29|0]<<16|y[a+30|0]<<24);x[b+16>>2]=y[a+31|0]|y[a+32|0]<<8|(y[a+33|0]<<16|y[a+34|0]<<24);db=e+16|0}function P7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=E(0),q=E(0),r=0,s=0,t=0,u=E(0),v=0;i=db-16|0;db=i;if(Yh(a+44|0)){n=x[a+44>>2];j=Ac(n,0);k=Ac(n,1);n=x[a+56>>2];t=Ac(n,0);n=Ac(n,1);u=B[xb(a+4208|0,1)>>2];x[i+12>>2]=d;s=x[a+4220>>2];q=E(E(1)/E(s>>>0));v=x[a+4216>>2];o=d;f=n;g=t;while(1){if(o){h=x[a+4224>>2];a:{if(s>>>0>h>>>0){x[i+8>>2]=s-h;r=x[Cb(i+12|0,i+8|0)>>2];m=0;b:{if(u<E(1)){l=h+r|0;e=h>>>0>l>>>0?h:l;while(1){if((h|0)==(e|0)){break b}p=E(h>>>0);B[g>>2]=q*E(B[j>>2]*p);B[f>>2]=q*E(B[k>>2]*p);h=h+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((m|0)!=(r|0)){B[g>>2]=B[j>>2];B[f>>2]=B[k>>2];m=m+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}break}l=h+r|0}o=o-r|0;x[i+12>>2]=o;break a}m=v-h|0;x[i+4>>2]=m;l=x[Cb(i+12|0,i+4|0)>>2];e=0;c:{if(u<E(1)){e=m-l|0;while(1){if(e>>>0>=m>>>0){break c}p=E(m>>>0);B[g>>2]=q*E(B[j>>2]*p);B[f>>2]=q*E(B[k>>2]*p);m=m-1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((e|0)!=(l|0)){x[g>>2]=0;x[f>>2]=0;e=e+1|0;f=f+4|0;g=g+4|0;continue}break}e=l<<2;k=e+k|0;j=j+e|0}o=o-l|0;x[i+12>>2]=o;e=h+l|0;l=e>>>0<v>>>0?e:0}x[a+4224>>2]=l;continue}else{li(a,b,c,t,n,d)}break}}db=i+16|0}function m4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=db-2160|0;db=b;Sx(b+112|0);a:{b:{c:{f=x[c+4>>2];if(!f){a=ac(8);x[23549]=0;b=O(54,b+100|0,10336)|0;c=x[23549];x[23549]=0;if((c|0)==1){break c}a=pc(a,b);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}g=x[c>>2];d=x[c+12>>2];e=x[c+8>>2];x[b+92>>2]=e;x[b+96>>2]=d;c=x[b+96>>2];x[b+40>>2]=x[b+92>>2];x[b+44>>2]=c;x[b+88>>2]=f;x[b+84>>2]=g;c=x[b+88>>2];x[b+32>>2]=x[b+84>>2];x[b+36>>2]=c;h=yJ(b+32|0);if(h){c=b- -64|0;x[c>>2]=e;x[b+68>>2]=d;d=x[c+4>>2];x[b+24>>2]=x[c>>2];x[b+28>>2]=d;x[b+60>>2]=f;x[b+56>>2]=g;c=x[b+60>>2];x[b+16>>2]=x[b+56>>2];x[b+20>>2]=c;c=sJ(b+16|0)}else{c=0}x[b+72>>2]=c;x[b+76>>2]=0;d=0;c=2048;while(1){if(c){e=ib[f|0](g,(b+112|0)+d|0,c)|0;c=c-e|0;d=d+e|0;if(e){continue}}break}c=ec(b+48|0,b+112|0,d);d=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=d;a=Ws(a,b+8|0,h?b+72|0:0);if(a+1>>>0>=3){a=ac(8);x[23549]=0;b=O(54,b+100|0,7955)|0;c=x[23549];x[23549]=0;if((c|0)!=1){a=pc(a,b);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;jc(a);break b}db=b+2160|0;return a|0}c=N()|0;jc(a)}Q(c|0)}p()}function Aea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;l=db-48|0;db=l;if(qf(x[b>>2],x[b+4>>2])>>>0>c>>>0){while(1){k=n&65535;if(k>>>0<=c>>>0){g=Rf(x[b>>2],k);e=x[g>>2];if(Kb(e,x[g+4>>2])){o=l+28|0;e=yb(e);k=yb(x[Rf(x[b>>2],k)+4>>2]);f=DQ(l+8|0,d);m=db-16|0;db=m;x[m+12>>2]=e;while(1){if(Kb(e,k)){j=db-16|0;db=j;if(!(y[e+5|0]|y[e+3|0]!=4)){g=j+8|0;Fb(g,x[f>>2],z[f+14>>1]);Dh(g,0);v[e+3|0]=0}i=y[e+2|0];if(!(y[e+4|0]|(i|0)!=11)){g=j+8|0;Fb(g,x[f>>2],z[f+14>>1]);Dh(g,0);v[e+2|0]=0;i=0}a:{b:{if(!y[e|0]){Fb(j+8|0,x[f>>2],z[f+14>>1]);i=y[e+2|0];h=y[e+3|0];if(!Ib(x[x[j+8>>2]>>2],x[j+12>>2])){break b}if(!((i|0)==11|h)){v[e+5|0]=0;h=4;v[e+3|0]=4;break a}if((h|0)==4|i){break a}v[e+4|0]=0;v[e+2|0]=11;break a}h=y[e+3|0]}g=j+8|0;Fb(g,x[f>>2],z[f+14>>1]);Dh(g,(h|0)==4|(i|0)==11);h=y[e+3|0]}c:{d:{e:{if(!(!y[f+16|0]|h)){v[e+3|0]=17;i=0;h=125;break e}i=0;f:{switch(h-16|0){case 1:break d;case 0:break f;default:break c}}if(y[e+5|0]){break c}i=1;h=6}v[e+5|0]=h}v[f+16|0]=i}w[f+14>>1]=(z[f+14>>1]+1>>>0)%z[f+12>>1];db=j+16|0;e=x[lk(m+12|0)>>2];continue}break}BQ(o,f);db=m+16|0;He(o);He(f)}n=n+1|0;continue}break}}BQ(a,d);db=l+48|0}function Eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=db-16|0;db=e;q=x[a+16>>2];r=cg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);i=x[a+8>>2];j=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];k=x[a+128>>2];if(k){l=dg(i,j,k);m=hb;h=x[a+76>>2];Ff(b,g,bf(i,j,d),hb);n=hb>>>0>h>>>0?d:0}h=a+112|0;s=x[a+24>>2];t=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;while(1){if(d){g=x[e+4>>2];b=x[e>>2];x[e+8>>2]=b;x[e+12>>2]=0;n=n-1|0;f=n;l=f?l:0;m=f?m:0;d=d-1|0;p=(((g&2147483647)<<1|b>>>31)&-2)+q|0;g=k;a:{b:while(1){c:{if((g|0)<=0){Qb(h,x[a+120>>2],x[a+124>>2]);g=x[a+116>>2];if(!g){break a}f=x[e+8>>2];o=((x[e+12>>2]&2147483647)<<1|f>>>31)&-2;f=0;b=0;break c}f=x[e+8>>2];o=((x[e+12>>2]&2147483647)<<1|f>>>31)&-2;b=0;f=0;while(1)if((b|0)==2){Md(h,f>>>3<<16>>16);Ld(h,4);Qb(e+8|0,l,m);g=g-1|0;continue b}else{f=(v[(b+o|0)+p|0]<<8)+f|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){f=(v[(b+o|0)+p|0]<<8)+f|0;b=b+1|0;continue}break}Md(h,f>>>3<<16>>16);Ld(h,g);x[h>>2]=x[h>>2];x[h+4>>2]=0}b=bg(h,r);x[c>>2]=x[c>>2]+D(b,t);x[c+4>>2]=x[c+4>>2]+D(b,s);Qb(e,i,j);c=c+8|0;continue}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;db=e+16|0}function $aa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=db-16|0;db=i;e=x[b+1298304>>2];if(!ud(e)){d=db-16|0;db=d;c=Hc(12);x[23549]=0;e=R(888,c|0)|0;f=x[23549];x[23549]=0;a:{if((f|0)!=1){c=x[of(d+12|0,e)>>2];db=d+16|0;break a}a=N()|0;Eb(c);Q(a|0);p()}x[i+12>>2]=c;c=b+1298304|0;d=i+12|0;oN(c,Zd(d));Ey(d);e=x[c>>2]}f=db-32|0;db=f;c=f+8|0;cN(c,a);x[23549]=0;S(8,f+20|0,0,c|0);c=x[23549];x[23549]=0;b:{c:{if((c|0)!=1){tb(f+8|0);m=f,n=yb(x[e>>2]),x[m+4>>2]=n;l=yb(x[e+4>>2]);c=0;e=0;d:{while(1){e:{h=x[f+4>>2];if(!Kb(h,l)){if(!e){break e}c=x[e+4>>2];if(!c){break e}x[23549]=0;U(c|0,e|0,b|0,a|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){break e}break d}j=0;d=x[h>>2];if(x[d+32>>2]==x[a+16>>2]){j=x[d+36>>2]==x[a+20>>2]}x[23549]=0;P(889,f+8|0,d+8|0);d=x[23549];x[23549]=0;if((d|0)==1){break d}g=db-16|0;db=g;k=f+8|0;ze(g+8|0,k);ze(g,f+20|0);d=BM(x[g+8>>2],x[g+12>>2],x[g>>2],x[g+4>>2]);db=g+16|0;tb(k);f:{if(!(!j|(d|0)!=0)){e=x[h>>2];c=3;break f}if((c|0)<2&j){e=x[h>>2];c=2;break f}d=!d&(c|0)<=0;e=d?x[h>>2]:e;c=d?1:c}Ae(f+4|0);continue}break}tb(f+20|0);db=f+32|0;break b}e=N()|0;tb(f+20|0);break c}e=N()|0;tb(f+8|0)}Q(e|0);p()}db=i+16|0}function qja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;f=db-288|0;db=f;Ze(b);a:{if(!Lb(x[a>>2],x[a+8>>2],1)){break a}while(1){d=f+32|0;tn(f+8|0,d,uq(d));j=x[a>>2];g=x[a+8>>2];d=db-32|0;db=d;Ng(d+16|0,x[f+8>>2],x[f+12>>2]);e=x[x[j>>2]+28>>2];h=x[d+20>>2];x[d+8>>2]=x[d+16>>2];x[d+12>>2]=h;ib[e|0](d+24|0,j,g,d+8|0);Ng(f+20|0,x[d+24>>2],x[d+28>>2]);db=d+32|0;x[f+28>>2]=x[f+24>>2];o=f,q=c-Oc(x[b+4>>2],y[b+11|0])|0,x[o+4>>2]=q;d=x[Cb(f+28|0,f+4|0)>>2];if(!d){break a}j=f+32|0;m=j+d|0;k=oi(j,m,0);d=x[vb(f,tf(b))>>2];l=db-16|0;db=l;g=he(d,od(b));b:{c:{d=j;e=ri(d,k);d:{if(!e){od(b);break d}if(!Wx(b,d)){h=Bb(x[b+4>>2],y[b+11|0]);i=Mc(b);e:{if(e>>>0<=i-h>>>0){i=Mb(b);if((g|0)==(h|0)){break e}n=g+i|0;pl(e+n|0,n,h-g|0);break e}cm(b,i,(e+h|0)-i|0,h,g,0,e);i=x[b>>2]}e=e+h|0;Wg(b,e);hd(e+i|0,0);e=g+i|0;while(1){if((d|0)!=(k|0)){hd(e,y[d|0]);d=d+1|0;e=e+1|0;continue}break}Ie(od(b),g);break d}d=vg(l+4|0,d,k);h=od(d);i=tf(d);x[23549]=0;fa(348,b|0,e|0,g|0,h|0,i|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break c}tb(d)}db=l+16|0;break b}a=N()|0;tb(d);Q(a|0);p()}Zb(a,k-j|0);if(k>>>0>=m>>>0){continue}break}Zb(a,1)}db=f+288|0}function A3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;c=db+-64|0;db=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;xf(c+48|0,c+32|0,e);a=x[d+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=db-32|0;db=a;a:{b:{c:{d:{h=x[c+4>>2];if(h>>>0>=f>>>0){if(A[c+20>>2]<f>>>0){break d}if(e>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(he(x[c+24>>2],i)>>>0<e>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];b=0;e:while(1){d=0;if((b|0)==(e|0)){break a}while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{n=a,o=+(om(je(fg(C[Pg(m,h,d,b)>>3])*134217728))+gd(ps(k),21)|0)*7.450580596923828e-9,C[n+24>>3]=o;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=je(C[wg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){g=~~j;break f}g=-2147483648}g=Sc(g);n=In(l,i,d,b),q=g,w[n>>1]=q;d=d+1|0;continue}}}_(7130,8943,77,8623);p()}_(7095,8943,78,8623);p()}_(5838,8943,79,8623);p()}_(5808,8943,80,8623);p()}db=a+32|0;db=c- -64|0}function zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=db-16|0;db=e;q=x[a+16>>2];r=cg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+8>>2];m=x[a+12>>2];b=x[a>>2];f=x[a+4>>2];n=x[a+128>>2];if(n){o=dg(l,m,n);p=hb;g=x[a+76>>2];Ff(b,f,bf(l,m,d),hb);k=hb>>>0>g>>>0?d:0}g=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=f;a:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;k=k-1|0;o=k?o:0;p=k?p:0;f=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+q|0;b=n;while(1)if((b|0)<=0){Qb(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;Md(g,(w[(h<<1|2)+f>>1]+w[f+((h&2147483646)<<1)>>1]|0)/8<<16>>16);Ld(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}b=bg(g,r);f=x[a+32>>2];j=x[a+28>>2]+j|0;x[c>>2]=x[c>>2]+D(b,j>>12);i=f+i|0;x[c+4>>2]=x[c+4>>2]+D(b,i>>12);Qb(e,l,m);c=c+8|0;b=x[e>>2];f=x[e+4>>2];continue a}else{h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;Md(g,(w[(h<<1|2)+f>>1]+w[f+((h&2147483646)<<1)>>1]|0)/8<<16>>16);Ld(g,4);Qb(e+8|0,o,p);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;db=e+16|0}function Bd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=db+-64|0;db=d;x[a+480180>>2]=b;b=tq(a);Xz(d,b);e=x[d+12>>2];c=a+1074320|0;x[c>>2]=x[d+8>>2];x[c+4>>2]=e;c=x[d+4>>2];x[a+1074312>>2]=x[d>>2];x[a+1074316>>2]=c;Xs(a+8|0,b);b=1;while(1){c=b&65535;if(c>>>0>z[a+480192>>1]){x[a+480184>>2]=0;x[a+480188>>2]=0;x[a+480236>>2]=65536;x[a+480228>>2]=48;x[a+480232>>2]=48;v[a+480268|0]=5;x[a+480260>>2]=16;x[a+480264>>2]=32767;x[a+480204>>2]=125e4;x[a+480208>>2]=0;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+1074304>>2]=0;x[a+1074308>>2]=0;w[a+480192>>1]=0;Ay(a,4);e=db+-64|0;db=e;b=a+484344|0;Zs(b);f=kk(x[b>>2],x[b+4>>2]);c=dy(e+12|0,b);x[23549]=0;S(791,b|0,f|0,c|0);b=x[23549];x[23549]=0;a:{if((b|0)!=1){Nj(c);db=e- -64|0;break a}a=N()|0;Nj(c);Q(a|0);p()}SP(a+484360|0);Ze(a+1298308|0);Ze(a+1298320|0);Ze(a+1298332|0);c=Vb(d,0,64);b=uN(c);d=zb(a+1298344|0,b);zb(d+12|0,b+12|0);zb(d+24|0,b+24|0);zb(d+36|0,b+36|0);zb(d+48|0,b+48|0);x[d+60>>2]=x[b+60>>2];Fy(b);Dc(a+1298408|0);Dc(a+480248|0);if(x[a+480180>>2]&738230281){x[a+480208>>2]=x[a+480208>>2]|8388608}db=c- -64|0;return}c=((c<<2)+a|0)+900380|0;e=x[c>>2];if(e){Eb(cu(e))}x[c>>2]=0;b=b+1|0;continue}}function Nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;h=db-16|0;db=h;e=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];f=x[a+44>>2];q=x[a+16>>2];j=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=j;r=b+24|0;s=x[a+72>>2];k=x[a+68>>2];t=k>>31;l=x[a+64>>2];u=l>>31;m=x[a+60>>2];v=m>>31;j=x[a+8>>2];y=x[a+12>>2];while(1){b=f;if(d){f=Ub(b,-16777216,16776704);g=yka(l,u,f,f>>31);f=hb;e=Ub(e,-16777216,16776704);e=yka(k,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];i=g;g=(x[h+12>>2]<<1)+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;n=(((((D(w[g+4>>1],w[e+10>>1])+D(w[g+2>>1],w[e+8>>1])|0)+D(w[g+6>>1],w[e+12>>1])|0)+D(w[g+8>>1],w[e+14>>1])|0)/2|0)+((((D(w[g-4>>1],w[e+2>>1])+D(w[g-6>>1],w[e>>1])|0)+D(w[g-2>>1],w[e+4>>1])|0)+D(w[g>>1],w[e+6>>1])|0)/2|0)|0)/16384<<8;e=n;g=yka(e,e>>31,m,v);i=i+g|0;e=hb+f|0;e=g>>>0>i>>>0?e+1|0:e;f=i+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Lc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,o);Qb(h+8|0,j,y);f=f-(s&n)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;db=h+16|0}function uba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(x[a+4>>2]!=x[wb(a)>>2]){d=db-16|0;db=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+32;MN(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+32;fc(c);db=d+16|0;return}j=db-32|0;db=j;c=wb(a);c=xt(j+12|0,$p(a,hg(x[a>>2],x[a+4>>2])+1|0),hg(x[a>>2],x[a+4>>2]),c);MN(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+32;h=db-16|0;db=h;b=vb(h+12|0,x[a+4>>2]);e=vb(h+8|0,x[a>>2]);f=x[vb(h+4|0,x[c+4>>2])>>2];i=db-16|0;db=i;d=db-32|0;db=d;Od(d+24|0,x[b>>2],x[e>>2]);k=d+16|0;b=x[d+24>>2];l=x[d+28>>2];g=db-16|0;db=g;x[g+8>>2]=f;x[g+12>>2]=b;while(1){if(sd(b,l)){b=Wj(b);e=Wj(x[g+8>>2]);f=y[b+23|0]|y[b+24|0]<<8|(y[b+25|0]<<16|y[b+26|0]<<24);v[e+23|0]=f;v[e+24|0]=f>>>8;v[e+25|0]=f>>>16;v[e+26|0]=f>>>24;f=x[b+20>>2];x[e+16>>2]=x[b+16>>2];x[e+20>>2]=f;f=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=f;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;b=po(g+12|0);po(g+8|0);b=x[b>>2];continue}break}vc(k,b,g+8|0);db=g+16|0;b=x[d+16>>2];x[d+12>>2]=x[d+20>>2];vc(i+8|0,b,d+12|0);db=d+32|0;db=i+16|0;x[c+4>>2]=x[i+12>>2];Pb(a,c+4|0);Pb(a+4|0,c+8|0);Pb(wb(a),kc(c));x[c>>2]=x[c+4>>2];db=h+16|0;IQ(c);db=j+32|0}function q3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=db+-64|0;db=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;xf(c+48|0,c+32|0,e);a=x[d+4>>2];f=x[a+8>>2];h=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;e=c+16|0;a=db-32|0;db=a;a:{b:{c:{d:{i=x[c+4>>2];if(i>>>0>=h>>>0){if(A[e+4>>2]<h>>>0){break d}if(A[c+8>>2]<f>>>0){break c}if(he(x[e+8>>2],x[e+12>>2])>>>0<f>>>0){break b}k=b+12|0;l=x[c>>2];b=0;e:while(1){d=0;if((b|0)==(f|0)){break a}while(1)if((d|0)==(h|0)){b=b+1|0;continue e}else{m=a,n=+(om(je(fg(C[Pg(l,i,d,b)>>3])*134217728))+gd(ps(k),21)|0)*7.450580596923828e-9,C[m+24>>3]=n;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=je(C[wg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){g=~~j;break f}g=-2147483648}g=Sc(g);m=Hn(e,d,b),o=g,w[m>>1]=o;d=d+1|0;continue}}}_(7130,8943,77,8623);p()}_(7095,8943,78,8623);p()}_(5838,8943,79,8623);p()}_(5808,8943,80,8623);p()}db=a+32|0;db=c- -64|0}function i9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=db-16|0;db=h;if(!y[a+4242|0]){Ox(a);a:{if(!y[a+4240|0]){break a}e=ZM(x[a+16>>2]);if(e==C[a+4288>>3]){break a}C[a+4288>>3]=e;Ls(a)}f=a+4256|0;b:{if(y[a+4244|0]){if(C[f>>3]>1){x[f>>2]=0;x[f+4>>2]=1072693248}break b}i=(x[a+4232>>2]&-2)!=4;e=C[f>>3];c:{if(F(e)<2147483648){g=~~e;break c}g=-2147483648}if(!(i|(g|0)<=0)){Nx(a);e=C[a+4256>>3]}C[f>>3]=e-+(g|0)}e=0;d:{e:{switch(x[a+4232>>2]){case 0:e=ui(C[f>>3]*6.283185307179586);break d;case 1:e=F(C[f>>3]+-.5)*-4+1;break d;case 2:e=C[f>>3];e=e+e+-1;break d;case 3:e=C[f>>3]<.5?-1:1;break d;case 4:e=C[a+4272>>3];break d;case 5:break e;default:break d}}e=C[a+4256>>3];e=e*(e*e)*(e*(e*6+-15)+10);e=C[a+4280>>3]*e+C[a+4272>>3]*(1-e)}C[h+8>>3]=(y[a+4241|0]?-e:e)*+B[a+4220>>2]+ +B[a+4224>>2];FO(h+8|0,1);g=Mj(a);f:{if(!g){break f}f=x[a+4236>>2];if(y[a+4243|0]){k=g,l=(f>>>8&15|176)&191|(f&127)<<8|uo(C[h+8>>3]*127)<<16,j=x[x[g>>2]+68>>2],ib[j](k|0,l|0)|0;break f}ib[x[x[g>>2]+44>>2]](g,f,E(C[h+8>>3]))}C[a+4256>>3]=C[a+4264>>3]*+(d>>>0)+C[a+4256>>3]}g=a;a=x[a+44>>2];li(g,b,c,Ac(a,0),Ac(a,1),d);db=h+16|0}function Oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;h=db-16|0;db=h;e=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];f=x[a+44>>2];q=x[a+16>>2];j=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=j;r=b+24|0;s=x[a+72>>2];k=x[a+68>>2];t=k>>31;l=x[a+64>>2];u=l>>31;m=x[a+60>>2];y=m>>31;j=x[a+8>>2];z=x[a+12>>2];while(1){b=f;if(d){f=Ub(b,-16777216,16776704);g=yka(l,u,f,f>>31);f=hb;e=Ub(e,-16777216,16776704);e=yka(k,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];i=g;g=x[h+12>>2]+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;n=((((D(v[g+2|0],w[e+10>>1])+D(v[g+1|0],w[e+8>>1])|0)+D(v[g+3|0],w[e+12>>1])|0)+D(v[g+4|0],w[e+14>>1])<<8>>1)+(((D(v[g-2|0],w[e+2>>1])+D(v[g-3|0],w[e>>1])|0)+D(v[g-1|0],w[e+4>>1])|0)+D(v[g|0],w[e+6>>1])<<8>>1)|0)/16384<<8;e=n;g=yka(e,e>>31,m,y);i=i+g|0;e=hb+f|0;e=g>>>0>i>>>0?e+1|0:e;f=i+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Lc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,o);Qb(h+8|0,j,z);f=f-(s&n)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;db=h+16|0}function kka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=db-32|0;db=e;v[e+28|0]=44;x[e+20>>2]=-1;x[e+24>>2]=0;x[e+12>>2]=1058;x[e+16>>2]=2;c=db-48|0;db=c;h=x[e+12>>2]&2?16:10;f=db-32|0;db=f;d=Ye(f+20|0,1,0);a:{b:{c:{while(1){g=Mb(d);up(f+12|0,g,Bb(x[d+4>>2],y[d+11|0])+g|0,x[b>>2],h);if(!x[f+16>>2]){break c}g=$f(Bb(x[d+4>>2],y[d+11|0]));x[23549]=0;P(58,d|0,g|0);g=x[23549];x[23549]=0;if((g|0)!=1){continue}break}break b}b=x[f+12>>2];h=Mb(d);x[23549]=0;P(59,d|0,b-h|0);b=x[23549];x[23549]=0;d:{if((b|0)!=1){x[23549]=0;P(60,c|0,d|0);b=x[23549];x[23549]=0;if((b|0)!=1){break d}break b}break b}tb(d);db=f+32|0;break a}a=N()|0;tb(d);Q(a|0);p()}b=c+12|0;Xl(b,c,x[e+12>>2]);d=x[e+16>>2];f=x[e+12>>2];x[23549]=0;V(73,c+24|0,b|0,f|0,d|0);b=x[23549];x[23549]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=y[e+28|0];d=x[e+24>>2];x[23549]=0;V(74,c+36|0,c+24|0,d|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break i}x[23549]=0;P(57,a|0,c+36|0);a=x[23549];x[23549]=0;if((a|0)==1){break h}tb(c+36|0);tb(c+24|0);tb(c+12|0);tb(c);db=c+48|0;break e}a=N()|0;break f}a=N()|0;break g}a=N()|0;tb(c+36|0)}tb(c+24|0)}tb(c+12|0);tb(c);Q(a|0);p()}db=e+32|0}function Yia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=db-32|0;db=e;v[e+28|0]=44;x[e+20>>2]=-1;x[e+24>>2]=0;x[e+12>>2]=1042;x[e+16>>2]=2;c=db-48|0;db=c;h=x[e+12>>2]&2?16:10;f=db-32|0;db=f;d=Ye(f+20|0,1,0);a:{b:{c:{while(1){g=Mb(d);up(f+12|0,g,Bb(x[d+4>>2],y[d+11|0])+g|0,z[b>>1],h);if(!x[f+16>>2]){break c}g=$f(Bb(x[d+4>>2],y[d+11|0]));x[23549]=0;P(58,d|0,g|0);g=x[23549];x[23549]=0;if((g|0)!=1){continue}break}break b}b=x[f+12>>2];h=Mb(d);x[23549]=0;P(59,d|0,b-h|0);b=x[23549];x[23549]=0;d:{if((b|0)!=1){x[23549]=0;P(71,c|0,d|0);b=x[23549];x[23549]=0;if((b|0)!=1){break d}break b}break b}tb(d);db=f+32|0;break a}a=N()|0;tb(d);Q(a|0);p()}b=c+12|0;Xl(b,c,x[e+12>>2]);d=x[e+16>>2];f=x[e+12>>2];x[23549]=0;V(75,c+24|0,b|0,f|0,d|0);b=x[23549];x[23549]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=y[e+28|0];d=x[e+24>>2];x[23549]=0;V(76,c+36|0,c+24|0,d|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break i}x[23549]=0;P(70,a|0,c+36|0);a=x[23549];x[23549]=0;if((a|0)==1){break h}tb(c+36|0);tb(c+24|0);tb(c+12|0);tb(c);db=c+48|0;break e}a=N()|0;break f}a=N()|0;break g}a=N()|0;tb(c+36|0)}tb(c+24|0)}tb(c+12|0);tb(c);Q(a|0);p()}db=e+32|0}function nda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=db-16|0;db=g;f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+32>>2];s=x[a+28>>2];t=x[a+72>>2];n=x[a+68>>2];u=n>>31;o=x[a+64>>2];v=o>>31;p=x[a+60>>2];y=p>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){e=Ub(b,-16777216,16776704);k=yka(o,v,e,e>>31);l=hb;e=x[g+8>>2];h=(x[g+12>>2]<<1)+q|0;e=e>>>21&2040;h=(((D(w[h>>1],w[e+39938>>1])+D(w[h-2>>1],w[e+39936>>1])|0)+D(w[h+2>>1],w[e+39940>>1])|0)+D(w[h+4>>1],w[e+39942>>1])|0)/16384<<8;e=h;e=yka(e,e>>31,p,y);k=e+k|0;m=hb+l|0;m=e>>>0>k>>>0?m+1|0:m;f=Ub(f,-16777216,16776704);e=yka(n,u,f,f>>31);l=e+k|0;f=hb+m|0;f=e>>>0>l>>>0?f+1|0:f;e=l+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Lc(e,f,24);f=(e|0)/256|0;j=j+s|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+r|0;x[c+4>>2]=x[c+4>>2]+D(f,i>>12);Qb(g+8|0,z,A);e=e-(h&t)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;db=g+16|0}function B_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){h=db-32|0;db=h;f=b-c|0;b=x[wb(a)>>2];d=x[a+4>>2];a:{if(f>>>0<=b-d>>2>>>0){nG(a,f);break a}e=rw(a);c=eg(a,oc(x[a>>2],d)+f|0);g=oc(x[a>>2],x[a+4>>2]);d=db-16|0;db=d;b=h+12|0;Hf(b+12|0,e);b:{if(!c){e=0;c=0;break b}fG(d+8|0,x[b+16>>2],c);e=x[d+12>>2];c=x[d+8>>2]}x[b>>2]=c;g=c+(g<<2)|0;x[b+8>>2]=g;x[b+4>>2]=g;j=kc(b),k=c+(e<<2)|0,x[j>>2]=k;db=d+16|0;e=db-16|0;db=e;c=Bl(e+4|0,b+8|0,f);d=x[c>>2];while(1){if(x[c+4>>2]!=(d|0)){gG(d);d=x[c>>2]+4|0;x[c>>2]=d;continue}break}Kd(c);db=e+16|0;d=db-16|0;db=d;e=vb(d+12|0,x[a+4>>2]);g=vb(d+8|0,x[a>>2]);i=x[vb(d+4|0,x[b+4>>2])>>2];f=db-16|0;db=f;c=db-32|0;db=c;An(c+24|0,x[e>>2],x[g>>2]);lQ(c+16|0,x[c+24>>2],x[c+28>>2],i);e=x[c+16>>2];x[c+12>>2]=x[c+20>>2];vc(f+8|0,e,c+12|0);db=c+32|0;db=f+16|0;x[b+4>>2]=x[f+12>>2];Pb(a,b+4|0);Pb(a+4|0,b+8|0);Pb(wb(a),kc(b));x[b>>2]=x[b+4>>2];db=d+16|0;c=x[b+4>>2];a=x[b+8>>2];while(1){if((a|0)!=(c|0)){a=a-4|0;x[b+8>>2]=a;continue}break}a=x[b>>2];if(a){jG(x[b+16>>2],a,Iz(b))}}db=h+32|0;return}if(b>>>0<c>>>0){iG(a,d+(b<<2)|0)}}function Zt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=db-32|0;db=e;v[e+28|0]=44;x[e+20>>2]=-1;x[e+24>>2]=0;x[e+12>>2]=1058;x[e+16>>2]=2;c=db-48|0;db=c;h=x[e+12>>2]&2?16:10;f=db-32|0;db=f;d=Ye(f+20|0,1,0);a:{b:{c:{while(1){g=Mb(d);up(f+12|0,g,Bb(x[d+4>>2],y[d+11|0])+g|0,y[b|0],h);if(!x[f+16>>2]){break c}g=$f(Bb(x[d+4>>2],y[d+11|0]));x[23549]=0;P(58,d|0,g|0);g=x[23549];x[23549]=0;if((g|0)!=1){continue}break}break b}b=x[f+12>>2];h=Mb(d);x[23549]=0;P(59,d|0,b-h|0);b=x[23549];x[23549]=0;d:{if((b|0)!=1){x[23549]=0;P(60,c|0,d|0);b=x[23549];x[23549]=0;if((b|0)!=1){break d}break b}break b}tb(d);db=f+32|0;break a}a=N()|0;tb(d);Q(a|0);p()}b=c+12|0;Xl(b,c,x[e+12>>2]);d=x[e+16>>2];f=x[e+12>>2];x[23549]=0;V(73,c+24|0,b|0,f|0,d|0);b=x[23549];x[23549]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=y[e+28|0];d=x[e+24>>2];x[23549]=0;V(74,c+36|0,c+24|0,d|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break i}x[23549]=0;P(57,a|0,c+36|0);a=x[23549];x[23549]=0;if((a|0)==1){break h}tb(c+36|0);tb(c+24|0);tb(c+12|0);tb(c);db=c+48|0;break e}a=N()|0;break f}a=N()|0;break g}a=N()|0;tb(c+36|0)}tb(c+24|0)}tb(c+12|0);tb(c);Q(a|0);p()}db=e+32|0}function mba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=db-16|0;db=i;x[i+12>>2]=b;o=Bf(a);while(1){if(xg(b,c)){b=x[vb(i+8|0,o)>>2];j=td(x[i+12>>2]);m=db-16|0;db=m;n=0;k=db-16|0;db=k;h=db-32|0;db=h;f=h+28|0;d=h+24|0;e=db-16|0;db=e;a:{b:{if(!qc(b,x[vb(e+12|0,Kf(a))>>2])){g=y[j|0];l=y[td(b)|0];if(!Xn(g,l)){break b}}x[e+12>>2]=b;g=vb(e+8|0,yb(x[a>>2]));c:{d=x[e+12>>2];if(!qc(d,x[g>>2])){d=x[nz(e+12|0)>>2];l=y[td(d)|0];g=y[j|0];if(!Xn(l,g)){break c}}if(!x[b>>2]){x[f>>2]=b;break a}x[f>>2]=d;b=d+4|0;break a}b=Oy(a,f,g);break a}if(Xn(l,g)){d:{d=lz(b);if(!qc(d,x[vb(e+12|0,Kf(a))>>2])){g=y[j|0];if(!Xn(g,y[td(d)|0])){break d}}if(!x[b+4>>2]){x[f>>2]=b;b=b+4|0;break a}x[f>>2]=d;b=d;break a}b=Oy(a,f,g);break a}x[f>>2]=b;x[d>>2]=b;b=d}db=e+16|0;d=b;b=x[b>>2];if(!b){b=db-16|0;db=b;e=gc(a);f=h+12|0;e=rh(f,Hc(24),Ag(b+8|0,e));NN(x[e>>2]+16|0,x[j>>2],x[j+4>>2]);p=gc(e),q=1,v[p+4|0]=q;db=b+16|0;Yg(a,x[h+28>>2],d,x[h+12>>2]);b=Zd(f);ol(f);n=1}Xg(k+8|0,x[vb(h+12|0,b)>>2],n);db=h+32|0;db=k+16|0;vb(m+12|0,x[k+8>>2]);db=m+16|0;b=x[Vg(i+12|0)>>2];continue}else{db=i+16|0}break}}function u$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=db-448|0;db=a;x[a+440>>2]=c;x[a+444>>2]=b;x[a+20>>2]=1136;b=pe(a+24|0,a+32|0,a+20|0);Nc(a+16|0,x[e+28>>2]);x[23549]=0;h=R(1115,x[a+16>>2])|0;i=x[23549];x[23549]=0;if((i|0)!=1){a:{v[a+15|0]=0;e=x[e+4>>2];x[23549]=0;c=la(1145,a+444|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+432|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}d:{if(ue(y[g+11|0])){zd(x[g>>2],0);re(g,0);break d}zd(g,0);ff(g,0)}if(y[a+15|0]){x[23549]=0;c=O(1132,h|0,45)|0;d=x[23549];x[23549]=0;if((d|0)==1){break a}x[23549]=0;P(48,g|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break a}}x[23549]=0;d=O(1132,h|0,48)|0;c=x[23549];x[23549]=0;if((c|0)==1){break b}e=x[a+20>>2];h=e-4|0;c=x[b>>2];while(1){if(!((d|0)!=x[c>>2]|c>>>0>=h>>>0)){c=c+4|0;continue}break}x[23549]=0;U(1150,g|0,c|0,e|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break c}break a}x[23549]=0;c=O(1120,a+444|0,a+440|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break a}if(c){x[f>>2]=x[f>>2]|2}c=x[a+444>>2];Xb(a+16|0);Kc(b);db=a+448|0;return c|0}}}c=N()|0;Xb(a+16|0);Kc(b);Q(c|0);p()}function nh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{b:{c:{switch(b|0){case 1:b=Gb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[23549]=0;P(47,b|0,Oc(e,d)|0);d=x[23549];x[23549]=0;d:{if((d|0)!=1){e:{while(1){if(Oc(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=v[uc(c,a)|0];x[23549]=0;P(48,b|0,((d|0)<0?65533:d&255)|0);d=x[23549];x[23549]=0;if((d|0)==1){break e}a=a+1|0;continue}break}break d}}break a}return;case 2:b=Gb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[23549]=0;P(47,b|0,Oc(e,d)|0);d=x[23549];x[23549]=0;f:{if((d|0)!=1){while(1){if(Oc(x[c+4>>2],y[c+11|0])>>>0<=a>>>0){break f}d=y[uc(c,a)|0];x[23549]=0;P(48,b|0,d|0);d=x[23549];x[23549]=0;if((d|0)!=1){a=a+1|0;continue}break}}break a}return;case 3:gm(a,c,49728);return;case 5:gm(a,c,50752);return;case 4:gm(a,c,51776);return;case 6:gm(a,c,52800);return;case 7:gm(a,c,53824);return;case 8:gm(a,c,54848);return;case 9:My(a,c,55872);return;case 10:My(a,c,49728);return;case 11:My(a,c,53824);return;default:a=ac(8);x[23549]=0;b=O(44,a|0,10956)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break b}b=N()|0;jc(a);Q(b|0);p();case 0:break c}}JN(a,c);return}da(b|0,92428,24);p()}a=N()|0;Ec(b);Q(a|0);p()}function oda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0;h=db-16|0;db=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];l=x[a+68>>2];t=l>>31;m=x[a+64>>2];u=m>>31;n=x[a+60>>2];y=n>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=f;if(d){f=Ub(b,-16777216,16776704);g=yka(m,u,f,f>>31);f=hb;e=Ub(e,-16777216,16776704);e=yka(l,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];k=g;g=x[h+12>>2]+p|0;e=e>>>21&2040;o=(((D(v[g|0],w[e+39938>>1])+D(v[g-1|0],w[e+39936>>1])|0)+D(v[g+1|0],w[e+39940>>1])|0)+D(v[g+2|0],w[e+39942>>1])<<8)/16384<<8;e=o;g=yka(e,e>>31,n,y);k=k+g|0;e=hb+f|0;e=g>>>0>k>>>0?e+1|0:e;f=k+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Lc(f,e,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Qb(h+8|0,z,A);f=f-(s&o)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;db=h+16|0}function nO(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=x[b+64>>2];a:{b:{g=x[b+60>>2];f=z[b+68>>1];if(!((g|0)==-1&(f|0)==65535)){c:{d:{if((e|0)==-1){break d}e=a+1074312|0;if(Ob(e,68)){break d}if(h=Ob(e,103),i=0,j=(f|0)!=65535,j?h:i){break c}if(h=Ob(e,49),i=0,j=(f|0)!=65535,j?h:i){break c}e=x[b+64>>2];break b}if((f|0)!=65535){break c}w[b+68>>1]=z[b+72>>1]+1}if((g|0)==-1){x[b+60>>2]=0}f=Ic(x[c>>2],x[c+4>>2]);e=z[b+68>>1];if(f>>>0<=e>>>0){e=z[c+28>>1];w[b+68>>1]=e}e:{if(z[b+72>>1]==(e&65535)){break e}c=a+1074312|0;if(Ob(c,26)){break e}if(Ob(c,68)|x[a+480180>>2]==1){break e}c=z[a+480188>>1];e=0;while(1){if((c|0)==(e|0)){break e}v[(D(e,872)+b|0)+1457|0]=0;e=e+1|0;continue}}x[b+52>>2]=x[b+60>>2];if(d){e=1;if(y[a+480208|0]&32){break a}}w[b+74>>1]=z[b+68>>1];return 1}if((e|0)!=-1){break b}e=0;break a}x[b+52>>2]=e;w[b+74>>1]=z[b+72>>1];f:{if(!x[b+20>>2]){break f}c=x[a+480180>>2];if((c|0)==32){if(Ob(a+1074312|0,103)){break f}c=x[a+480180>>2]}if((c|0)==2){break f}x[b+52>>2]=x[b+52>>2]+1}e=0;if(A[b+64>>2]<A[Yb(x[a+484344>>2],z[b+70>>1])+12>>2]){break a}x[b+52>>2]=0;w[b+74>>1]=z[b+74>>1]+1;return 0}return e}function hda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=db-16|0;db=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];m=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+j|0;b=(b>>>16&65520)+g|0;n=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];r=w[b+6>>1];s=w[b+4>>1];t=w[b+2>>1];u=w[b>>1];i=0;while(1){if((i|0)!=2){b=(i<<1)+m|0;x[(i<<2)+e>>2]=(((((((D(w[b-8>>1],t)+D(w[b-12>>1],u)|0)+D(w[b-4>>1],s)|0)+D(w[b>>1],r)|0)+D(w[b+4>>1],q)|0)+D(w[b+8>>1],p)|0)+D(w[b+12>>1],o)|0)+D(w[b+16>>1],n)|0)/32768;i=i+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],k);Qb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;db=e+16|0}function gH(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=db-16|0;db=l;g=y[a|0];a:{if(!g){f=a;break a}f=a;b:{while(1){if(!Ik(g<<24>>24)){break b}g=y[f+1|0];f=f+1|0;if(g){continue}break}break a}c:{g=g&255;switch(g-43|0){case 0:case 2:break c;default:break a}}j=(g|0)==45?-1:0;f=f+1|0}d:{if(!((c|16)!=16|y[f|0]!=48)){n=1;if((y[f+1|0]&223)==88){f=f+2|0;m=16;break d}f=f+1|0;m=c?c:8;break d}m=c?c:10}c=0;while(1){e:{g=-48;i=v[f|0];f:{if((i-48&255)>>>0<10){break f}g=-87;if((i-97&255)>>>0<26){break f}g=-55;if((i-65&255)>>>0>25){break e}}i=g+i|0;if((i|0)>=(m|0)){break e}nf(l,m,0,0,0,k,h,0,0);g=1;g:{if(x[l+8>>2]|x[l+12>>2]){break g}o=yka(k,h,m,0);p=hb;if((p|0)==-1&(i^-1)>>>0<o>>>0){break g}h=p;k=i+o|0;h=k>>>0<i>>>0?h+1|0:h;n=1;g=c}f=f+1|0;c=g;continue}break}if(b){x[b>>2]=n?f:a}h:{i:{j:{if(c){x[23424]=68;a=d&1;j=a?0:j;k=d;h=e;break j}if((e|0)==(h|0)&d>>>0>k>>>0|e>>>0>h>>>0){break i}a=d&1}if(!(a|j)){x[23424]=68;a=d;d=a-1|0;e=e-!a|0;break h}if((e|0)==(h|0)&d>>>0>=k>>>0|e>>>0>h>>>0){break i}x[23424]=68;break h}a=j^k;d=a-j|0;b=j>>31;e=(b^h)-((a>>>0<j>>>0)+b|0)|0}db=l+16|0;hb=e;return d}function Uv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=db-32|0;db=e;v[e+28|0]=44;x[e+20>>2]=-1;x[e+24>>2]=0;x[e+12>>2]=c;x[e+16>>2]=d;c=db-48|0;db=c;g=e+12|0;i=x[g>>2]&2?16:10;f=db-32|0;db=f;d=Ye(f+20|0,1,0);a:{b:{c:{while(1){h=Mb(d);up(f+12|0,h,Bb(x[d+4>>2],y[d+11|0])+h|0,x[b>>2],i);if(!x[f+16>>2]){break c}h=$f(Bb(x[d+4>>2],y[d+11|0]));x[23549]=0;P(58,d|0,h|0);h=x[23549];x[23549]=0;if((h|0)!=1){continue}break}break b}b=x[f+12>>2];i=Mb(d);x[23549]=0;P(59,d|0,b-i|0);b=x[23549];x[23549]=0;d:{if((b|0)!=1){x[23549]=0;P(71,c|0,d|0);b=x[23549];x[23549]=0;if((b|0)!=1){break d}break b}break b}tb(d);db=f+32|0;break a}a=N()|0;tb(d);Q(a|0);p()}b=c+12|0;Xl(b,c,x[g>>2]);d=x[g+4>>2];f=x[g>>2];x[23549]=0;V(75,c+24|0,b|0,f|0,d|0);b=x[23549];x[23549]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=y[g+16|0];d=x[g+12>>2];x[23549]=0;V(76,c+36|0,c+24|0,d|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break i}x[23549]=0;P(70,a|0,c+36|0);a=x[23549];x[23549]=0;if((a|0)==1){break h}tb(c+36|0);tb(c+24|0);tb(c+12|0);tb(c);db=c+48|0;break e}a=N()|0;break f}a=N()|0;break g}a=N()|0;tb(c+36|0)}tb(c+24|0)}tb(c+12|0);tb(c);Q(a|0);p()}db=e+32|0}function Zv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=db-32|0;db=e;v[e+28|0]=44;x[e+20>>2]=-1;x[e+24>>2]=0;x[e+12>>2]=c;x[e+16>>2]=d;c=db-48|0;db=c;g=e+12|0;i=x[g>>2]&2?16:10;f=db-32|0;db=f;d=Ye(f+20|0,1,0);a:{b:{c:{while(1){h=Mb(d);up(f+12|0,h,Bb(x[d+4>>2],y[d+11|0])+h|0,y[b|0],i);if(!x[f+16>>2]){break c}h=$f(Bb(x[d+4>>2],y[d+11|0]));x[23549]=0;P(58,d|0,h|0);h=x[23549];x[23549]=0;if((h|0)!=1){continue}break}break b}b=x[f+12>>2];i=Mb(d);x[23549]=0;P(59,d|0,b-i|0);b=x[23549];x[23549]=0;d:{if((b|0)!=1){x[23549]=0;P(71,c|0,d|0);b=x[23549];x[23549]=0;if((b|0)!=1){break d}break b}break b}tb(d);db=f+32|0;break a}a=N()|0;tb(d);Q(a|0);p()}b=c+12|0;Xl(b,c,x[g>>2]);d=x[g+4>>2];f=x[g>>2];x[23549]=0;V(75,c+24|0,b|0,f|0,d|0);b=x[23549];x[23549]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=y[g+16|0];d=x[g+12>>2];x[23549]=0;V(76,c+36|0,c+24|0,d|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break i}x[23549]=0;P(70,a|0,c+36|0);a=x[23549];x[23549]=0;if((a|0)==1){break h}tb(c+36|0);tb(c+24|0);tb(c+12|0);tb(c);db=c+48|0;break e}a=N()|0;break f}a=N()|0;break g}a=N()|0;tb(c+36|0)}tb(c+24|0)}tb(c+12|0);tb(c);Q(a|0);p()}db=e+32|0}function fo(a,b,c){var d=0,e=0,f=0,g=0;f=a+1074312|0;d=Ob(f,96);x[b+660>>2]=(d?0:x[b+660>>2])+c;e=x[a+480180>>2];d=x[b+84>>2];if(!(!(e&18)|d>>>0>c>>>0|(!(y[b+88|0]&2)|!d))){g=c;c=x[b+80>>2];c=((g-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(x[b+88>>2]&1&(e|0)==16384)|0;a:{b:{if(!Tc(y[b+788|0])){if(!Ob(f,114)){break b}}d=x[b+656>>2];c:{if(!d){break c}e=y[b+788|0];if(!Tc(e)){break c}if((z[_b(d+236|0,e-1|0)>>1]-1&65535)>>>0>=z[a+480190>>1]){break a}}if(y[a+480210|0]&32){d=c;c=x[b+660>>2];x[b+660>>2]=d+c}x[b>>2]=0;x[b+4>>2]=c;if((!(y[b+88|0]&2)|A[b+84>>2]>c>>>0)&A[b+76>>2]>c>>>0){break a}d:{if(!Ob(f,57)){c=x[a+480180>>2];if((c|0)!=16){break d}}x[b+700>>2]=0;x[b+88>>2]=x[b+88>>2]|2097152;return}if(!(c&1048581)){if(Ob(f,27)){if(y[a+480208|0]&4){c=x[b+76>>2];x[b>>2]=0;x[b+4>>2]=c;return}x[b>>2]=0;x[b+4>>2]=0;return}c=x[b+80>>2];x[b>>2]=0;x[b+4>>2]=c;if(!(y[a+480208|0]&4)){break a}a=x[b+76>>2];if(a>>>0<5){break a}x[b>>2]=0;x[b+4>>2]=a-2;return}if(!(y[b+88|0]&2)|(c|0)!=1){break a}a=x[b+80>>2];x[b>>2]=0;x[b+4>>2]=a;return}if(!(x[a+480180>>2]&268582928)|A[b+76>>2]<=c>>>0){break a}x[b>>2]=0;x[b+4>>2]=c}}function FN(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=db-16|0;db=f;e=D(b,872)+a|0;a:{if(c){Fb(f+8|0,a+1074312|0,90);if(!Ib(x[x[f+8>>2]>>2],x[f+12>>2])){v[(D(b,872)+a|0)+1075803|0]=c}v[(D(b,872)+a|0)+1075804|0]=c;break a}c=y[e+1075804|0]}e=e+1074992|0;h=c&255;i=0-h|0;j=!(x[a+480180>>2]&204473357)&(d^-1);AN(a,b,i,j);g=x[a+480180>>2];b:{c:{if((g|0)!=268435456){if((g|0)!=16777216){break c}k=x[(D(b,872)+a|0)+1075648>>2];if(!k|!x[k+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){zN(x[a+1074392>>2],x[a+1074416>>2],e,240-h|0);break b}if(!(b>>>0<224|d)){yN(e,224-h|0);break b}xN(e,i);break b}x[(D(b,872)+a|0)+1075700>>2]=65535}d:{if(!j|(c&255)>>>0<224){break d}e:{d=h&15;if(!d){break e}c=c&240;if((c|0)!=224){if((c|0)!=240){break e}Gy(a,e,d);break b}if((g|0)==524288){break d}CN(a,e,d);break b}if((g|0)!=524288){break b}}f:{if(!(v[(D(b,872)+a|0)+1075843|0]&1)){break f}if(x[a+1074416>>2]==1){Fb(f+8|0,a+1074312|0,6);if(Ib(x[x[f+8>>2]>>2],x[f+12>>2])){break f}g=x[a+480180>>2]}if(g&32832){break f}if(!(x[a+480208>>2]&2)|(g|0)!=8){break b}}Oj(a,e,(D(b,872)+a|0)+1075692|0,0-(h<<2)|0,0)}db=f+16|0}function mW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=db-32|0;db=g;v[g+16|0]=0;m=XB(g+20|0,d,g+16|0);f=x[m>>2];x[g+16>>2]=d;h=d;while(1){if(!(!b|!h)){a:{i=b-1|0;k=y[a|0];if(!(!i|(k|0)!=(e&255))){x[g+12>>2]=y[a+1|0];i=a+2|0;j=Cb(g+12|0,g+16|0);b:{k=b-2|0;if(!k){break b}j=x[j>>2];if(!(j&255)){break b}i=y[i|0];while(1){if(!(j&255)){break a}v[f|0]=i;h=x[g+16>>2]-1|0;x[g+16>>2]=h;f=f+1|0;j=j-1|0;continue}}v[f|0]=e;h=x[g+16>>2]-1|0;x[g+16>>2]=h;f=f+1|0;b=k;a=i;continue}a=a+1|0;v[f|0]=k;h=x[g+16>>2]-1|0;x[g+16>>2]=h;f=f+1|0;b=i;continue}b=b-3|0;a=a+3|0;continue}break}e=d-h|0;a=x[m>>2];k=0;f=128;b=0;i=0;c:while(1){if((e|0)==(i|0)){while(1){if(e){d=k<<24>>24;b=v[c|0];a=128;d:{if((b|0)==-128){break d}a=b;if((b|0)>=0){break d}a=0-(b&127)|0}k=d-(a&255)|0;v[c|0]=k;e=e-1|0;c=c+1|0;continue}break}bc(m);db=g+32|0;return}n=y[a|0];h=0;j=0;while(1)if((j&65535)>>>0>=8){f=f&65535;f=(f<<8|f)>>>h&255;i=i+1|0;a=a+1|0;continue c}else{l=b+c|0;v[l|0]=y[l|0]|D(f&n,257)>>>(h-j&7);b=b+1|0;l=b>>>0>=d>>>0;b=l?0:b;j=j+1|0;h=h+l|0;f=(f<<8|f)>>>1&255;continue}}}function Fja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=db-1072|0;db=d;x[d+1068>>2]=c;o=d,q=ee(b),v[o+8|0]=q;v[d+4|0]=1;c=d+8|0;g=y[af(c,d+4|0)|0];f=zB(c,b);l=zq(f);x[23549]=0;c=R(188,b|0)|0;e=x[23549];x[23549]=0;a:{if((e|0)!=1){x[d+4>>2]=c;x[d>>2]=536870911;tc(d+1068|0,x[Cb(d+4|0,d)>>2]<<3);x[23549]=0;m=x[d+1068>>2];k=O(325,a|0,m|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){x[23549]=0;c=8;h=O(150,f|0,8)|0;a=x[23549];x[23549]=0;b:{if((a|0)!=1){c:{o=Db(x[k>>2],0),q=h,v[o|0]=q;i=1;a=g;while(1){c=c&255;n=c>>>0<=9?9:c;e=a;d:{e:{while(1){if(i>>>0>=m>>>0){break d}x[23549]=0;j=O(150,f|0,c|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){if(j){break e}if((c|0)==(n|0)){break d}c=c+1|0;e=g;continue}break}break c}a=j>>>1|0;h=(j&1?0-a|0:a)+h|0;o=Db(x[k>>2],i),q=h,v[o|0]=q;i=i+1|0;a=g;if(j>>>c-1|0){continue}a=e-1|0;e=a&255;a=e?a:g;c=c-(!e&(c&255)>>>0>1)|0;continue}break}a=zq(f);x[23549]=0;O(141,b|0,((a-l|0)+3&-4)+l|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){break b}}}c=N()|0;bc(k);break a}ub(f);db=d+1072|0;return}c=N()|0;break a}c=N()|0}ub(f);Q(c|0);p()}function eB(a,b){a:{b:{switch((y[a+3|0]|64)+-64|0){case 0:v[a+3|0]=y[a+5|0]?37:0;return;case 1:v[a+3|0]=16;return;case 2:v[a+3|0]=12;return;case 3:v[a+3|0]=14;if(b){break a}b=a;a=y[a+5|0];v[b+5|0]=D(a>>>4|0,10)+(a&15);return;case 4:v[a+3|0]=11;return;case 5:v[a+3|0]=3;return;case 6:v[a+3|0]=2;return;case 7:v[a+3|0]=4;return;case 8:v[a+3|0]=5;return;case 9:v[a+3|0]=18;return;case 10:v[a+3|0]=1;return;case 11:v[a+3|0]=7;return;case 12:v[a+3|0]=6;return;case 13:v[a+3|0]=21;return;case 14:v[a+3|0]=22;return;case 15:v[a+3|0]=10;return;case 16:v[a+3|0]=29;return;case 17:v[a+3|0]=15;return;case 18:v[a+3|0]=8;return;case 19:v[a+3|0]=20;return;case 20:v[a+3|0]=17;return;case 21:v[a+3|0]=26;return;case 22:v[a+3|0]=23;return;case 23:v[a+3|0]=24;return;case 24:v[a+3|0]=9;return;case 25:v[a+3|0]=27;return;case 26:v[a+3|0]=31;return;case 28:v[a+3|0]=b?32:31;return;case 29:v[a+3|0]=b?33:0;return;case 27:v[a+3|0]=b?34:0;return;case 30:v[a+3|0]=b?35:0;return;case 31:v[a+3|0]=b?36:0;return;case 50:v[a+3|0]=b?25:0;return;case 51:v[a+3|0]=b?30:0;return;default:break b}}v[a+3|0]=0}}function YS(a,b,c,d,e){var f=0,g=0;f=db-16|0;db=f;g=z[c>>1];a:{if((d&255)>>>0<=4){while(1){d=g<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!ef(a,f+15|0)){break a}d=y[f+15|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!ef(a,f+14|0)){break a}d=y[f+14|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;g=y[c|0];w[c>>1]=g;if(!g){if(!ef(a,f+13|0)){break a}d=y[f+13|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;g=y[c|0];w[c>>1]=g;if(y[b|0]){continue}break a}if(y[b|0]){continue}break a}}while(1){d=g<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!ef(a,f+12|0)){break a}d=y[f+12|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;g=y[c|0];w[c>>1]=g;if(!g){if(!ef(a,f+11|0)){break a}d=y[f+11|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;g=y[c|0];w[c>>1]=g;if(y[b|0]){continue}break a}if(y[b|0]){continue}break}}db=f+16|0}function ida(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=db-16|0;db=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];m=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+j|0;b=(b>>>16&65520)+g|0;n=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];r=w[b+6>>1];s=w[b+4>>1];t=w[b+2>>1];u=w[b>>1];i=0;while(1){if((i|0)!=2){b=i+m|0;x[(i<<2)+e>>2]=(((((((D(v[b-4|0],t)+D(v[b-6|0],u)|0)+D(v[b-2|0],s)|0)+D(v[b|0],r)|0)+D(v[b+2|0],q)|0)+D(v[b+4|0],p)|0)+D(v[b+6|0],o)|0)+D(v[b+8|0],n)<<8)/32768;i=i+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],k);Qb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;db=e+16|0}function EL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0);c=db-80|0;db=c;d=x[b>>2];b=x[b+4>>2];e=Xd(c+52|0);f=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=f;b=mr(c+60|0,d,b,c+8|0);x[23549]=0;d=R(188,b|0)|0;e=x[23549];x[23549]=0;a:{if((e|0)==1){break a}x[23549]=0;d=U(886,b|0,c+19|0,d|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break a}if(!(!d|(y[c+23|0]|y[c+24|0]<<8|(y[c+25|0]<<16|y[c+26|0]<<24)|(y[c+19|0]|y[c+20|0]<<8|(y[c+21|0]<<16|y[c+22|0]<<24))!=542066252))){g=a,h=Fd((l(2,y[c+27|0]|y[c+28|0]<<8|(y[c+29|0]<<16|y[c+30|0]<<24)),r()),E(0)),B[g+4220>>2]=h;g=a,h=Fd((l(2,y[c+31|0]|y[c+32|0]<<8|(y[c+33|0]<<16|y[c+34|0]<<24)),r()),E(0)),B[g+4224>>2]=h;g=a,h=Fd((l(2,y[c+35|0]|y[c+36|0]<<8|(y[c+37|0]<<16|y[c+38|0]<<24)),r()),E(0)),B[g+4228>>2]=h;d=y[c+39|0]|y[c+40|0]<<8|(y[c+41|0]<<16|y[c+42|0]<<24);if(d>>>0<=5){x[a+4232>>2]=d}x[a+4236>>2]=y[c+43|0]|y[c+44|0]<<8|(y[c+45|0]<<16|y[c+46|0]<<24);v[a+4240|0]=y[c+47|0]!=0;v[a+4241|0]=y[c+48|0]!=0;v[a+4242|0]=y[c+49|0]!=0;v[a+4243|0]=y[c+50|0]!=0;v[a+4244|0]=y[c+51|0]!=0;Ms(a)}ub(b);db=c+80|0;return}a=N()|0;ub(b);Q(a|0);p()}function K8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=0,v=0,w=0,z=E(0);h=x[a+44>>2];g=Ac(h,0);h=Ac(h,1);j=x[a+56>>2];n=Ac(j,0);j=Ac(j,1);e=oc(x[a+4208>>2],x[a+4212>>2]);o=D(x[x[a+16>>2]+1074404>>2],y[a+4233|0]);k=o<<1;if(e>>>0<k>>>0){Yk(a+4208|0,k)}l=y[a+4232|0];a:{if(l){e=x[a+4220>>2];k=x[a+4208>>2];u=l-1|0;l=0;while(1){if((d|0)==(l|0)){break a}r=B[h>>2];e=e>>>0<o>>>0?e:0;i=e-o|0;i=((i|0)<0?e:i)<<1;v=xb(k,i);f=B[xb(k,i|1)>>2];s=B[g>>2];t=B[v>>2];p=E(s+t);B[n>>2]=p;q=E(r+f);B[j>>2]=q;f=E(0);m=E(0);b:{c:{switch(u|0){case 0:f=B[a+4224>>2];m=E(q*f);f=E(p*f);break b;case 1:case 2:f=B[a+4224>>2];m=E(p*f);f=E(q*f);break b;case 3:break c;default:break b}}f=E(E(E(E(s+r)*E(.5))+t)*B[a+4224>>2]);m=f}j=j+4|0;n=n+4|0;h=h+4|0;g=g+4|0;i=e<<1;w=xb(k,i),z=E(F(f))<E(10000000195414814e-40)?E(0):f,B[w>>2]=z;w=xb(k,i|1),z=E(F(m))<E(10000000195414814e-40)?E(0):m,B[w>>2]=z;e=e+1|0;x[a+4220>>2]=e;l=l+1|0;continue}}e=g;g=d<<2;kl(e,e+g|0,n);kl(h,h+g|0,j)}g=a;a=x[a+56>>2];li(g,b,c,Ac(a,0),Ac(a,1),d)}function B3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=db+-64|0;db=b;c=x[a>>2];a=x[c>>2];d=x[a+4>>2];x[b+40>>2]=x[a+20>>2];e=x[a+16>>2];x[b+32>>2]=x[a+12>>2];x[b+36>>2]=e;xf(b+48|0,b+32|0,d);a=x[c+4>>2];d=x[a+8>>2];e=x[a+4>>2];c=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=c;c=x[b+52>>2];x[b+16>>2]=x[b+48>>2];x[b+20>>2]=c;x[b+8>>2]=x[a+8>>2];c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;a=db-32|0;db=a;a:{b:{c:{d:{h=x[b+4>>2];if(h>>>0>=e>>>0){if(A[b+20>>2]<e>>>0){break d}if(d>>>0>A[b+8>>2]){break c}i=x[b+28>>2];if(he(x[b+24>>2],i)>>>0<d>>>0){break b}k=x[b+16>>2];l=x[b>>2];e:while(1){c=0;if((d|0)==(f|0)){break a}while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{m=a,n=C[Pg(l,h,c,f)>>3],C[m+24>>3]=n;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=je(C[wg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){g=~~j;break f}g=-2147483648}g=Sc(g);m=In(k,i,c,f),o=g,w[m>>1]=o;c=c+1|0;continue}}}_(7130,8943,77,8623);p()}_(7095,8943,78,8623);p()}_(5838,8943,79,8623);p()}_(5808,8943,80,8623);p()}db=a+32|0;db=b- -64|0}function GN(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;f=db-16|0;db=f;e=D(b,872)+a|0;a:{if(c){Fb(f+8|0,a+1074312|0,90);if(!Ib(x[x[f+8>>2]>>2],x[f+12>>2])){v[(D(b,872)+a|0)+1075804|0]=c}v[(D(b,872)+a|0)+1075803|0]=c;break a}c=y[e+1075803|0]}e=e+1074992|0;h=c&255;i=!(x[a+480180>>2]&204473357)&(d^-1);AN(a,b,h,i);g=x[a+480180>>2];b:{c:{if((g|0)!=268435456){if((g|0)!=16777216){break c}j=x[(D(b,872)+a|0)+1075648>>2];if(!j|!x[j+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){zN(x[a+1074392>>2],x[a+1074416>>2],e,h-240|0);break b}if(!(b>>>0<224|d)){yN(e,h-224|0);break b}xN(e,h);break b}x[(D(b,872)+a|0)+1075700>>2]=1}d:{if(!i|(c&255)>>>0<224){break d}e:{d=h&15;if(!d){break e}c=c&240;if((c|0)!=224){if((c|0)!=240){break e}Hy(a,e,d);break b}if((g|0)==524288){break d}BN(a,e,d);break b}if((g|0)!=524288){break b}}f:{if(!(v[(D(b,872)+a|0)+1075843|0]&1)){break f}if(x[a+1074416>>2]==1){Fb(f+8|0,a+1074312|0,6);if(Ib(x[x[f+8>>2]>>2],x[f+12>>2])){break f}g=x[a+480180>>2]}if(g&32832){break f}if(!(x[a+480208>>2]&2)|(g|0)!=8){break b}}Oj(a,e,(D(b,872)+a|0)+1075692|0,h<<2,0)}db=f+16|0}function Nn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=db-80|0;db=c;g=Nb(a);a=x[b+24>>2];a:{b:{if(bj(x[a+484360>>2],x[a+484364>>2])){c:{d:{e:while(1){if(bj(x[a+484360>>2],x[a+484364>>2])>>>0<=f>>>0){break d}d=RM(KS(c+40|0,1),f&255,0,0);x[23549]=0;e=x[d+12>>2];x[c+16>>2]=x[d+8>>2];x[c+20>>2]=e;e=x[d+20>>2];x[c+24>>2]=x[d+16>>2];x[c+28>>2]=e;e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;V(1020,c+68|0,a|0,0,c+8|0);a=x[23549];x[23549]=0;if((a|0)==1){break c}j=c,k=yb(x[c+68>>2]),x[j+36>>2]=k;d=yb(x[c+72>>2]);while(1){a=x[c+36>>2];if(!Kb(a,d)){f=f+1|0;vi(c+68|0);a=x[b+24>>2];continue e}h=C[a>>3];e=x[a+16>>2];i=z[a+24>>1];a=c+40|0;x[a+16>>2]=f;x[a+12>>2]=i;x[a+8>>2]=e;C[a>>3]=h;x[23549]=0;P(1040,g|0,a|0);a=x[23549];x[23549]=0;if((a|0)!=1){Wp(c+36|0);continue}break}break}a=N()|0;vi(c+68|0);break b}db=c+80|0;return}a=N()|0;break b}b=ac(8);x[23549]=0;d=O(54,c+40|0,7208)|0;a=x[23549];x[23549]=0;if((a|0)!=1){a=pc(b,d);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break b}a=N()|0;jc(b)}Yf(g);Q(a|0)}p()}function q8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=E(0),t=0,u=0,v=0,w=0,y=0,z=E(0);a:{j=x[a+4272>>2];if(!j){break a}if(!Yh(a+44|0)){break a}f=x[a+44>>2];l=Ac(f,0);m=Ac(f,1);u=x[a+4252>>2]-1|0;i=x[a+4268>>2];k=x[a+4256>>2];n=d;f=x[a+56>>2];q=Ac(f,0);o=q;r=Ac(f,1);p=r;while(1){if(n){e=B[m>>2];f=i<<1;h=xb(k,f);g=B[l>>2];B[h>>2]=g;y=xb(k,f|1),z=e,B[y>>2]=z;s=B[a+4276>>2];e=E(E(F(jL(E(E(E(F(g))+E(F(e)))*E(536870912)),31,5)))*E(4.656612873077393e-10));e=E(E(E(s-e)*B[(e>=s?4236:4240)+a>>2])+e);B[a+4276>>2]=e;g=B[a+4244>>2];e=E(E(E(E(g-(e<g?g:e))*B[a+4248>>2])+E(.9999998807907104))*E(2147483648));b:{if(e<E(4294967296)&e>=E(0)){f=~~e>>>0;break b}f=0}t=((((i<<12)+u|0)+j|0)/4096|0)%(j|0)<<1;g=B[xb(k,t)>>2];h=f<<5;v=h;w=h|-2147483648;h=f>>>0<67108864;e=E(B[a+4232>>2]*E(E((h?v:w)>>>(h?31:32-(f>>>26|0)|0)>>>0)*E(4.656612873077393e-10)));B[o>>2]=g*e;y=p,z=E(B[xb(k,t|1)>>2]*e),B[y>>2]=z;i=((i?0:j)+i|0)-1|0;x[a+4268>>2]=i;n=n-1|0;p=p+4|0;o=o+4|0;m=m+4|0;l=l+4|0;continue}else{li(a,b,c,q,r,d)}break}}}function Dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=db-16|0;db=e;o=x[a+16>>2];p=cg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);j=x[a+8>>2];k=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];l=x[a+128>>2];if(l){m=dg(j,k,l);n=hb;f=x[a+76>>2];Ff(b,g,bf(j,k,d),hb);i=hb>>>0>f>>>0?d:0}f=a+112|0;q=x[a+24>>2];r=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){g=x[e+4>>2];b=x[e>>2];x[e+8>>2]=b;x[e+12>>2]=0;i=i-1|0;m=i?m:0;n=i?n:0;d=d-1|0;g=((((g&2147483647)<<1|b>>>31)&2147483646)<<1)+o|0;b=l;while(1)if((b|0)<=0){Qb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;Md(f,(w[(h<<1|2)+g>>1]+w[((h&2147483646)<<1)+g>>1]|0)/8<<16>>16);Ld(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=bg(f,p);x[c>>2]=x[c>>2]+D(b,r);x[c+4>>2]=x[c+4>>2]+D(b,q);Qb(e,j,k);c=c+8|0;continue a}else{h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;Md(f,(w[(h<<1|2)+g>>1]+w[((h&2147483646)<<1)+g>>1]|0)/8<<16>>16);Ld(f,4);Qb(e+8|0,m,n);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;db=e+16|0}function uO(a,b){var c=0,d=0,e=0,f=0;d=db-16|0;db=d;a:{b:{switch(y[a+480224|0]-1|0){default:c=x[a+24620>>2];x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2]<<1;c=yka(c,c>>31,5e4,0);e=hb;b=x[Yc(d+12|0,d+8|0)>>2];c=Cc(zka(c,e,b,b>>31),hb);break a;case 0:c=x[a+24620>>2];x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2];c=yka(c,c>>31,1e4,0);e=hb;b=x[Yc(d+12|0,d+8|0)>>2];c=Cc(zka(c,e,b,b>>31),hb);break a;case 1:break b}}f=60/(+A[b+44>>2]/1e4*(+(yka(x[b+32>>2],0,x[b+40>>2],0)>>>0)+ +(hb>>>0)*4294967296))*+A[a+24620>>2];c:{d:{c=x[a+484344>>2];e=z[b+70>>1];if(!se(c,x[a+484348>>2],e)){break d}c=Yb(c,e);if(!Kb(x[c+24>>2],x[c+28>>2])){break d}c=QM(c);break c}c=a+480248|0}e=x[c>>2];c=x[c+4>>2];if(!qc(e,c)){f=f*+A[xb(e,A[b+48>>2]%(oc(e,c)>>>0)|0)>>2]*5.960464477539063e-8}e:{if(F(f)<2147483648){c=~~f;break e}c=-2147483648}f=C[b+8>>3]+(f-+(c>>>0));C[b+8>>3]=f;if(f>=1){C[b+8>>3]=f+-1;c=c+1|0;break a}if(!(C[a+1074384>>3]<=-1)){break a}C[b+8>>3]=f+1;c=c-1|0}b=yka(x[a+480244>>2],0,c,0);a=hb;b=b+32768|0;a=b>>>0<32768?a+1|0:a;a=Qc((a&65535)<<16|b>>>16,a>>>16|0);db=d+16|0;return a>>>0<=1?1:a}function s3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=db+-64|0;db=b;c=x[a>>2];a=x[c>>2];d=x[a+4>>2];x[b+40>>2]=x[a+20>>2];e=x[a+16>>2];x[b+32>>2]=x[a+12>>2];x[b+36>>2]=e;xf(b+48|0,b+32|0,d);a=x[c+4>>2];e=x[a+8>>2];h=x[a+4>>2];c=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=c;c=x[b+52>>2];x[b+16>>2]=x[b+48>>2];x[b+20>>2]=c;x[b+8>>2]=x[a+8>>2];c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;d=b+16|0;a=db-32|0;db=a;a:{b:{c:{d:{i=x[b+4>>2];if(i>>>0>=h>>>0){if(A[d+4>>2]<h>>>0){break d}if(A[b+8>>2]<e>>>0){break c}if(he(x[d+8>>2],x[d+12>>2])>>>0<e>>>0){break b}k=x[b>>2];e:while(1){c=0;if((e|0)==(f|0)){break a}while(1)if((c|0)==(h|0)){f=f+1|0;continue e}else{l=a,m=C[Pg(k,i,c,f)>>3],C[l+24>>3]=m;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=je(C[wg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){g=~~j;break f}g=-2147483648}g=Sc(g);l=Hn(d,c,f),n=g,w[l>>1]=n;c=c+1|0;continue}}}_(7130,8943,77,8623);p()}_(7095,8943,78,8623);p()}_(5838,8943,79,8623);p()}_(5808,8943,80,8623);p()}db=a+32|0;db=b- -64|0}function U8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=db+-64|0;db=b;g=Nb(a);x[23549]=0;W(890,g|0);a=x[23549];x[23549]=0;a:{if((a|0)!=1){a=44784;b:{c:{d:{e:{f:{g:{h:{i:{j:{while(1){if((a|0)==45096){db=b- -64|0;return g|0}k:{h=Vs(44);if(h){x[23549]=0;d=O(54,b+36|0,x[a+4>>2])|0;c=x[23549];x[23549]=0;if((c|0)==1){break k}c=x[a>>2];x[23549]=0;P(891,b+48|0,d|0);e=x[23549];x[23549]=0;if((e|0)==1){break j}x[23549]=0;e=O(54,b+12|0,x[a+8>>2])|0;f=x[23549];x[23549]=0;if((f|0)==1){break i}x[23549]=0;P(891,b+24|0,e|0);f=x[23549];x[23549]=0;if((f|0)==1){break h}x[23549]=0;c=ba(892,h|0,c|0,b+48|0,b+24|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break g}Ab(b+24|0);tb(e);Ab(b+48|0);tb(d);x[b+60>>2]=c;x[23549]=0;P(893,g|0,b+60|0);d=x[23549];x[23549]=0;if((d|0)==1){break b}v[c+40|0]=y[a+20|0];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;v[c+41|0]=y[c+41|0]&253|y[a+21|0]<<1}a=a+24|0;continue}break}a=N()|0;break c}a=N()|0;break d}a=N()|0;break e}a=N()|0;break f}a=N()|0;Ab(b+24|0)}tb(e)}Ab(b+48|0)}tb(d)}Eb(h);break a}a=N()|0;break a}a=N()|0}sc(g);Q(a|0);p()}function AI(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=E(0),q=0;a:{if(y[b+21|0]){q=D(d,g);j=x[e>>2];l=x[f>>2];m=x[b>>2];b:{while(1){if((h|0)>0){if(x[a+1396>>2]<=9){Ok(a)}g=x[a+1392>>2];k=w[(((g&1023)<<1)+b|0)+36>>1];c:{if((k|0)>=0){i=g;k=k&65535;g=y[k+x[b+8>>2]|0];x[a+1392>>2]=i>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;k=(g|0)<0?-1:k;break c}k=Vl(a,b)}if((k|0)>=x[b+2092>>2]?y[b+23|0]:0){break a}if((k|0)<0){if(!y[a+1376|0]){b=0;if(x[a+1384>>2]){break b}}cc(a,21);return 0}else{g=0;n=D(d,l);m=((m+n|0)+j|0)>(q|0)?(q-n|0)+j|0:m;n=(m|0)>0?m:0;k=D(k,x[b>>2]);o=E(0);d:{if(y[b+22|0]){while(1){if((g|0)==(n|0)){break d}o=E(o+B[x[b+28>>2]+(g+k<<2)>>2]);i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=o+B[i>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}while(1){if((g|0)==(n|0)){break d}i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=B[i>>2]+E(B[x[b+28>>2]+(g+k<<2)>>2]+E(0))}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}h=h-m|0;continue}}break}x[e>>2]=j;x[f>>2]=l;b=1}return b}cc(a,21);return 0}_(7450,13048,1887,6492);p()}function A$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=db-144|0;db=a;x[a+136>>2]=c;x[a+140>>2]=b;x[a+20>>2]=1136;b=pe(a+24|0,a+32|0,a+20|0);Nc(a+16|0,x[e+28>>2]);x[23549]=0;h=R(18,x[a+16>>2])|0;i=x[23549];x[23549]=0;if((i|0)!=1){a:{v[a+15|0]=0;e=x[e+4>>2];x[23549]=0;c=la(1137,a+140|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}Ze(g);if(y[a+15|0]){x[23549]=0;c=O(19,h|0,45)|0;d=x[23549];x[23549]=0;if((d|0)==1){break a}x[23549]=0;P(46,g|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break a}}x[23549]=0;d=O(19,h|0,48)|0;c=x[23549];x[23549]=0;if((c|0)==1){break b}e=x[a+20>>2];h=e-1|0;c=x[b>>2];d=d&255;while(1){if(!((d|0)!=y[c|0]|c>>>0>=h>>>0)){c=c+1|0;continue}break}x[23549]=0;U(1143,g|0,c|0,e|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break c}break a}x[23549]=0;c=O(1105,a+140|0,a+136|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break a}if(c){x[f>>2]=x[f>>2]|2}c=x[a+140>>2];Xb(a+16|0);Kc(b);db=a+144|0;return c|0}}}c=N()|0;Xb(a+16|0);Kc(b);Q(c|0);p()}function pN(a){var b=0,c=0,d=0,e=0,f=0,g=0;while(1){if((f|0)!=4e3){g=db-32|0;db=g;b=tt(g);d=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);c=(f<<5)+a|0;e=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[c|0]=e;v[c+1|0]=e>>>8;v[c+2|0]=e>>>16;v[c+3|0]=e>>>24;v[c+4|0]=d;v[c+5|0]=d>>>8;v[c+6|0]=d>>>16;v[c+7|0]=d>>>24;d=y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24);e=y[b+24|0]|y[b+25|0]<<8|(y[b+26|0]<<16|y[b+27|0]<<24);v[c+24|0]=e;v[c+25|0]=e>>>8;v[c+26|0]=e>>>16;v[c+27|0]=e>>>24;v[c+28|0]=d;v[c+29|0]=d>>>8;v[c+30|0]=d>>>16;v[c+31|0]=d>>>24;d=y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24);e=y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24);v[c+16|0]=e;v[c+17|0]=e>>>8;v[c+18|0]=e>>>16;v[c+19|0]=e>>>24;v[c+20|0]=d;v[c+21|0]=d>>>8;v[c+22|0]=d>>>16;v[c+23|0]=d>>>24;d=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);b=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[c+8|0]=b;v[c+9|0]=b>>>8;v[c+10|0]=b>>>16;v[c+11|0]=b>>>24;v[c+12|0]=d;v[c+13|0]=d>>>8;v[c+14|0]=d>>>16;v[c+15|0]=d>>>24;db=g+32|0;f=f+1|0;continue}break}}function vI(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=a;d=db-208|0;db=d;x[d+8>>2]=1;x[d+12>>2]=0;h=b<<2;a:{if(!h){break a}x[d+16>>2]=4;x[d+20>>2]=4;a=4;b=4;e=2;while(1){f=a;a=(a+b|0)+4|0;x[(d+16|0)+(e<<2)>>2]=a;e=e+1|0;b=f;if(a>>>0<h>>>0){continue}break}f=(g+h|0)-4|0;b:{if(f>>>0<=g>>>0){b=0;e=1;h=0;a=1;f=0;break b}e=1;a=1;while(1){c:{if((e&3)==3){_w(g,c,a,d+16|0);gs(d+8|0,2);a=a+2|0;break c}b=a-1|0;d:{if(A[(d+16|0)+(b<<2)>>2]>=f-g>>>0){fs(g,c,e,x[d+12>>2],a,0,d+16|0);break d}_w(g,c,a,d+16|0)}if((a|0)==1){es(d+8|0,1);a=0;break c}es(d+8|0,b);a=1}b=x[d+8>>2];e=b|1;x[d+8>>2]=e;g=g+4|0;if(f>>>0>g>>>0){continue}break}h=b>>>0>1;b=x[d+12>>2];f=(b|0)!=0}fs(g,c,e,b,a,0,d+16|0);if(!(f|((a|0)!=1|h))){break a}while(1){e:{if((a|0)<=1){f=oI(e,b);gs(d+8|0,f);b=x[d+12>>2];e=x[d+8>>2];a=a+f|0;break e}e=d+8|0;es(e,2);x[d+8>>2]=x[d+8>>2]^7;gs(e,1);b=g-4|0;h=d+16|0;f=a-2|0;fs(b-x[h+(f<<2)>>2]|0,c,x[d+8>>2],x[d+12>>2],a-1|0,1,h);es(e,1);e=x[d+8>>2]|1;x[d+8>>2]=e;a=b;b=x[d+12>>2];fs(a,c,e,b,f,1,h);a=f}g=g-4|0;if((a|0)!=1|(e|0)!=1|b){continue}break}}db=d+208|0}function pY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=db-32|0;db=d;f=Nb(a);a=0;a:{b:{c:{d:{e:{while(1){if((Qv(b,c,a)|0)==-1){break b}e=Qv(b,c,a);x[23549]=0;V(108,d+8|0,b|0,a|0,e-a|0);e=x[23549];x[23549]=0;if((e|0)!=1){x[23549]=0;P(109,d+20|0,d+8|0);e=x[23549];x[23549]=0;if((e|0)==1){break e}x[23549]=0;P(110,f|0,d+20|0);e=x[23549];x[23549]=0;if((e|0)==1){break d}tb(d+20|0);tb(d+8|0);a=Qv(b,c,a)+Oc(x[c+4>>2],y[c+11|0])|0;continue}break}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(d+20|0)}tb(d+8|0);break a}f:{g:{h:{i:{j:{k:{if(qc(x[f>>2],x[f+4>>2])){x[23549]=0;V(108,d+20|0,b|0,a|0,-1);c=x[23549];x[23549]=0;if((c|0)==1){break j}c=Oc(x[d+24>>2],y[d+31|0]);tb(d+20|0);if(!c){break k}}x[23549]=0;V(108,d+8|0,b|0,a|0,-1);a=x[23549];x[23549]=0;if((a|0)==1){break i}x[23549]=0;P(109,d+20|0,d+8|0);a=x[23549];x[23549]=0;if((a|0)==1){break h}x[23549]=0;P(110,f|0,d+20|0);a=x[23549];x[23549]=0;if((a|0)==1){break g}tb(d+20|0);tb(d+8|0)}db=d+32|0;return}a=N()|0;break a}a=N()|0;break a}a=N()|0;break f}a=N()|0;tb(d+20|0)}tb(d+8|0)}Yd(f);Q(a|0);p()}function cha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=db-48|0;db=f;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;c=f+44|0;zo(b,c);a:{if(!nQ(c)){break a}d=y[f+46|0];g=y[f+47|0];e=y[f+45|0];v[a+4|0]=1;h=e>>>3&3;c=(h|0)!=3;e=(e^-1)>>>1&3;g=g>>>0<192;w[a+2>>1]=z[(D(c,6)+(e<<1)|0)+27432>>1]<<g;i=D(D(y[(e+D(c,3)|0)+27208|0],z[((D(c,90)+D(e,30)|0)+(d>>>3&30)|0)+27216>>1]),1e3);d=d>>>1|0;d=((i>>>0)/z[(D(h,6)+(d&6)|0)+27408>>1]|0)+(d&1)<<(!e<<1);w[a>>1]=d;e=y[(g|c<<1)+27444|0];if(e+8>>>0>(d&65535)>>>0){break a}c=db-32|0;db=c;x[c+28>>2]=e+4;x[c+8>>2]=36;g=x[b>>2];h=x[b+8>>2];d=x[Cb(c+28|0,c+8|0)>>2];if(!Lb(g,h,d)){d=rf(b)}g=c+8|0;br(g,f);h=ec(c+16|0,x[c+8>>2],d);lc(c,x[b>>2],x[b+8>>2],x[h>>2],x[h+4>>2]);br(g,f);Vb(x[c+8>>2]+d|0,0,36-d|0);Zb(b,x[c+28>>2]);db=c+32|0;b=2;c=e>>>0<=2?2:e;while(1){if((b|0)!=(c|0)){d=b+f|0;b=b+1|0;if(!y[d|0]){continue}break a}break}b=e+f|0;if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))==1868983881){b=1}else{b=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))==1735289176}v[a+5|0]=b}db=f+48|0;return a|0}function Eda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0;h=db-16|0;db=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];m=x[a+68>>2];t=m>>31;n=x[a+64>>2];u=n>>31;o=x[a+60>>2];w=o>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){b=f;if(d){f=Ub(b,-16777216,16776704);g=yka(n,u,f,f>>31);f=hb;e=Ub(e,-16777216,16776704);e=yka(m,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;l=g;g=x[h+12>>2]+p|0;k=v[g|0];k=((D(v[g+1|0]-k|0,x[h+8>>2]>>>10&4194048)|0)/16384<<8)+(k<<16)|0;e=k;g=yka(e,e>>31,o,w);l=g+l|0;e=hb+f|0;e=g>>>0>l>>>0?e+1|0:e;f=l+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Lc(f,e,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Qb(h+8|0,y,z);f=f-(k&s)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;db=h+16|0}function Y8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=E(0),h=0,i=0;c=db-32|0;db=c;a:{d=x[a+20>>2];b:{if(!d){break b}x[d+148>>2]=-1;h=c,i=ib[x[x[a>>2]+40>>2]](a)|0,x[h+16>>2]=i;x[c+8>>2]=1073741822;f=x[Cb(c+16|0,c+8|0)>>2];b=f<<2;if(!b){break b}e=x[a+20>>2];d=0;x[23549]=0;P(274,e+4|0,b+4|0);b=x[23549];x[23549]=0;c:{d:{if((b|0)!=1){b=x[a+20>>2];ge(c+8|0,x[b+4>>2],x[b+8>>2]);x[c>>2]=0;x[c+4>>2]=0;e=x[c+12>>2];b=c+16|0;x[b>>2]=x[c+8>>2];x[b+4>>2]=e;e=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=e;e=db-16|0;db=e;x[e+12>>2]=0;AL(b,e+12|0);db=e+16|0;b=x[x[a>>2]+180>>2];x[23549]=0;P(b|0,a|0,-1);b=x[23549];x[23549]=0;if((b|0)==1){break d}while(1){if((d|0)==(f|0)){d=x[x[a>>2]+184>>2];x[23549]=0;W(d|0,a|0);d=x[23549];x[23549]=0;if((d|0)!=1){break b}break d}b=x[x[a>>2]+48>>2];x[23549]=0;g=E(Wa(b|0,a|0,d|0));b=x[23549];x[23549]=0;if((b|0)!=1){B[c+8>>2]=g;d=d+1|0;AL(c+16|0,c+8|0);continue}break}d=T(92296)|0;break c}d=T(92296)|0;break c}d=T(92296)|0}if((eb|0)!=($(92296)|0)){break a}Y(d|0)|0;Dc(x[a+20>>2]+4|0);Z()}db=c+32|0;return}Q(d|0);p()}function Dda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;h=db-16|0;db=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];m=x[a+68>>2];t=m>>31;n=x[a+64>>2];u=n>>31;o=x[a+60>>2];v=o>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){b=f;if(d){f=Ub(b,-16777216,16776704);g=yka(n,u,f,f>>31);f=hb;e=Ub(e,-16777216,16776704);e=yka(m,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;l=g;g=(x[h+12>>2]<<1)+p|0;k=w[g>>1];k=k+((D(w[g+2>>1]-k|0,x[h+8>>2]>>>18|0)|0)/16384|0)<<8;e=k;g=yka(e,e>>31,o,v);l=g+l|0;e=hb+f|0;e=g>>>0>l>>>0?e+1|0:e;f=l+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Lc(f,e,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Qb(h+8|0,y,z);f=f-(k&s)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;db=h+16|0}function JR(a){a=a|0;var b=0,c=0,d=0,e=0;c=db-80|0;db=c;x[c+72>>2]=0;x[c+76>>2]=0;b=c- -64|0;x[b>>2]=0;x[b+4>>2]=0;x[c+56>>2]=0;x[c+60>>2]=0;x[c+48>>2]=0;x[c+52>>2]=0;Jz(a,qQ(a),c+48|0);b=mc(c+40|0,13883);Xe(te(a,0),x[b>>2],x[b+4>>2]);b=mc(c+32|0,13961);Xe(te(a,1),x[b>>2],x[b+4>>2]);b=mc(c+24|0,5437);Xe(te(a,3),x[b>>2],x[b+4>>2]);b=mc(c+16|0,15322);Xe(te(a,4),x[b>>2],x[b+4>>2]);b=mc(c+8|0,9163);Xe(te(a,8),x[b>>2],x[b+4>>2]);e=te(a+288|0,0);b=db-16|0;db=b;d=e;e=mc(b+8|0,4873);Xe(d,x[e>>2],x[e+4>>2]);db=b+16|0;e=a+800|0;b=0;a=db+-64|0;db=a;a:{b:{while(1){if((b|0)==128){break a}x[a+60>>2]=b<<3;c:{d:{if(b>>>0<=15){hf(a+28|0,4025);x[23549]=0;P(276,a+16|0,a+60|0);d=x[23549];x[23549]=0;if((d|0)==1){break c}x[23549]=0;S(277,a+40|0,a+28|0,a+16|0);d=x[23549];x[23549]=0;if((d|0)!=1){d=a+40|0;ze(a+52|0,d);Xe(te(e,b),x[a+52>>2],x[a+56>>2]);tb(d);tb(a+16|0);Ab(a+28|0);break d}b=N()|0;tb(a+16|0);break b}d=mc(a+8|0,21204);Xe(te(e,b),x[d>>2],x[a+12>>2])}b=b+1|0;continue}break}b=N()|0}Ab(a+28|0);Q(b|0);p()}db=a- -64|0;db=c+80|0}function Ija(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=db-32|0;db=g;e=b;b=x[a>>2];b=he(e,yb(b))+b|0;f=aV(c,d);a:{if((f|0)<=0){break a}e=x[wb(a)>>2];j=x[a+4>>2];if((e-j|0)>=(f|0)){x[g+12>>2]=d;k=j-b|0;if((k|0)<(f|0)){x[g+12>>2]=c;cU(g+12|0,k);h=x[g+12>>2];m=db-16|0;db=m;n=Gk(m+4|0,a,f-k|0);i=wb(a);e=db+-64|0;db=e;l=x[n+4>>2];x[e+56>>2]=l;x[e+60>>2]=h;x[e+52>>2]=l;i=rd(e+24|0,i,e+52|0,e+56|0);x[e+16>>2]=x[i+8>>2];l=x[i+4>>2];x[e+8>>2]=x[i>>2];x[e+12>>2]=l;Ke(e+36|0,e+8|0);while(1){if(Kb(h,d)){Fk(x[e+56>>2],y[h|0]);h=Oe(e+60|0);x[e+56>>2]=x[e+56>>2]+1;h=x[h>>2];continue}break}d=e+36|0;Je(d);h=x[e+56>>2];ik(d);db=e- -64|0;x[n+4>>2]=h;fc(n);db=m+16|0;if((k|0)<=0){break a}}$U(a,b,j,b+f|0);qu(c,x[g+12>>2],b);break a}e=wb(a);f=Ol(g+12|0,Ek(a,Pc(x[a>>2],j)+f|0),b-x[a>>2]|0,e);e=db-16|0;db=e;x[e+12>>2]=c;c=bw(e,f+8|0,aV(c,d));d=x[c>>2];while(1){if(x[c+4>>2]!=(d|0)){Fk(d,y[x[e+12>>2]]);d=x[c>>2]+1|0;x[c>>2]=d;Oe(e+12|0);continue}break}Kd(c);db=e+16|0;b=_U(a,f,b);Ml(f)}yb(b);db=g+32|0}function fda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=db-16|0;db=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}l=x[a+16>>2];j=x[a+40>>2];k=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];g=(x[e+12>>2]<<1)+l|0;b=(b>>>16&65520)+h|0;b=(((((((D(w[g-4>>1],w[b+2>>1])+D(w[g-6>>1],w[b>>1])|0)+D(w[g-2>>1],w[b+4>>1])|0)+D(w[g>>1],w[b+6>>1])|0)+D(w[g+2>>1],w[b+8>>1])|0)+D(w[g+4>>1],w[b+10>>1])|0)+D(w[g+6>>1],w[b+12>>1])|0)+D(w[g+8>>1],w[b+14>>1])|0)/32768|0;k=k+n|0;x[c>>2]=x[c>>2]+D(b,k>>12);j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Qb(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;db=e+16|0}function taa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=db-16|0;db=d;nd(c,0);w[d+14>>1]=y[a+36|0]|y[a+37|0]<<8;w[d+12>>1]=32767;g=c,h=(z[Uc(d+14|0,d+12|0)>>1]<<8>>>0)/32767|0,w[g+28>>1]=h;w[d+10>>1]=y[a+38|0]|y[a+39|0]<<8;w[d+8>>1]=32767;g=c,h=(z[Uc(d+10|0,d+8|0)>>1]<<8>>>0)/32767|0,w[g+30>>1]=h;w[c+32>>1]=64;x[c>>2]=y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24);x[c+4>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[c+8>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[c+24>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);e=y[b+166|0];if(e>>>0<=4){v[c+38|0]=y[e+42938|0]}e=y[b+167|0]|y[b+168|0]<<8;v[c+39|0]=e;f=(y[b+171|0]|y[b+172|0]<<8)>>>4|0;v[c+41|0]=f;b=(y[b+169|0]|y[b+170|0]<<8)>>>2|0;v[c+40|0]=b;if((b|f)&255){v[c+39|0]=e^-1}b=y[a+40|0]|y[a+41|0]<<8;if(b&4){w[c+34>>1]=z[c+34>>1]|1;b=y[a+40|0]|y[a+41|0]<<8}if(b&8){w[c+34>>1]=z[c+34>>1]|2;b=y[a+40|0]|y[a+41|0]<<8}if(b&16){w[c+34>>1]=z[c+34>>1]|4;b=y[a+40|0]|y[a+41|0]<<8}if(b&32){w[c+34>>1]=z[c+34>>1]|32}db=d+16|0}function x7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=db-16|0;db=g;i=g+4|0;e=db-160|0;db=e;d=e+24|0;f=d+56|0;c=Bs(f);x[d>>2]=76780;x[c>>2]=76800;x[d+56>>2]=76840;x[d>>2]=76820;h=f;f=d+4|0;On(h,f);x[d>>2]=76780;x[c>>2]=76800;c=ws(f);x[c>>2]=76264;Gb(c+32|0);x[c+44>>2]=0;x[c+48>>2]=16;c=x[x[d>>2]-12>>2];x[23549]=0;f=ca(61)|0;h=x[23549];x[23549]=0;a:{b:{c:{d:{e:{f:{if((h|0)==1){break f}x[23549]=0;S(62,e+20|0,c+d|0,f|0);c=x[23549];x[23549]=0;if((c|0)==1){break f}Xb(e+20|0);c=db-16|0;db=c;x[c+12>>2]=17;db=c+16|0;Zl(x[x[d>>2]-12>>2]+d|0,x[c+12>>2]);j=C[b>>3];x[23549]=0;b=Xa(63,d|0,+j)|0;c=x[23549];x[23549]=0;if((c|0)==1){break e}x[23549]=0;P(64,e+8|0,b|0);c=x[23549];x[23549]=0;if((c|0)==1){break d}x[23549]=0;P(60,i|0,e+8|0);c=x[23549];x[23549]=0;if((c|0)==1){break c}tb(e+8|0);xp(b);db=e+160|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}a=N()|0;tb(e+8|0)}xp(d);Q(a|0);p()}x[23549]=0;P(57,a|0,i|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(g+4|0);db=g+16|0;return}a=N()|0;tb(g+4|0);Q(a|0);p()}
function jf(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=db-80|0;db=e;c=x[a+28>>2];dn(x[x[c>>2]-12>>2]+c|0,0);if(!ed(a,4)){jw(a)}a:{if(!x[a+4>>2]){break a}if(ed(a,6)){break a}if(ed(a,7)){break a}f=x[a+28>>2];g=e- -64|0;c=x[a+84>>2];d=D(x[a+20>>2],x[a+4>>2]);h=d;d=d+x[a+80>>2]|0;c=h>>>0>d>>>0?c+1|0:c;c=gh(g,d,c);d=x[c+12>>2];x[e+24>>2]=x[c+8>>2];x[e+28>>2]=d;d=x[c+4>>2];x[e+16>>2]=x[c>>2];x[e+20>>2]=d;Gj(f,e+16|0)}d=0;b:{if(!ed(a,5)){break b}f=fh(x[a+44>>2],x[a+48>>2]);c=0;while(1){if((c|0)==(f|0)){break b}g=(x[a+96>>2]+c>>>0)%(f>>>0)|0;j=_c(x[a+44>>2],g);i=x[j>>2];c:{h=x[a+32>>2];if(Pc(h,x[a+36>>2])>>>0<=i>>>0){break c}i=jn(e+52|0,Db(h,i),z[j+12>>1]);j=pw(b,i);Ab(i);if(!j){break c}b=g+1|0;x[a+96>>2]=(b|0)!=(f|0)?b:0;d=_c(x[a+44>>2],g);c=x[d+4>>2];if(!c){break b}d=x[a+28>>2];f=e+32|0;b=x[a+12>>2];h=c;c=x[a+8>>2]+c|0;b=h>>>0>c>>>0?b+1|0:b;b=gh(f,c,b);c=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=c;c=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=c;Gj(d,e);d=_c(x[a+44>>2],g);break b}c=c+1|0;continue}}db=e+80|0;return d}function zI(a,b,c,d,e){var f=E(0),g=0,h=E(0),i=0,j=E(0),k=E(0);if(!(a&3)){c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;while(1){if((a|0)>0){b=d-4|0;h=B[b>>2];j=B[c>>2];k=B[d>>2];B[c>>2]=j+k;g=c-4|0;f=B[g>>2];B[g>>2]=f+B[b>>2];j=E(j-k);f=E(f-h);B[d>>2]=E(j*B[e>>2])-E(B[e+4>>2]*f);B[b>>2]=E(f*B[e>>2])+E(j*B[e+4>>2]);b=d-12|0;j=B[b>>2];g=c-8|0;f=B[g>>2];i=g;g=d-8|0;k=B[g>>2];B[i>>2]=f+k;i=c-12|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+32>>2])-E(B[e+36>>2]*h);B[b>>2]=E(h*B[e+32>>2])+E(f*B[e+36>>2]);b=d-20|0;j=B[b>>2];g=c-16|0;f=B[g>>2];i=g;g=d-16|0;k=B[g>>2];B[i>>2]=f+k;i=c-20|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+64>>2])-E(B[e+68>>2]*h);B[b>>2]=E(h*B[e+64>>2])+E(f*B[e+68>>2]);b=d-28|0;j=B[b>>2];g=c-24|0;f=B[g>>2];i=g;g=d-24|0;k=B[g>>2];B[i>>2]=f+k;i=c-28|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+96>>2])-E(B[e+100>>2]*h);B[b>>2]=E(h*B[e+96>>2])+E(f*B[e+100>>2]);a=a-1|0;d=d-32|0;c=c-32|0;e=e+128|0;continue}break}return}_(15411,13048,2423,9109);p()}function gda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=db-16|0;db=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}l=x[a+16>>2];j=x[a+40>>2];k=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];g=x[e+12>>2]+l|0;b=(b>>>16&65520)+h|0;b=(((((((D(v[g-2|0],w[b+2>>1])+D(v[g-3|0],w[b>>1])|0)+D(v[g-1|0],w[b+4>>1])|0)+D(v[g|0],w[b+6>>1])|0)+D(v[g+1|0],w[b+8>>1])|0)+D(v[g+2|0],w[b+10>>1])|0)+D(v[g+3|0],w[b+12>>1])|0)+D(v[g+4|0],w[b+14>>1])<<8)/32768|0;k=k+n|0;x[c>>2]=x[c>>2]+D(b,k>>12);j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Qb(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;db=e+16|0}function IE(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0;a:{h=db-48|0;db=h;l=x[c>>2]&2?16:10;j=db-32|0;db=j;i=Ye(j+20|0,1,0);b:{c:{d:{while(1){k=Mb(i);UJ(j+12|0,k,Bb(x[i+4>>2],y[i+11|0])+k|0,x[b>>2],l);if(!x[j+16>>2]){break d}k=$f(Bb(x[i+4>>2],y[i+11|0]));x[23549]=0;P(58,i|0,k|0);k=x[23549];x[23549]=0;if((k|0)!=1){continue}break}break c}b=x[j+12>>2];l=Mb(i);x[23549]=0;P(59,i|0,b-l|0);b=x[23549];x[23549]=0;e:{if((b|0)!=1){x[23549]=0;P(g|0,h|0,i|0);b=x[23549];x[23549]=0;if((b|0)!=1){break e}break c}break c}tb(i);db=j+32|0;break b}a=N()|0;tb(i);Q(a|0);p()}b=h+12|0;Xl(b,h,x[c>>2]);g=x[c+4>>2];i=x[c>>2];x[23549]=0;V(f|0,h+24|0,b|0,i|0,g|0);b=x[23549];x[23549]=0;f:{g:{h:{i:{if((b|0)!=1){b=y[c+16|0];c=x[c+12>>2];x[23549]=0;V(e|0,h+36|0,h+24|0,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break i}x[23549]=0;P(d|0,a|0,h+36|0);a=x[23549];x[23549]=0;if((a|0)==1){break h}tb(h+36|0);tb(h+24|0);tb(h+12|0);tb(h);db=h+48|0;break a}a=N()|0;break f}a=N()|0;break g}a=N()|0;tb(h+36|0)}tb(h+24|0)}tb(h+12|0);tb(h);Q(a|0);p()}}function iX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=db-96|0;db=d;wc(b);ap(a);a:{if(!sv(b,d+60|0)){break a}if(!tD(d+60|0)){break a}b:{if(!c){break b}if(!Lb(x[b>>2],x[b+8>>2],$b(y[d+64|0]|y[d+65|0]<<8|(y[d+66|0]<<16|y[d+67|0]<<24))-28|0)){break a}Iv(a);g=d,h=Hv(),x[g+40>>2]=h;e=d+40|0;Gv(yh(x[a+4>>2])+32|0,e);or(e);c=x[yh(x[a+4>>2])+32>>2];x[23549]=0;P(177,e|0,b|0);b=x[23549];x[23549]=0;c:{if((b|0)==1){break c}b=x[d+40>>2];e=y[d+64|0]|y[d+65|0]<<8|(y[d+66|0]<<16|y[d+67|0]<<24);f=y[d+72|0]|y[d+73|0]<<8|(y[d+74|0]<<16|y[d+75|0]<<24);x[23549]=0;b=ba(178,b|0,$b(e)-28|0,c|0,$b(f)|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break c}e=0;if(!b){break a}ge(d+24|0,x[c>>2],x[c+4>>2]);Ng(d+32|0,x[d+24>>2],x[d+28>>2]);b=Xd(d+16|0);c=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=c;b=mr(d+40|0,x[d+32>>2],x[d+36>>2],d+8|0);Zc(yh(x[a+4>>2])+12|0,b);ub(b);break b}a=wa(92296,26136)|0;b=eb;d:{if(($(92296)|0)==(b|0)){break d}if(($(26136)|0)==(b|0)){break d}Q(a|0);p()}Y(a|0)|0;Z();e=0;break a}e=1}db=d+96|0;return e|0}function Jz(a,b,c){var d=0,e=0;b=b-a>>5;while(1){if((b|0)>0){d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);e=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a|0]=e;v[a+1|0]=e>>>8;v[a+2|0]=e>>>16;v[a+3|0]=e>>>24;v[a+4|0]=d;v[a+5|0]=d>>>8;v[a+6|0]=d>>>16;v[a+7|0]=d>>>24;d=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);e=y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24);v[a+24|0]=e;v[a+25|0]=e>>>8;v[a+26|0]=e>>>16;v[a+27|0]=e>>>24;v[a+28|0]=d;v[a+29|0]=d>>>8;v[a+30|0]=d>>>16;v[a+31|0]=d>>>24;d=y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24);e=y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24);v[a+16|0]=e;v[a+17|0]=e>>>8;v[a+18|0]=e>>>16;v[a+19|0]=e>>>24;v[a+20|0]=d;v[a+21|0]=d>>>8;v[a+22|0]=d>>>16;v[a+23|0]=d>>>24;d=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);e=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[a+8|0]=e;v[a+9|0]=e>>>8;v[a+10|0]=e>>>16;v[a+11|0]=e>>>24;v[a+12|0]=d;v[a+13|0]=d>>>8;v[a+14|0]=d>>>16;v[a+15|0]=d>>>24;b=b-1|0;a=a+32|0;continue}break}}function hka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=db-32|0;db=g;i=a+8|0;c=x[a+8>>2];h=kc(a);a:{if((c|0)!=x[h>>2]){break a}k=a+4|0;d=x[a+4>>2];e=x[a>>2];if(d>>>0>e>>>0){f=db-16|0;db=f;l=f+8|0;a=db-32|0;db=a;Od(a+24|0,d,c);m=a+16|0;c=x[a+24>>2];h=x[a+28>>2];j=((d-e>>1)+1|0)/-2<<1;d=d+j|0;e=db-16|0;db=e;while(1){if((c|0)!=(h|0)){d=SV(d,c)+2|0;c=c+2|0;continue}break}x[e+12>>2]=d;vc(m,h,e+12|0);db=e+16|0;c=x[a+16>>2];x[a+12>>2]=x[a+20>>2];vc(l,c,a+12|0);db=a+32|0;db=f+16|0;c=x[f+12>>2];x[i>>2]=c;x[k>>2]=x[k>>2]+j;break a}x[g+8>>2]=c-e;x[g+28>>2]=1;d=g+8|0;c=x[Yc(d,g+28|0)>>2];c=uj(d,c,c>>>2|0,x[a+16>>2]);d=vb(g+4|0,x[a+4>>2]);e=x[vb(g,x[a+8>>2])>>2];f=db-16|0;db=f;d=x[d>>2];x[f+12>>2]=d;e=So(f,c+8|0,JB(d,e));d=x[e>>2];while(1){if(x[e+4>>2]!=(d|0)){j=d;d=x[f+12>>2];Eo(j,y[d|0]|y[d+1|0]<<8);d=x[e>>2]+2|0;x[e>>2]=d;Se(f+12|0);continue}break}Kd(e);db=f+16|0;Pb(a,c);Pb(k,c+4|0);Pb(i,c+8|0);Pb(h,kc(c));Di(c);c=x[a+8>>2]}Eo(c,y[b|0]|y[b+1|0]<<8);x[i>>2]=x[i>>2]+2;db=g+32|0}function rda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;g=db-16|0;db=g;f=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+72>>2];l=x[a+68>>2];s=l>>31;m=x[a+64>>2];t=m>>31;n=x[a+60>>2];u=n>>31;v=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){e=Ub(b,-16777216,16776704);i=yka(m,t,e,e>>31);j=hb;e=x[g+8>>2];h=(x[g+12>>2]<<1)+q|0;e=e>>>21&2040;h=(((D(w[h>>1],w[e+39938>>1])+D(w[h-2>>1],w[e+39936>>1])|0)+D(w[h+2>>1],w[e+39940>>1])|0)+D(w[h+4>>1],w[e+39942>>1])|0)/16384<<8;e=h;e=yka(e,e>>31,n,u);i=e+i|0;k=hb+j|0;k=e>>>0>i>>>0?k+1|0:k;f=Ub(f,-16777216,16776704);e=yka(l,s,f,f>>31);j=e+i|0;f=hb+k|0;f=e>>>0>j>>>0?f+1|0:f;e=j+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Lc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,o);Qb(g+8|0,v,y);e=e-(h&r)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;db=g+16|0}function Ij(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=db-16|0;db=i;x[i+8>>2]=c;x[i+12>>2]=b;Nc(i+4|0,x[d+28>>2]);c=0;x[23549]=0;j=R(18,x[i+4>>2])|0;b=x[23549];x[23549]=0;if((b|0)!=1){Xb(i+4|0);x[e>>2]=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(Og(i+12|0,i+8|0)){break b}c:{if((nn(j,v[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){break b}d:{e:{b=nn(j,v[c|0]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+2|0)==(h|0)){break b}k=b;b=nn(j,v[g+2|0])}l=i,m=ib[x[x[a>>2]+36>>2]](a,x[i+12>>2],x[i+8>>2],d,e,f,b,k)|0,x[l+12>>2]=m;g=c+2|0;break c}b=x[j+8>>2];if(ih(b,1,v[g|0])){while(1){f:{g=g+1|0;if((h|0)==(g|0)){g=h;break f}if(ih(b,1,v[g|0])){continue}}break}while(1){if(Og(i+12|0,i+8|0)){break c}b=Mk(x[i+12>>2]);if(!ih(x[j+8>>2],1,b)){break c}Tl(i+12|0);continue}}if((Aw(j,Mk(x[i+12>>2]))|0)==(Aw(j,v[g|0])|0)){g=g+1|0;Tl(i+12|0);break c}x[e>>2]=4}c=x[e>>2];continue}break}x[e>>2]=4}if(Og(i+12|0,i+8|0)){x[e>>2]=x[e>>2]|2}db=i+16|0;return x[i+12>>2]}a=N()|0;Xb(i+4|0);Q(a|0);p()}function IJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;c=db+-64|0;db=c;e=x[a>>2];a=x[e>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;xf(c+48|0,c+32|0,f);a=x[e+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a:{b:{c:{d:{h=x[c+4>>2];if(f>>>0<=h>>>0){if(f>>>0>A[c+20>>2]){break d}if(e>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(he(x[c+24>>2],i)>>>0<e>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];e:while(1){a=0;if((e|0)==(g|0)){break a}while(1)if((a|0)==(f|0)){g=g+1|0;continue e}else{d=Kh(m,h,a,g);j=xb(x[b>>2],a);d=x[d>>2]+(x[j>>2]>>1)|0;n=d;d=qs(k)+d&-4096;x[j>>2]=n-d;d=gd(d|2048,12);d=(d|0)>=32767?32767:d;o=In(l,i,a,g),q=(d|0)<=-32768?-32768:d,w[o>>1]=q;a=a+1|0;continue}}}_(7130,8943,33,8656);p()}_(7095,8943,34,8656);p()}_(5838,8943,35,8656);p()}_(5808,8943,36,8656);p()}db=c- -64|0}function GH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;q=a;i=db-1040|0;db=i;r=x[23424];a:{b:{a=i+16|0;l=z[((b>>>0<=153?b:0)<<1)+90752>>1]+88832|0;c=x[x[116055]+20>>2];if(c){j=x[c+4>>2];c=x[c>>2];e=x[c>>2]+1794895138|0;h=Rl(x[c+8>>2],e);f=Rl(x[c+12>>2],e);d=Rl(x[c+16>>2],e);c:{if(j>>>2>>>0<=h>>>0){break c}k=j-(h<<2)|0;if((d|f)&3|(k>>>0<=f>>>0|d>>>0>=k>>>0)){break c}s=d>>>2|0;t=f>>>2|0;f=0;while(1){k=h>>>1|0;m=k+f|0;n=m<<1;d=c+(n+t<<2)|0;o=Rl(x[d>>2],e);d=Rl(x[d+4>>2],e);if(d>>>0>=j>>>0|j-d>>>0<=o>>>0|y[c+(d+o|0)|0]){break c}d=Vk(l,c+d|0);if(!d){f=c+(s+n<<2)|0;h=Rl(x[f>>2],e);e=Rl(x[f+4>>2],e);if(e>>>0>=j>>>0|h>>>0>=j-e>>>0){break c}g=y[c+(e+h|0)|0]?0:c+e|0;break c}if((h|0)==1){break c}d=(d|0)<0;h=d?k:h-k|0;f=d?f:m;continue}}}g=g?g:l;c=Pf(g);d:{if(c>>>0>=1024){rc(a,g,1023);v[a+1023|0]=0;g=68;break d}rc(a,g,c+1|0);g=0}if(g){if((g|0)!=28){break b}a=21204}break a}sa();p()}if(!y[a|0]){x[i>>2]=b;a=i+16|0;Fw(a,1024,12865,i)}x[23424]=r;Tb(q,a);db=i+1040|0}function oka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=db-144|0;db=f;x[23549]=0;l=R(260,a|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){while(1){a:{if((j&65535)>>>0>=l>>>0){ub(a);db=f+144|0;return}x[23549]=0;P(279,a|0,f+8|0);e=x[23549];x[23549]=0;if((e|0)!=1){b:{e=Hb(z[f+8>>1]);if((e-1&65535)>>>0>=z[c+480192>>1]){break b}e=x[((e<<2)+c|0)+900380>>2];if(!e){break b}e=Ci(e,b);g=y[f+11|0];c:{if(!g){break c}h=y[f+10|0];if(h&1){v[e+12|0]=y[e+12|0]|1}if(h&2){v[e+12|0]=y[e+12|0]|4}if(!(h&4)){break c}v[e+12|0]=y[e+12|0]|2}v[f+4|0]=g;v[f+7|0]=31;h=y[Sb(f+4|0,f+7|0)|0];x[23549]=0;h=h+1&255;P(280,e|0,h|0);g=x[23549];x[23549]=0;if((g|0)==1){break a}v[e+13|0]=y[f+13|0];v[e+14|0]=y[f+14|0];g=y[f+12|0];v[e+15|0]=g;v[e+16|0]=g;g=x[e>>2];e=0;while(1){if((e|0)==(h|0)){break b}i=(f+8|0)+(e<<2)|0;m=Hb(z[i+8>>1]);k=xb(g,e);w[k>>1]=m;i=Hb(z[i+10>>1]);w[f+4>>1]=d?i+128>>>2|0:i;Wf(f+4|0,64);v[k+2|0]=y[f+4|0];e=e+1|0;continue}}j=j+1|0;continue}}break}}b=N()|0;ub(a);Q(b|0);p()}function sda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0;h=db-16|0;db=h;e=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+72>>2];j=x[a+68>>2];r=j>>31;k=x[a+64>>2];s=k>>31;l=x[a+60>>2];t=l>>31;u=x[a+8>>2];y=x[a+12>>2];while(1){b=f;if(d){f=Ub(b,-16777216,16776704);g=yka(k,s,f,f>>31);f=hb;e=Ub(e,-16777216,16776704);e=yka(j,r,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];i=g;g=x[h+12>>2]+p|0;e=e>>>21&2040;m=(((D(v[g|0],w[e+39938>>1])+D(v[g-1|0],w[e+39936>>1])|0)+D(v[g+1|0],w[e+39940>>1])|0)+D(v[g+2|0],w[e+39942>>1])<<8)/16384<<8;e=m;g=yka(e,e>>31,l,t);i=i+g|0;e=hb+f|0;e=g>>>0>i>>>0?e+1|0:e;f=i+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Lc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,n);Qb(h+8|0,u,y);f=f-(q&m)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;db=h+16|0}function ko(a,b,c,d){v[a+841|0]=0;x[a+708>>2]=0;x[a+656>>2]=0;x[a+104>>2]=0;v[a+797|0]=0;x[a+764>>2]=0;w[a+802>>1]=0;w[a+804>>1]=0;x[a+696>>2]=0;x[a+668>>2]=0;x[a+88>>2]=x[a+88>>2]|6144;if(Ob(b+1074312|0,23)){v[a+807|0]=1;v[a+808|0]=0}v[a+846|0]=0;v[a+839|0]=0;w[a+774>>1]=0;v[a+850|0]=255;x[a+660>>2]=0;v[a+851|0]=y[a+851|0]&224;qo(a+788|0);x[a+84>>2]=0;x[a+76>>2]=0;x[a+80>>2]=0;x[a+700>>2]=0;x[a+656>>2]=0;x[a+104>>2]=0;x[a+92>>2]=0;x[a+96>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;v[a+845|0]=0;v[a+838|0]=0;v[a+821|0]=0;x[a+688>>2]=0;x[a+672>>2]=0;x[a+676>>2]=0;w[a+836>>1]=32512;v[a+819|0]=0;v[a+820|0]=0;w[a+842>>1]=0;x[a+28>>2]=0;x[a+32>>2]=0;x[a+20>>2]=0;x[a+24>>2]=0;x[a+852>>2]=0;x[a+856>>2]=0;v[a+851|0]=y[a+851|0]&159;a:{if(c>>>0<=126){b=(c<<5)+b|0;c=x[b+480280>>2];x[a+88>>2]=c;x[a+692>>2]=z[b+480284>>1];x[a+748>>2]=z[b+480286>>1];if(!(c&1024)){break a}x[a+88>>2]=c&-1025|d;break a}x[a+748>>2]=64;x[a+692>>2]=128;x[a+88>>2]=0}w[a+784>>1]=0;v[a+795|0]=0;v[a+796|0]=0}function Pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;e=db-16|0;db=e;g=x[a+40>>2];h=x[a+36>>2];k=x[a+16>>2];j=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=j;l=b+24|0;m=x[a+32>>2];n=x[a+28>>2];j=x[a+8>>2];o=x[a+12>>2];while(1){if(d){b=x[e+8>>2];p=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;q=w[b+14>>1];r=w[b+12>>1];s=w[b+10>>1];t=w[b+8>>1];u=w[b+6>>1];v=w[b+4>>1];y=w[b+2>>1];b=w[b>>1];i=0;while(1){if((i|0)!=2){f=(i<<1)+p|0;x[(i<<2)+e>>2]=(((((D(w[f+8>>1],s)+D(w[f+4>>1],t)|0)+D(w[f+12>>1],r)|0)+D(w[f+16>>1],q)|0)/2|0)+((((D(w[f-8>>1],y)+D(w[f-12>>1],b)|0)+D(w[f-4>>1],v)|0)+D(w[f>>1],u)|0)/2|0)|0)/16384;i=i+1|0;continue}break}h=h+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],h>>12);g=g+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],g>>12);Qb(e+8|0,j,o);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;db=e+16|0}function u0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=db-32|0;db=g;x[g+28>>2]=b;a:{b:{if(!(v[d+4|0]&1)){x[g>>2]=-1;b=ib[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}Nc(g,x[d+28>>2]);x[23549]=0;b=R(1115,x[g>>2])|0;a=x[23549];x[23549]=0;d:{e:{f:{g:{if((a|0)!=1){Xb(g);Nc(g,x[d+28>>2]);x[23549]=0;a=R(1116,x[g>>2])|0;d=x[23549];x[23549]=0;if((d|0)==1){break g}Xb(g);x[23549]=0;P(1117,g|0,a|0);d=x[23549];x[23549]=0;if((d|0)==1){b=N()|0;break d}x[23549]=0;P(1118,g|12,a|0);a=x[23549];x[23549]=0;if((a|0)==1){break f}x[23549]=0;d=g+24|0;a=qa(1119,g+28|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[23549];x[23549]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+28>>2];while(1){d=Ec(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=N()|0;Xb(g);break d}b=N()|0;Xb(g);break d}b=N()|0;Ec(g);break d}b=N()|0;while(1){d=Ec(d-12|0);if((g|0)!=(d|0)){continue}break}}Q(b|0);p()}v[f|0]=0}db=g+32|0;return b|0}function Dj(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=Ii(a)&2047;c=Ii(5551115123125783e-32);a:{if(e-c>>>0>=Ii(512)-c>>>0){if(c>>>0>e>>>0){return a+1}o(+a);c=j(1)|0;d=j(0)|0;b:{if(Ii(1024)>>>0>e>>>0){break b}b=0;if(!d&(c|0)==-1048576){break a}if(Ii(Infinity)>>>0<=e>>>0){return a+1}if((c|0)>0|(c|0)>=0){return Gr(3105036184601418e216)}if(c>>>0<3230714880){break b}return Gr(12882297539194267e-247)}c=c<<1|d>>>31;e=!(d<<1)&(c|0)==-2129002496|c>>>0<2165964800?e:0}b=C[177];f=b+a;a=a-(f-b);b=a*a;g=b*b*(a*C[182]+C[181]);b=b*(a*C[180]+C[179]);a=a*C[178];o(+f);j(1)|0;i=j(0)|0;d=i<<4&2032;a=g+(b+(a+C[d+1464>>3]));d=d+1472|0;h=x[d>>2];c=x[d+4>>2];d=h;h=0;d=d+h|0;c=(i<<13)+c|0;c=d>>>0<h>>>0?c+1|0:c;if(!e){c:{if(!(i&-2147483648)){l(0,d|0);l(1,c+-1048576|0);b=+n();a=b*a+b;a=a+a;break c}l(0,d|0);l(1,c+1071644672|0);b=+n();f=b*a;a=f+b;if(a<1){AE(EE()*22250738585072014e-324);g=a+1;a=g+(f+(b-a)+(a+(1-g)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,d|0);l(1,c|0);b=+n();b=b*a+b}return b}function F0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=db-32|0;db=g;x[g+28>>2]=b;a:{b:{if(!(v[d+4|0]&1)){x[g>>2]=-1;b=ib[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}Nc(g,x[d+28>>2]);x[23549]=0;b=R(18,x[g>>2])|0;a=x[23549];x[23549]=0;d:{e:{f:{g:{if((a|0)!=1){Xb(g);Nc(g,x[d+28>>2]);x[23549]=0;a=R(1099,x[g>>2])|0;d=x[23549];x[23549]=0;if((d|0)==1){break g}Xb(g);x[23549]=0;P(1100,g|0,a|0);d=x[23549];x[23549]=0;if((d|0)==1){b=N()|0;break d}x[23549]=0;P(1101,g|12,a|0);a=x[23549];x[23549]=0;if((a|0)==1){break f}x[23549]=0;d=g+24|0;a=qa(1102,g+28|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[23549];x[23549]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+28>>2];while(1){d=tb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=N()|0;Xb(g);break d}b=N()|0;Xb(g);break d}b=N()|0;tb(g);break d}b=N()|0;while(1){d=tb(d-12|0);if((g|0)!=(d|0)){continue}break}}Q(b|0);p()}v[f|0]=0}db=g+32|0;return b|0}function CQ(a,b,c){var d=0,e=0;d=y[a|0]&15;v[a|0]=y[d+27136|0];a:{b:{c:{switch(d|0){case 0:if(y[b|0]?c>>>0>=51:0){break b}v[a|0]=0;return;case 5:d:{e:{d=y[b|0];e=d&15;f:{if(!((e|0)!=2&(d&240)!=32)){v[a|0]=20;d=159;v[b|0]=159;break f}if((e|0)==12){break e}}if(c>>>0<51){break b}if((d&240)==192){break d}break b}if(c>>>0<51){break b}}v[a|0]=25;v[b|0]=0;return;case 7:if(c>>>0>51){break b}v[a|0]=0;return;case 10:a=y[b|0]&240;if(!a){break b}v[b|0]=a;return;case 11:v[b|0]=D(y[b|0]&15,17);return;case 12:v[b|0]=y[b|0]>>>2;return;case 13:a=y[b|0];v[b|0]=D(a>>>4|0,10)+(a&15);return;case 14:g:{switch((y[b|0]>>>4|0)-1|0){case 0:v[a|0]=2;break a;case 1:v[a|0]=3;break a;case 7:if(c>>>0<52){break b}v[a|0]=20;v[b|0]=y[b|0]&15|96;return;case 8:v[a|0]=15;v[b|0]=y[b|0]&15;return;case 9:v[a|0]=11;v[b|0]=y[b|0]<<4|15;return;case 10:v[a|0]=11;break a;case 11:case 12:break g;default:break b}}v[a|0]=20;return;case 15:break c;default:break b}}if(y[b|0]<48){break b}v[a|0]=17}return}v[b|0]=y[b|0]|240}function Tha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=eu(c,d);d=b&63;if(e>>>0>d>>>0){c=ET(c,d);d=0;g=db-16|0;db=g;v[a+12|0]=0;Dc(a);e=db-32|0;db=e;a:{b:{if(Qh(a)>>>0<=14){if(eh(1073741823)>>>0<=14){break b}f=wb(a);f=Jf(e+12|0,15,oc(x[a>>2],x[a+4>>2]),f);kv(a,f);If(f)}db=e+32|0;break a}Rc();p()}h=0-y[c+1|0]|0;while(1){c:{if((d|0)==15){break c}e=c+(d<<1)|0;f=y[e+1|0];if(!f){break c}v[g+11|0]=64;h=f+(h<<16>>16)|0;f=vo(g+12|0,h&65535,y[Sb(e+2|0,g+11|0)|0]);d:{if(A[a+4>>2]<A[wb(a)>>2]){AT(a,f);break d}i=db-32|0;db=i;e=wb(a);e=Jf(i+12|0,eg(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),e);kq(x[e+8>>2],z[f>>1]|z[f+2>>1]<<16);x[e+8>>2]=x[e+8>>2]+4;kv(a,e);If(e);db=i+32|0}d=d+1|0;continue}break}d=y[c+32|0];v[a+14|0]=d>>>4;v[a+13|0]=d&15;c=y[c+31|0];d=c&15;v[a+15|0]=d;v[a+16|0]=d;if(c&16){v[a+12|0]=y[a+12|0]|4}if(c&32){v[a+12|0]=y[a+12|0]|2}db=g+16|0}e:{if(b<<24>>24>=0){c=y[a+12|0]&-2;a=a+12|0;break e}c=y[a+12|0]&-2|qc(x[a>>2],x[a+4>>2])^1;a=a+12|0}v[a|0]=c}function Hj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=db-16|0;db=i;x[i+8>>2]=c;x[i+12>>2]=b;Nc(i+4|0,x[d+28>>2]);b=0;x[23549]=0;j=R(1115,x[i+4>>2])|0;c=x[23549];x[23549]=0;if((c|0)!=1){Xb(i+4|0);x[e>>2]=0;a:{while(1){if((g|0)==(h|0)|b){break a}b:{if(Jh(i+12|0,i+8|0)){break b}c:{if((mn(j,x[g>>2])|0)==37){b=g+4|0;if((h|0)==(b|0)){break b}d:{e:{c=mn(j,x[b>>2]);if((c|0)==69){break e}k=0;if((c&255)==48){break e}b=g;break d}if((g+8|0)==(h|0)){break b}k=c;c=mn(j,x[g+8>>2])}l=i,m=ib[x[x[a>>2]+36>>2]](a,x[i+12>>2],x[i+8>>2],d,e,f,c,k)|0,x[l+12>>2]=m;g=b+8|0;break c}if(Jk(j,1,x[g>>2])){while(1){f:{g=g+4|0;if((h|0)==(g|0)){g=h;break f}if(Jk(j,1,x[g>>2])){continue}}break}while(1){if(Jh(i+12|0,i+8|0)){break c}if(!Jk(j,1,Kk(x[i+12>>2]))){break c}yn(i+12|0);continue}}if((yl(j,Kk(x[i+12>>2]))|0)==(yl(j,x[g>>2])|0)){g=g+4|0;yn(i+12|0);break c}x[e>>2]=4}b=x[e>>2];continue}break}x[e>>2]=4}if(Jh(i+12|0,i+8|0)){x[e>>2]=x[e>>2]|2}db=i+16|0;return x[i+12>>2]}a=N()|0;Xb(i+4|0);Q(a|0);p()}function CJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=db+-64|0;db=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;xf(c+48|0,c+32|0,f);a=x[d+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;d=c+16|0;a:{b:{c:{d:{i=x[c+4>>2];if(i>>>0>=g>>>0){if(A[d+4>>2]<g>>>0){break d}if(f>>>0>A[c+8>>2]){break c}if(he(x[d+8>>2],x[d+12>>2])>>>0<f>>>0){break b}k=b+12|0;l=x[c>>2];e:while(1){a=0;if((f|0)==(h|0)){break a}while(1)if((a|0)==(g|0)){h=h+1|0;continue e}else{e=Kh(l,i,a,h);j=xb(x[b>>2],a);e=x[e>>2]+(x[j>>2]>>1)|0;m=e;e=qs(k)+e&-4096;x[j>>2]=m-e;e=gd(e|2048,12);e=(e|0)>=32767?32767:e;n=Hn(d,a,h),o=(e|0)<=-32768?-32768:e,w[n>>1]=o;a=a+1|0;continue}}}_(7130,8943,33,8656);p()}_(7095,8943,34,8656);p()}_(5838,8943,35,8656);p()}_(5808,8943,36,8656);p()}db=c- -64|0}function nca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=db-16|0;db=g;x[g+12>>2]=1;a:{if(to(a)){c=x[a>>2];k=hg(c,x[a+4>>2]);x[g+8>>2]=k;l=x[Cb(g+12|0,g+8|0)>>2];while(1){if(l){l=l-1|0;if((b|0)!=(c|0)){i=yb(x[b>>2]);e=yb(x[b+4>>2]);f=db-16|0;db=f;h=JB(i,e);b:{if(h>>>0<=Qm(c)>>>0){x[f+12>>2]=e;m=x[c>>2];d=Ic(m,x[c+4>>2]);n=d>>>0>=h>>>0;if(n){d=e}else{x[f+12>>2]=i;WP(f+12|0,d);d=x[f+12>>2]}j=db-16|0;db=j;YP(j+8|0,i,d,m);d=x[j+12>>2];db=j+16|0;if(!n){_P(c,x[f+12>>2],e,h-Ic(x[c>>2],x[c+4>>2])|0);break b}Dd(c,d);break b}ZP(c);nA(c,vj(c,h));_P(c,i,e,h)}db=f+16|0;Aj(c+12|0,b+12|0);w[c+28>>1]=z[b+28>>1]}c=c+32|0;continue}break}if(!k){Bz(a,1-k|0,b);break a}PP(a,x[a>>2]+32|0);break a}if(x[a>>2]){RP(a);e=x[a>>2];to(a);Eb(e);o=wb(a),q=0,x[o>>2]=q;x[a>>2]=0;x[a+4>>2]=0}d=$p(a,1);e=db-16|0;db=e;if(eh(134217727)>>>0<d>>>0){Rc();p()}HQ(e+8|0,d);d=x[e+8>>2];x[a+4>>2]=d;x[a>>2]=d;o=wb(a),q=d+(x[e+12>>2]<<5)|0,x[o>>2]=q;db=e+16|0;Bz(a,1,b)}db=g+16|0}function Lv(a,b,c,d){var e=0,f=0,g=0,h=0;g=db-32|0;db=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;a:{if((f|0)==(e|0)&0|e>>>0>f>>>0){e=c<<4|b>>>28;c=d<<4|c>>>28;b=b&268435455;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){f=c+1073741824|0;e=e+1|0;f=e?f:f+1|0;break a}f=c+1073741824|0;if(a|(b|0)!=134217728){break a}a=e&1;e=a+e|0;f=a>>>0>e>>>0?f+1|0:f;break a}if(!(!c&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){a=d<<4|c>>>28;e=c<<4|b>>>28;f=a&524287|2146959360;break a}e=0;f=2146435072;if(h>>>0>1140785151){break a}f=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;zf(g+16|0,a,b,c,e,h-15233|0);em(g,a,b,c,e,15361-h|0);b=x[g+8>>2];e=b<<4;b=x[g+12>>2]<<4|b>>>28;c=x[g>>2];f=x[g+4>>2];h=f;e=f>>>28|e;f=b;a=h&268435455;b=c|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){e=e+1|0;f=e?f:f+1|0;break a}if(b|(a|0)!=134217728){break a}a=e;e=e+(e&1)|0;f=a>>>0>e>>>0?f+1|0:f}db=g+32|0;l(0,e|0);l(1,d&-2147483648|f);return+n()}function rp(a,b,c,d,e,f){var g=E(0),h=0,i=E(0),j=0,k=E(0),l=E(0);c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;b=f<<2;while(1){if((a|0)>0){f=d-4|0;i=B[f>>2];k=B[c>>2];l=B[d>>2];B[c>>2]=k+l;h=c-4|0;g=B[h>>2];B[h>>2]=g+B[f>>2];k=E(k-l);g=E(g-i);B[d>>2]=E(k*B[e>>2])-E(B[e+4>>2]*g);B[f>>2]=E(g*B[e>>2])+E(k*B[e+4>>2]);f=d-12|0;k=B[f>>2];h=c-8|0;g=B[h>>2];j=h;h=d-8|0;l=B[h>>2];B[j>>2]=g+l;j=c-12|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);f=d-20|0;k=B[f>>2];h=c-16|0;g=B[h>>2];j=h;h=d-16|0;l=B[h>>2];B[j>>2]=g+l;j=c-20|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);f=d-28|0;k=B[f>>2];h=c-24|0;g=B[h>>2];j=h;h=d-24|0;l=B[h>>2];B[j>>2]=g+l;j=c-28|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);e=b+e|0;a=a-1|0;d=d-32|0;c=c-32|0;continue}break}}function Tda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=db-16|0;db=g;f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+32>>2];s=x[a+28>>2];t=x[a+72>>2];l=x[a+68>>2];u=l>>31;m=x[a+64>>2];v=m>>31;n=x[a+60>>2];y=n>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){o=w[(x[g+12>>2]<<1)+q>>1]<<8;e=o;e=yka(e,e>>31,n,y);k=hb;h=e;e=Ub(b,-16777216,16776704);e=yka(m,v,e,e>>31);p=h+e|0;h=hb+k|0;h=e>>>0>p>>>0?h+1|0:h;f=Ub(f,-16777216,16776704);e=yka(l,u,f,f>>31);k=e+p|0;f=hb+h|0;f=e>>>0>k>>>0?f+1|0:f;e=k+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Lc(e,f,24);f=(e|0)/256|0;j=j+s|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+r|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,f);Qb(g+8|0,z,A);e=e-(t&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;db=g+16|0}function Qf(a){var b=0;a:{b:{switch(y[a+3|0]){case 0:if(!y[a+5|0]){break a}v[a+3|0]=1;return;case 1:v[a+3|0]=2;return;case 2:v[a+3|0]=3;return;case 3:v[a+3|0]=4;return;case 4:v[a+3|0]=5;return;case 5:v[a+3|0]=6;return;case 6:v[a+3|0]=7;return;case 7:v[a+3|0]=8;return;case 8:v[a+3|0]=9;return;case 9:v[a+3|0]=10;return;case 10:v[a+3|0]=11;return;case 11:v[a+3|0]=12;return;case 12:v[a+3|0]=13;return;case 13:v[a+3|0]=14;b=a;a=y[a+5|0];v[b+5|0]=D(a>>>4|0,10)+(a&15);return;case 14:v[a+3|0]=19;return;case 15:if(y[a+5|0]<=31){v[a+3|0]=16;return}v[a+3|0]=17;return;case 16:v[a+3|0]=23;return;case 17:v[a+3|0]=24;return;case 20:v[a+3|0]=25;return;case 21:v[a+3|0]=30;return;case 25:v[a+3|0]=29;return;case 27:v[a+3|0]=15;return;case 29:v[a+3|0]=18;return;case 32:v[a+3|0]=37;return;case 33:v[a+3|0]=28;return;case 34:v[a+3|0]=27;return;case 35:v[a+3|0]=31;return;case 36:v[a+3|0]=32;return;case 37:v[a+3|0]=32;return;case 38:v[a+3|0]=34;return;default:break b}}v[a+3|0]=0}}function Uda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=db-16|0;db=g;f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+32>>2];s=x[a+28>>2];t=x[a+72>>2];l=x[a+68>>2];u=l>>31;m=x[a+64>>2];w=m>>31;n=x[a+60>>2];y=n>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){o=v[x[g+12>>2]+q|0]<<16;e=o;e=yka(e,e>>31,n,y);k=hb;h=e;e=Ub(b,-16777216,16776704);e=yka(m,w,e,e>>31);p=h+e|0;h=hb+k|0;h=e>>>0>p>>>0?h+1|0:h;f=Ub(f,-16777216,16776704);e=yka(l,u,f,f>>31);k=e+p|0;f=hb+h|0;f=e>>>0>k>>>0?f+1|0:f;e=k+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Lc(e,f,24);f=(e|0)/256|0;j=j+s|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+r|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,f);Qb(g+8|0,z,A);e=e-(t&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;db=g+16|0}function Pja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=db-2608|0;db=f;d=zB(f+4|0,a);x[d+1060>>2]=0;x[d+1064>>2]=0;e=d+2604|0;a=d+1068|0;while(1){v[a+4|0]=0;w[a>>1]=0;w[a+2>>1]=0;a=a+6|0;if((e|0)!=(a|0)){continue}break}x[23549]=0;W(308,d|0);a=x[23549];x[23549]=0;a:{b:{if((a|0)!=1){if((w[d+1068>>1]|w[d+1070>>1])<0){break a}c:{while(1){if((c|0)==(g|0)){break a}x[23549]=0;j=O(150,d|0,1)|0;a=x[23549];x[23549]=0;if((a|0)==1){break c}a=0;d:{while(1){x[23549]=0;k=O(150,d|0,1)|0;e=x[23549];x[23549]=0;if((e|0)==1){break d}a=w[(d+D(a,6)|0)+(k?1070:1068)>>1];e:{if((a|0)>255){break e}e=d+D(a,6)|0;h=y[e+1072|0];if(w[e+1068>>1]<0){break e}if(w[e+1070>>1]>=0){continue}}break}h=(j?-1:0)^h;i=(i&255)+(h&255)|0;v[b+g|0]=i;g=g+1|0;continue}break}a=T(30544)|0;break b}a=T(30544)|0;break b}a=T(30544)|0}if((eb|0)==($(30544)|0)){Y(a|0)|0;x[23549]=0;X(17);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0}ub(d);Q(a|0);p()}a=zq(d);ub(d);db=f+2608|0;return a|0}function Rx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=E(0);c=db-48|0;db=c;a:{b=x[a+20>>2];b:{if(!b){break b}d=x[b+4>>2];b=x[b+8>>2];if(Pc(d,b)>>>0<4){break b}ge(c+16|0,d,b);b=Xd(c+8|0);d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;d=cV(c+28|0,x[c+16>>2],x[c+20>>2],c);x[23549]=0;b=R(143,d|0)|0;f=x[23549];x[23549]=0;c:{if((f|0)!=1){if(b){break c}b=x[x[a>>2]+40>>2];x[23549]=0;f=R(b|0,a|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break a}b=x[a+20>>2];if(Pc(x[b+4>>2],x[b+8>>2])-4>>>0<f<<2>>>0){break c}e=x[x[a>>2]+172>>2];b=0;x[23549]=0;P(e|0,a|0,-1);e=x[23549];x[23549]=0;if((e|0)==1){break a}while(1){if((b|0)==(f|0)){b=x[x[a>>2]+176>>2];x[23549]=0;W(b|0,a|0);a=x[23549];x[23549]=0;if((a|0)!=1){break c}break a}x[23549]=0;g=E(va(415,d|0));e=x[23549];x[23549]=0;d:{if((e|0)==1){break d}e=x[x[a>>2]+44>>2];x[23549]=0;ua(e|0,a|0,b|0,E(bm(g)?g:E(0)));e=x[23549];x[23549]=0;if((e|0)==1){break d}b=b+1|0;continue}break}break a}break a}ub(d)}db=c+48|0;return}a=N()|0;ub(d);Q(a|0);p()}function r6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[23549]=0;W(952,a|0);e=x[23549];x[23549]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}x[23549]=0;W(928,b|0);e=x[23549];x[23549]=0;if((e|0)==1){break e}e=0;x[23549]=0;W(953,c|0);f=x[23549];x[23549]=0;if((f|0)==1){break e}a=Vb(c,0,d);if(!y[b|0]){break b}if(Vk(b,7164)|(d|0)!=8){break d}x[a+4>>2]=954;x[a>>2]=955;break c}Y(T(0)|0)|0;x[23549]=0;V(914,12134,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();return 0}if(!(Vk(b,11099)|(d|0)!=64)){x[a+60>>2]=956;x[a+56>>2]=957;x[a+52>>2]=958;x[a+48>>2]=959;x[a+44>>2]=960;x[a+40>>2]=961;x[a+36>>2]=962;x[a+32>>2]=963;x[a+28>>2]=964;x[a+24>>2]=965;x[a+20>>2]=966;x[a+16>>2]=967;x[a+12>>2]=968;x[a+8>>2]=969;x[a+4>>2]=970;x[a>>2]=971;break c}if(Vk(b,14782)|(d|0)!=24){break b}x[a+20>>2]=972;x[a+16>>2]=973;x[a+12>>2]=974;x[a+8>>2]=975;x[a+4>>2]=976;x[a>>2]=977}e=1}return e|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function uK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=db-16|0;db=d;a:{b:{c:{d:{e:{f:{g:{e=x[a+36>>2];c=x[a+40>>2];h:{if(Kb(e,c)){xc(d+12|0);break h}Nn(d,a);x[23549]=0;c=R(986,d|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break g}x[d+12>>2]=c;Yf(d);c=x[a+40>>2];e=x[a+36>>2]}e=(h=a+36|0,i=x[d+12>>2],j=Kb(e,c),j?h:i);if((b|0)==-1){f=x[e>>2];g=4194304;c=0;break e}if((b|0)>=0){c=b;f=x[e>>2];if((Mn(f,x[e+4>>2])|0)>(b|0)){break e}}b=ac(8);x[23549]=0;c=O(54,d|0,10816)|0;a=x[23549];x[23549]=0;if((a|0)==1){break f}a=pc(b,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break b}a=N()|0;tb(c);break d}a=N()|0;Yf(d);break c}a=N()|0;jc(b);break d}x[a+8>>2]=b;b=x[a+24>>2];x[b+480208>>2]=x[b+480208>>2]&-4194305|g;oj(b+484360|0,y[nl(f,c)+16|0]);b=nl(x[e>>2],c);c=x[b+8>>2];b=x[b+12>>2];x[23549]=0;+ma(1017,a|0,b|0,c|0);b=x[23549];x[23549]=0;if((b|0)!=1){break a}a=N()|0}Qk(d+12|0)}Q(a|0)}p()}x[a+16>>2]=0;x[a+20>>2]=0;Qk(d+12|0);db=d+16|0}function Bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=db-16|0;db=e;p=x[a+16>>2];q=cg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);j=x[a+8>>2];k=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];l=x[a+128>>2];if(l){m=dg(j,k,l);n=hb;f=x[a+76>>2];Ff(b,g,bf(j,k,d),hb);o=hb>>>0>f>>>0?d:0}f=a+112|0;h=x[a+40>>2];i=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;o=o-1|0;b=o;m=b?m:0;n=b?n:0;g=(g<<1)+p|0;b=l;while(1)if((b|0)<=0){Qb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Md(f,w[g+(x[e+12>>2]<<1)>>1]/4<<16>>16);Ld(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=bg(f,q);g=x[a+32>>2];i=x[a+28>>2]+i|0;x[c>>2]=x[c>>2]+D(b,i>>12);h=g+h|0;x[c+4>>2]=x[c+4>>2]+D(b,h>>12);Qb(e,j,k);c=c+8|0;b=x[e>>2];g=x[e+4>>2];continue a}else{Md(f,w[g+(x[e+12>>2]<<1)>>1]/4<<16>>16);Ld(f,4);Qb(e+8|0,m,n);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=g;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;db=e+16|0}function hQ(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=E(0),l=0,m=0,n=0;if(gj(x[a+656>>2])){e=y[a+797|0];e=(l=e,m=y[a+799|0],n=Tc(e),n?l:m);f=Ob(d+1074312|0,34);d=x[a+656>>2];a:{if(!f){break a}f=e&255;if(!f|f>>>0>120){break a}e=y[Db(d+108|0,(e&255)-1|0)|0]}k=E(E(x[a+704>>2])*b);d=x[d+44>>2];g=((e&255)+c|0)-61<<16>>16;b:{c:{c=x[a+852>>2]+w[a+772>>1]|0;if(c){h=x[d+36>>2];if(h){break c}}b=dm(d,c+g<<16>>16);break b}j=h+1|0;i=Vx(c,j);e=Xx(c,j);b=E(1);f=w[d+28>>1];c=g+i<<16>>16;d:{if((f|0)>(c|0)){break d}g=x[d+4>>2];if((c|0)>(oc(g,x[d+8>>2])+f|0)-1<<16>>16){break d}if(!e){b=B[xb(g,c-f|0)>>2];break b}e:{f:{g:{switch(z[d>>1]-1|0){case 2:h=x[d+16>>2];if(!oc(h,x[d+20>>2])){break f}b=B[xb(h,e-1|0)>>2];break e;case 0:break g;default:break f}}i=x[d+16>>2];if(!oc(i,x[d+20>>2])){break f}b=B[xb(i,(e+D(h,_x(c,z[d+30>>1])<<16>>16)|0)-1|0)>>2];break e}b=qe(E(dm(d,c+1<<16>>16)/dm(d,c)),E(E(e|0)/E(j|0)))}b=E(b*B[xb(g,c-f|0)>>2])}}l=a,m=Uj(E(E(k*b)*E(16))),x[l+700>>2]=m}}function Qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;e=db-16|0;db=e;g=x[a+40>>2];h=x[a+36>>2];k=x[a+16>>2];j=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=j;l=b+24|0;m=x[a+32>>2];n=x[a+28>>2];j=x[a+8>>2];o=x[a+12>>2];while(1){if(d){b=x[e+8>>2];p=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;q=w[b+14>>1];r=w[b+12>>1];s=w[b+10>>1];t=w[b+8>>1];u=w[b+6>>1];y=w[b+4>>1];z=w[b+2>>1];b=w[b>>1];i=0;while(1){if((i|0)!=2){f=i+p|0;x[(i<<2)+e>>2]=((((D(v[f+4|0],s)+D(v[f+2|0],t)|0)+D(v[f+6|0],r)|0)+D(v[f+8|0],q)<<8>>1)+(((D(v[f-4|0],z)+D(v[f-6|0],b)|0)+D(v[f-2|0],y)|0)+D(v[f|0],u)<<8>>1)|0)/16384;i=i+1|0;continue}break}h=h+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],h>>12);g=g+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],g>>12);Qb(e+8|0,j,o);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;db=e+16|0}function $F(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=db-16|0;db=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;b=x[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=x[b>>2];if(b>>>0>1114111|(b&-2048)==55296){break a}b:{c:{if(b>>>0<=127){c=1;f=x[a+8>>2];if((g-f|0)<=0){break a}x[a+8>>2]=f+1;v[f|0]=b;break c}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}c=x[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}if((f|0)<4){break b}x[a+8>>2]=c+1;v[c|0]=b>>>18|240;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>12&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}b=x[a+12>>2]+4|0;x[a+12>>2]=b;continue}break}c=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];db=a+16|0;return c|0}function vja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=db-16|0;db=e;nd(b,32);g=b,h=$b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24)),x[g>>2]=h;f=$b(y[a+10|0]|y[a+11|0]<<8|(y[a+12|0]<<16|y[a+13|0]<<24));x[b+4>>2]=f;g=b,h=$b(y[a+14|0]|y[a+15|0]<<8|(y[a+16|0]<<16|y[a+17|0]<<24))+f|0,x[g+8>>2]=h;if(!(d?0:c)){c=$b(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))}x[b+24>>2]=c;c=y[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=Hb(y[a+42|0]|y[a+43|0]<<8);if(!d|(d|0)==48){break a}c=(c-(d<<7)|0)+6144|0}vq(b,+(c|0)*.0006510416666666666);v[e+15|0]=y[a+9|0];v[e+14|0]=64;g=b,h=y[Sb(e+15|0,e+14|0)|0]<<2,w[g+30>>1]=h;c=x[b+4>>2];d=x[b+8>>2];if(v[a+40|0]&1){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;w[b+34>>1]=z[b+34>>1]|64;x[b>>2]=x[b>>2]>>>1}if(y[a+41|0]>=9){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;w[b+34>>1]=z[b+34>>1]|1;x[b>>2]=x[b>>2]>>>1}b:{if(c+1>>>0<d>>>0){w[b+34>>1]=z[b+34>>1]|2;break b}x[b+4>>2]=0;x[b+8>>2]=0}db=e+16|0}function gy(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=db-16|0;db=d;f=y[a+2|0];if(!(!f|(f|0)==255)){x[d+12>>2]=f+1;x[d+8>>2]=10;ah(b,x[qd(d+12|0,d+8|0)>>2]);i=y[a+3|0];v[b+15|0]=i;v[b+16|0]=i;j=y[a+4|0];v[b+13|0]=j;l=y[a+5|0];v[b+14|0]=l;f=511;a:{b:{switch(c-1|0){case 1:e=4096;f=128;break a;case 0:break b;default:break a}}e=32768;f=1024}o=f>>>1|e;c=x[b>>2];k=ne(c,x[b+4>>2]);e=0;c:{while(1){if((e|0)==(k|0)){d:{c=y[b+12|0]&-2|v[a|0]&1;v[b+12|0]=c;if(y[a|0]&2){break d}c=c&251;break c}}else{m=xb(c,e);h=(e<<2)+a|0;g=(y[h+6|0]|y[h+7|0]<<8)>>>4|0;w[m>>1]=g;e:{if(e){n=z[xb(c,e-1|0)>>1];if(g>>>0>=n>>>0){break e}g=n+1|0}else{g=0}p=xb(c,e),q=g,w[p>>1]=q}x[d+12>>2]=(((y[h+8|0]|y[h+9|0]<<8)<<16>>16)+o|0)/(f|0);x[d+8>>2]=0;x[d+4>>2]=64;p=m,q=x[sj(d+12|0,d+8|0,d+4|0)>>2],v[p+2|0]=q;e=e+1|0;continue}break}c=c&-5|(k>>>0>=i>>>0)<<2}v[b+12|0]=c;if(j>>>0<=l>>>0?y[a|0]&4:0){a=c&-3|(k>>>0>=j>>>0)<<1}else{a=c&253}v[b+12|0]=a}db=d+16|0}function F9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=x[a>>2];c=wj(d,x[a+4>>2]);if(c>>>0<b>>>0){g=db-32|0;db=g;f=b-c|0;b=x[wb(a)>>2];c=x[a+4>>2];a:{if(f>>>0<=b-c>>11>>>0){c=db-16|0;db=c;b=c+4|0;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+(f<<11);a=x[b+4>>2];d=x[b+8>>2];while(1){if((a|0)==(d|0)){fc(b);db=c+16|0}else{Sx(a);a=a+2048|0;x[b+4>>2]=a;continue}break}break a}h=wb(a);i=g+12|0;b=a;e=wj(x[a>>2],c)+f|0;c=db-16|0;db=c;x[c+12>>2]=e;d=db-16|0;db=d;x[d+12>>2]=2097151;x[d+8>>2]=2147483647;a=x[Cb(d+12|0,d+8|0)>>2];db=d+16|0;b:{if(a>>>0>=e>>>0){d=Tx(b);if(d>>>0<a>>>1>>>0){x[c+8>>2]=d<<1;a=x[Yc(c+8|0,c+12|0)>>2]}db=c+16|0;break b}Rc();p()}d=QL(i,a,wj(x[b>>2],x[b+4>>2]),h);c=d;e=db-16|0;db=e;a=e+4|0;x[a>>2]=x[c+8>>2];h=x[c+8>>2];x[a+8>>2]=c+8;x[a+4>>2]=h+(f<<11);c=x[a>>2];while(1){if(x[a+4>>2]!=(c|0)){Sx(c);c=x[a>>2]+2048|0;x[a>>2]=c;continue}break}Kd(a);db=e+16|0;PL(b,d);OL(d)}db=g+32|0;return}if(b>>>0<c>>>0){Dd(a,d+(b<<11)|0)}}function tw(a,b,c,d,e,f,g,h,i,j,k,l){var m=0,n=0;a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break a}f=0;v[b|0]=0;a=x[e>>2];x[e>>2]=a+1;v[a|0]=46;if(!Bb(x[h+4>>2],y[h+11|0])){break b}a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Bb(x[h+4>>2],y[h+11|0])){break c}if(!y[b|0]){break a}f=0;a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;x[k>>2]=0;return 0}f=-1;a=vw(l,l+128|0,a)-l|0;if((a|0)>124){break b}g=v[(a>>2)+81792|0];d:{e:{f=a&-5;if((f|0)!=88){if((f|0)!=96){break e}a=x[e>>2];if((a|0)!=(d|0)){f=-1;if((un(v[a-1|0])|0)!=(un(v[c|0])|0)){break b}}x[e>>2]=a+1;v[a|0]=g;return 0}v[c|0]=80;break d}d=un(g);if((d|0)!=v[c|0]){break d}m=c,n=uH(d),v[m|0]=n;if(!y[b|0]){break d}v[b|0]=0;if(!Bb(x[h+4>>2],y[h+11|0])){break d}b=x[j>>2];if((b-i|0)>159){break d}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c}b=x[e>>2];x[e>>2]=b+1;v[b|0]=g;f=0;if((a|0)>84){break b}x[k>>2]=x[k>>2]+1}return f}return-1}function xw(a,b,c,d,e,f,g,h,i,j,k,l){var m=0,n=0;a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break a}f=0;v[b|0]=0;a=x[e>>2];x[e>>2]=a+1;v[a|0]=46;if(!Bb(x[h+4>>2],y[h+11|0])){break b}a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Bb(x[h+4>>2],y[h+11|0])){break c}if(!y[b|0]){break a}f=0;a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;x[k>>2]=0;return 0}f=-1;a=oi(l,l+32|0,a)-l|0;if((a|0)>31){break b}g=v[a+81792|0];d:{e:{switch((a&-2)-22|0){case 2:a=x[e>>2];if((a|0)!=(d|0)){if((un(v[a-1|0])|0)!=(un(v[c|0])|0)){break b}}x[e>>2]=a+1;v[a|0]=g;return 0;case 0:v[c|0]=80;break d;default:break e}}d=un(g);if((d|0)!=v[c|0]){break d}m=c,n=uH(d),v[m|0]=n;if(!y[b|0]){break d}v[b|0]=0;if(!Bb(x[h+4>>2],y[h+11|0])){break d}b=x[j>>2];if((b-i|0)>159){break d}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c}b=x[e>>2];x[e>>2]=b+1;v[b|0]=g;f=0;if((a|0)>21){break b}x[k>>2]=x[k>>2]+1}return f}return-1}function Bc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=x[b>>2];e=db-48|0;db=e;f=x[b+4>>2];b=y[b+8|0];d=f-(((b|0)==1|(b|0)==4)&(f|0)!=0)|0;f=Gb(a);b:{c:{d:{e:{f:{g:{h:{if((b-1&255)>>>0<=1){a=oi(c,c+d|0,0);x[23549]=0;U(52,f|0,c|0,a|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){break h}a=N()|0;break b}if((b-3&255)>>>0>1){break h}x[23549]=0;b=U(52,f|0,c|0,c+d|0)|0;a=x[23549];x[23549]=0;if((a|0)==1){break g}c=od(b);d=tf(b);g=od(b);a=db-16|0;db=a;x[a+8>>2]=g;x[a+12>>2]=c;while(1){if(Kb(c,d)){c=v[c|0];v[x[a+8>>2]]=c?c:32;c=Oe(a+12|0);Oe(a+8|0);c=x[c>>2];continue}break}db=a+16|0;x[23549]=0;c=O(53,e+24|0,b|0)|0;a=x[23549];x[23549]=0;if((a|0)==1){break f}x[23549]=0;d=O(54,e+12|0,17394)|0;a=x[23549];x[23549]=0;if((a|0)==1){break e}x[23549]=0;S(55,e+36|0,c|0,d|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}a=e+36|0;zb(b,a);tb(a);tb(d);tb(c)}db=e+48|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break c}a=N()|0;tb(d)}tb(c)}tb(f);Q(a|0);p()}}function tq(a){var b=0,c=0,d=0,e=0,f=0;e=db-16|0;db=e;a:{b:{c:{d:{e:{f:{g:{h:{b=x[a+480180>>2];switch(b-1|0){case 7:break e;case 0:case 1:case 3:break f;case 2:case 4:case 5:case 6:break g;default:break h}}if((b|0)==16){break b}if((b|0)==32){break f}if((b|0)==64|(b|0)==256|((b|0)==512|(b|0)==2048)|(b|0)==8192){break b}if((b|0)==65536){break d}d=1;if((b|0)==2097152){break a}if((b|0)==4194304){break c}if((b|0)==536870912|(b|0)==67108864|(b|0)==134217728){break a}d=b;if((b|0)==16777216){break a}}d=32;break a}d=b;break a}d=4;if(z[a+480192>>1]){break a}c=yb(x[a+484344>>2]);x[e+12>>2]=c;a=yb(x[a+484348>>2]);while(1){if(!Kb(c,a)){d=1;break a}if(!(!Kb(x[c>>2],x[c+4>>2])|x[c+12>>2]==64)){break a}c=x[so(e+12|0)>>2];continue}}d=16777216;break a}d=32;f=z[a+480188>>1];if(f>>>0>16){break a}while(1){if((c|0)==(f|0)){break b}b=(c<<5)+a|0;if(v[b+480281|0]&1){break a}c=c+1|0;if(z[b+480286>>1]==64){continue}break}break a}d=2}db=e+16|0;return d}function dY(a){a=a|0;var b=0,c=0,d=0,e=0;b=db-48|0;db=b;e=Gb(a);x[23549]=0;a=ca(112)|0;c=x[23549];x[23549]=0;a:{b:{if((c|0)==1){break b}c:{d:{if(!a){break d}x[23549]=0;c=O(1,b+24|0,8861)|0;a=x[23549];x[23549]=0;if((a|0)==1){break c}x[23549]=0;a=ca(112)|0;d=x[23549];x[23549]=0;e:{f:{g:{h:{if((d|0)==1){break h}x[23549]=0;x[b+8>>2]=a;P(118,b+12|0,b+8|0);a=x[23549];x[23549]=0;if((a|0)==1){break h}x[23549]=0;S(2,b+36|0,c|0,b+12|0);a=x[23549];x[23549]=0;if((a|0)==1){break g}d=b+36|0;a=zb(e,d);tb(d);tb(b+12|0);tb(c);x[23549]=0;c=ca(114)|0;d=x[23549];x[23549]=0;if((d|0)==1){break b}if(!c){break e}x[23549]=0;O(119,a|0,17087)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break e}break b}a=N()|0;break f}a=N()|0;tb(b+12|0)}tb(c);break a}x[23549]=0;c=ca(113)|0;d=x[23549];x[23549]=0;if((d|0)==1){break b}if(!c){break d}x[23549]=0;O(119,a|0,16389)|0;a=x[23549];x[23549]=0;if((a|0)==1){break b}}db=b+48|0;return}a=N()|0;break a}a=N()|0}tb(e);Q(a|0);p()}function y3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=db+-64|0;db=c;e=x[a>>2];a=x[e>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;xf(c+48|0,c+32|0,f);a=x[e+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a:{b:{c:{d:{g=x[c+4>>2];if(f>>>0<=g>>>0){if(f>>>0>A[c+20>>2]){break d}if(e>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(he(x[c+24>>2],h)>>>0<e>>>0){break b}i=b+12|0;j=x[c+16>>2];k=x[c>>2];b=0;e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{d=gd((x[Kh(k,g,a,b)>>2]+gd(ps(i),21)|0)+2048|0,12);d=(d|0)>=32767?32767:d;l=In(j,h,a,b),m=(d|0)<=-32768?-32768:d,w[l>>1]=m;a=a+1|0;continue}}}_(7130,8943,33,8656);p()}_(7095,8943,34,8656);p()}_(5838,8943,35,8656);p()}_(5808,8943,36,8656);p()}db=c- -64|0}function Ir(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{b:{d=Ii(a)&2047;c=Ii(5551115123125783e-32);if(d-c>>>0<Ii(512)-c>>>0){i=d;break b}if(c>>>0>d>>>0){return a+1}if(Ii(1024)>>>0>d>>>0){break b}o(+a);c=j(1)|0;b=0;if(!(j(0)|0)&(c|0)==-1048576){break a}if(Ii(Infinity)>>>0<=d>>>0){return a+1}if((c|0)<0){return Gr(12882297539194267e-247)}return Gr(3105036184601418e216)}b=C[170];e=C[169]*a+b;b=e-b;a=b*C[172]+(b*C[171]+a);b=a*a;f=b*b*(a*C[176]+C[175]);b=b*(a*C[174]+C[173]);o(+e);j(1)|0;h=j(0)|0;c=h<<4&2032;a=f+(b+(C[c+1464>>3]+a));c=c+1472|0;g=x[c>>2];d=x[c+4>>2];c=g;g=0;c=c+g|0;d=(h<<13)+d|0;d=c>>>0<g>>>0?d+1|0:d;if(!i){c:{if(!(h&-2147483648)){l(0,c|0);l(1,d-1058013184|0);b=+n();a=(b*a+b)*5486124068793689e288;break c}l(0,c|0);l(1,d+1071644672|0);b=+n();e=b*a;a=e+b;if(a<1){AE(EE()*22250738585072014e-324);f=a+1;a=f+(e+(b-a)+(a+(1-f)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,c|0);l(1,d|0);b=+n();b=b*a+b}return b}function Cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=db-16|0;db=e;p=x[a+16>>2];q=cg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);j=x[a+8>>2];k=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];l=x[a+128>>2];if(l){m=dg(j,k,l);n=hb;f=x[a+76>>2];Ff(b,g,bf(j,k,d),hb);o=hb>>>0>f>>>0?d:0}f=a+112|0;h=x[a+40>>2];i=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;o=o-1|0;b=o;m=b?m:0;n=b?n:0;g=g+p|0;b=l;while(1)if((b|0)<=0){Qb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Md(f,v[g+x[e+12>>2]|0]<<6);Ld(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=bg(f,q);g=x[a+32>>2];i=x[a+28>>2]+i|0;x[c>>2]=x[c>>2]+D(b,i>>12);h=g+h|0;x[c+4>>2]=x[c+4>>2]+D(b,h>>12);Qb(e,j,k);c=c+8|0;b=x[e>>2];g=x[e+4>>2];continue a}else{Md(f,v[g+x[e+12>>2]|0]<<6);Ld(f,4);Qb(e+8|0,m,n);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=g;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;db=e+16|0}function lY(){var a=0,b=0,c=0,d=0;c=db-32|0;db=c;a:{b=Tb(c+20|0,14956);if(!Oc(x[b+4>>2],y[b+11|0])){break a}b:{if((sg(b,14304)|0)!=-1){a=sg(b,14304);x[23549]=0;V(116,c+8|0,b|0,a+1|0,-1);a=x[23549];x[23549]=0;if((a|0)==1){break b}a=c+8|0;zb(b,a);tb(a)}if((sg(b,16387)|0)!=-1){a=sg(b,16387);x[23549]=0;V(116,c+8|0,b|0,a+1|0,-1);a=x[23549];x[23549]=0;if((a|0)==1){break b}a=c+8|0;zb(b,a);tb(a)}if((sg(b,13616)|0)!=-1){a=sg(b,13616);x[23549]=0;V(116,c+8|0,b|0,0,a|0);a=x[23549];x[23549]=0;if((a|0)==1){break b}a=c+8|0;zb(b,a);tb(a)}if((sg(b,13491)|0)!=-1){a=sg(b,13491);x[23549]=0;V(116,c+8|0,b|0,0,a|0);a=x[23549];x[23549]=0;if((a|0)==1){break b}a=c+8|0;zb(b,a);tb(a)}if((sg(b,13534)|0)!=-1){a=sg(b,13534);x[23549]=0;V(116,c+8|0,b|0,0,a|0);a=x[23549];x[23549]=0;if((a|0)==1){break b}a=c+8|0;zb(b,a);tb(a)}x[23549]=0;a=R(117,b|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){break a}}c=N()|0;tb(b);Q(c|0);p()}tb(b);db=c+32|0;return a|0}function c8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=0,p=0,q=0,r=0,s=0,t=E(0),u=E(0),v=E(0),w=E(0),z=0,A=0,C=0,D=0,G=0,H=E(0);g=db-16|0;db=g;m=x[a+4240>>2];a:{if(!m){break a}if(!Yh(a+44|0)){break a}n=B[a+4220>>2];e=x[a+44>>2];D=g,G=Ac(e,0),x[D+8>>2]=G;D=g,G=Ac(e,1),x[D+12>>2]=G;e=x[a+56>>2];o=Ac(e,0);x[g>>2]=o;p=Ac(e,1);x[g+4>>2]=p;w=E(E(1)-n);q=x[a+4208>>2];z=y[a+4264|0];e=d;b:while(1){if(e){k=x[a+4244>>2];A=k<<1;f=0;l=0;while(1)if((f|0)==2){f=k+1|0;x[a+4244>>2]=(f|0)!=(m|0)?f:0;e=e-1|0;continue b}else{h=(z?1-l|0:f)&255;j=x[((h<<2)+a|0)+4248>>2];C=x[a+4240>>2];r=f<<2;s=r+(g+8|0)|0;i=x[s>>2];x[s>>2]=i+4;j=k-j|0;t=B[xb(q,h+((j>>31&C)+j<<1)|0)>>2];u=B[i>>2];v=E(E(t*B[a+4224>>2])+E(u*B[a+4260>>2]));D=xb(q,f+A|0),H=E(F(v))<E(10000000195414814e-40)?E(0):v,B[D>>2]=H;h=g+r|0;i=x[h>>2];x[h>>2]=i+4;B[i>>2]=E(u*w)+E(n*t);l=l+1|0;f=f+1|0;continue}}break}li(a,b,c,o,p,d)}db=g+16|0}function qX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=db-32|0;db=h;e=Um(h+12|0,a);c=db-48|0;db=c;i=-1;a:{if(!uD(e,c+12|0)){break a}i=0;if(!yD(c+12|0)){break a}j=Pf(12955);if(j){n=x[e+12>>2];b:{if(!ml(e,y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24))){break b}while(1){c:{if((y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24))>>>0>l>>>0){if(zh(e,5)){break c}}d=k&1;break b}d:{if((y[c+16|0]|y[c+17|0]<<8)>>>0>=64){a=Jq(e);d=a&63;g=a<<24>>24;e:{if(!(a&64)){break e}f=6;while(1){a=Jq(e);d=(a&127)<<f|d;if(a<<24>>24>=0){break e}a=f>>>0<25;f=f+7|0;if(a){continue}break}}if((((g|0)<0?(d|0)<0?-2147483648:0-d|0:d)|0)<=0){break d}}d=0;f=1;while(1){g=Jq(e);if(g){m=d>>>0>=j>>>0;a=m&f;if(!((f^1)&1|m)){a=(Dp(g<<24>>24)&255)==y[d+12955|0]}f=a;d=d+1|0;continue}break}dd(e,4);k=(d|0)==(j|0)?f&1?1:k:k}l=l+1|0;continue}}ml(e,n)}if(!d){break a}i=Ge(e,b,xD(c+12|0),0)}db=c+48|0;db=h+32|0;return i|0}function o3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=db+-64|0;db=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;xf(c+48|0,c+32|0,e);a=x[d+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;d=c+16|0;a:{b:{c:{d:{h=x[c+4>>2];if(h>>>0>=f>>>0){if(A[d+4>>2]<f>>>0){break d}if(e>>>0>A[c+8>>2]){break c}if(he(x[d+8>>2],x[d+12>>2])>>>0<e>>>0){break b}i=b+12|0;j=x[c>>2];b=0;e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{g=gd((x[Kh(j,h,a,b)>>2]+gd(ps(i),21)|0)+2048|0,12);g=(g|0)>=32767?32767:g;k=Hn(d,a,b),l=(g|0)<=-32768?-32768:g,w[k>>1]=l;a=a+1|0;continue}}}_(7130,8943,33,8656);p()}_(7095,8943,34,8656);p()}_(5838,8943,35,8656);p()}_(5808,8943,36,8656);p()}db=c- -64|0}function Cp(a){a=a|0;var b=0,c=0,d=0,e=0,f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=E(0);b=x[a+36>>2];if(!b){Dc(a+16|0);return}a:{b:{switch(z[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){Dc(c);return}Yk(c,b);b=x[a+36>>2]+1|0;c=b>>>0<=1?1:b;e=w[a+28>>1];g=qe(E(dm(a,e+1<<16>>16)/dm(a,e)),E(E(1)/E(b>>>0)));a=x[a+16>>2];b=1;while(1){if((b|0)==(c|0)){break a}f=qe(g,E(b>>>0));n=xb(a,b-1|0),o=f,B[n>>2]=o;b=b+1|0;continue};case 1:c=a+16|0;e=z[a+30>>1];if(e>>>0>1e3/(b>>>0)>>>0){Dc(c);return}Yk(c,D(b,e));h=z[a+30>>1];j=_x(w[a+28>>1],h);i=x[a+36>>2];g=E(E(1)/E(i+1>>>0));c=0;c:while(1){if(e>>>0<=(c&65535)>>>0){break a}b=1;d=_x(c+j<<16>>16,h);f=dm(a,d+1<<16>>16);d=d<<16>>16;f=qe(E(f/dm(a,d)),g);k=D(d,x[a+36>>2]);l=x[a+16>>2];while(1){d=b&65535;if(d>>>0>i>>>0){c=c+1|0;continue c}else{m=qe(f,E(d>>>0));n=xb(l,(d+k|0)-1|0),o=m,B[n>>2]=o;b=b+1|0;continue}}};case 0:Dc(a+16|0);return;default:break b}}Dc(a+16|0);x[a+36>>2]=0}}function Ida(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0;h=db-16|0;db=h;e=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+72>>2];k=x[a+68>>2];r=k>>31;l=x[a+64>>2];s=l>>31;m=x[a+60>>2];t=m>>31;u=x[a+8>>2];w=x[a+12>>2];while(1){b=f;if(d){f=Ub(b,-16777216,16776704);g=yka(l,s,f,f>>31);f=hb;e=Ub(e,-16777216,16776704);e=yka(k,r,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;j=g;g=x[h+12>>2]+p|0;i=v[g|0];i=((D(v[g+1|0]-i|0,x[h+8>>2]>>>10&4194048)|0)/16384<<8)+(i<<16)|0;e=i;g=yka(e,e>>31,m,t);j=g+j|0;e=hb+f|0;e=g>>>0>j>>>0?e+1|0:e;f=j+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Lc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,n);Qb(h+8|0,u,w);f=f-(i&q)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;db=h+16|0}function U6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=db-80|0;db=e;x[e+76>>2]=c;a=Vf(a,e+76|0);c=xc(a+4|0);g=xc(a+24|0);h=xc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[23549]=0;P(922,a|0,d|0);f=x[23549];x[23549]=0;a:{b:{c:{d:{if((f|0)!=1){f=x[b>>2];k=x[b+4>>2];l=x[b+12>>2];x[e+48>>2]=x[b+8>>2];x[e+52>>2]=l;x[e+40>>2]=f;x[e+44>>2]=k;b=Xd(e+32|0);f=x[e+52>>2];x[e+24>>2]=x[e+48>>2];x[e+28>>2]=f;x[23549]=0;f=x[e+44>>2];x[e+16>>2]=x[e+40>>2];x[e+20>>2]=f;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;S(911,e+56|0,e+16|0,e+8|0);b=x[23549];x[23549]=0;if((b|0)==1){break d}x[23549]=0;S(923,a|0,e+56|0,d|0);b=x[23549];x[23549]=0;if((b|0)==1){break c}ub(e+56|0);x[23549]=0;W(924,a|0);b=x[23549];x[23549]=0;if((b|0)==1){break b}xe(e+76|0);db=e+80|0;return a|0}d=N()|0;break a}d=N()|0;break a}d=N()|0;ub(e+56|0);break a}d=N()|0}Yd(j);Yf(i);us(h);Xi(g);Wi(c);xe(a);xe(e+76|0);Q(d|0);p()}function Hda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=db-16|0;db=h;e=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+72>>2];k=x[a+68>>2];r=k>>31;l=x[a+64>>2];s=l>>31;m=x[a+60>>2];t=m>>31;u=x[a+8>>2];v=x[a+12>>2];while(1){b=f;if(d){f=Ub(b,-16777216,16776704);g=yka(l,s,f,f>>31);f=hb;e=Ub(e,-16777216,16776704);e=yka(k,r,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;j=g;g=(x[h+12>>2]<<1)+p|0;i=w[g>>1];i=i+((D(w[g+2>>1]-i|0,x[h+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;g=yka(e,e>>31,m,t);j=g+j|0;e=hb+f|0;e=g>>>0>j>>>0?e+1|0:e;f=j+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Lc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,n);Qb(h+8|0,u,v);f=f-(i&q)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;db=h+16|0}function gha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=db-16|0;db=e;w[e+12>>1]=0;x[e+8>>2]=0;j=8;n=D(c,d)<<1;a:while(1){if((d|0)!=(l|0)){i=(l<<1)+b|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){w[e+6>>1]=0;YS(a,e+15|0,e+12|0,j,e+6|0);g=z[e+6>>1];f=z[e+12>>1];c=j;while(1){if(c&255){h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!ef(a,e+5|0)){break c}f=y[e+5|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}w[e+12>>1]=f;break b}l=l+1|0;continue a}w[e+12>>1]=0}c=1;h=g&65535;e:{if(h>>>0<4){break e}f=15;while(1){c=f;m=f&255;if(m>>>0<2){break e}f=c-1|0;if(!(h&1<<m)){continue}break}}f=g&1;v[e+15|0]=f;g=f-1^(g&65534)>>>1;f=g+z[e+8>>1]|0;w[e+6>>1]=f;w[i>>1]=f;x[e+8>>2]=((g>>1)-(k<<16>>16)|0)+(f<<16>>16<<1);i=(d<<1)+i|0;j=(c+j&254)>>>1|0;c=-32768;k=x[e+8>>2];f:{if((k|0)>=-32768){c=32767;if((k|0)<32768){break f}}x[e+8>>2]=c}k=f;continue}}break}db=e+16|0}function z3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=db+-64|0;db=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;xf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(he(x[c+24>>2],h)>>>0<d>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){a=0;if((b|0)==(d|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{f=gd(x[Kh(j,g,a,b)>>2]+2048|0,12);f=(f|0)>=32767?32767:f;k=In(i,h,a,b),l=(f|0)<=-32768?-32768:f,w[k>>1]=l;a=a+1|0;continue}}}_(7130,8943,33,8656);p()}_(7095,8943,34,8656);p()}_(5838,8943,35,8656);p()}_(5808,8943,36,8656);p()}db=c- -64|0}function jda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=db-16|0;db=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];g=(x[e+12>>2]<<1)+j|0;b=(b>>>16&65520)+h|0;b=(((((((D(w[g-4>>1],w[b+2>>1])+D(w[g-6>>1],w[b>>1])|0)+D(w[g-2>>1],w[b+4>>1])|0)+D(w[g>>1],w[b+6>>1])|0)+D(w[g+2>>1],w[b+8>>1])|0)+D(w[g+4>>1],w[b+10>>1])|0)+D(w[g+6>>1],w[b+12>>1])|0)+D(w[g+8>>1],w[b+14>>1])|0)/32768|0;x[c>>2]=x[c>>2]+D(b,l);x[c+4>>2]=x[c+4>>2]+D(b,k);Qb(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;db=e+16|0}function y9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=E(0),q=E(0),r=0,s=0,t=0,u=E(0),v=E(0),w=E(0),y=E(0),z=0,A=0,C=0,D=E(0);r=x[a+4220>>2];if(r){f=x[a+44>>2];k=Ac(f,0);l=Ac(f,1);g=x[a+56>>2];s=Ac(g,0);j=x[a+4208>>2];z=x[a+4228>>2];f=d;t=Ac(g,1);m=t;g=s;while(1){if(f){h=x[a+4224>>2];e=h-z|0;e=(x[a+4220>>2]&e>>31)+e<<1;A=xb(j,e);n=B[xb(j,e|1)>>2];u=B[a+4244>>2];o=B[A>>2];v=B[a+4252>>2];p=B[l>>2];w=B[a+4248>>2];q=B[k>>2];y=B[a+4256>>2];i=E(E(n*u)+E(E(o*v)+E(E(p*w)+E(q*y))));e=h<<1;C=xb(j,e),D=E(F(i))<E(10000000195414814e-40)?E(0):i,B[C>>2]=D;i=E(E(o*u)+E(E(n*v)+E(E(q*w)+E(p*y))));C=xb(j,e|1),D=E(F(i))<E(10000000195414814e-40)?E(0):i,B[C>>2]=D;h=h+1|0;x[a+4224>>2]=(h|0)!=(r|0)?h:0;B[g>>2]=E(q*B[a+4240>>2])+E(o*B[a+4236>>2]);B[m>>2]=E(p*B[a+4240>>2])+E(n*B[a+4236>>2]);f=f-1|0;m=m+4|0;g=g+4|0;l=l+4|0;k=k+4|0;continue}else{li(a,b,c,s,t,d)}break}}}function vH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=db-32|0;db=c;a:{if(y[a+52|0]){d=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}x[c+24>>2]=1;e=x[Re(c+24|0,a+44|0)>>2];g=(e|0)>0?e:0;while(1){if((f|0)!=(g|0)){d=-1;h=vt(x[a+32>>2]);if((h|0)==-1){break a}v[(c+24|0)+f|0]=h;f=f+1|0;continue}break}b:{c:{if(y[a+53|0]){v[c+23|0]=y[c+24|0];break c}h=c+24|0;while(1){d:{f=x[a+40>>2];d=x[f>>2];j=x[f+4>>2];i=c+24|0;g=i+e|0;e:{switch(JH(x[a+36>>2],f,i,g,c+16|0,c+23|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}f=x[a+40>>2];x[f>>2]=d;x[f+4>>2]=j;if((e|0)==8){break b}d=vt(x[a+32>>2]);if((d|0)==-1){break b}v[g|0]=d;e=e+1|0;continue}break}v[c+23|0]=y[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((Xr(Lh(v[e+(c+24|0)|0]),x[a+32>>2])|0)!=-1){continue}break a}}d=Lh(v[c+23|0]);x[a+48>>2]=d;break a}d=Lh(v[c+23|0]);break a}d=-1}db=c+32|0;return d}function $J(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=db-16|0;db=e;x[e+12>>2]=c;a:{b:{if(!b){a=a+120|0;Jn(a);c=x[e+12>>2];b=db-16|0;db=b;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(b+8|0,x[vb(b+4|0,a)>>2]);c:{if(c){x[23549]=0;P(1046,a|0,c|0);d=x[23549];x[23549]=0;if((d|0)==1){break a}XJ(a,c)}c=b+8|0;Hd(c);Vh(c);db=b+16|0;break c}v[a+20|0]=0;break b}d=db-16|0;db=d;x[d+12>>2]=c;d:{if((b|0)==1){b=a+120|0;Jn(b);h=vx(b,a,x[d+12>>2]),i=1,v[h+20|0]=i;break d}f=db-16|0;db=f;x[f+12>>2]=c;e:{if((b|0)==2){a=a+120|0;Jn(a);c=x[f+12>>2];b=db-16|0;db=b;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(b+8|0,x[vb(b+4|0,a)>>2]);f:{if(c){x[23549]=0;P(1045,a|0,c|0);g=x[23549];x[23549]=0;if((g|0)==1){break a}XJ(a,c)}c=b+8|0;Hd(c);Vh(c);db=b+16|0;break f}Xd(a+12|0);v[a+20|0]=2;break e}b=db-16|0;db=b;x[b+12>>2]=c;c=a+120|0;Jn(c);h=vx(c,a,x[b+12>>2]),i=3,v[h+20|0]=i;db=b+16|0}db=f+16|0}db=d+16|0}db=e+16|0;return}a=N()|0;Vh(b+8|0);Q(a|0);p()}function qx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0);c=db+-64|0;db=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;xf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(he(x[c+24>>2],g)>>>0<d>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){a=0;if((b|0)==(d|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{j=om(je(fg(C[Pg(i,f,a,b)>>3])*134217728));k=px(h,g,a,b),l=E(+(j|0)*7.450580596923828e-9),B[k>>2]=l;a=a+1|0;continue}}}_(7130,8943,77,8623);p()}_(7095,8943,78,8623);p()}_(5838,8943,79,8623);p()}_(5808,8943,80,8623);p()}db=c- -64|0}function Pu(a){var b=0,c=0,d=0,e=0;c=db-16|0;db=c;a:{if(y[a+3|0]!=19){break a}v[a+3|0]=20;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{b=y[a+5|0];switch(b>>>4|0){case 4:break j;case 3:break k;case 2:break l;case 1:break m;case 0:break n;case 13:break b;case 12:break c;case 11:break d;case 10:break e;case 9:break f;case 7:break g;case 6:break h;case 5:break i;default:break a}}v[a+3|0]=0;break a}v[a+3|0]=2;v[a+5|0]=b|240;break a}v[a+3|0]=3;v[a+5|0]=b|240;break a}v[a+5|0]=b&15|16;break a}v[a+5|0]=b&3|48;break a}v[a+5|0]=b&223^120;break a}v[a+5|0]=b&15|176;break a}v[a+5|0]=b&3|64;break a}v[a+3|0]=15;v[a+5|0]=b&15;break a}if(b&15){v[a+3|0]=11;v[a+5|0]=b<<4|15;break a}v[a+3|0]=0;break a}b=b&15;if(b){v[a+3|0]=11;x[c+12>>2]=b;x[c+8>>2]=14;d=a,e=y[qd(c+12|0,c+8|0)|0]|240,v[d+5|0]=e;break a}v[a+3|0]=0;break a}if((b|0)!=192){break a}v[a|0]=254;v[a+3|0]=0;break a}if((b|0)!=208){break a}v[a+3|0]=0}db=c+16|0}function WF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;b=0;a=c;while(1){a:{if(a>>>0>=d>>>0|b>>>0>=e>>>0){break a}g=1;f=v[a|0];b:{if((f|0)>=0){break b}if(f>>>0<4294967234){break a}if(f>>>0<=4294967263){if((d-a|0)<2){break a}g=2;if((y[a+1|0]&192)!=128){break a}break b}g=f&255;if(f>>>0<=4294967279){if((d-a|0)<3){break a}h=y[a+2|0];f=y[a+1|0];c:{d:{if((g|0)!=237){if((g|0)!=224){break d}if((f&224)==160){break c}break a}if((f&224)!=128){break a}break c}if((f&192)!=128){break a}}g=3;if((h&192)!=128){break a}break b}if((d-a|0)<4|f>>>0>4294967284|e-b>>>0<2){break a}h=y[a+3|0];i=y[a+2|0];f=y[a+1|0];e:{f:{switch(g-240|0){case 0:if((f+112&255)>>>0>=48){break a}break e;case 4:if((f&240)!=128){break a}break e;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(g<<18&1835008|(f&48)<<12)>>>0>1114111){break a}b=b+1|0;g=4}b=b+1|0;a=a+g|0;continue}break}return a-c|0}function Gha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=db-432|0;db=d;wc(b);MA(b,d+380|0,d+300|0,d+16|0);k=d,l=xi((m=y[d+431|0]+1|0,n=1,o=$b(y[d+412|0]|y[d+413|0]<<8|(y[d+414|0]<<16|y[d+415|0]<<24)),o?m:n)),v[k+12|0]=l;i=y[Sb(26864,d+12|0)|0];v[d+15|0]=i;w[d+12>>1]=4;a:{b:{while(1){if((h&255)>>>0>=i>>>0){break b}e=Hb(z[d+16>>1])<<16>>16;if(!((e|0)<0|y[d+299|0]>63)){e=e&65535;f=0;while(1){if((f|0)==(e|0)){c:{e=g;g=$b(x[d+300>>2]);if(e>>>0<g>>>0){if(Vc(b,g)){break c}}v[d+15|0]=h+1;break b}}else{d:{if(!Vc(b,$b(y[d+396|0]|y[d+397|0]<<8|(y[d+398|0]<<16|y[d+399|0]<<24))+(f<<2)|0)){break d}if(!Vc(b,Io(b))){break d}e:{if(!c){j=ee(b);break e}j=PB(b)}w[d+10>>1]=j;k=d,l=z[Ve(d+12|0,d+10|0)>>1],w[k+12>>1]=l}f=f+1|0;continue}break}g=$b(x[d+300>>2]);MA(b,d+380|0,d+300|0,d+16|0);h=h+1|0;continue}break}jv(a);break a}w[a>>1]=z[d+12>>1];v[a+2|0]=y[d+15|0]}db=d+432|0}
function h7(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=db-16|0;db=d;x[23549]=0;g=O(12,d+8|0,a|0)|0;c=x[23549];x[23549]=0;a:{b:{c:{if((c|0)!=1){d:{if(!vd(y[g|0])){break d}Nc(d+4|0,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[23549]=0;c=R(67,x[d+4>>2])|0;e=x[23549];x[23549]=0;e:{f:{if((e|0)!=1){Xb(d+4|0);e=Fm(d,a);f=x[x[a>>2]-12>>2];x[23549]=0;f=a+f|0;h=R(13,f|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break f}e=x[e>>2];x[23549]=0;c=Oa(68,c|0,e|0,f|0,h|0,+b)|0;e=x[23549];x[23549]=0;if((e|0)==1){break f}if(c){break d}c=x[x[a>>2]-12>>2];x[23549]=0;P(15,a+c|0,5);c=x[23549];x[23549]=0;if((c|0)!=1){break d}c=T(0)|0;break e}c=T(0)|0;Xb(d+4|0);break e}c=T(0)|0}jk(g);break c}jk(g);break b}c=T(0)|0}Y(c|0)|0;c=x[x[a>>2]-12>>2];x[23549]=0;W(16,a+c|0);c=x[23549];x[23549]=0;if((c|0)==1){break a}Z()}db=d+16|0;return a|0}a=N()|0;x[23549]=0;X(17);d=x[23549];x[23549]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function wH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=db-32|0;db=c;a:{if(y[a+52|0]){d=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}x[c+24>>2]=1;e=x[Re(c+24|0,a+44|0)>>2];g=(e|0)>0?e:0;while(1){if((f|0)!=(g|0)){d=-1;h=vt(x[a+32>>2]);if((h|0)==-1){break a}v[(c+24|0)+f|0]=h;f=f+1|0;continue}break}b:{c:{if(y[a+53|0]){x[c+20>>2]=v[c+24|0];break c}h=c+24|0;while(1){d:{f=x[a+40>>2];d=x[f>>2];j=x[f+4>>2];i=c+24|0;g=i+e|0;e:{switch(JH(x[a+36>>2],f,i,g,c+16|0,c+20|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}f=x[a+40>>2];x[f>>2]=d;x[f+4>>2]=j;if((e|0)==8){break b}d=vt(x[a+32>>2]);if((d|0)==-1){break b}v[g|0]=d;e=e+1|0;continue}break}x[c+20>>2]=v[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((Xr(v[e+(c+24|0)|0],x[a+32>>2])|0)!=-1){continue}break a}}d=x[c+20>>2];x[a+48>>2]=d;break a}d=x[c+20>>2];break a}d=-1}db=c+32|0;return d}function eN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{f=b;c=db-16|0;db=c;d=Gb(a);while(1){b:{c:{d:{if(Oc(x[f+4>>2],y[f+11|0])>>>0>g>>>0){b=x[_i(f,g)>>2];if(b>>>0>=2097152){x[23549]=0;P(50,d|0,63);a=x[23549];x[23549]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;v[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=y[c+10|0]|64}else{a=y[c+10|0]}x[23549]=0;P(50,d|0,a<<24>>24);a=x[23549];x[23549]=0;if((a|0)!=1){break c}break b}db=c+16|0;break a}i=(2<<a)+255<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=y[j|0];x[23549]=0;P(50,d|0,(a|i)<<24>>24);h=x[23549];x[23549]=0;a=e;break e}x[23549]=0;a=a-1|0;P(50,d|0,v[a+(c+10|0)|0]|-128);h=x[23549];x[23549]=0}if((h|0)!=1){continue}break}break b}g=g+1|0;continue}break}a=N()|0;tb(d);Q(a|0);p()}}function kda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=db-16|0;db=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];g=x[e+12>>2]+j|0;b=(b>>>16&65520)+h|0;b=(((((((D(v[g-2|0],w[b+2>>1])+D(v[g-3|0],w[b>>1])|0)+D(v[g-1|0],w[b+4>>1])|0)+D(v[g|0],w[b+6>>1])|0)+D(v[g+1|0],w[b+8>>1])|0)+D(v[g+2|0],w[b+10>>1])|0)+D(v[g+3|0],w[b+12>>1])|0)+D(v[g+4|0],w[b+14>>1])<<8)/32768|0;x[c>>2]=x[c>>2]+D(b,l);x[c+4>>2]=x[c+4>>2]+D(b,k);Qb(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;db=e+16|0}function DI(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=x[a+32>>2];a:{b:{b=x[a+1380>>2];if((b|0)==-1){d=1;b=-1;break b}e=x[a+1116>>2];d=(b|0)>(e|0)?b:e;while(1){c:{if((b|0)!=(d|0)){f=y[(a+b|0)+1120|0];c=f+c|0;if((f|0)==255){break c}d=b}if(A[a+40>>2]<c>>>0){cc(a,1);break a}b=(d|0)==(e|0)?-1:d;d=0;break b}b=b+1|0;continue}}while(1){if((b|0)!=-1){return 1}e=x[a+40>>2];if(e>>>0<=c+26>>>0){cc(a,1);break a}if((y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))!=(y[93220]|y[93221]<<8|(y[93222]<<16|y[93223]<<24))){cc(a,21);break a}if(y[c+4|0]){cc(a,21);break a}d:{if(d){if(!x[a+992>>2]|!(v[c+5|0]&1)){break d}cc(a,21);break a}if(v[c+5|0]&1){break d}cc(a,21);break a}b=0;f=c+27|0;d=y[c+26|0];c=f+d|0;if(e>>>0<c>>>0){cc(a,1);break a}while(1){e:{if((b|0)==(d|0)){b=d;break e}g=y[b+f|0];c=g+c|0;if((g|0)!=255){break e}b=b+1|0;continue}break}b=(b|0)==(d|0)?-1:b;d=0;if(c>>>0<=e>>>0){continue}break}cc(a,1)}return 0}function p3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=db+-64|0;db=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;xf(c+48|0,c+32|0,d);a=x[b+4>>2];e=x[a+8>>2];g=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;d=c+16|0;b=0;a:{b:{c:{d:{h=x[c+4>>2];if(h>>>0>=g>>>0){if(A[d+4>>2]<g>>>0){break d}if(A[c+8>>2]<e>>>0){break c}if(he(x[d+8>>2],x[d+12>>2])>>>0<e>>>0){break b}i=x[c>>2];e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(g|0)){b=b+1|0;continue e}else{f=gd(x[Kh(i,h,a,b)>>2]+2048|0,12);f=(f|0)>=32767?32767:f;j=Hn(d,a,b),k=(f|0)<=-32768?-32768:f,w[j>>1]=k;a=a+1|0;continue}}}_(7130,8943,33,8656);p()}_(7095,8943,34,8656);p()}_(5838,8943,35,8656);p()}_(5808,8943,36,8656);p()}db=c- -64|0}function ZF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;while(1){a:{if(e>>>0<=i>>>0|a>>>0>=d>>>0){break a}f=1;b=v[a|0];b:{if((b|0)>=0){break b}if(b>>>0<4294967234){break a}if(b>>>0<=4294967263){if((d-a|0)<2){break a}f=2;if((y[a+1|0]&192)!=128){break a}break b}g=b&255;if(b>>>0<=4294967279){if((d-a|0)<3){break a}h=y[a+2|0];b=y[a+1|0];c:{d:{if((g|0)!=237){if((g|0)!=224){break d}if((b&224)==160){break c}break a}if((b&224)!=128){break a}break c}if((b&192)!=128){break a}}f=3;if((h&192)!=128){break a}break b}if((d-a|0)<4|b>>>0>4294967284){break a}f=y[a+3|0];h=y[a+2|0];b=y[a+1|0];e:{f:{switch(g-240|0){case 0:if((b+112&255)>>>0>=48){break a}break e;case 4:if((b&240)!=128){break a}break e;default:break f}}if((b&192)!=128){break a}}if((h&192)!=128|(f&192)!=128){break a}f=4;if((g<<18&1835008|(b&48)<<12)>>>0>1114111){break a}}i=i+1|0;a=a+f|0;continue}break}return a-c|0}function bC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=db-560|0;db=f;w[f+558>>1]=b;a:{if((b-256&65535)>>>0<65281){break a}e=((b<<2)+a|0)+900380|0;b=x[e>>2];b:{if(b){c=fQ(f,c);d=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=d;d=y[c+11|0]|y[c+12|0]<<8|(y[c+13|0]<<16|y[c+14|0]<<24);e=y[c+7|0]|y[c+8|0]<<8|(y[c+9|0]<<16|y[c+10|0]<<24);v[b+7|0]=e;v[b+8|0]=e>>>8;v[b+9|0]=e>>>16;v[b+10|0]=e>>>24;v[b+11|0]=d;v[b+12|0]=d>>>8;v[b+13|0]=d>>>16;v[b+14|0]=d>>>24;v[b+15|0]=y[c+15|0];d=x[c+44>>2];x[b+40>>2]=x[c+40>>2];x[b+44>>2]=d;d=x[c+36>>2];x[b+32>>2]=x[c+32>>2];x[b+36>>2]=d;d=x[c+28>>2];x[b+24>>2]=x[c+24>>2];x[b+28>>2]=d;d=x[c+20>>2];x[b+16>>2]=x[c+16>>2];x[b+20>>2]=d;wy(b+48|0,c+48|0);wy(b+68|0,c+68|0);wy(b+88|0,c+88|0);rc(b+108|0,c+108|0,448);d=b;cu(c);break b}b=Vs(556);if(!b){x[e>>2]=0;break a}d=fQ(b,c);x[e>>2]=d}g=a,h=z[Ve(a+480192|0,f+558|0)>>1],w[g+480192>>1]=h}db=f+560|0;return d|0}function ox(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);c=db+-64|0;db=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;xf(c+48|0,c+32|0,d);a=x[b+4>>2];e=x[a+8>>2];f=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;d=c+16|0;b=0;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=f>>>0){if(A[d+4>>2]<f>>>0){break d}if(A[c+8>>2]<e>>>0){break c}if(he(x[d+8>>2],x[d+12>>2])>>>0<e>>>0){break b}h=x[c>>2];e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{i=om(je(fg(C[Pg(h,g,a,b)>>3])*134217728));j=nx(d,a,b),k=E(+(i|0)*7.450580596923828e-9),B[j>>2]=k;a=a+1|0;continue}}}_(7130,8943,77,8623);p()}_(7095,8943,78,8623);p()}_(5838,8943,79,8623);p()}_(5808,8943,80,8623);p()}db=c- -64|0}function Sea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=db-16|0;db=f;w[f+12>>1]=c;w[f+14>>1]=b;w[f+10>>1]=d;h=z[x[x[a+24>>2]+8>>2]+12>>1];a:{if(h>>>0<=b>>>0){break a}if(!c|cj(a)>>>0>=h>>>0){break a}Wf(f+12|0,h-b&65535);k=f,l=vl(x[a>>2],x[a+4>>2]),w[k+8>>1]=l;d=z[f+12>>1];lT(a,d+z[Ve(f+14|0,f+8|0)>>1]|0);i=f+4|0;c=x[a>>2];e=a;if(Ic(c,x[a+4>>2])>>>0<b>>>0){Sf(e,b);c=x[e>>2]}a=x[vb(i,XP(yb(c),b))>>2];j=f+10|0;i=db-32|0;db=i;b=a;a=x[e>>2];g=(Fo(b,yb(a))<<1)+a|0;a=d;b:{if(!a){break b}b=x[wb(e)>>2];d=x[e+4>>2];if(a>>>0<=b-d>>1>>>0){b=a;c=d-g>>1;if(c>>>0<a>>>0){Lo(e,a-c|0,j);b=c;if((d|0)==(g|0)){break b}}VP(e,g,d,(a<<1)+g|0);_t(g,b,((g>>>0<=j>>>0?A[e+4>>2]>j>>>0?a:0:0)<<1)+j|0);break b}b=wb(e);b=uj(i+12|0,vj(e,Ic(x[e>>2],d)+a|0),g-x[e>>2]>>1,b);NC(b,a,j);g=TP(e,b,g);Di(b)}yb(g);db=i+32|0;if(Ic(x[e>>2],x[e+4>>2])>>>0<=h>>>0){break a}Sf(e,h)}db=f+16|0}function os(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0);c=db+-64|0;db=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;xf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(he(x[c+24>>2],g)>>>0<d>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){a=0;if((b|0)==(d|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{j=Kh(i,f,a,b);k=px(h,g,a,b),l=E(E(x[j>>2])*E(7.450580596923828e-9)),B[k>>2]=l;a=a+1|0;continue}}}_(7130,8943,33,8656);p()}_(7095,8943,34,8656);p()}_(5838,8943,35,8656);p()}_(5808,8943,36,8656);p()}db=c- -64|0}function gia(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=db-16|0;db=e;b=db-16|0;db=b;x[b+4>>2]=1073741824;w[b+10>>1]=12;c=Hc(64);x[23549]=0;d=R(812,c|0)|0;f=x[23549];x[23549]=0;a:{b:{c:{if((f|0)!=1){c=of(b,d);d=x[c>>2];x[23549]=0;P(813,d|0,a|0);a=x[23549];x[23549]=0;if((a|0)==1){break c}a=x[c>>2];x[23549]=0;a=U(814,a|0,b+10|0,b+4|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break c}d:{if(!a){xc(b+12|0);break d}a=x[c>>2];x[23549]=0;P(815,a|0,15);a=x[23549];x[23549]=0;if((a|0)==1){break c}Vf(b+12|0,c)}Lf(c);db=b+16|0;b=x[b+12>>2];break a}a=N()|0;Eb(c);break b}a=N()|0;Lf(c)}Q(a|0);p()}x[e+12>>2]=b;a=0;e:{f:{g:{while(1){if((a|0)==12){break e}x[23549]=0;c=O(1,e|0,(a<<2)+32224|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){x[23549]=0;S(440,b|0,a|0,c|0);d=x[23549];x[23549]=0;if((d|0)==1){break g}tb(c);a=a+1|0;continue}break}a=N()|0;break f}a=N()|0;tb(c)}Lf(e+12|0);Q(a|0);p()}db=e+16|0;return b|0}function yA(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=db-32|0;db=i;IS(a,b);h=db-16|0;db=h;nd(c,1);g=Hb(y[b+22|0]|y[b+23|0]<<8)<<1;x[c>>2]=g;v[c+37|0]=y[b+24|0]<<4;v[h+15|0]=y[b+25|0];v[h+14|0]=64;l=c,m=y[Sb(h+15|0,h+14|0)|0]<<2,w[l+30>>1]=m;f=Hb(y[b+26|0]|y[b+27|0]<<8);a=f<<1;j=f;k=Hb(y[b+28|0]|y[b+29|0]<<8);f=k<<1;a=k>>>0>=2?a+f>>>0<=g>>>0?a:j+f>>>0>g>>>0?a:j:a;a:{b:{switch(g|0){case 2:x[c>>2]=0;break a;case 0:break a;default:break b}}x[c+4>>2]=a;f=a+f|0;x[c+8>>2]=f;if(a>>>0>=g>>>0){a=g-1|0;x[c+4>>2]=a}if(!(!(f>>>0<4|a>>>0>f>>>0)&f-a>>>0>3)){x[c+4>>2]=0;x[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|f>>>0>=g>>>0|(!e|a))){x[c+8>>2]=0;break a}if(a>>>0>=f>>>0){break a}w[c+34>>1]=z[c+34>>1]|2}db=h+16|0;c=i+8|0;zl(c,3,b);a=i+20|0;Bc(a,c);c=zc(d,a);tb(a);a=0;while(1){if((a|0)!=32){d=a+c|0;if((y[d|0]-1&255)>>>0<=30){v[d|0]=32}a=a+1|0;continue}break}a=AA(b);db=i+32|0;return a}function dha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=db-16|0;db=e;w[e+12>>1]=0;x[e+8>>2]=0;n=D(c,d);k=4;a:while(1){if((d|0)!=(l|0)){i=b+l|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){v[e+7|0]=0;XS(a,e+15|0,e+12|0,e+7|0);g=y[e+7|0];f=z[e+12>>1];c=k;while(1){if(c&255){h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!ef(a,e+6|0)){break c}f=y[e+6|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}w[e+12>>1]=f;break b}l=l+1|0;continue a}w[e+12>>1]=0}c=1;h=g&255;e:{if(h>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(m>>>0<2){break e}f=c-1|0;if(!(h&1<<m)){continue}break}}f=g&1;v[e+15|0]=f;g=f-1^(g&254)>>>1;f=g+y[e+8|0]|0;v[e+7|0]=f;v[i|0]=f;x[e+8>>2]=((g>>1)-(j<<24>>24)|0)+(f<<24>>24<<1);i=d+i|0;k=(c+k&254)>>>1|0;c=-128;j=x[e+8>>2];f:{if((j|0)>=-128){c=127;if((j|0)<128){break f}}x[e+8>>2]=c}j=f;continue}}break}db=e+16|0}function eE(a,b,c,d){var e=0,f=0,g=0,h=0;g=db-32|0;db=g;f=d&2147483647;e=f-1065418752|0;h=f-1082064896|0;a:{if((e|0)==(h|0)&0|e>>>0<h>>>0){f=(d&33554431)<<7|c>>>25;e=0;h=e;c=c&33554431;if(!(!e&(c|0)==16777216?!(a|b):!e&c>>>0<16777216)){e=f+1073741825|0;break a}e=f+1073741824|0;if(c^16777216|a|(b|h)){break a}e=(f&1)+e|0;break a}if(!(!c&(f|0)==2147418112?!(a|b):f>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(f>>>0>1082064895){break a}e=0;f=f>>>16|0;if(f>>>0<16145){break a}e=d&65535|65536;zf(g+16|0,a,b,c,e,f-16129|0);em(g,a,b,c,e,16257-f|0);a=x[g+8>>2];e=(x[g+12>>2]&33554431)<<7|a>>>25;c=x[g>>2]|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;f=x[g+4>>2];b=0;a=a&33554431;if(!(!b&(a|0)==16777216?!(c|f):!b&a>>>0<16777216)){e=e+1|0;break a}if(a^16777216|c|(b|f)){break a}e=(e&1)+e|0}db=g+32|0;return l(2,d&-2147483648|e),r()}function bW(a,b){var c=0,d=0;d=y[a|0];if(d>>>0>=36){v[a|0]=0;return}c=y[d+26368|0];v[a|0]=c;a:{b:{c:{d:{e:{f:{switch(c-6|0){default:if((c|0)==31){break b}if((c|0)==23){break e}if(y[b|0]|(c|0)!=1){break a}v[a|0]=0;return;case 8:a=y[b|0];v[b|0]=D(a>>>4|0,10)+(a&15);return;case 2:case 3:case 4:case 6:case 7:case 9:case 10:case 12:break a;case 11:break c;case 13:break d;case 0:case 1:case 5:break f}}c=y[b|0];a=c&240;if(!a|(a|0)==240|(c&15)==15){break a}v[b|0]=a;return}a=y[b|0];if(a>>>0<=64){v[b|0]=a<<1;return}v[b|0]=128;return}g:{h:{i:{j:{c=y[b|0];switch((c&240)-48>>>4|0){case 4:break g;case 2:break h;case 1:break i;case 0:break j;default:break a}}v[a|0]=20;v[b|0]=159;return}v[a|0]=20;v[b|0]=192;return}if(c&14){break a}v[a|0]=21;v[b|0]=(y[b|0]!=80)<<6;return}v[a|0]=20;v[b|0]=y[b|0]&15|160;return}if(y[b|0]>31){break a}v[a|0]=16;return}v[b|0]=(d<<5|y[b|0]>>>3)^128}}function Tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=db-16|0;db=e;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];h=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=h;l=b+24|0;h=x[a+8>>2];m=x[a+12>>2];while(1){if(d){b=x[e+8>>2];n=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;o=w[b+14>>1];p=w[b+12>>1];q=w[b+10>>1];r=w[b+8>>1];s=w[b+6>>1];t=w[b+4>>1];u=w[b+2>>1];b=w[b>>1];g=0;while(1){if((g|0)!=2){f=(g<<1)+n|0;x[(g<<2)+e>>2]=(((((D(w[f+8>>1],q)+D(w[f+4>>1],r)|0)+D(w[f+12>>1],p)|0)+D(w[f+16>>1],o)|0)/2|0)+((((D(w[f-8>>1],u)+D(w[f-12>>1],b)|0)+D(w[f-4>>1],t)|0)+D(w[f>>1],s)|0)/2|0)|0)/16384;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i);Qb(e+8|0,h,m);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;db=e+16|0}function v7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=E(0),p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=E(0),v=E(0),w=E(0);h=db-16|0;db=h;if(Yh(a+44|0)){f=x[a+44>>2];g=Ac(f,0);x[h+8>>2]=g;f=Ac(f,1);x[h+12>>2]=f;j=x[a+56>>2];m=Ac(j,0);x[h>>2]=m;j=Ac(j,1);x[h+4>>2]=j;a:{if(B[xb(a+4208|0,2)>>2]!=E(.5)){f=d;b:while(1){g=0;if(!f){break a}while(1)if((g|0)==2){f=f-1|0;continue b}else{k=g<<2;e=k+(h+8|0)|0;i=x[e>>2];x[e>>2]=i+4;e=a+k|0;n=e+4248|0;q=B[n>>2];l=B[i>>2];r=B[a+4236>>2];s=B[a+4232>>2];t=B[a+4228>>2];u=B[a+4220>>2];v=B[a+4224>>2];i=e+4240|0;o=B[i>>2];B[n>>2]=o;B[i>>2]=l;i=e+4264|0;w=B[i>>2];e=e+4256|0;p=B[e>>2];B[i>>2]=p;l=E(E(E(E(t*q)+E(E(u*l)+E(v*o)))-E(s*p))-E(r*w));B[e>>2]=l;k=h+k|0;e=x[k>>2];x[k>>2]=e+4;B[e>>2]=l;g=g+1|0;continue}}}e=g;g=d<<2;rc(m,e,g);rc(j,f,g);f=x[a+56>>2];m=Ac(f,0);j=Ac(f,1)}li(a,b,c,m,j,d)}db=h+16|0}function tba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=db-16|0;db=f;b=x[a+4>>2];if(vd(y[b+223884|0])){BO(b+223860|0);b=x[a+4>>2]}x[a+24>>2]=0;x[a+28>>2]=0;x[b>>2]=0;c=x[a>>2];x[b+40>>2]=x[c+480196>>2];x[b+44>>2]=x[c+480204>>2];x[b+80>>2]=x[c+480200>>2];c=z[c+480188>>1];x[f+8>>2]=0;x[f+12>>2]=0;d=f+8|0;w[d+4>>1]=65280;x[d>>2]=0;e=db-16|0;db=e;x[e+12>>2]=c;b=a+8|0;a:{if(an(b)>>>0>=c>>>0){g=x[b>>2];h=Hg(g,x[b+4>>2]);x[e+8>>2]=h;i=x[Cb(e+12|0,e+8|0)>>2];while(1){if(i){x[g>>2]=x[d>>2];w[g+4>>1]=z[d+4>>1];i=i-1|0;g=g+8|0;continue}break}if(c>>>0>h>>>0){ON(b,c-h|0,d);break a}Dd(b,x[b>>2]+(c<<3)|0);break a}YO(b);mP(b,jr(b,c));ON(b,c,d)}db=e+16|0;b=0;while(1){c=x[a>>2];if(z[c+480188>>1]<=b>>>0){db=f+16|0}else{d=D(b,872);ko((d+x[a+4>>2]|0)+616|0,c,b&65535,134217728);c=d+x[a+4>>2]|0;w[c+1432>>1]=0;v[c+1418|0]=0;v[c+1415|0]=0;v[c+1413|0]=0;b=b+1|0;continue}break}}function ns(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);c=db+-64|0;db=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;xf(c+48|0,c+32|0,d);a=x[b+4>>2];e=x[a+8>>2];f=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;d=c+16|0;b=0;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=f>>>0){if(A[d+4>>2]<f>>>0){break d}if(A[c+8>>2]<e>>>0){break c}if(he(x[d+8>>2],x[d+12>>2])>>>0<e>>>0){break b}h=x[c>>2];e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{i=Kh(h,g,a,b);j=nx(d,a,b),k=E(E(x[i>>2])*E(7.450580596923828e-9)),B[j>>2]=k;a=a+1|0;continue}}}_(7130,8943,33,8656);p()}_(7095,8943,34,8656);p()}_(5838,8943,35,8656);p()}_(5808,8943,36,8656);p()}db=c- -64|0}function Fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=db-16|0;db=e;n=x[a+16>>2];o=cg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);i=x[a+8>>2];j=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];k=x[a+128>>2];if(k){l=dg(i,j,k);m=hb;f=x[a+76>>2];Ff(b,g,bf(i,j,d),hb);h=hb>>>0>f>>>0?d:0}f=a+112|0;p=x[a+24>>2];q=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){g=x[e+4>>2];x[e+8>>2]=x[e>>2];x[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=(g<<1)+n|0;b=k;while(1)if((b|0)<=0){Qb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Md(f,w[(x[e+12>>2]<<1)+g>>1]/4<<16>>16);Ld(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=bg(f,o);x[c>>2]=x[c>>2]+D(b,q);x[c+4>>2]=x[c+4>>2]+D(b,p);Qb(e,i,j);c=c+8|0;continue a}else{Md(f,w[(x[e+12>>2]<<1)+g>>1]/4<<16>>16);Ld(f,4);Qb(e+8|0,l,m);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;db=e+16|0}function sea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=db-32|0;db=g;e=db-16|0;db=e;c=a+33|0;x[b>>2]=y[c+206|0]|y[c+207|0]<<8;wM(c,b+48|0,y[c+192|0],y[c+200|0],y[c+194|0],y[c+195|0],y[c+196|0],0);wM(c,b+68|0,y[c+193|0],y[c+201|0],y[c+197|0],y[c+198|0],y[c+199|0],1);f=b+236|0;while(1){if((d|0)==96){if(y[c+208|0]){v[b+31|0]=y[c+209|0]+1;f=y[b+31|0];a:{b:{if(!f){d=1;break b}d=16;if(f>>>0<17){break a}}v[b+31|0]=d}w[e+14>>1]=y[c+210|0]|y[c+211|0]<<8;w[e+12>>1]=127;j=b,k=y[Uc(e+14|0,e+12|0)|0]+1|0,v[j+30|0]=k}v[b+33|0]=y[c+212|0];db=e+16|0}else{i=y[c+d|0];j=_b(f,d+12|0),k=i,w[j>>1]=k;d=d+1|0;continue}break}e=b+236|0;while(1){if((h|0)!=96){d=y[c+h|0];f=y[a+27|0]|y[a+28|0]<<8;j=_b(e,h+12|0),k=d>>>0<f>>>0?d:0,w[j>>1]=k;h=h+1|0;continue}break}d=g+8|0;zl(d,3,a+4|0);c=g+20|0;Bc(c,d);zc(b+492|0,c);tb(c);if(!y[a+241|0]){v[b+30|0]=y[a+26|0]}db=g+32|0}function iF(a,b,c,d,e,f,g,h){var i=0,j=0,k=E(0);i=db-96|0;db=i;uy(x[a+24>>2]);v[x[a+24>>2]+1298420|0]=x[a+52>>2]!=0;x[i+92>>2]=f;x[i+88>>2]=e;x[i+84>>2]=d;x[i+80>>2]=c;e=i+40|0;c=i+80|0;a:{d=0;while(1){b:{if((d|0)!=4){if(x[(d<<2)+c>>2]){break b}}else{d=4}break a}d=d+1|0;continue}}c=rd(e,c,d,b);k=B[a+48>>2];e=x[a+32>>2];x[i+16>>2]=x[c+8>>2];d=x[c+4>>2];x[i+8>>2]=x[c>>2];x[i+12>>2]=d;d=db-16|0;db=d;x[d+8>>2]=x[i+16>>2];c=x[i+12>>2];x[d>>2]=x[i+8>>2];x[d+4>>2]=c;c=NJ(i+52|0);x[c+8>>2]=e;x[c+4>>2]=0;x[c>>2]=h;e=x[d+4>>2];x[c+12>>2]=x[d>>2];x[c+16>>2]=e;x[c+20>>2]=x[d+8>>2];B[c+24>>2]=k;x[c>>2]=g;db=d+16|0;while(1){if(b){d=x[a+24>>2];x[i+32>>2]=b;x[i+36>>2]=0;x[i+24>>2]=134217727;x[i+28>>2]=0;d=PJ(d,x[Vq(i+32|0,i+24|0)>>2],c);j=d+j|0;b=b-d|0;if(d){continue}}break}if(!(x[a+52>>2]!=1|j)){a=x[a+24>>2];x[a+480208>>2]=x[a+480208>>2]&-513}db=i+96|0;return j}function Vl(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;Ok(a);a:{b:{c:{f=x[b+32>>2];d:{if(!f){e=x[b+2084>>2];if(e){break d}break b}c=x[b+4>>2];if((c|0)<9){break c}e=x[b+2084>>2];if(!e){break c}}h=x[a+1392>>2];j=Ul(h);d=x[b+2092>>2];c=0;while(1){if((d|0)>=2){f=d>>>1|0;i=f+c|0;g=A[(i<<2)+e>>2]>j>>>0;d=g?f:d-f|0;c=g?c:i;continue}break}d=x[a+1396>>2];c=y[b+23|0]?c:x[x[b+2088>>2]+(c<<2)>>2];b=y[c+x[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;b=0;break e}x[a+1392>>2]=h>>>b;b=d-b|0}x[a+1396>>2]=b;return c}if(y[b+23|0]){break a}e=(c|0)>0?c:0;while(1){if((d|0)!=(e|0)){f:{c=y[x[b+8>>2]+d|0];if((c|0)==255){break f}g=x[a+1392>>2];if(x[f+(d<<2)>>2]!=(g&(-1<<c^-1))){break f}e=x[a+1396>>2];if((e|0)>=(c|0)){x[a+1392>>2]=g>>>c;x[a+1396>>2]=e-y[x[b+8>>2]+d|0];return d}x[a+1396>>2]=0;break b}d=d+1|0;continue}break}cc(a,21);x[a+1396>>2]=0}return-1}_(11236,13048,1705,5386);p()}function Sl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=db-16|0;db=e;x[a+4>>2]=0;if(vd(y[Cn(e+15|0,a,1)|0])){a:{b:{c:{if((b|0)==2147483647){b=a+24|0;while(1){c=x[b+x[x[a>>2]-12>>2]>>2];x[23549]=0;c=R(90,c|0)|0;d=x[23549];x[23549]=0;d:{if((d|0)!=1){if(!qc(c,-1)){break d}break b}break c}x[a+4>>2]=x[a+4>>2]+1;continue}}if(x[a+4>>2]>=(b|0)){break a}c=a+24|0;e:{while(1){d=x[c+x[x[a>>2]-12>>2]>>2];x[23549]=0;d=R(90,d|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break e}if(qc(d,-1)){break b}d=x[a+4>>2]+1|0;x[a+4>>2]=d;if((b|0)>(d|0)){continue}break}c=0;break a}}Y(T(0)|0)|0;c=1;Bn(x[x[a>>2]-12>>2]+a|0,1);f:{g:{if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[23549]=0;X(91);a=x[23549];x[23549]=0;if((a|0)!=1){break f}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)==1){break g}Q(a|0);p()}Z();break a}T(0)|0;Rb()}p()}c=2}qj(x[x[a>>2]-12>>2]+a|0,c)}db=e+16|0;return a|0}function WB(a){var b=0,c=0,d=0,e=0,f=0,g=0;if((y[a|0]-16&255)>>>0>=241){e=a+1954|0;c=a+1698|0;a:{b:{while(1){if((c|0)==(e|0)){c=0;e=0;while(1){b=32;if((c|0)==32){break a}d=D(c,13)+a|0;if(y[d+14|0]){break b}b=(c<<4)+a|0;if(y[b+418|0]|y[b+419|0]<<8|(y[b+420|0]<<16|y[b+421|0]<<24)){break b}f=y[b+422|0]|y[b+423|0]<<8|(y[b+424|0]<<16|y[b+425|0]<<24);if(y[d+942|0]|f>>>0>1048575){break b}d=D(c,11)+a|0;g=d+1346|0;if(y[g|0]>15|y[d+1351|0]>3|y[d+1356|0]>3){break b}c:{d:{e:{if(f){d=y[b+430|0]|y[b+431|0]<<8|(y[b+432|0]<<16|y[b+433|0]<<24);if(d>>>0<=1048574&(d>>>0<(y[b+426|0]|y[b+427|0]<<8|(y[b+428|0]<<16|y[b+429|0]<<24))>>>0|d>>>0>f>>>0)){break b}b=1;if(e){break c}if(f){break d}break e}b=1;if(e){break c}}if(cd(g,26333,11)){break d}b=0;break c}b=1}e=b;c=c+1|0;continue}}b=v[c|0];c=c+1|0;if((b|0)>-2){continue}break}return 0}b=c}a=b>>>0>31&e}else{a=0}return a}function Xda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;g=db-16|0;db=g;f=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+72>>2];j=x[a+68>>2];s=j>>31;k=x[a+64>>2];t=k>>31;l=x[a+60>>2];u=l>>31;v=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){m=w[(x[g+12>>2]<<1)+q>>1]<<8;e=m;e=yka(e,e>>31,l,u);i=hb;h=e;e=Ub(b,-16777216,16776704);e=yka(k,t,e,e>>31);n=h+e|0;h=hb+i|0;h=e>>>0>n>>>0?h+1|0:h;f=Ub(f,-16777216,16776704);e=yka(j,s,f,f>>31);i=e+n|0;f=hb+h|0;f=e>>>0>i>>>0?f+1|0:f;e=i+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Lc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,o);Qb(g+8|0,v,y);e=e-(r&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;db=g+16|0}function v3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0);c=db+-64|0;db=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;xf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(he(x[c+24>>2],g)>>>0<d>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){a=0;if((b|0)==(d|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{j=Pg(i,f,a,b);k=px(h,g,a,b),l=E(C[j>>3]),B[k>>2]=l;a=a+1|0;continue}}}_(7130,8943,77,8623);p()}_(7095,8943,78,8623);p()}_(5838,8943,79,8623);p()}_(5808,8943,80,8623);p()}db=c- -64|0}function Ew(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;a:{if(b&3){while(1){c=y[b|0];if(!c|(c|0)==61){break a}b=b+1|0;if(b&3){continue}break}}c=x[b>>2];b:{if((c^-1)&c-16843009&-2139062144){break b}while(1){if((c^1027423549)-16843009&(c^-1)&-2139062144){break b}c=x[b+4>>2];b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}while(1){c=b;e=y[b|0];if((e|0)!=61){b=c+1|0;if(e){continue}}break}b=c}if((a|0)==(b|0)){return 0}g=b-a|0;c:{if(y[g+a|0]){break c}f=x[116846];if(!f){break c}b=x[f>>2];if(!b){break c}while(1){d:{c=a;e=b;i=0;h=g;d=0;e:{if(!g){break e}d=y[c|0];f:{if(!d){break f}while(1){g:{j=y[e|0];if((j|0)!=(d|0)|!j){break g}h=h-1|0;if(!h){break g}e=e+1|0;d=y[c+1|0];c=c+1|0;if(d){continue}break f}break}i=d}d=(i&255)-y[e|0]|0}if(!d){b=b+g|0;if(y[b|0]==61){break d}}b=x[f+4>>2];f=f+4|0;if(b){continue}break c}break}k=b+1|0}return k}function gP(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=db-16|0;db=g;b=x[a>>2];vb(g+12|0,b);a:{b:{c:{d:{e:{if(ud(x[b+16>>2])){while(1){if(c>>>0>31){break e}x[23549]=0;d=ca(42)|0;e=x[23549];x[23549]=0;if((e|0)!=1){f=d|f;c=c+32|0;continue}break}c=T(92880)|0;if((eb|0)!=($(92880)|0)){break c}Y(c|0)|0;v[b+20|0]=0;x[23549]=0;W(30,b|0);c=x[23549];x[23549]=0;if((c|0)==1){break d}Z();break e}v[b+20|0]=0}if(!y[b+20|0]){d=x[b+24>>2];b=0;c=1;while(1){if(c){c=0;b=x[d+2496>>2];e=d+(b<<2)|0;i=x[d+((b+397>>>0)%624<<2)>>2];h=(b+1>>>0)%624|0;b=x[d+(h<<2)>>2];b=i^(b&2147483647|x[e>>2]&-2147483648)>>>1^0-(b&1)&-1727483681;x[e>>2]=b;x[d+2496>>2]=h;b=b^b>>>11;b=b<<7&-1658038656^b;b=b<<15&-272236544^b;b=b>>>18^b;continue}break}f=b^f}db=g+16|0;break a}c=N()|0;x[23549]=0;X(17);a=x[23549];x[23549]=0;if((a|0)==1){break b}}Q(c|0);p()}T(0)|0;Rb();p()}return x[a+28>>2]&f}function Yda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0;g=db-16|0;db=g;f=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+72>>2];j=x[a+68>>2];s=j>>31;k=x[a+64>>2];t=k>>31;l=x[a+60>>2];u=l>>31;w=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){m=v[x[g+12>>2]+q|0]<<16;e=m;e=yka(e,e>>31,l,u);i=hb;h=e;e=Ub(b,-16777216,16776704);e=yka(k,t,e,e>>31);n=h+e|0;h=hb+i|0;h=e>>>0>n>>>0?h+1|0:h;f=Ub(f,-16777216,16776704);e=yka(j,s,f,f>>31);i=e+n|0;f=hb+h|0;f=e>>>0>i>>>0?f+1|0:f;e=i+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Lc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,o);Qb(g+8|0,w,y);e=e-(r&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;db=g+16|0}function Ip(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=db-16|0;db=c;a:{b:{switch(y[a+480224|0]-1|0){default:b=x[a+24620>>2];d=b>>31;x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2]<<1;e=yka(b,d,5e4,0);f=hb;b=x[Yc(c+8|0,c)>>2];b=Cc(zka(e,f,b,b>>31),hb);x[a+1074404>>2]=b;break a;case 1:b=x[a+24620>>2];x[c+8>>2]=1;x[c+12>>2]=0;g=c,h=yka(x[a+1074420>>2],0,yka(x[a+1074408>>2],0,x[a+1074416>>2],0),hb),x[g>>2]=h;x[c+4>>2]=hb;b=yka(b,0,6e5,0);d=c+8|0;f=b;e=hb;b=fv(x[d>>2],x[d+4>>2],x[c>>2],x[c+4>>2])?c:d;b=Bka(f,e,x[b>>2],x[b+4>>2]);x[a+1074404>>2]=b;break a;case 0:break b}}b=x[a+24620>>2];d=b>>31;x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2];e=yka(b,d,1e4,0);f=hb;b=x[Yc(c+8|0,c)>>2];b=Cc(zka(e,f,b,b>>31),hb);x[a+1074404>>2]=b}d=a+1074404|0;a=x[a+480244>>2];b=yka(a,a>>31,b,b>>31);a=hb;b=b+32768|0;a=b>>>0<32768?a+1|0:a;a=Cc(zka(b,a,65536,0),hb);x[d>>2]=a>>>0<=1?1:a;db=c+16|0}function Uca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=db-16|0;db=e;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];h=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=h;l=b+24|0;h=x[a+8>>2];m=x[a+12>>2];while(1){if(d){b=x[e+8>>2];n=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;o=w[b+14>>1];p=w[b+12>>1];q=w[b+10>>1];r=w[b+8>>1];s=w[b+6>>1];t=w[b+4>>1];u=w[b+2>>1];b=w[b>>1];g=0;while(1){if((g|0)!=2){f=g+n|0;x[(g<<2)+e>>2]=((((D(v[f+4|0],q)+D(v[f+2|0],r)|0)+D(v[f+6|0],p)|0)+D(v[f+8|0],o)<<8>>1)+(((D(v[f-4|0],u)+D(v[f-6|0],b)|0)+D(v[f-2|0],t)|0)+D(v[f|0],s)<<8>>1)|0)/16384;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i);Qb(e+8|0,h,m);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;db=e+16|0}function k3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);c=db+-64|0;db=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;xf(c+48|0,c+32|0,d);a=x[b+4>>2];e=x[a+8>>2];f=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;d=c+16|0;b=0;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=f>>>0){if(A[d+4>>2]<f>>>0){break d}if(A[c+8>>2]<e>>>0){break c}if(he(x[d+8>>2],x[d+12>>2])>>>0<e>>>0){break b}h=x[c>>2];e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{i=Pg(h,g,a,b);j=nx(d,a,b),k=E(C[i>>3]),B[j>>2]=k;a=a+1|0;continue}}}_(7130,8943,77,8623);p()}_(7095,8943,78,8623);p()}_(5838,8943,79,8623);p()}_(5808,8943,80,8623);p()}db=c- -64|0}function Paa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=db-32|0;db=d;e=Gb(d+20|0);a:{b:{c:{if(c>>>0<=63){break c}x[23549]=0;c=R(175,b|0)|0;f=x[23549];x[23549]=0;d:{if((f|0)!=1){x[d+16>>2]=c;if((c|0)>0){break d}x[23549]=0;O(54,a|0,21204)|0;a=x[23549];x[23549]=0;if((a|0)!=1){break b}}break a}x[23549]=0;c=R(188,b|0)|0;f=x[23549];x[23549]=0;if((f|0)!=1){g=d,h=Hh(c),x[g+12>>2]=h;c=x[qd(d+16|0,d+12|0)>>2];x[23549]=0;P(45,e|0,c|0);c=x[23549];x[23549]=0;if((c|0)!=1){break c}}break a}e:{while(1){f:{x[23549]=0;c=R(192,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break f}if(!c){break e}x[23549]=0;U(825,e|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=x[23549];x[23549]=0;if((c|0)!=1){continue}}break}break a}x[23549]=0;O(174,b|0,4)|0;b=x[23549];x[23549]=0;if((b|0)==1){break a}ad(a,e)}tb(e);db=d+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function Jha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(A[a+4>>2]<A[wb(a)>>2]){c=db-16|0;db=c;a=QV(c+4|0,a);PA(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+28;fc(a);db=c+16|0;return}h=db-32|0;db=h;c=wb(a);c=OV(h+12|0,PV(a,Fq(x[a>>2],x[a+4>>2])+1|0),Fq(x[a>>2],x[a+4>>2]),c);PA(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+28;g=db-16|0;db=g;e=wb(a);b=vb(g+12|0,x[a+4>>2]);i=vb(g+8|0,x[a>>2]);f=vb(g+4|0,x[c+4>>2]);d=x[b>>2];i=x[i>>2];b=db+-64|0;db=b;f=x[f>>2];x[b+56>>2]=f;x[b+60>>2]=d;x[b+52>>2]=f;e=rd(b+24|0,e,b+52|0,b+56|0);x[b+16>>2]=x[e+8>>2];f=x[e+4>>2];x[b+8>>2]=x[e>>2];x[b+12>>2]=f;Ke(b+36|0,b+8|0);while(1){if(sd(d,i)){PA(Cm(x[b+56>>2]),Cm(d));d=Cu(b+60|0);Cu(b+56|0);d=x[d>>2];continue}break}d=b+36|0;Je(d);e=x[b+56>>2];MV(d);db=b- -64|0;x[c+4>>2]=e;Pb(a,c+4|0);Pb(a+4|0,c+8|0);Pb(wb(a),kc(c));x[c>>2]=x[c+4>>2];db=g+16|0;NV(c);db=h+32|0}function Gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=db-16|0;db=e;n=x[a+16>>2];o=cg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);i=x[a+8>>2];j=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];k=x[a+128>>2];if(k){l=dg(i,j,k);m=hb;f=x[a+76>>2];Ff(b,g,bf(i,j,d),hb);h=hb>>>0>f>>>0?d:0}f=a+112|0;p=x[a+24>>2];q=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){g=x[e+4>>2];x[e+8>>2]=x[e>>2];x[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=g+n|0;b=k;while(1)if((b|0)<=0){Qb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Md(f,v[x[e+12>>2]+g|0]<<6);Ld(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=bg(f,o);x[c>>2]=x[c>>2]+D(b,q);x[c+4>>2]=x[c+4>>2]+D(b,p);Qb(e,i,j);c=c+8|0;continue a}else{Md(f,v[x[e+12>>2]+g|0]<<6);Ld(f,4);Qb(e+8|0,l,m);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;db=e+16|0}function gk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(A[a+4>>2]<A[wb(a)>>2]){c=db-16|0;db=c;a=QV(c+4|0,a);IB(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+28;fc(a);db=c+16|0;return}h=db-32|0;db=h;c=wb(a);c=OV(h+12|0,PV(a,Fq(x[a>>2],x[a+4>>2])+1|0),Fq(x[a>>2],x[a+4>>2]),c);IB(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+28;g=db-16|0;db=g;e=wb(a);b=vb(g+12|0,x[a+4>>2]);i=vb(g+8|0,x[a>>2]);f=vb(g+4|0,x[c+4>>2]);d=x[b>>2];i=x[i>>2];b=db+-64|0;db=b;f=x[f>>2];x[b+56>>2]=f;x[b+60>>2]=d;x[b+52>>2]=f;e=rd(b+24|0,e,b+52|0,b+56|0);x[b+16>>2]=x[e+8>>2];f=x[e+4>>2];x[b+8>>2]=x[e>>2];x[b+12>>2]=f;Ke(b+36|0,b+8|0);while(1){if(sd(d,i)){IB(Cm(x[b+56>>2]),Cm(d));d=Cu(b+60|0);Cu(b+56|0);d=x[d>>2];continue}break}d=b+36|0;Je(d);e=x[b+56>>2];MV(d);db=b- -64|0;x[c+4>>2]=e;Pb(a,c+4|0);Pb(a+4|0,c+8|0);Pb(wb(a),kc(c));x[c>>2]=x[c+4>>2];db=g+16|0;NV(c);db=h+32|0}function iv(a,b,c,d){var e=0,f=0,g=0,h=0;g=db-16|0;db=g;a:{if(!c){break a}if(d){b=ec(g+8|0,a,b);a=db-16|0;db=a;x[a+12>>2]=c;d=x[b+4>>2];b:{if(!d){d=x[b>>2];break b}c=32-d|0;x[a+8>>2]=c;e=x[b>>2];h=c;c=x[Cb(a+8|0,a+12|0)>>2];x[e>>2]=-1<<d&-1>>>h-c|x[e>>2];c=x[a+12>>2]-c|0;x[a+12>>2]=c;d=e+4|0;x[b>>2]=d}x[a+4>>2]=-1;e=d;d=c>>>5|0;cD(e,d,a+4|0);e=x[a+12>>2];c=c&-32;f=e-c|0;x[a+12>>2]=f;if((c|0)!=(e|0)){c=b;b=x[b>>2]+(d<<2)|0;x[c>>2]=b;x[b>>2]=x[b>>2]|-1>>>32-f}db=a+16|0;break a}b=ec(g,a,b);a=db-16|0;db=a;x[a+12>>2]=c;d=x[b+4>>2];c:{if(!d){d=x[b>>2];break c}e=32-d|0;x[a+8>>2]=e;c=x[b>>2];f=x[c>>2];h=e;e=x[Cb(a+8|0,a+12|0)>>2];x[c>>2]=(-1<<d&-1>>>h-e^-1)&f;f=x[a+12>>2];d=c+4|0;x[b>>2]=d;c=f-e|0}e=d;d=c>>>5|0;bD(e,d);c=c&31;x[a+12>>2]=c;if(c){e=b;b=x[b>>2]+(d<<2)|0;x[e>>2]=b;x[b>>2]=x[b>>2]&(-1>>>32-c^-1)}db=a+16|0}db=g+16|0}function UK(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=E(0),m=0,n=0,o=E(0);e=a+4208|0;j=E(E(B[xb(e,2)>>2]*E(2999.9990234375))+E(.0010000000474974513));l=E(B[xb(e,3)>>2]*E(.9980000257492065));f=-3e3/+E(j*E(A[x[a+16>>2]+24620>>2]));e=a+4272|0;c=Ej(10,f*+A[xb(e,4)>>2]);g=a+4232|0;n=xb(g,0),o=E(c),B[n>>2]=o;c=Ej(10,f*+A[xb(e,5)>>2]);n=xb(g,1),o=E(c),B[n>>2]=o;m=f*(1/+E(l+E(.0010000000474974513))+-1);c=0;while(1){if((d|0)==4){d=a+4208|0;f=Ej(10,+RK(B[xb(d,0)>>2])*.05);b=4/M(c)*f;c=Ej(10,+RK(B[xb(d,1)>>2])*.1);B[a+4228>>2]=b*M(c);B[a+4224>>2]=f*M(1-c)}else{h=x[xb(e,d)>>2];k=d>>>1|0;i=Ej(10,m*+(x[xb(e,d)>>2]+x[xb(e,k+4|0)>>2]>>>0));b=Ej(10,f*+(h>>>0));j=B[xb(g,k)>>2];h=d<<1;i=(1-i)*.5;n=xb(g,h+2|0),o=E(b*(1-i)),B[n>>2]=o;n=xb(g,h+3|0),o=E(b*i),B[n>>2]=o;b=b*+j;b=b*(b*(b*(b+1)+1)+1)+1;c=b*b+c;d=d+1|0;continue}break}}function _ea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;while(1){a:{g=c;if(!c){g=0;break a}c=g-1|0;if(!y[c+b|0]){continue}}break}b:{if((d|0)!=4){break b}c=0;while(1){if((c|0)==(g|0)){if((e|0)==(f|0)){d=2;if((e|0)==(h|0)){break b}}if(e){d=0;if(!f){break b}}d=e?3:f?1:3}else{c:{d:{e:{d=b+c|0;i=y[d|0];switch(i-10|0){case 0:break d;case 3:break e;default:break c}}e=e+1|0;break c}f=f+1|0}h=c?((i|0)==10&y[d-1|0]==13)+h|0:h;c=c+1|0;continue}break}}e=0;f=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){c=((f&y[b+c|0]==13)+c|0)+1|0;e=e+1|0;continue}break}Ze(a);Np(a,e);f=(d|0)==1?32:13;h=d&-3?13:32;d=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){f:{g:{h:{i:{e=v[b+c|0];switch(e-10|0){case 1:case 2:break f;case 0:break g;case 3:break h;default:break i}}if(e){break f}e=32;break f}c=c+d|0;e=f;break f}e=h}Lp(a,e);c=c+1|0;continue}break}}function HI(a,b,c,d){var e=0,f=E(0),g=0,h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=E(0),o=0;e=db-96|0;db=e;o=(d|0)>0?d:0;while(1){if((j|0)!=(o|0)){B[e+48>>2]=-B[a>>2];B[e>>2]=B[a+68>>2];d=0;while(1){if((d|0)!=4){i=(e+48|0)+(d<<3)|0;g=(d<<4)+a|0;h=B[g+4>>2];f=B[g+8>>2];B[i+4>>2]=h+f;k=d<<1;B[(8-k<<2)+e>>2]=h-f;h=B[g+16>>2];f=B[g+12>>2];B[(7-k<<2)+e>>2]=h-f;B[i+8>>2]=-E(h+f);d=d+1|0;continue}break}GI(e+48|0);GI(e);B[e+4>>2]=-B[e+4>>2];B[e+12>>2]=-B[e+12>>2];B[e+20>>2]=-B[e+20>>2];B[e+28>>2]=-B[e+28>>2];g=0;while(1){if((g|0)!=9){d=g<<2;i=d+b|0;h=B[i>>2];f=B[d+(e+48|0)>>2];l=B[d+70224>>2];m=B[d+70260>>2];n=B[d+e>>2];B[i>>2]=E(f*l)-E(m*n);i=a+d|0;d=c+d|0;f=E(E(f*m)+E(n*l));B[i>>2]=E(h*B[d>>2])-E(B[d+36>>2]*f);B[(17-g<<2)+a>>2]=E(h*B[d+36>>2])+E(f*B[d>>2]);g=g+1|0;continue}break}b=b+36|0;a=a+72|0;j=j+1|0;continue}break}db=e+96|0}function oB(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=db-16|0;db=h;f=wb(a);c=vb(h+12|0,x[a+4>>2]);g=vb(h+8|0,x[a>>2]);e=vb(h+4|0,x[b+4>>2]);d=x[c>>2];g=x[g>>2];c=db+-64|0;db=c;e=x[e>>2];x[c+56>>2]=e;x[c+60>>2]=d;x[c+52>>2]=e;f=rd(c+24|0,f,c+52|0,c+56|0);x[c+16>>2]=x[f+8>>2];e=x[f+4>>2];x[c+8>>2]=x[f>>2];x[c+12>>2]=e;Ke(c+36|0,c+8|0);while(1){if(sd(d,g)){rB(nB(x[c+56>>2]),nB(d));d=SU(c+60|0);SU(c+56|0);d=x[d>>2];continue}break}Je(c+36|0);i=x[c+56>>2];if(!y[c+48|0]){f=db-16|0;db=f;d=vb(f+12|0,x[x[c+44>>2]>>2]);j=x[vb(f+8|0,x[x[c+40>>2]>>2])>>2];g=db-16|0;db=g;d=x[d>>2];x[g+12>>2]=d;while(1){if(ai(d,j)){e=db-16|0;db=e;x[e+12>>2]=d;d=nB(x[yg(e+12|0)>>2]);db=e+16|0;ub(d);d=x[yg(g+12|0)>>2];continue}break}db=g+16|0;db=f+16|0}db=c- -64|0;x[b+4>>2]=i;Pb(a,b+4|0);Pb(a+4|0,b+8|0);Pb(wb(a),kc(b));x[b>>2]=x[b+4>>2];db=h+16|0}function nW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=db-16|0;db=e;nd(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=Nq(a+4|0,a);d=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=d;c=Nq(a+8|0,a);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+8>>2]=f;c=(y[a+15|0]|y[a+16|0]<<8)<<1;x[b+24>>2]=c;c=y[a+15|0]|y[a+16|0]<<8?c:16726;x[b+24>>2]=c;g=b,h=(D(Ru(v[a+17|0],y[a+14|0]<<28>>24),c)>>>0)/8363|0,x[g+24>>2]=h;v[e+15|0]=y[a+18|0];v[e+14|0]=127;g=b,h=(((y[Sb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[g+30>>1]=h;c=y[a+14|0];if(c>>>0>=16){w[b+34>>1]=32;w[b+28>>1]=c&240}c=y[a+19|0];if(c&4){w[b+34>>1]=z[b+34>>1]|1;c=y[a+19|0]}a:{if(!(c&8)|d>>>0>=f>>>0){break a}f=z[b+34>>1];d=f|2;w[b+34>>1]=d;c=y[a+19|0];if(c&16){d=f|6;w[b+34>>1]=d;c=y[a+19|0]}if(!(c&64)){break a}w[b+34>>1]=d|128}db=e+16|0}function OP(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=db-16|0;db=h;f=wb(a);c=vb(h+12|0,x[a+4>>2]);g=vb(h+8|0,x[a>>2]);e=vb(h+4|0,x[b+4>>2]);d=x[c>>2];g=x[g>>2];c=db+-64|0;db=c;e=x[e>>2];x[c+56>>2]=e;x[c+60>>2]=d;x[c+52>>2]=e;f=rd(c+24|0,f,c+52|0,c+56|0);x[c+16>>2]=x[f+8>>2];e=x[f+4>>2];x[c+8>>2]=x[f>>2];x[c+12>>2]=e;Ke(c+36|0,c+8|0);while(1){if(sd(d,g)){zz(Wj(x[c+56>>2]),Wj(d));d=po(c+60|0);po(c+56|0);d=x[d>>2];continue}break}Je(c+36|0);i=x[c+56>>2];if(!y[c+48|0]){f=db-16|0;db=f;d=vb(f+12|0,x[x[c+44>>2]>>2]);j=x[vb(f+8|0,x[x[c+40>>2]>>2])>>2];g=db-16|0;db=g;d=x[d>>2];x[g+12>>2]=d;while(1){if(ai(d,j)){e=db-16|0;db=e;x[e+12>>2]=d;d=Wj(x[Wp(e+12|0)>>2]);db=e+16|0;Tj(d);d=x[Wp(g+12|0)>>2];continue}break}db=g+16|0;db=f+16|0}db=c- -64|0;x[b+4>>2]=i;Pb(a,b+4|0);Pb(a+4|0,b+8|0);Pb(wb(a),kc(b));x[b>>2]=x[b+4>>2];db=h+16|0}function GD(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=db-16|0;db=h;f=wb(a);c=vb(h+12|0,x[a+4>>2]);g=vb(h+8|0,x[a>>2]);e=vb(h+4|0,x[b+4>>2]);d=x[c>>2];g=x[g>>2];c=db+-64|0;db=c;e=x[e>>2];x[c+56>>2]=e;x[c+60>>2]=d;x[c+52>>2]=e;f=rd(c+24|0,f,c+52|0,c+56|0);x[c+16>>2]=x[f+8>>2];e=x[f+4>>2];x[c+8>>2]=x[f>>2];x[c+12>>2]=e;Ke(c+36|0,c+8|0);while(1){if(sd(d,g)){vv(yh(x[c+56>>2]),yh(d));d=FD(c+60|0);FD(c+56|0);d=x[d>>2];continue}break}Je(c+36|0);i=x[c+56>>2];if(!y[c+48|0]){f=db-16|0;db=f;d=vb(f+12|0,x[x[c+44>>2]>>2]);j=x[vb(f+8|0,x[x[c+40>>2]>>2])>>2];g=db-16|0;db=g;d=x[d>>2];x[g+12>>2]=d;while(1){if(ai(d,j)){e=db-16|0;db=e;x[e+12>>2]=d;d=yh(x[ED(e+12|0)>>2]);db=e+16|0;Vo(d);d=x[ED(g+12|0)>>2];continue}break}db=g+16|0;db=f+16|0}db=c- -64|0;x[b+4>>2]=i;Pb(a,b+4|0);Pb(a+4|0,b+8|0);Pb(wb(a),kc(b));x[b>>2]=x[b+4>>2];db=h+16|0}function t4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=db+-64|0;db=e;a:{b:{if((b|0)>=0){d=x[a+24>>2];if(cj(Wb(x[d+484360>>2],y[d+484376|0]))>>>0>b>>>0){break b}}a=a+16|0;break a}d=0;c:{f=x[a+24>>2];g=x[f+484344>>2];i=x[f+484348>>2];h=z[_b(x[Wb(x[f+484360>>2],y[f+484376|0])>>2],b)>>1];if(!Gm(g,i,h)){break c}if((c|0)>=0){d=c;if((d|0)<x[Yb(g,h)+12>>2]){break c}}a=a+16|0;break a}w[f+1074448>>1]=b;c=f;f=b&65535;YM(c,f);c=x[a+24>>2];x[c+1074392>>2]=-2;x[c+1074428>>2]=d;g=y[a+64|0];b=e+24|0;w[b+4>>1]=0;v[b+6|0]=255;x[b+16>>2]=2;x[b>>2]=0;w[b+12>>1]=f;x[b+8>>2]=d;d=x[b+20>>2];x[e+16>>2]=x[b+16>>2];x[e+20>>2]=d;d=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=d;d=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=d;b=e+52|0;Wt(b,c,g?7:1,e);j=a,k=C[Wj(x[e+56>>2])>>3],C[j+16>>3]=k;vi(b);a=a+16|0}db=e- -64|0;return+C[a>>3]}function wM(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=db-16|0;db=k;v[k+15|0]=c;v[k+14|0]=12;ah(b,y[Sb(k+15|0,k+14|0)|0]);c=0;l=x[b>>2];m=x[b+4>>2];p=ne(l,m);while(1){if((c|0)==(p|0)){c=0;v[b+12|0]=0;a:{if(!(d&1)){break a}if(qc(l,m)){break a}c=1;v[b+12|0]=1}if(e>>>0<=11){if(d&2){c=c|4;v[b+12|0]=c}v[b+15|0]=e;v[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){v[b+12|0]=c|2}v[b+14|0]=g;v[b+13|0]=f}db=k+16|0}else{b:{c:{d:{switch(h|0){case 0:j=xb(l,c);i=(c<<2)+a|0;w[j>>1]=y[i+96|0]|y[i+97|0]<<8;i=i+98|0;break c;case 1:break d;default:break b}}j=xb(l,c);i=(c<<2)+a|0;w[j>>1]=y[i+144|0]|y[i+145|0]<<8;i=i+146|0}v[j+2|0]=y[i|0]}e:{if(!c){break e}i=xb(l,c);j=z[i>>1];n=xb(l,c-1|0);o=z[n>>1];if(j>>>0>255|j>>>0>=o>>>0){break e}j=j|o&65280;w[i>>1]=j;if(j>>>0>=z[n>>1]){break e}w[i>>1]=j+256}c=c+1|0;continue}break}}function xaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;nd(c,0);w[c+28>>1]=y[a+36|0]<<2;d=y[a+37|0];w[c+32>>1]=64;w[c+30>>1]=d<<2;x[c>>2]=y[a+40|0]|y[a+41|0]<<8|(y[a+42|0]<<16|y[a+43|0]<<24);x[c+4>>2]=y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24);x[c+8>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[c+24>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);d=y[b+151|0];if(d>>>0<=4){v[c+38|0]=y[d+42938|0]}d=y[b+152|0]|y[b+153|0]<<8;v[c+39|0]=d;e=(y[b+156|0]|y[b+157|0]<<8)>>>4|0;v[c+41|0]=e;b=(y[b+154|0]|y[b+155|0]<<8)>>>2|0;v[c+40|0]=b;if((b|e)&255){v[c+39|0]=d^-1}b=y[a+38|0]|y[a+39|0]<<8;if(b&4){w[c+34>>1]=z[c+34>>1]|1;b=y[a+38|0]|y[a+39|0]<<8}if(b&8){w[c+34>>1]=z[c+34>>1]|2;b=y[a+38|0]|y[a+39|0]<<8}if(b&16){w[c+34>>1]=z[c+34>>1]|4;b=y[a+38|0]|y[a+39|0]<<8}if(b&32){w[c+34>>1]=z[c+34>>1]|32}}function tda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=db-16|0;db=b;f=x[a+40>>2];g=x[a+36>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=e>>>21&2040;p=w[e+39942>>1];q=w[e+39940>>1];r=w[e+39938>>1];e=w[e+39936>>1];h=0;while(1){if((h|0)!=2){i=(h<<1)+o|0;x[(h<<2)+b>>2]=(((D(w[i>>1],r)+D(w[i-4>>1],e)|0)+D(w[i+4>>1],q)|0)+D(w[i+8>>1],p)|0)/16384;h=h+1|0;continue}break}g=g+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Qb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;db=b+16|0}function m$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=db-16|0;db=k;a:{if(a){a=wG(c);b:{if(b){b=k+4|0;Ck(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;Bk(b,a);break b}b=k+4|0;Jr(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;Fh(b,a)}Li(i,b);Ec(b);l=e,m=Qi(a),x[l>>2]=m;l=f,m=Ri(a),x[l>>2]=m;b=k+4|0;Mg(b,a);zb(g,b);tb(b);Gh(b,a);Li(h,b);Ec(b);a=Ak(a);break a}a=vG(c);c:{if(b){b=k+4|0;Ck(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;Bk(b,a);break c}b=k+4|0;Jr(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;Fh(b,a)}Li(i,b);Ec(b);l=e,m=Qi(a),x[l>>2]=m;l=f,m=Ri(a),x[l>>2]=m;b=k+4|0;Mg(b,a);zb(g,b);tb(b);Gh(b,a);Li(h,b);Ec(b);a=Ak(a)}x[j>>2]=a;db=k+16|0}function Saa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=db-48|0;db=b;e=32272;a=Nb(a);a:{while(1){b:{if((e|0)==32848){e=32848;break b}c=mc(b+40|0,x[e+8>>2]);f=x[b+44>>2];c:{if(!f){break c}d=x[a+4>>2];if(!qc(x[a>>2],d)){c=x[c>>2];d=mc(b+32|0,x[Gf(d)>>2]);g=x[d+4>>2];x[b+8>>2]=x[d>>2];x[b+12>>2]=g;if(!jA(c,f,b+8|0)){break c}}x[23549]=0;P(821,a|0,e+8|0);c=x[23549];x[23549]=0;if((c|0)==1){break a}}e=e+12|0;continue}break}d:{while(1){if((e|0)==32896){break d}c=mc(b+40|0,x[e+8>>2]);e:{f=x[b+44>>2];f:{if(!f){break f}d=x[a+4>>2];if(!qc(x[a>>2],d)){g=x[c>>2];d=mc(b+24|0,x[Gf(d)>>2]);h=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=h;if(!jA(g,f,b)){break f}}c=x[c>>2];x[23549]=0;x[b+20>>2]=c;P(822,a|0,b+20|0);c=x[23549];x[23549]=0;if((c|0)==1){break e}}e=e+12|0;continue}break}break a}db=b+48|0;return}b=N()|0;sc(a);Q(b|0);p()}function q$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=db-16|0;db=k;a:{if(a){a=BG(c);b:{if(b){b=k+4|0;Ck(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;Bk(b,a);break b}b=k+4|0;Jr(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;Fh(b,a)}zb(i,b);tb(b);l=e,m=Qi(a),v[l|0]=m;l=f,m=Ri(a),v[l|0]=m;b=k+4|0;Mg(b,a);zb(g,b);tb(b);Gh(b,a);zb(h,b);tb(b);a=Ak(a);break a}a=zG(c);c:{if(b){b=k+4|0;Ck(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;Bk(b,a);break c}b=k+4|0;Jr(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;Fh(b,a)}zb(i,b);tb(b);l=e,m=Qi(a),v[l|0]=m;l=f,m=Ri(a),v[l|0]=m;b=k+4|0;Mg(b,a);zb(g,b);tb(b);Gh(b,a);zb(h,b);tb(b);a=Ak(a)}x[j>>2]=a;db=k+16|0}function iba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=db-880|0;db=b;c=Vb(a,0,76);x[c+84>>2]=0;x[c+88>>2]=0;x[c+80>>2]=256;w[c+76>>1]=65535;x[c+92>>2]=0;x[c+96>>2]=0;v[c+100|0]=1;d=c+223848|0;e=c+616|0;a=e;while(1){a=LQ(a)+872|0;if((d|0)!=(a|0)){continue}break}d=Nb(d);g=Qy(c+223860|0);f=b+8|0;Vb(f,0,108);Qz(b+120|0,48e3);Vb(b+664|0,0,72);v[b+754|0]=0;w[b+752>>1]=65535;v[b+746|0]=0;w[b+744>>1]=65535;v[b+738|0]=0;w[b+736>>1]=65535;x[b+748>>2]=0;x[b+740>>2]=0;Vb(b+756|0,0,103);x[b+868>>2]=0;x[b+872>>2]=0;v[b+875|0]=0;v[b+876|0]=0;v[b+877|0]=0;v[b+878|0]=0;x[b+860>>2]=0;x[b+864>>2]=0;v[b+859|0]=y[b+859|0]&128;a=((e+223232|0)-e|0)/872|0;while(1){if((a|0)>0){a=a-1|0;e=Mp(e,f)+872|0;continue}break}x[23549]=0;P(496,d|0,32);a=x[23549];x[23549]=0;if((a|0)!=1){db=b+880|0;return c|0}a=N()|0;Op(g);bc(d);Q(a|0);p()}function UQ(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=db-16|0;db=g;m=x[a+20>>2];h=z[a+34>>1]&65;x[g+12>>2]=h;x[g+8>>2]=h^65;h=b;n=d+1298224|0;e=d+1074992|0;j=Zi(d);o=a+4|0;p=a+12|0;q=a+8|0;r=a+16|0;while(1){if((e|0)!=(n|0)){if(x[e+104>>2]==(a|0)){if(x[e+16>>2]){x[e+16>>2]=h}if(A[e+4>>2]>c>>>0){x[e>>2]=0;x[e+4>>2]=0}b=a;if(x[e+76>>2]){tc(e+76|0,c);b=x[e+104>>2]}f=x[e+88>>2];b=oD(f,b);i=x[(b?p:o)>>2];x[e+84>>2]=x[(b?r:q)>>2];x[e+80>>2]=i;b=f|x[g+12>>2];x[e+88>>2]=b;x[e+88>>2]=b&(x[g+8>>2]^-1);f=x[e+704>>2];b=x[a+24>>2];a:{if(!f|!b){break a}if(ym(x[d+480180>>2])){break a}i=yka(x[e+700>>2],0,j?b:f,0);f=j?f:b;k=i+(f>>>1|0)|0;l=hb;s=e,t=Qc(Bka(k,i>>>0>k>>>0?l+1|0:l,f,0),hb),x[s+700>>2]=t}x[e+704>>2]=b}e=e+872|0;continue}break}x[a>>2]=c;x[a+20>>2]=h;Ez(m);db=g+16|0}function K7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;b=ni(a,b,c,d);x[b+4260>>2]=0;x[b>>2]=46924;c=b+4960|0;e=b+4504|0;d=e;while(1){d=Nb(d)+24|0;if((d|0)!=(c|0)){continue}break}v[b+5046|0]=1;w[b+5044>>1]=0;a=b+4208|0;f=xb(a,0),g=1063675494,x[f>>2]=g;f=xb(a,1),g=1065185444,x[f>>2]=g;f=xb(a,2),g=0,x[f>>2]=g;f=xb(a,3),g=1032805417,x[f>>2]=g;f=xb(a,4),g=1053079357,x[f>>2]=g;f=xb(a,5),g=1059859440,x[f>>2]=g;f=xb(a,6),g=1047457519,x[f>>2]=g;f=xb(a,7),g=1062836634,x[f>>2]=g;f=xb(a,8),g=1038174126,x[f>>2]=g;f=xb(a,9),g=1065353216,x[f>>2]=g;f=xb(a,10),g=1065353216,x[f>>2]=g;f=xb(a,11),g=1048525618,x[f>>2]=g;f=xb(a,12),g=1059760811,x[f>>2]=g;x[23549]=0;P(878,b+44|0,2);a=x[23549];x[23549]=0;if((a|0)==1){a=N()|0;while(1){c=sc(c-24|0);if((e|0)!=(c|0)){continue}break}yf(b);Q(a|0);p()}mi(b);return b|0}function yt(a,b){var c=0,d=0,e=0,f=0;d=db-48|0;db=d;NQ(d+28|0,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);NQ(d+8|0,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);b=x[d+28>>2];b=Hb(y[b|0]|y[b+1|0]<<8);a=x[d+8>>2];a=Hb(y[a|0]|y[a+1|0]<<8);c=1;a:{if(b>>>0<a>>>0){break a}c=0;if(a>>>0<b>>>0){break a}b=x[d+32>>2];b=Hb(y[b|0]|y[b+1|0]<<8);a=x[d+12>>2];a=Hb(y[a|0]|y[a+1|0]<<8);c=1;b:{if(b>>>0<a>>>0){break b}c=0;if(a>>>0<b>>>0){break b}b=x[d+36>>2];b=Hb(y[b|0]|y[b+1|0]<<8);a=x[d+16>>2];a=Hb(y[a|0]|y[a+1|0]<<8);c=1;c:{if(b>>>0<a>>>0){break c}c=0;if(a>>>0<b>>>0){break c}b=x[d+44>>2];a=x[d+20>>2];f=x[d+24>>2];e=x[d+40>>2];e=Hb(y[e|0]|y[e+1|0]<<8)<<16>>16;a=Hb(y[a|0]|y[a+1|0]<<8)<<16>>16;c=1;d:{if((e|0)<(a|0)){break d}c=0;if((a|0)<(e|0)){break d}c=Hb(y[b|0]|y[b+1|0]<<8)>>>0<Hb(y[f|0]|y[f+1|0]<<8)>>>0}}}}a=c;db=d+48|0;return a}function WC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=db-16|0;db=e;x[23549]=0;f=O(12,e+8|0,466856)|0;c=x[23549];x[23549]=0;a:{b:{c:{if((c|0)!=1){d:{e:{if(!vd(y[f|0])){break e}c=Fm(e+4|0,466856);d=x[x[116714]-12>>2];g=x[d+466860>>2];x[23549]=0;d=d+466856|0;h=R(13,d|0)|0;i=x[23549];x[23549]=0;if((i|0)==1){break d}c=x[c>>2];x[23549]=0;b=a+b|0;a=ga(14,c|0,a|0,((g&176)==32?b:a)|0,b|0,d|0,h|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break d}if(a){break e}a=x[x[116714]-12>>2];x[23549]=0;P(15,a+466856|0,5);a=x[23549];x[23549]=0;if((a|0)!=1){break e}break d}jk(f);break b}a=T(0)|0;jk(f);break c}a=T(0)|0}Y(a|0)|0;a=x[x[116714]-12>>2];x[23549]=0;W(16,a+466856|0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z()}db=e+16|0;return}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)==1){T(0)|0;Rb();p()}Q(a|0);p()}function f3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=db-96|0;db=d;x[23549]=0;e=x[b+12>>2];x[d+40>>2]=x[b+8>>2];x[d+44>>2]=e;e=x[b+4>>2];x[d+32>>2]=x[b>>2];x[d+36>>2]=e;e=R(1058,d+32|0)|0;f=x[23549];x[23549]=0;if((f|0)!=1){a:{b:{if(e){x[23549]=0;P(1059,d+72|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){b=d+80|0;zv(b,x[d+72>>2],x[d+76>>2]);e=rg(d+88|0,b);f=rg(d- -64|0,c);g=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=g;e=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=e;Av(a,d+8|0,d);break b}break a}x[23549]=0;P(1060,d+72|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break a}b=d+80|0;zv(b,x[d+72>>2],x[d+76>>2]);e=rg(d+56|0,b);f=rg(d+48|0,c);g=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=g;e=x[f+4>>2];x[d+16>>2]=x[f>>2];x[d+20>>2]=e;Av(a,d+24|0,d+16|0)}fe(b);fe(d+72|0);fe(c);db=d+96|0;return}}a=N()|0;fe(c);Q(a|0);p()}function gn(a,b,c,d){var e=0,f=0;f=db-16|0;db=f;x[23549]=0;W(927,a|0);e=x[23549];x[23549]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){e=x[a+24>>2];x[23549]=0;P(d|0,f+4|0,e|0);d=x[23549];x[23549]=0;if((d|0)==1){break i}d=x[f+4>>2];e=Cd(d,x[f+8>>2]);if(e>>>0<2147483647){break h}d=ac(8);x[23549]=0;b=O(981,d|0,7327)|0;e=x[23549];x[23549]=0;if((e|0)==1){break g}x[23549]=0;S(105,b|0,92656,154);b=x[23549];x[23549]=0;if((b|0)!=1){break b}b=T(0)|0;break f}b=T(0)|0;break e}b=T(0)|0;break e}j:{if(!((b|0)<(e|0)&(b|0)>=0)){b=_f(21204);break j}b=_f(Mb($d(d,b)))}Yd(f+4|0);break d}b=T(0)|0;jc(d)}Yd(f+4|0)}Y(b|0)|0;b=0;x[23549]=0;V(914,c|0,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break c}Z()}db=f+16|0;return b}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){break a}T(0)|0;Rb()}p()}Q(a|0);p()}function SG(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=db-32|0;db=h;a:{b:{c:{if((b|0)!=(c|0)){j=x[23424];x[23424]=0;g=db-16|0;db=g;yd();e=db-16|0;db=e;f=db-16|0;db=f;Dw(f,b,h+28|0,2);k=x[f>>2];i=x[f+4>>2];b=x[f+12>>2];x[e+8>>2]=x[f+8>>2];x[e+12>>2]=b;x[e>>2]=k;x[e+4>>2]=i;db=f+16|0;i=x[e>>2];f=x[e+4>>2];b=x[e+12>>2];x[g+8>>2]=x[e+8>>2];x[g+12>>2]=b;x[g>>2]=i;x[g+4>>2]=f;db=e+16|0;f=x[g>>2];e=x[g+4>>2];b=x[g+12>>2];x[h+16>>2]=x[g+8>>2];x[h+20>>2]=b;x[h+8>>2]=f;x[h+12>>2]=e;db=g+16|0;g=x[h+16>>2];i=x[h+20>>2];e=x[h+8>>2];f=x[h+12>>2];b=x[23424];if(!b){break c}if(x[h+28>>2]!=(c|0)){break b}l=e;m=f;n=g;o=i;if((b|0)!=68){break a}break b}x[d>>2]=4;break a}x[23424]=j;if(x[h+28>>2]==(c|0)){break a}}x[d>>2]=4;e=l;f=m;g=n;i=o}x[a>>2]=e;x[a+4>>2]=f;x[a+8>>2]=g;x[a+12>>2]=i;db=h+32|0}function I6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=db-32|0;db=e;x[23549]=0;W(927,a|0);d=x[23549];x[23549]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}x[23549]=0;W(928,b|0);d=x[23549];x[23549]=0;if((d|0)==1){break g}x[23549]=0;W(928,c|0);d=x[23549];x[23549]=0;if((d|0)==1){break g}f=x[a+24>>2];x[23549]=0;d=O(54,e+20|0,b|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break g}x[23549]=0;c=O(54,e+8|0,c|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break f}x[23549]=0;V(943,f|0,d|0,c|0,1);b=x[23549];x[23549]=0;if((b|0)==1){break e}tb(c);tb(d);b=1;break b}b=T(0)|0;break c}b=T(0)|0;break d}b=T(0)|0;tb(c)}tb(d)}Y(b|0)|0;b=0;x[23549]=0;V(914,6350,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z()}db=e+32|0;return b|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function uda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=db-16|0;db=b;f=x[a+40>>2];g=x[a+36>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=e>>>21&2040;p=w[e+39942>>1];q=w[e+39940>>1];r=w[e+39938>>1];e=w[e+39936>>1];h=0;while(1){if((h|0)!=2){i=h+o|0;x[(h<<2)+b>>2]=(((D(v[i|0],r)+D(v[i-2|0],e)|0)+D(v[i+2|0],q)|0)+D(v[i+4|0],p)<<8)/16384;h=h+1|0;continue}break}g=g+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Qb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;db=b+16|0}function Rca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=db-16|0;db=e;g=x[a+40>>2];h=x[a+36>>2];j=x[a+16>>2];i=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=i;k=b+24|0;l=x[a+32>>2];m=x[a+28>>2];i=x[a+8>>2];n=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=(x[e+12>>2]<<1)+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=(((((D(w[f+4>>1],w[b+10>>1])+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/2|0)+((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)/2|0)|0)/16384|0;h=h+m|0;x[c>>2]=x[c>>2]+D(b,h>>12);g=g+l|0;x[c+4>>2]=x[c+4>>2]+D(b,g>>12);Qb(e+8|0,i,n);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;db=e+16|0}function yd(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;if(y[467668]){return x[116916]}c=db-32|0;db=c;a:{b:{while(1){e=(c+8|0)+(a<<2)|0;d=1<<a&2147483647;if(d|1){d=lH(a,d?13962:21204)}else{d=x[a<<2>>2]}x[e>>2]=d;if((d|0)==-1){break b}a=a+1|0;if((a|0)!=6){continue}break}if(!kH(0)){b=88784;if(!cd(c+8|0,88784,24)){break a}b=88808;if(!cd(c+8|0,88808,24)){break a}a=0;if(!y[467440]){while(1){f=(a<<2)+467392|0,g=lH(a,21204),x[f>>2]=g;a=a+1|0;if((a|0)!=6){continue}break}v[467440]=1;x[116854]=x[116848]}b=467392;if(!cd(c+8|0,467392,24)){break a}b=467416;if(!cd(c+8|0,467416,24)){break a}b=Nd(24);if(!b){break b}}a=x[c+12>>2];x[b>>2]=x[c+8>>2];x[b+4>>2]=a;a=x[c+28>>2];x[b+16>>2]=x[c+24>>2];x[b+20>>2]=a;a=x[c+20>>2];x[b+8>>2]=x[c+16>>2];x[b+12>>2]=a;break a}b=0}db=c+32|0;v[467668]=1;x[116916]=b;return b}function Xz(a,b){var c=0;c=db-16|0;db=c;a=dr(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(Jb(a,7,1),9,1),10,1),13,1),15,1),16,1),17,1),18,1),20,1),21,1),24,1),25,1),26,1),28,1),30,1),31,1),33,1),34,1),39,1),41,1),44,1),46,1),45,1),47,1),48,1),50,1),99,1),102,1),104,1),105,1),115,1);break a;case 1:zy(c,2);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;Of(a,107);break a;case 3:zy(c,4);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;Of(a,4);break a;case 2:break b;case 0:break c}}Jb(a,88,1);break a}zy(c,b);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b}db=c+16|0}function oia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=db-16|0;db=e;c=jf(a,c);ae(e,x[a+28>>2]);i=a;a:{if(!c){d=0;if(ed(a,5)){break a}}d=db-32|0;db=d;f=x[a+28>>2];Mf(f,d+30|0);b:{c:{d:{e:{a=z[d+30>>1];if(a>>>0>=4001){j=x[b+12>>2];a=db-16|0;db=a;g=d+4|0;h=Tb(a+4|0,15547);ad(g,h);tb(h);db=a+16|0;x[23549]=0;S(432,d+16|0,g|0,d+30|0);a=x[23549];x[23549]=0;if((a|0)==1){break e}a=x[j+1298464>>2];x[23549]=0;S(359,a|0,2,d+16|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}tb(d+16|0);Ab(d+4|0);a=4e3}Sf(jj(x[b>>2],0),a);b=jj(x[b>>2],0);k=d,l=yb(x[b>>2]),x[k+16>>2]=l;b=yb(x[b+4>>2]);break b}b=N()|0;break c}b=N()|0;tb(d+16|0)}Ab(d+4|0);Q(b|0);p()}while(1){a=x[d+16>>2];if(Kb(a,b)){Mf(f,d+4|0);w[a>>1]=z[d+4>>1];Se(d+16|0);continue}break}db=d+32|0;d=c}cf(i,d);db=e+16|0}function Ly(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=z[a+480188>>1];h=d>>>0<=256?256:d;f=x[a+1298300>>2];c=d;a:{while(1){if((c|0)!=(h|0)){e=D(c,872)+a|0;if(!x[e+1075068>>2]){if(!Pj(x[e+1075648>>2])|y[e+1075081|0]&24){break a}}if(y[e+1075081|0]&2){if(!ud(f)){break a}if(!LN(f,c&65535)){break a}}c=c+1|0;continue}break}g=8388608;if(b>>>0<=255){b=D(b,872)+a|0;if(!x[b+1075688>>2]){c=65535;if(x[b+1075068>>2]){break a}}g=x[b+1075680>>2]|x[b+1075672>>2]<<9}e=0;c=65535;while(1){if((d|0)==(h|0)){break a}b=D(d,872)+a|0;if(!(x[b+1075688>>2]?0:x[b+1075068>>2])){f=(x[b+1075680>>2]|x[b+1075672>>2]<<9)>>>(x[b+1075080>>2]>>>1&1)|0;b:{c:{if(f>>>0<g>>>0){b=x[b+1075716>>2];break c}if((f|0)!=(g|0)){break b}b=x[b+1075716>>2];if(e>>>0>=b>>>0){break b}}g=f;c=d;e=b}d=d+1|0;continue}break}c=d}return c&65535}function jd(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=x[a+112>>2];d=x[a+116>>2];i=!!(b|d);e=b;f=x[a+4>>2];h=x[a+44>>2];b=f-h|0;g=b;c=b+x[a+120>>2]|0;b=x[a+124>>2]+(b>>31)|0;a:{b=c>>>0<g>>>0?b+1|0:b;if(!(((b|0)>=(d|0)&c>>>0>=e>>>0|(b|0)>(d|0))&i)){i=Jw(a);if((i|0)>=0){break a}f=x[a+4>>2];h=x[a+44>>2]}x[a+112>>2]=-1;x[a+116>>2]=-1;x[a+104>>2]=f;g=c;c=h-f|0;d=g+c|0;b=(c>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=c>>>0>d>>>0?b+1|0:b;return-1}d=c+1|0;b=d?b:b+1|0;f=x[a+4>>2];h=x[a+8>>2];e=x[a+116>>2];g=e;c=x[a+112>>2];b:{if(!(e|c)){break b}e=c-d|0;c=g-(b+(c>>>0<d>>>0)|0)|0;j=h-f|0;g=j>>31;if((c|0)>=(g|0)&e>>>0>=j>>>0|(c|0)>(g|0)){break b}h=e+f|0}x[a+104>>2]=h;c=x[a+44>>2];e=c-f|0;d=e+d|0;b=(e>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=d>>>0<e>>>0?b+1|0:b;if(c>>>0>=f>>>0){v[f-1|0]=i}return i}function G9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{b:{if((wj(x[a>>2],x[a+4>>2])|0)==2){if((wj(x[a+12>>2],x[a+16>>2])|0)==(b|0)){break b}}x[23549]=0;P(880,a|0,2);c=x[23549];x[23549]=0;c:{if((c|0)==1){break c}x[23549]=0;P(880,a+12|0,b|0);c=x[23549];x[23549]=0;if((c|0)==1){break c}x[23549]=0;P(881,a+24|0,2);c=x[23549];x[23549]=0;if((c|0)==1){break c}x[23549]=0;P(881,a+36|0,b|0);c=x[23549];x[23549]=0;if((c|0)==1){break c}c=a;while(1)if((d|0)==2){a=0;while(1){if((a|0)==(b|0)){break b}d=$q(x[c+12>>2],a);f=xb(x[c+36>>2],a),g=d,x[f>>2]=g;a=a+1|0;continue}}else{e=$q(x[a>>2],d);f=xb(x[a+24>>2],d),g=e,x[f>>2]=g;d=d+1|0;continue}}b=T(92296)|0;if((eb|0)!=($(92296)|0)){break a}Y(b|0)|0;Dc(a);SL(a);b=a+12|0;Dc(b);SL(b);b=a+24|0;Dc(b);RL(b);a=a+36|0;Dc(a);RL(a);Z()}return}Q(b|0);p()}function dga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=db+-64|0;db=c;i=c,j=rf(a)>>>5|0,w[i+32>>1]=j;w[c+20>>1]=3999;d=z[Uc(c+32|0,c+20|0)>>1];w[b+480190>>1]=d;g=1;while(1){f=g&65535;if(d>>>0>=f>>>0){d=_j(b,f);e=c+32|0;Ut(a,e);nd(d,0);h=c+8|0;nj(h,2,e);e=c+20|0;Bc(e,h);zc(((f<<5)+b|0)+946304|0,e);tb(e);x[d+24>>2]=8287;i=c,j=Hb(y[c+60|0]|y[c+61|0]<<8),w[i+20>>1]=j;w[c+8>>1]=64;i=d,j=z[Uc(e,h)>>1]<<2,w[i+30>>1]=j;i=d,j=$b(y[c+52|0]|y[c+53|0]<<8|(y[c+54|0]<<16|y[c+55|0]<<24))&-2,x[i>>2]=j;e=Hb(y[c+62|0]|y[c+63|0]<<8);i=xb(d+68|0,0),j=e,x[i>>2]=j;e=Hb(y[c+56|0]|y[c+57|0]<<8);f=Hb(y[c+58|0]|y[c+59|0]<<8);a:{if(f>>>0<2){break a}f=e+f<<1;if(f>>>0>A[d>>2]){break a}x[d+16>>2]=f;x[d+12>>2]=e<<1;w[d+34>>1]=z[d+34>>1]|8}g=g+1|0;d=z[b+480190>>1];continue}break}db=c- -64|0}function X8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0);c=db-4112|0;db=c;h=ib[x[x[a>>2]+116>>2]](a)|0;if(!h){ib[x[x[a>>2]+120>>2]](a)}x[c+12>>2]=0;f=db-16|0;db=f;while(1){d=x[a+44>>2];if(wj(d,x[a+48>>2])>>>0<=e>>>0){db=f+16|0}else{x[f+12>>2]=0;d=$q(d,e);g=(d+2048|0)-d>>2;while(1){if((g|0)>0){B[d>>2]=B[f+12>>2];g=g-1|0;d=d+4|0;continue}break}e=e+1|0;continue}break}f=c+2064|0;a:while(1){if(b){x[c+8>>2]=b;tc(c+8|0,512);e=c+16|0;Cy(e);d=x[c+8>>2];ib[x[x[a>>2]+60>>2]](a,e,f,d);e=0;while(1)if((e|0)==(d|0)){b=b-d|0;continue a}else{g=(c+16|0)+(e<<2)|0;B[c+4>>2]=F(B[g>>2]);i=c,j=B[Lx(c+12|0,c+4|0)>>2],B[i+12>>2]=j;B[c+4>>2]=F(B[g+2048>>2]);i=c,j=B[Lx(c+12|0,c+4|0)>>2],B[i+12>>2]=j;e=e+1|0;continue}}break}if(!h){ib[x[x[a>>2]+124>>2]](a)}db=c+4112|0;return E(B[c+12>>2])}function MO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=db-16|0;db=g;c=vb(g+12|0,x[a+4>>2]);d=vb(g+8|0,x[a>>2]);e=x[vb(g+4|0,x[b+4>>2])>>2];h=db-16|0;db=h;j=h+8|0;f=db-32|0;db=f;Od(f+24|0,x[c>>2],x[d>>2]);k=f+16|0;c=x[f+24>>2];l=x[f+28>>2];d=db-16|0;db=d;x[d+8>>2]=e;x[d+12>>2]=c;while(1){if(sd(c,l)){c=JO(c);e=JO(x[d+8>>2]);i=y[c+3|0]|y[c+4|0]<<8|(y[c+5|0]<<16|y[c+6|0]<<24);v[e+3|0]=i;v[e+4|0]=i>>>8;v[e+5|0]=i>>>16;v[e+6|0]=i>>>24;c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[e|0]=c;v[e+1|0]=c>>>8;v[e+2|0]=c>>>16;v[e+3|0]=c>>>24;c=IO(d+12|0);IO(d+8|0);c=x[c>>2];continue}break}vc(k,c,d+8|0);db=d+16|0;c=x[f+16>>2];x[f+12>>2]=x[f+20>>2];vc(j,c,f+12|0);db=f+32|0;db=h+16|0;x[b+4>>2]=x[h+12>>2];Pb(a,b+4|0);Pb(a+4|0,b+8|0);Pb(wb(a),kc(b));x[b>>2]=x[b+4>>2];db=g+16|0}function Sca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=db-16|0;db=e;g=x[a+40>>2];h=x[a+36>>2];j=x[a+16>>2];i=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=i;k=b+24|0;l=x[a+32>>2];m=x[a+28>>2];i=x[a+8>>2];n=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=x[e+12>>2]+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=((((D(v[f+2|0],w[b+10>>1])+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8>>1)+(((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])<<8>>1)|0)/16384|0;h=h+m|0;x[c>>2]=x[c>>2]+D(b,h>>12);g=g+l|0;x[c+4>>2]=x[c+4>>2]+D(b,g>>12);Qb(e+8|0,i,n);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;db=e+16|0}function j8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=0,q=0,r=0,s=0;h=db-16|0;db=h;if(Yh(a+44|0)){g=x[a+44>>2];r=h,s=Ac(g,0),x[r+8>>2]=s;r=h,s=Ac(g,1),x[r+12>>2]=s;g=x[a+56>>2];l=Ac(g,0);x[h>>2]=l;m=Ac(g,1);x[h+4>>2]=m;p=y[a+4273|0];q=y[a+4272|0];g=d;while(1){k=0;if(g){while(1){if((k|0)!=2){j=k<<2;i=j+(h+8|0)|0;e=x[i>>2];x[i>>2]=e+4;f=E(B[e>>2]*B[a+4240>>2]);e=a+j|0;i=e+4228|0;f=E(f+E(B[i>>2]*B[a+4236>>2]));B[i>>2]=f;f=jL(E(f*E(1073741824)),q,p);i=e+4244|0;e=e+4252|0;n=B[e>>2];o=B[a+4264>>2];f=E(E(E(f*B[a+4260>>2])-E(B[a+4268>>2]*B[i>>2]))-E(n*o));B[e>>2]=f;B[i>>2]=n+E(f*o);e=h+j|0;j=x[e>>2];x[e>>2]=j+4;B[j>>2]=f*E(9.313225746154785e-10);k=k+1|0;continue}break}g=g-1|0;continue}else{li(a,b,c,l,m,d)}break}}db=h+16|0}function UL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=db-16|0;db=e;if(!(oc(x[a>>2],x[a+4>>2])>>>0>511|x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){d=db-16|0;db=d;f=Hc(64);x[23549]=0;g=R(812,f|0)|0;h=x[23549];x[23549]=0;a:{b:{if((h|0)!=1){f=of(d+8|0,g);g=x[f>>2];x[23549]=0;g=U(875,g|0,b|0,c|0)|0;h=x[23549];x[23549]=0;c:{d:{if((h|0)!=1){if((g|0)==1){break d}xc(d+12|0);break c}a=N()|0;Lf(f);break b}Vf(d+12|0,f)}Lf(f);db=d+16|0;d=x[d+12>>2];break a}a=N()|0;Eb(f)}Q(a|0);p()}x[e+12>>2]=d;e:{f:{if(!ud(d)){x[23549]=0;b=O(874,b|0,c|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break f}x[e+8>>2]=b;b=e+8|0;gU(e+12|0,Zd(b));Lf(b);d=x[e+12>>2]}if(!ud(d)){break e}x[23549]=0;P(441,a|0,e+12|0);a=x[23549];x[23549]=0;i=d;if((a|0)!=1){break e}}a=N()|0;Lf(e+12|0);Q(a|0);p()}Lf(e+12|0)}db=e+16|0;return i}function $n(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=x[b+88>>2];d=c|2048;x[b+88>>2]=d;f=x[b+656>>2];if(!(!f|v[b+730|0]&1)){d=c|6144;x[b+88>>2]=d}a:{if(!x[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=x[b+104>>2];if(!c){break b}e=z[c+34>>1];if(e&2){d=(e&4?d|4:d&-135)|2;x[b+88>>2]=d;e=x[c>>2];x[b+76>>2]=e;g=x[c+4>>2];x[b+80>>2]=g;c=x[c+8>>2];x[b+84>>2]=c;if(c>>>0<e>>>0){x[b+76>>2]=c;h=c}else{h=e}e=x[b+4>>2];if(h>>>0>=e>>>0){break b}x[b>>2]=0;x[b+4>>2]=((e-g>>>0)%(c-g>>>0)|0)+g;break b}d=d&-135;x[b+88>>2]=d;x[b+76>>2]=x[c>>2]}if(!f){break a}if(!(!(y[f+60|0]&2|x[a+480180>>2]&1064964)|!x[f>>2])){x[b+88>>2]=d|4096}if(y[f+65|0]==255|z[b+728>>1]!=65535){break a}i=b,j=Sc(Xp(f+48|0,x[b+724>>2],256,64)),w[i+728>>1]=j;i=b,j=z[xb(x[f+48>>2],y[f+65|0])>>1],x[i+724>>2]=j}}function zp(a){var b=E(0),c=0,d=0,e=0,f=0;c=db-16|0;db=c;e=(q(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=E(1);if(d>>>0<964689920){break a}b=bi(+a);break a}if(d>>>0<=1081824209){if(d>>>0>=1075235812){b=E(-bi(((e|0)<0?3.141592653589793:-3.141592653589793)+ +a));break a}f=+a;if((e|0)<0){b=ci(f+1.5707963267948966);break a}b=ci(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=bi(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if((e|0)<0){b=ci(-4.71238898038469-+a);break a}b=ci(+a+-4.71238898038469);break a}b=E(a-a);if(d>>>0>=2139095040){break a}b:{switch(Xw(a,c+8|0)&3){case 0:b=bi(C[c+8>>3]);break a;case 1:b=ci(-C[c+8>>3]);break a;case 2:b=E(-bi(C[c+8>>3]));break a;default:break b}}b=ci(C[c+8>>3])}a=b;db=c+16|0;return a}function Xp(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=db-16|0;db=h;a:{e=x[a>>2];f=x[a+4>>2];if(qc(e,f)){break a}i=ne(e,f)-1|0;while(1){b:{if(ne(e,f)-1>>>0>g>>>0){j=Fc(e,f,g);f=x[a+4>>2];e=x[a>>2];if(z[j>>1]<(b|0)){break b}i=g}g=z[Fc(e,f,i)>>1];f=0;x[h+12>>2]=0;c:{if((b|0)>=(g|0)){k=h,l=(y[Fc(x[a>>2],x[a+4>>2],i)+2|0]<<16>>>0)/(d>>>0)|0,x[k+12>>2]=l;break c}e=0;if(i){e=i-1|0;f=(y[Fc(x[a>>2],x[a+4>>2],e)+2|0]<<16>>>0)/(d>>>0)|0;x[h+12>>2]=f;e=z[Fc(x[a>>2],x[a+4>>2],e)>>1]}if((b|0)<=(e|0)|e>>>0>=g>>>0){break c}a=((y[Fc(x[a>>2],x[a+4>>2],i)+2|0]<<16>>>0)/(d>>>0)|0)-f|0;d=a;i=a>>31;a=b-e|0;b=yka(d,i,a,a>>31);a=g-e|0;k=h,l=Cc(zka(b,hb,a,a>>31),hb)+f|0,x[k+12>>2]=l}ke(h+12|0,0,65536);g=(D(x[h+12>>2],c)+32768|0)/65536|0;break a}g=g+1|0;continue}}db=h+16|0;return g}function rF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=db-32|0;db=d;x[23549]=0;W(927,a|0);e=x[23549];x[23549]=0;a:{b:{c:{if((e|0)!=1){e=Gb(d+20|0);x[23549]=0;W(c|0,d+8|0);c=x[23549];x[23549]=0;d:{e:{if((c|0)!=1){h=d,i=yb(x[d+8>>2]),x[h+4>>2]=i;f=1;while(1){g=yb(x[d+12>>2]);c=x[d+4>>2];if(!Kb(c,g)){c=_f(Mb(e));Yd(d+8|0);tb(e);break b}if(!f){x[23549]=0;O(916,e|0,14279)|0;c=x[23549];x[23549]=0;if((c|0)==1){break e}c=x[d+4>>2]}x[23549]=0;O(777,e|0,c|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break e}Bj(d+4|0);f=0;continue}}c=T(0)|0;break d}c=T(0)|0;Yd(d+8|0)}tb(e);break c}c=T(0)|0}Y(c|0)|0;c=0;x[23549]=0;V(914,b|0,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z()}db=d+32|0;return c}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)==1){T(0)|0;Rb();p()}Q(a|0);p()}function h2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=db-32|0;db=c;x[c+28>>2]=0;if(vd(y[Cn(c+27|0,a,0)|0])){Nc(c+16|0,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[23549]=0;e=R(1078,x[c+16>>2])|0;d=x[23549];x[23549]=0;a:{b:{if((d|0)!=1){d=Fm(c+12|0,a);f=xc(c+8|0);g=x[x[a>>2]-12>>2];f=x[f>>2];d=x[d>>2];x[23549]=0;ia(1080,e|0,d|0,f|0,a+g|0,c+28|0,c+20|0);e=x[23549];x[23549]=0;if((e|0)!=1){break b}}b=T(0)|0;Xb(c+16|0);Y(b|0)|0;b=x[c+28>>2]|1;x[c+28>>2]=b;Bn(x[x[a>>2]-12>>2]+a|0,b);c:{d:{if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[23549]=0;X(91);a=x[23549];x[23549]=0;if((a|0)!=1){break c}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)==1){break d}Q(a|0);p()}Z();break a}T(0)|0;Rb()}p()}Xb(c+16|0);x[b>>2]=x[c+20>>2]}qj(x[x[a>>2]-12>>2]+a|0,x[c+28>>2])}db=c+32|0;return a|0}function SJ(a,b){var c=0,d=0,e=0;x[a+4>>2]=b;x[a>>2]=94240;x[a+8>>2]=b;e=(b|0)!=0;x[a+12>>2]=e;c=b&31;if((b&63)>>>0>=32){c=-1<<c}else{c=(1<<c)-1&-1>>>32-c|-1<<c}x[a+24>>2]=0;c=c&65536;x[a+28>>2]=c;d=c^65536;a:{if((c|0)==(d|0)|c>>>0>d>>>0){c=b;break a}c=b>>>e|0;x[a+8>>2]=c;e=b?2:1;x[a+12>>2]=e;d=c&31;if((c&63)>>>0>=32){d=-1<<d}else{d=(1<<d)-1&-1>>>32-d|-1<<d}x[a+24>>2]=0;x[a+28>>2]=d&65536}x[a+16>>2]=e-((b>>>0)%(e>>>0)|0);d=63-c|0;b=d&31;if((d&63)>>>0>=32){d=0;b=-1>>>b|0}else{d=-1>>>b|0;b=d|(1<<b)-1<<32-b}x[a+48>>2]=b;x[a+52>>2]=d;d=64-c|0;b=d&31;if((d&63)>>>0>=32){d=0;b=-1>>>b|0}else{d=-1>>>b|0;b=d|(1<<b)-1<<32-b}x[a+40>>2]=c?b:0;x[a+44>>2]=c?d:0;c=c+1|0;b=c&31;if((c&63)>>>0>=32){c=-1<<b}else{c=(1<<b)-1&-1>>>32-b|-1<<b}x[a+32>>2]=0;x[a+36>>2]=c&65536;return a}function S3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=db-16|0;db=d;j=d,k=jK(),x[j+12>>2]=k;g=a+24|0;c=d+12|0;hK(g,Zd(c));Xi(c);w[a+28>>1]=0;MP();f=db-16|0;db=f;e=Hc(144);x[23549]=0;h=O(1042,e|0,4)|0;i=x[23549];x[23549]=0;a:{if((i|0)!=1){e=x[of(f+12|0,h)>>2];db=f+16|0;break a}a=N()|0;Eb(e);Q(a|0);p()}x[d+12>>2]=e;gK(a+32|0,Zd(c));us(c);j=d,k=iK(x[a>>2]),x[j+12>>2]=k;fK(a+4|0,Zd(c));Wi(c);Kn(x[g>>2],x[a+4>>2]);x[a+60>>2]=0;x[a+48>>2]=1065353216;x[a+52>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;v[a- -64|0]=0;j=d,k=kj(x[b>>2]),x[j+12>>2]=k;e=Bf(b);b:{while(1){b=x[d+12>>2];if(!xg(b,e)){break b}c=td(b);b=qg(d,c);x[23549]=0;V(943,a|0,b|0,c+12|0,0);c=x[23549];x[23549]=0;if((c|0)!=1){tb(b);Vg(d+12|0);continue}break}a=N()|0;tb(b);Q(a|0);p()}db=d+16|0}function KK(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=db-48|0;db=j;k=x[a+4>>2];l=x[a>>2];a=x[a+8>>2];x[j+32>>2]=b;x[j+44>>2]=a;x[j+36>>2]=l;x[j+40>>2]=k;x[23549]=0;a=O(907,(d?d:908)|0,e|0)|0;b=x[23549];x[23549]=0;a:{b:{c:{d:{if((b|0)!=1){x[j+24>>2]=a;a=x[Vf(j+28|0,j+24|0)>>2];b=x[j+44>>2];x[j+16>>2]=x[j+40>>2];x[j+20>>2]=b;x[23549]=0;b=x[j+36>>2];x[j+8>>2]=x[j+32>>2];x[j+12>>2]=b;c=+ta(909,j+8|0,+c,a|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}xe(j+24|0);break b}a=T(0)|0;break c}a=T(0)|0;xe(j+24|0)}Y(a|0)|0;x[23549]=0;ea(910,14706,d|0,e|0,f|0,g|0,h|0,i|0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();c=0}db=j+48|0;return+c}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function nX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;g=db-16|0;db=g;Vc(b,y[c+32|0]|y[c+33|0]<<8|(y[c+34|0]<<16|y[c+35|0]<<24));h=Nb(a);a=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);x[23549]=0;P(170,h|0,a|0);a=x[23549];x[23549]=0;if((a|0)!=1){a:{a=0;while(1){b:{if((y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24))>>>0<=a>>>0){break b}e=x[b+8>>2];f=x[b>>2];x[23549]=0;e=U(142,f|0,e|0,4)|0;f=x[23549];x[23549]=0;if((f|0)==1){break a}if(!e){break b}e=y[c+4|0]|y[c+5|0]<<8;x[23549]=0;e=O(171,b|0,e|0)|0;f=x[23549];x[23549]=0;c:{if((f|0)!=1){x[g+12>>2]=e;if(Cd(x[d>>2],x[d+4>>2])>>>0<=e>>>0){break c}x[23549]=0;P(172,h|0,g+12|0);e=x[23549];x[23549]=0;if((e|0)!=1){break c}}break a}a=a+1|0;continue}break}db=g+16|0;return}}a=N()|0;sc(h);Q(a|0);p()}function FL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=db-16|0;db=c;e=x[b+4220>>2];f=x[b+4224>>2];g=x[b+4228>>2];h=x[b+4232>>2];i=x[b+4240>>2];j=x[b+4236>>2];k=y[b+4244|0];Ji(b+4208|0,33);d=x[b+4208>>2];v[d+32|0]=k;v[d+24|0]=j;v[d+25|0]=j>>>8;v[d+26|0]=j>>>16;v[d+27|0]=j>>>24;v[d+28|0]=i;v[d+29|0]=i>>>8;v[d+30|0]=i>>>16;v[d+31|0]=i>>>24;v[d+16|0]=g;v[d+17|0]=g>>>8;v[d+18|0]=g>>>16;v[d+19|0]=g>>>24;v[d+20|0]=h;v[d+21|0]=h>>>8;v[d+22|0]=h>>>16;v[d+23|0]=h>>>24;v[d+8|0]=e;v[d+9|0]=e>>>8;v[d+10|0]=e>>>16;v[d+11|0]=e>>>24;v[d+12|0]=f;v[d+13|0]=f>>>8;v[d+14|0]=f>>>16;v[d+15|0]=f>>>24;v[d|0]=76;v[d+1|0]=70;v[d+2|0]=79;v[d+3|0]=32;v[d+4|0]=0;v[d+5|0]=0;v[d+6|0]=0;v[d+7|0]=0;ge(c+8|0,x[b+4208>>2],x[b+4212>>2]);ec(a,x[c+8>>2],x[c+12>>2]);db=c+16|0}function Ov(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;h=db-16|0;db=h;e=wb(a);c=vb(h+12|0,x[a+4>>2]);f=vb(h+8|0,x[a>>2]);g=vb(h+4|0,x[b+4>>2]);d=x[c>>2];f=x[f>>2];c=db+-64|0;db=c;g=x[g>>2];x[c+56>>2]=g;x[c+60>>2]=d;x[c+52>>2]=g;e=rd(c+24|0,e,c+52|0,c+56|0);x[c+16>>2]=x[e+8>>2];g=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=g;Ke(c+36|0,c+8|0);while(1){if(sd(d,f)){xr(dh(x[c+56>>2]),dh(d));d=Cj(c+60|0);Cj(c+56|0);d=x[d>>2];continue}break}Je(c+36|0);g=x[c+56>>2];if(!y[c+48|0]){e=db-16|0;db=e;d=vb(e+12|0,x[x[c+44>>2]>>2]);i=x[vb(e+8|0,x[x[c+40>>2]>>2])>>2];f=db-16|0;db=f;d=x[d>>2];x[f+12>>2]=d;while(1){if(ai(d,i)){Ab(Mv(d));d=x[Bj(f+12|0)>>2];continue}break}db=f+16|0;db=e+16|0}db=c- -64|0;x[b+4>>2]=g;Pb(a,b+4|0);Pb(a+4|0,b+8|0);Pb(wb(a),kc(b));x[b>>2]=x[b+4>>2];db=h+16|0}function nL(a){var b=0,c=0,d=0,e=0;b=db-16|0;db=b;e=(q(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=ci(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<0){a=E(-bi(d+1.5707963267948966));break a}a=bi(d+-1.5707963267948966);break a}a=ci(-(((e|0)>=0?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){if(c>>>0<=1085271519){d=+a;if((e|0)<0){a=bi(d+4.71238898038469);break a}a=E(-bi(d+-4.71238898038469));break a}a=ci(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if(c>>>0>=2139095040){a=E(a-a);break a}b:{switch(Xw(a,b+8|0)&3){case 0:a=ci(C[b+8>>3]);break a;case 1:a=bi(C[b+8>>3]);break a;case 2:a=ci(-C[b+8>>3]);break a;default:break b}}a=E(-bi(C[b+8>>3]))}db=b+16|0;return a}function fha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=db-16|0;db=e;v[e+15|0]=0;w[e+12>>1]=0;j=8;n=D(c,d)<<1;a:while(1){if((d|0)!=(k|0)){h=(k<<1)+b|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){w[e+10>>1]=0;YS(a,e+15|0,e+12|0,j,e+10|0);i=z[e+10>>1];f=z[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!ef(a,e+9|0)){break c}f=y[e+9|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}w[e+12>>1]=f;break b}k=k+1|0;continue a}w[e+12>>1]=0}c=1;g=i&65535;e:{if(g>>>0<4){break e}f=15;while(1){c=f;m=f&255;if(m>>>0<2){break e}f=c-1|0;if(!(g&1<<m)){continue}break}}f=i&1;v[e+15|0]=f;l=(f-1^(i&65534)>>>1)+l|0;w[e+10>>1]=l;w[h>>1]=l;h=(d<<1)+h|0;j=(c+j&254)>>>1|0;continue}}break}db=e+16|0}function GI(a){var b=E(0),c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),j=E(0),k=E(0),l=E(0),m=E(0),n=E(0),o=E(0);f=B[a>>2];i=B[a+24>>2];c=E(f-i);d=B[a+16>>2];b=B[a+32>>2];g=B[a+8>>2];e=E(d+E(b-g));B[a+16>>2]=c+e;j=E(c-E(e*E(.5)));c=B[a+4>>2];e=B[a+20>>2];h=B[a+28>>2];k=E(E(E(c-e)-h)*E(.8660253882408142));B[a+4>>2]=j+k;l=E(E(d-b)*E(.1736481785774231));f=E(f+E(i*E(.5)));i=E(E(g+b)*E(.7660444378852844));m=E(l+E(f-i));n=E(E(c+e)*E(.9848077297210693));b=E(B[a+12>>2]*E(.8660253882408142));c=E(E(c+h)*E(.6427876353263855));o=E(E(n-b)-c);B[a+12>>2]=m+o;B[a+20>>2]=m-o;B[a+28>>2]=j-k;d=E(E(g+d)*E(.9396926164627075));g=E(E(f+d)-l);e=E(E(e-h)*E(.3420201539993286));h=E(E(e-b)-n);B[a+32>>2]=g+h;d=E(E(f-d)+i);b=E(E(b+e)-c);B[a+24>>2]=d+b;B[a+8>>2]=d-b;B[a>>2]=g-h}function Bea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=db-80|0;db=c;a:{d=x[a+4>>2];b:{if(d>>>0<b>>>0){f=Xd(c+72|0);e=b-d|0;g=wt(a);c:{if(!(e>>>0>g>>>0|d>>>0>g-e>>>0)){bq(c+60|0,x[a>>2],d);ec(f,x[c+60>>2],x[c+64>>2]);x[a+4>>2]=x[a+4>>2]+e;break c}d=oo(c+60|0);x[23549]=0;b=O(698,a|0,b|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break a}x[23549]=0;P(699,d|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break a}x[d+4>>2]=x[a+4>>2]+e;tm(c+44|0,x[a>>2]);bq(c+32|0,x[a>>2],x[a+4>>2]);tm(c+24|0,x[d>>2]);b=x[c+48>>2];x[c+8>>2]=x[c+44>>2];x[c+12>>2]=b;VR(c+52|0,c+8|0,x[c+32>>2],x[c+36>>2],x[c+24>>2],x[c+28>>2]);ec(f,x[c+52>>2],x[c+56>>2]);Dt(a,d);He(d)}a=ec(c+16|0,x[f>>2],x[f+4>>2]);iv(x[a>>2],x[a+4>>2],e,0);break b}x[a+4>>2]=b}db=c+80|0;return}a=N()|0;He(d);Q(a|0);p()}function Wy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{f=a+1074312|0;if(j=Ob(f,77),k=0,l=x[(D(c,872)+b|0)+704>>2]&134218752,l?j:k){break a}g=x[a+480180>>2]!=2?c:0;e=D(g,872);if(!d){x[(b+e|0)+1380>>2]=x[b+48>>2];return}h=(b+e|0)+1457|0;c=y[h|0];b:{if(c){c=c-1|0;v[h|0]=c;if(c&255){break b}if(!Ob(f,16)&x[a+480180>>2]!=2){break a}x[(D(g,872)+b|0)+1380>>2]=x[b+48>>2]+1;return}c:{if(Ob(f,17)|y[a+480180|0]&3){break c}c=b+616|0;i=e+c|0;e=0;a=z[a+480188>>1];while(1){if(a>>>0<=(e&65535)>>>0){break c}if(y[c+841|0]?(c|0)!=(i|0):0){break a}c=c+872|0;e=e+1|0;continue}}v[h|0]=d}a=x[(D(g,872)+b|0)+1380>>2];x[b+56>>2]=a;if((a|0)==-1){break a}d:{if(x[b+60>>2]==-1){break d}if(!Ob(f,68)){break d}x[b+60>>2]=a}x[b+64>>2]=a;if(!Ob(f,103)){break a}w[b+68>>1]=65535}}function Tk(a,b,c){var d=0,e=0,f=0,g=0;e=db-48|0;db=e;d=x[a+24>>2];g=x[d+24620>>2];a:{if(!((g|0)!=(b|0)|x[d+24624>>2]!=(c|0))){if(y[a+29|0]){break a}OM(d,1);break a}f=e+8|0;rc(f,d+24604|0,40);x[e+28>>2]=c;x[e+24>>2]=b;c=x[e+44>>2];vs(f,x[e+40>>2]);io(f,c);vy(d,f);if((b|0)==(g|0)){break a}b=x[a+24>>2];d=b+946300|0;c=b+906300|0;while(1){if((c|0)!=(d|0)){b=x[c>>2];b:{if(!b){break b}if(!(ib[x[x[b>>2]+116>>2]](b)|0)){break b}ib[x[x[b>>2]+108>>2]](b,0);ib[x[x[b>>2]+96>>2]](b);ib[x[x[b>>2]+124>>2]](b)}c=c+160|0;continue}break}b=x[a+24>>2];d=b+946300|0;c=b+906300|0;while(1){if((c|0)!=(d|0)){b=x[c>>2];c:{if(!b){break c}if(ib[x[x[b>>2]+116>>2]](b)|0){break c}ib[x[x[b>>2]+108>>2]](b,1);ib[x[x[b>>2]+120>>2]](b)}c=c+160|0;continue}break}}v[a+29|0]=1;db=e+48|0}function Dr(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=db-32|0;db=d;x[d+28>>2]=0;a:{b:{c:{if(vd(y[Cn(d+27|0,a,0)|0])){Nc(d+20|0,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[23549]=0;g=R(1078,x[d+20>>2])|0;e=x[23549];x[23549]=0;d:{e:{if((e|0)==1){break e}e=Fm(d+16|0,a);f=xc(d+12|0);h=x[x[a>>2]-12>>2];f=x[f>>2];e=x[e>>2];x[23549]=0;ia(c|0,g|0,e|0,f|0,a+h|0,d+28|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break e}Xb(d+20|0);break d}b=T(0)|0;Xb(d+20|0);Y(b|0)|0;b=x[d+28>>2]|1;x[d+28>>2]=b;Bn(x[x[a>>2]-12>>2]+a|0,b);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[23549]=0;X(91);a=x[23549];x[23549]=0;if((a|0)!=1){break b}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)==1){break c}Q(a|0);p()}Z()}qj(x[x[a>>2]-12>>2]+a|0,x[d+28>>2])}db=d+32|0;break a}T(0)|0;Rb()}p()}return a}function FS(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;while(1){if((c|0)!=20){g=b;b=v[a+c|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b;a:{if(b>>>0>5){break a}while(1){if((h|0)!=15){e=D(h,30)+a|0;f=e+20|0;c=0;b=0;while(1){if((c|0)!=22){g=b;b=v[c+f|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b+d|0;if(d>>>0>48){break a}c=y[e+45|0];if(y[e+44|0]|c>>>0>64){break a}b=Hb(y[e+42|0]|y[e+43|0]<<8);if(b>>>0>32768){break a}h=h+1|0;i=c|i;j=b+j|0;continue}break}if(!j|!(i&255)){break a}d=y[a+470|0];if(d>>>0>128){break a}b=y[a+471|0];if(b>>>0>220){break a}a=a+472|0;f=sA(a);b:{if((a|0)==(f|0)){break b}c=a;while(1){c=c+1|0;if((f|0)==(c|0)){break b}a=Ur(y[a|0],y[c|0])?c:a;continue}}a=y[a|0];if(a>>>0>63){break a}k=(b|(a|d))!=0}return k}function X6(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=db-16|0;db=g;if(a){a=mc(g+8|0,a);e=x[a>>2];b=x[a+4>>2];a=db-16|0;db=a;x[a>>2]=e;x[a+4>>2]=b;x[a+8>>2]=e;x[a+12>>2]=b;b=db+-64|0;db=b;a:{if(!x[a+4>>2]){break a}e=x[a>>2];i=x[a+4>>2];c=32272;while(1){if((c|0)==32848){c=32848;while(1){f=(c|0)!=32896;if((c|0)==32896){break a}x[b+40>>2]=e;x[b+44>>2]=i;d=mc(b+32|0,x[c+8>>2]);h=x[b+44>>2];x[b+8>>2]=x[b+40>>2];x[b+12>>2]=h;h=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=h;c=c+12|0;if(!EM(b+8|0,b)){continue}break}break a}x[b+56>>2]=e;x[b+60>>2]=i;f=mc(b+48|0,x[c+8>>2]);d=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=d;d=x[f+4>>2];x[b+16>>2]=x[f>>2];x[b+20>>2]=d;c=c+12|0;if(!EM(b+24|0,b+16|0)){continue}break}f=1}db=b- -64|0;db=a+16|0}db=g+16|0;return f|0}function X9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=db-16|0;db=h;k=jf(a,c);ae(h,x[a+28>>2]);l=a;a:{if(!k){c=0;if(ed(a,5)){break a}}e=db-48|0;db=e;i=x[a+28>>2];yk(i,e+40|0);f=x[e+44>>2];if(!f&A[e+40>>2]>=257|f){x[e+40>>2]=256;x[e+44>>2]=0}f=x[e+40>>2];m=x[e+44>>2];c=0;b:{c:{d:{e:{while(1){if(!m&c>>>0>=f>>>0){break b}Mf(i,e+38|0);g=Gb(e+24|0);x[23549]=0;O(439,i|0,g|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){x[23549]=0;S(11,e+12|0,d|0,g|0);a=x[23549];x[23549]=0;if((a|0)==1){break e}x[23549]=0;a=O(868,b|0,e+38|0)|0;j=x[23549];x[23549]=0;if((j|0)==1){break d}j=a;a=e+12|0;zb(j,a);tb(a);tb(g);c=c+1|0;continue}break}c=N()|0;break c}c=N()|0;break c}c=N()|0;tb(e+12|0)}tb(g);Q(c|0);p()}db=e+48|0;c=k}cf(l,c);db=h+16|0}function uz(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=db-16|0;db=h;i=gl(a,b);a:{if((i|0)==255){break a}if(Sj(x[a>>2])){break a}b:{if(c>>>0>6208431){f=7;c=1023;break b}g=c;f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}c=20-f|0;j=c&31;if((c&63)>>>0>=32){c=g<<j;g=0}else{c=(1<<j)-1&g>>>32-j;g=g<<j}g=g+24858e3|0;if(g>>>0<24858e3){c=c+1|0}c=Qc(Bka(g,c,49716e3,0),hb)}if(e){w[h+14>>1]=(b&3)+c;w[h+12>>1]=1023;c=z[Uc(h+14|0,h+12|0)>>1]}g=qt(i);e=a+8|0;k=Db(e,i),l=(f<<10|c)>>>8|(d?0:32),v[k|0]=l;Tg(x[a>>2],x[a+4>>2],b,g|160,c&255);c=Db(e,i);Tg(x[a>>2],x[a+4>>2],b,g|176,y[c|0]);v[a+534|0]=1}db=h+16|0}function ao(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;g=db-16|0;db=g;if(e){x[e>>2]=0}a:{h=x[a+484344>>2];if(!se(h,x[a+484348>>2],b)){break a}i=Yb(h,b);k=x[i+48>>2];b=$c(x[i>>2],x[k+12>>2],c,d);f=y[b+5|0];b:{c:{d:{e:{j=y[b+3|0];switch(j-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(j-35>>>0>=2){break a}}x[g+12>>2]=1;h=0;if((j|0)!=17){break b}h=x[a+480180>>2]==4;break b}x[g+12>>2]=2;h=0}x[g+8>>2]=x[i+12>>2]+(c^-1);d=0;c=x[Cb(g+8|0,g+12|0)>>2];a=c;while(1){f:{if(a){b=D(z[x[k+12>>2]+480188>>1],6)+b|0;if(y[b+3|0]==34){break f}c=d}f=(j-37&255)>>>0<254?f:c?f:f<<8;if(!e){break a}x[e>>2]=c;break a}i=f<<8;f=y[b+5|0]|(h?f>>>0<256?i+-8192|0:i:i);d=d+1|0;a=a-1|0;continue}}db=g+16|0;return f}function JN(a,b){var c=0,d=0,e=0,f=0,g=0;e=db-16|0;db=e;d=Gb(a);a=od(b);x[e+12>>2]=a;f=tf(b);b=0;a:{while(1){b:{if(!Kb(a,f)){if(!b){break b}x[23549]=0;P(48,d|0,65533);a=x[23549];x[23549]=0;if((a|0)!=1){break b}break a}a=y[a|0];c:{d:{if(!b){if(a<<24>>24>=0){b=0;x[23549]=0;P(48,d|0,a|0);a=x[23549];x[23549]=0;if((a|0)!=1){break c}break a}if((a&224)==192){c=a&31;b=1;break c}if((a&240)==224){c=a&15;b=2;break c}c=65533;if((a&248)!=240){break d}c=a&7;b=3;break c}if((a&192)!=128){c=0;x[23549]=0;P(48,d|0,65533);g=x[23549];x[23549]=0;b=0;if((g|0)==1){break a}}c=a&63|c<<6;b=b-1|0;if(b){break c}}b=0;x[23549]=0;P(48,d|0,c|0);a=x[23549];x[23549]=0;c=0;if((a|0)==1){break a}}a=x[Oe(e+12|0)>>2];continue}break}db=e+16|0;return}a=N()|0;Ec(d);Q(a|0);p()}function Fv(a,b,c,d){var e=0,f=0,g=0,h=0;e=db+-64|0;db=e;x[e+60>>2]=d;a:{f=x[b>>2];b:{if(!(ib[x[x[f>>2]+36>>2]](f,c,d)|0)){xh(a);break b}Fl(e+44|0,x[b>>2],x[b+4>>2]);b=x[b>>2];d=x[x[b>>2]+24>>2];x[23549]=0;b=R(d|0,b|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break a}x[e+40>>2]=b-c;g=x[Cb(e+60|0,e+40|0)>>2];b=x[e+48>>2];x[e+24>>2]=x[e+44>>2];x[e+28>>2]=b;b=db-16|0;db=b;d=e+24|0;f=Fl(b+8|0,x[d>>2],x[d+4>>2]);x[23549]=0;h=x[f+4>>2];x[b>>2]=x[f>>2];x[b+4>>2]=h;V(158,e+52|0,b|0,c|0,g|0);c=x[23549];x[23549]=0;c:{if((c|0)!=1){fe(d);db=b+16|0;break c}a=N()|0;fe(d);Q(a|0);p()}b=Xd(e+32|0);c=x[e+56>>2];x[e+16>>2]=x[e+52>>2];x[e+20>>2]=c;c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;Av(a,e+16|0,e+8|0)}db=e- -64|0;return}a=N()|0;fe(e+44|0);Q(a|0);p()}function mY(a){a=a|0;var b=0,c=0,d=0,e=0;c=db-176|0;db=c;b=c+12|0;lh(b,a);x[23549]=0;P(77,c+24|0,b|0);a=x[23549];x[23549]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[23549]=0;a=O(78,c+36|0,c+24|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break e}tb(c+24|0);tb(c+12|0);b=x[x[a>>2]-12>>2];x[23549]=0;d=ca(61)|0;e=x[23549];x[23549]=0;if((e|0)==1){break c}x[23549]=0;S(62,c+8|0,a+b|0,d|0);b=x[23549];x[23549]=0;if((b|0)==1){break c}Xb(c+8|0);b=a+x[x[a>>2]-12>>2]|0;x[b+4>>2]=x[b+4>>2]&-75;x[b+4>>2]=x[b+4>>2]|8;x[23549]=0;b=O(83,a|0,c+24|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break c}a=Pk(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);d=x[c+24>>2];mf(b);db=c+176|0;a=a?0:d;break a}b=N()|0;break d}b=N()|0;tb(c+24|0)}tb(c+12|0);break b}b=N()|0;mf(a)}Q(b|0);p()}return a|0}function eha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=db-16|0;db=e;v[e+15|0]=0;w[e+12>>1]=0;n=D(c,d);j=4;a:while(1){if((d|0)!=(k|0)){h=b+k|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){v[e+11|0]=0;XS(a,e+15|0,e+12|0,e+11|0);i=y[e+11|0];f=z[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!ef(a,e+10|0)){break c}f=y[e+10|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}w[e+12>>1]=f;break b}k=k+1|0;continue a}w[e+12>>1]=0}c=1;g=i&255;e:{if(g>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(m>>>0<2){break e}f=c-1|0;if(!(g&1<<m)){continue}break}}f=i&1;v[e+15|0]=f;l=(f-1^(i&254)>>>1)+l|0;v[e+11|0]=l;v[h|0]=l;h=d+h|0;j=(c+j&254)>>>1|0;continue}}break}db=e+16|0}function oaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=db-32|0;db=f;c=z[x[x[a+48>>2]+12>>2]+480188>>1];a:{if(!b){break a}c=D(b,c);b:{if(x[a+12>>2]!=(b|0)){break b}if((bk(x[a>>2],x[a+4>>2])|0)!=(c|0)){break b}b=db-16|0;db=b;d=yb(x[a>>2]);a=yb(x[a+4>>2]);Uh(b+10|0);e=Ts(a,d);c=db-16|0;db=c;x[c+12>>2]=d;while(1){if((e|0)>0){a=x[c+12>>2];d=y[b+10|0]|y[b+11|0]<<8|(y[b+12|0]<<16|y[b+13|0]<<24);v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;d=y[b+14|0]|y[b+15|0]<<8;v[a+4|0]=d;v[a+5|0]=d>>>8;e=e-1|0;lk(c+12|0);continue}break}db=c+16|0;db=b+16|0;break a}e=f+14|0;Uh(e);c=qU(f+20|0,c,e);nM(a);x[a>>2]=x[c>>2];x[a+4>>2]=x[c+4>>2];e=wb(c);g=wb(a),h=x[e>>2],x[g>>2]=h;x[e>>2]=0;x[c>>2]=0;x[c+4>>2]=0;ek(c);x[a+12>>2]=b}db=f+32|0}function hN(a,b){var c=E(0),d=E(0),e=E(0);a:{b:{c:{switch(b|0){case 0:Gp(a,E(1));Vn(a,E(3.725290298461914e-9));Fp(a,E(268435456));Ep(a,0);break b;case 1:Gp(a,E(32));Vn(a,E(4.656612873077393e-10));Fp(a,E(2147483648));Ep(a,0);break b;case 2:Gp(a,E(2));Vn(a,E(7.450580596923828e-9));Fp(a,E(134217728));Ep(a,1);break b;default:Gp(a,E(1));Vn(a,E(7.450580596923828e-9));Fp(a,E(134217728));Ep(a,1);py(a,0);oy(a,1);ny(a,1);d=E(256);c=E(128);e=E(128);b=0;break a;case 4:case 5:break c}}Gp(a,E(.75));Vn(a,E(7.450580596923828e-9));Fp(a,E(134217728));Ep(a,1);py(a,0);b=(b|0)==4;oy(a,b?2:3);ny(a,1);d=E(256);c=b?E(256):E(192);e=c;b=1;break a}py(a,1);oy(a,0);ny(a,0);d=E(128);e=E(100);c=E(256);b=4}B[a+16>>2]=c;B[a+20>>2]=e;B[a+24>>2]=d;x[a+28>>2]=b}function S6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=db-48|0;db=f;x[f+44>>2]=d;a=Vf(a,f+44|0);d=xc(a+4|0);g=xc(a+24|0);h=xc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[23549]=0;P(922,a|0,e|0);k=x[23549];x[23549]=0;a:{b:{c:{d:{if((k|0)!=1){dc(f+16|0,b,c);b=Xd(f+8|0);x[23549]=0;c=x[b+4>>2];x[f>>2]=x[b>>2];x[f+4>>2]=c;c=x[f+16>>2];Aa(926,f+24|0,c|0,x[f+20>>2],f|0);b=x[23549];x[23549]=0;if((b|0)==1){break d}x[23549]=0;S(923,a|0,f+24|0,e|0);b=x[23549];x[23549]=0;if((b|0)==1){break c}ub(f+24|0);x[23549]=0;W(924,a|0);b=x[23549];x[23549]=0;if((b|0)!=1){break a}}e=N()|0;break b}e=N()|0;break b}e=N()|0;ub(f+24|0)}Yd(j);Yf(i);us(h);Xi(g);Wi(d);xe(a);xe(f+44|0);Q(e|0);p()}xe(f+44|0);db=f+48|0;return a|0}function fI(a,b,c,d){a:{switch(b-9|0){case 0:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];return;case 6:b=x[c>>2];x[c>>2]=b+4;b=w[b>>1];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 7:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=z[b>>1];x[a+4>>2]=0;return;case 8:b=x[c>>2];x[c>>2]=b+4;b=v[b|0];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 9:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=y[b|0];x[a+4>>2]=0;return;case 16:b=x[c>>2]+7&-8;x[c>>2]=b+8;C[a>>3]=C[b>>3];return;case 17:ib[d|0](a,c);default:return;case 1:case 4:case 14:b=x[c>>2];x[c>>2]=b+4;b=x[b>>2];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 2:case 5:case 11:case 15:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];x[a+4>>2]=0;return;case 3:case 10:case 12:case 13:break a}}b=x[c>>2]+7&-8;x[c>>2]=b+8;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c}function MS(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;o=x[b>>2];while(1){if((i|0)==128){Sf(b,c);c=x[a+8>>2];d=c+d|0;i=z[e>>1];a:{b:{c:{if(!f){break c}j=f;f=h&65535;if((c+(j+(f<<11)|0)|0)!=(Ig(x[a>>2])&-2)){break c}Vc(a,c+(f<<10)|0);if(!xA(a,16,1)){break b}w[e>>1]=8;break b}if((h&65535)==(k&65535)){h=k;break a}f=k<<8&16776960;if(!g){if((Ig(x[a>>2])|0)!=(d+D(f,i)|0)){break a}}Vc(a,c+D(f,z[e>>1])|0);h=xA(a,64,1)?h:k}Vc(a,c)}c=l&65535;d:{if(c>>>0>(h&65535)>>>0){if((d+(D(c,z[e>>1])<<8)|0)==(Ig(x[a>>2])|0)){break d}}if(c>>>0>=255){wA(b,254,65534);wA(b,255,65535)}l=h}a=l&65535}else{j=z[_b(o,i)>>1];m=j+1|0;n=(h&65535)>>>0>j>>>0|j>>>0>127;k=n?k:c>>>0>i>>>0?m:k;l=(l&65535)>>>0>j>>>0?l:m;h=n?h:m;i=i+1|0;continue}break}return a}function lp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);b=j(1)|0;d=j(0)|0;a:{b:{c:{if(!(((b|0)>0|(b|0)>=0)&b>>>0>1048575)){if(!(b&2147483647|d)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(b>>>0>2146435071){break a}f=1072693248;g=-1023;if((b|0)!=1072693248){f=b;break b}if(d){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;d=j(0)|0;f=b;g=-1077}b=f+614242|0;h=+((b>>>20|0)+g|0);e=h*.6931471803691238;l(0,d|0);l(1,(b&1048575)+1072079006|0);a=+n()+-1;c=a/(a+2);i=e;k=a;m=c;e=a*(a*.5);c=c*c;a=c*c;a=i+(k+(m*(e+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+h*1.9082149292705877e-10-e))}return a}function _N(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=db-16|0;db=e;i=-1;a:{if(!qy(a,b,2)){break a}f=x[b+656>>2];d=a+1074312|0;g=Ob(d,31);h=x[b+740>>2];if(h?0:g){break a}h=h-Ob(d,31)|0;g=x[a+480180>>2];d=(g|0)==4096;j=f+88|0;f=d?64:(g|0)==16384?192:512;d=Xp(j,h,f,d?255:64)-(f>>>1|0)|0;if(y[b+746|0]&16){i=Rp(a,b,!(x[b+88>>2]&32768),d);break a}if(gj(x[b+656>>2])){if((d|0)==w[b+772>>1]){break a}k=b,l=Sc(d),w[k+772>>1]=l;v[b+851|0]=y[b+851|0]|64;break a}a=Zi(a);x[e+12>>2]=d;b:{if((d|0)<0){x[e+12>>2]=0-d;Zh(e+12|0,255);a=(x[e+12>>2]<<2)+(a?38384:37360)|0;break b}Zh(e+12|0,255);a=(x[e+12>>2]<<2)+(a?37360:38384)|0}a=x[a>>2];b=a;d=a>>31;a=x[c>>2];k=c,l=Cc(zka(yka(b,d,a,a>>31),hb,65536,0),hb),x[k>>2]=l}db=e+16|0;return i}function qca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=db-32|0;db=g;h=a+8|0;c=x[a+8>>2];j=kc(a);a:{if((c|0)!=x[j>>2]){break a}i=a+4|0;d=x[a+4>>2];e=x[a>>2];if(d>>>0>e>>>0){a=((d-e>>2)+1|0)/-2<<2;c=_g(d,c,a+d|0);x[h>>2]=c;x[i>>2]=a+x[i>>2];break a}x[g+8>>2]=c-e>>1;x[g+28>>2]=1;d=g+8|0;c=x[Yc(d,g+28|0)>>2];c=Jf(d,c,c>>>2|0,x[a+16>>2]);e=vb(g+4|0,x[a+4>>2]);f=x[vb(g,x[a+8>>2])>>2];d=db-16|0;db=d;e=x[e>>2];x[d+12>>2]=e;e=Bl(d,c+8|0,bu(f,e));f=x[e>>2];while(1){if(x[e+4>>2]!=(f|0)){k=f;f=x[d+12>>2];kq(k,z[f>>1]|z[f+2>>1]<<16);f=x[e>>2]+4|0;x[e>>2]=f;Ae(d+12|0);continue}break}Kd(e);db=d+16|0;Pb(a,c);Pb(i,c+4|0);Pb(h,c+8|0);Pb(j,kc(c));If(c);c=x[a+8>>2]}kq(c,z[b>>1]|z[b+2>>1]<<16);x[h>>2]=x[h>>2]+4;db=g+32|0}function QD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=db-16|0;db=h;f=Mb(b);d=Bb(x[b+4>>2],y[b+11|0]);i=Mb(c);g=Bb(x[c+4>>2],y[c+11|0]);d=d+f|0;e=-1;a:{while(1){if((d|0)==(f|0)){break a}d=d-1|0;if(hq(i,g,y[d|0])){continue}break}e=d-f|0}b:{c:{if((e|0)!=-1){c=vb(h+12|0,Ie(Ie(od(b),e),1));d=vb(h+8|0,tf(b));fD(b,x[c>>2],x[d>>2]);break c}if(!Oc(x[b+4>>2],y[b+11|0])){break c}f=Mb(b);d=Bb(x[b+4>>2],y[b+11|0]);i=Mb(c);g=Bb(x[c+4>>2],y[c+11|0]);if(!d|!g){c=-1}else{c=f;e=d+c|0;g=g+i|0;while(1){d:{d=i;e:{if((c|0)!=(e|0)){while(1){if((d|0)==(g|0)){break e}j=v[d|0];d=d+1|0;if(!qc(v[c|0],j)){continue}break}}else{c=e}break d}c=c+1|0;continue}break}c=(c|0)==(e|0)?-1:c-f|0}if(c){break c}Gb(a);break b}ad(a,b)}db=h+16|0}function rH(a,b,c,d,e,f){var g=0;g=db-80|0;db=g;a:{if((f|0)>=16384){Ed(g+32|0,b,c,d,e,0,0,0,2147352576);d=x[g+40>>2];e=x[g+44>>2];b=x[g+32>>2];c=x[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}Ed(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)>=49149?49149:f)-32766|0;d=x[g+24>>2];e=x[g+28>>2];b=x[g+16>>2];c=x[g+20>>2];break a}if((f|0)>-16383){break a}Ed(g- -64|0,b,c,d,e,0,0,0,7471104);d=x[g+72>>2];e=x[g+76>>2];b=x[g+64>>2];c=x[g+68>>2];if(f>>>0>4294934644){f=f+16269|0;break a}Ed(g+48|0,b,c,d,e,0,0,0,7471104);f=((f|0)<=-48920?-48920:f)+32538|0;d=x[g+56>>2];e=x[g+60>>2];b=x[g+48>>2];c=x[g+52>>2]}Ed(g,b,c,d,e,0,0,0,f+16383<<16);b=x[g+12>>2];x[a+8>>2]=x[g+8>>2];x[a+12>>2]=b;b=x[g+4>>2];x[a>>2]=x[g>>2];x[a+4>>2]=b;db=g+80|0}function Xw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=db-16|0;db=e;g=(q(a),j(2));c=g&2147483647;a:{if(c>>>0<=1305022426){h=+a;f=h*.6366197723675814+6755399441055744+-6755399441055744;d=h+f*-1.5707963109016418+f*-1.5893254773528196e-8;C[b>>3]=d;g=d<-.7853981852531433;if(F(f)<2147483648){c=~~f}else{c=-2147483648}if(g){d=f+-1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c-1|0;break a}if(!(d>.7853981852531433)){break a}d=f+1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c+1|0;break a}if(c>>>0>=2139095040){C[b>>3]=E(a-a);c=0;break a}i=c;c=(c>>>23|0)-150|0;C[e+8>>3]=(l(2,i-(c<<23)|0),r());c=kI(e+8|0,e,c,1,0);d=C[e>>3];if((g|0)<0){C[b>>3]=-d;c=0-c|0;break a}C[b>>3]=d}db=e+16|0;return c}function Jda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=db-16|0;db=b;f=x[a+40>>2];g=x[a+36>>2];k=x[a+16>>2];h=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=h;l=x[a+32>>2];m=x[a+28>>2];h=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=e>>>18|0;p=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+k|0;e=0;while(1){if((e|0)!=2){i=(e<<1)+p|0;j=w[i>>1];x[(e<<2)+b>>2]=j+((D(w[i+4>>1]-j|0,o)|0)/16384|0);e=e+1|0;continue}break}g=g+m|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Qb(b+8|0,h,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;db=b+16|0}function BA(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=db-16|0;db=f;e=y[a|0];if(e&1){v[b+12|0]=y[b+12|0]|1;e=y[a|0]}if(e&2){v[b+12|0]=y[b+12|0]|4;e=y[a|0]}if(e&4){v[b+12|0]=y[b+12|0]|2;e=y[a|0]}if(e&16){v[b+12|0]=y[b+12|0]|16;e=y[a|0]}if(e&32){v[b+12|0]=y[b+12|0]|8}v[f+15|0]=y[a+1|0];v[f+14|0]=25;ah(b,y[Sb(f+15|0,f+14|0)|0]);v[b+15|0]=y[a+2|0];v[b+16|0]=y[((d|0)==4?a+2|0:a+3|0)|0];v[b+13|0]=y[a+4|0];v[b+14|0]=y[a+5|0];h=x[b>>2];e=ne(h,x[b+4>>2]);b=0;while(1){if((b|0)!=(e|0)){i=xb(h,b);g=(b<<2)+a|0;d=y[g+6|0]|y[g+7|0]<<8;w[i>>1]=d;a:{if(!b){break a}j=d;d=z[xb(h,b-1|0)>>1];if(j>>>0>=d>>>0){break a}w[i>>1]=d+1}k=i,l=Ub((y[g+8|0]|y[g+9|0]<<8)<<16>>16>>c,0,64),v[k+2|0]=l;b=b+1|0;continue}break}db=f+16|0}function CS(a,b){var c=0,d=0,e=0;c=db-32|0;db=c;a:{if(!Lb(x[a>>2],x[a+8>>2],1024)){x[c+24>>2]=0;x[c+28>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;a=64;while(1){if(a){d=y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24);e=y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24);v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;v[b+4|0]=d;v[b+5|0]=d>>>8;v[b+6|0]=d>>>16;v[b+7|0]=d>>>24;d=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);e=y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24);v[b+8|0]=e;v[b+9|0]=e>>>8;v[b+10|0]=e>>>16;v[b+11|0]=e>>>24;v[b+12|0]=d;v[b+13|0]=d>>>8;v[b+14|0]=d>>>16;v[b+15|0]=d>>>24;a=a-1|0;b=b+16|0;continue}break}break a}uA(c+8|0,b);pd(c+16|0,a,x[c+8>>2],x[c+12>>2])}db=c+32|0}function G$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=db-416|0;db=h;d=h+416|0;x[h+12>>2]=d;c=db-144|0;db=c;x[c+28>>2]=c+132;i=c+32|0;FG(x[a+8>>2],i,c+28|0,e,f,g);x[c+16>>2]=0;x[c+20>>2]=0;x[c+12>>2]=i;e=h+16|0;g=oc(e,x[h+12>>2]);f=db-16|0;db=f;i=ei(f+12|0,x[a+8>>2]);a=hH(e,c+12|0,g,c+16|0);di(i);db=f+16|0;if((a|0)==-1){Wr(12451);p()}x[h+12>>2]=e+(a<<2);db=c+144|0;f=db-16|0;db=f;i=f+8|0;a=db-32|0;db=a;An(a+24|0,e,x[h+12>>2]);h=a+16|0;e=x[a+24>>2];g=x[a+28>>2];c=db-16|0;db=c;x[c+12>>2]=b;while(1){if((e|0)!=(g|0)){KH(c+12|0,x[e>>2]);e=e+4|0;continue}break}vc(h,g,c+12|0);db=c+16|0;b=x[a+16>>2];x[a+12>>2]=x[a+20>>2];vc(i,b,a+12|0);db=a+32|0;db=f+16|0;db=d;return x[f+12>>2]}function Cfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=db-32|0;db=f;nd(c,2);v[f+20|0]=y[b+13|0];v[f+8|0]=64;d=f+20|0;e=f+8|0;i=c,j=y[Sb(d,e)|0]<<2,w[i+30>>1]=j;x[c+24>>2]=(y[b+14|0]|y[b+15|0]<<8)<<1;ck(e,2,b+1|0);Bc(d,e);Ce(c+43|0,d);tb(d);d=Xc(a,8,1,0,2);a:{if((y[b|0]&3)!=1){break a}g=y[b+22|0]|y[b+23|0]<<8|(y[b+24|0]<<16|y[b+25|0]<<24);x[c>>2]=g;e=y[b+26|0]|y[b+27|0]<<8|(y[b+28|0]<<16|y[b+29|0]<<24);x[c+4>>2]=e;a=y[b+30|0]|y[b+31|0]<<8|(y[b+32|0]<<16|y[b+33|0]<<24);h=a-(a>>>0>e>>>0)|0;x[c+8>>2]=h;a=y[b|0];if(a&4){w[c+34>>1]=z[c+34>>1]|2;a=y[b|0]}if(a&8){w[c+34>>1]=z[c+34>>1]|4;a=y[b|0]}if(!(a&16)){break a}hd(d,16);Uf(d,9);x[c+8>>2]=h>>>1;x[c+4>>2]=e>>>1;x[c>>2]=g>>>1}db=f+32|0}function Pba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;i=db-16|0;db=i;d=x[vb(i+12|0,yb(x[a+4>>2]))>>2];h=db-32|0;db=h;e=d;d=x[a>>2];f=(Fo(e,yb(d))<<1)+d|0;e=jz(b,c);a:{if((e|0)<=0){break a}d=x[wb(a)>>2];g=x[a+4>>2];if((e|0)<=d-g>>1){k=g-f|0;j=k>>1;b:{if((e|0)<=(j|0)){d=c;break b}x[h+12>>2]=b;x[h+12>>2]=x[h+12>>2]+(j<<1);d=x[h+12>>2];Az(a,d,c,e-j|0);if((k|0)<=0){break a}}VP(a,f,g,(e<<1)+f|0);kl(b,d,f);break a}d=wb(a);e=uj(h+12|0,vj(a,Ic(x[a>>2],g)+e|0),f-x[a>>2]>>1,d);g=db-16|0;db=g;c=So(g+4|0,e+8|0,jz(b,c));d=x[c>>2];while(1){if(x[c+4>>2]!=(d|0)){tj(d,z[b>>1]);d=x[c>>2]+2|0;x[c>>2]=d;b=b+2|0;continue}break}Kd(c);db=g+16|0;f=TP(a,e,f);Di(e)}yb(f);db=h+32|0;db=i+16|0;return a|0}function J3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=db+-64|0;db=d;a=x[a+4>>2];Cv(d+16|0,b);x[23549]=0;b=O(1,d+4|0,17347)|0;e=x[23549];x[23549]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){x[23549]=0;S(2,d+28|0,d+16|0,b|0);e=x[23549];x[23549]=0;if((e|0)==1){break h}x[23549]=0;S(431,d+40|0,d+28|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break g}x[23549]=0;P(989,d+52|0,d+40|0);c=x[23549];x[23549]=0;if((c|0)==1){break f}c=x[x[a>>2]+8>>2];x[23549]=0;P(c|0,a|0,d+52|0);a=x[23549];x[23549]=0;if((a|0)==1){break e}tb(d+52|0);tb(d+40|0);tb(d+28|0);tb(b);tb(d+16|0);db=d- -64|0;return}a=N()|0;break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;tb(d+52|0)}tb(d+40|0)}tb(d+28|0)}tb(b)}tb(d+16|0);Q(a|0);p()}function Kda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=db-16|0;db=b;f=x[a+40>>2];g=x[a+36>>2];k=x[a+16>>2];h=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=h;l=x[a+32>>2];m=x[a+28>>2];h=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=e>>>10&4194048;p=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+k|0;e=0;while(1){if((e|0)!=2){i=e+p|0;j=v[i|0];x[(e<<2)+b>>2]=((D(v[i+2|0]-j|0,o)|0)/16384|0)+(j<<8);e=e+1|0;continue}break}g=g+m|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Qb(b+8|0,h,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;db=b+16|0}function Xy(a,b,c){var d=0,e=0,f=0,g=0;d=Gb(a);a=y[b+11|0];e=x[b+4>>2];x[23549]=0;P(45,d|0,Oc(e,a)|0);a=x[23549];x[23549]=0;if((a|0)!=1){a:{while(1){if(Oc(x[b+4>>2],y[b+11|0])>>>0>f>>>0){e=x[_i(b,f)>>2];g=e&-32;a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if((g|0)==128|(e|0)!=x[(a<<2)+c>>2]){a=a+1|0;continue}else{x[23549]=0;P(46,d|0,a<<24>>24);a=x[23549];x[23549]=0;if((a|0)!=1){break b}break a}}break}d:{while(1){if((a|0)==32){break d}if((e|0)!=x[(a<<2)+c>>2]){a=a+1|0;continue}break}x[23549]=0;P(46,d|0,a<<24>>24);a=x[23549];x[23549]=0;if((a|0)!=1){break b}break a}x[23549]=0;P(46,d|0,63);a=x[23549];x[23549]=0;if((a|0)!=1){break b}break a}f=f+1|0;continue}break}return}}a=N()|0;tb(d);Q(a|0);p()}function Gj(a,b){var c=0,d=0,e=0,f=0;c=db+-64|0;db=c;d=x[x[a>>2]-12>>2]+a|0;e=x[d+16>>2]&-3;dn(d,e);a:{b:{if(vd(y[Cn(c+63|0,a,1)|0])){d=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[23549]=0;f=x[b+12>>2];x[c+16>>2]=x[b+8>>2];x[c+20>>2]=f;f=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=f;S(94,c+40|0,d|0,c+8|0);b=x[23549];x[23549]=0;c:{if((b|0)!=1){b=gh(c+24|0,-1,-1);b=yE(x[c+48>>2],x[c+52>>2],x[b+8>>2],x[b+12>>2])?e|4:e;break c}Y(T(0)|0)|0;b=e|1;Bn(x[x[a>>2]-12>>2]+a|0,b);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[23549]=0;X(91);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}qj(x[x[a>>2]-12>>2]+a|0,b)}db=c- -64|0;return a}T(0)|0;Rb()}p()}function xda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=db-16|0;db=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=e>>>21&2040;n=w[e+39942>>1];o=w[e+39940>>1];p=w[e+39938>>1];e=w[e+39936>>1];f=0;while(1){if((f|0)!=2){g=(f<<1)+m|0;x[(f<<2)+b>>2]=(((D(w[g>>1],p)+D(w[g-4>>1],e)|0)+D(w[g+4>>1],o)|0)+D(w[g+8>>1],n)|0)/16384;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Qb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;db=b+16|0}function kh(a,b){var c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=0;f=XK(a);h=a+4208|0;c=E(E(B[xb(h,4)>>2]*E(1.899999976158142))+E(.10000000149011612));g=B[a+4268>>2];d=qe(E(10),E(E(E(E(E(x[((b<<2)+a|0)+4292>>2])/g)*E(-60))/E(E(B[xb(h,3)>>2]*E(19.899999618530273))+E(.10000000149011612)))/E(20)));c=E(E(qe(d,E(E(2)-E(E(2)/c)))+E(-1))/E(E(1)-zp(c>E(1)?E(3.1415927410125732):E(f*E(E(6.2831854820251465)/g)))));a:{if(c==E(0)){break a}if(!bm(c)){break a}g=E(c+c);f=E(E(-2)-g);c=E(E(f*f)+E(E(c*c)*E(-4)));if(c>E(0)){e=E(M(c))}c=E(E(e-f)/g);if(E(F(c))>E(1)){c=E(E(E(-f)-e)/g)}e=Af(c)}b=(b<<3)+a|0;B[b+4404>>2]=e;B[b+4400>>2]=d;c=B[a+4272>>2];c=E(c*c);e=E(E(1)-c);d=E(d*d);return E(E(E(e*E(d/E(E(1)-E(c*d))))*e)+c)}function hF(a,b,c,d,e,f){var g=0,h=0,i=E(0),j=0;g=db-80|0;db=g;uy(x[a+24>>2]);v[x[a+24>>2]+1298420|0]=x[a+52>>2]!=0;c=rd(g+40|0,d,c,b);i=B[a+48>>2];j=x[a+32>>2];x[g+16>>2]=x[c+8>>2];d=x[c+4>>2];x[g+8>>2]=x[c>>2];x[g+12>>2]=d;d=db-16|0;db=d;x[d+8>>2]=x[g+16>>2];c=x[g+12>>2];x[d>>2]=x[g+8>>2];x[d+4>>2]=c;c=NJ(g+52|0);x[c+8>>2]=j;x[c+4>>2]=0;x[c>>2]=f;f=x[d+4>>2];x[c+12>>2]=x[d>>2];x[c+16>>2]=f;x[c+20>>2]=x[d+8>>2];B[c+24>>2]=i;x[c>>2]=e;db=d+16|0;while(1){if(b){d=x[a+24>>2];x[g+32>>2]=b;x[g+36>>2]=0;x[g+24>>2]=134217727;x[g+28>>2]=0;d=PJ(d,x[Vq(g+32|0,g+24|0)>>2],c);h=d+h|0;b=b-d|0;if(d){continue}}break}if(!(x[a+52>>2]!=1|h)){a=x[a+24>>2];x[a+480208>>2]=x[a+480208>>2]&-513}db=g+80|0;return h}function Kga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=db-528|0;db=b;e=-1;a:{if(!zh(a,1468)){break a}ml(a,1464);c=b+524|0;TS(a,c);if(!de(c,26948)){e=0;if(!de(b+524|0,15151)){break a}}ml(a,20);c=1;b:{while(1){if((c&65535)>>>0>31){break b}if(QS(a,b)){c=c+1|0;d=AA(b)+d|0;continue}break}e=-1;break a}e=0;if(d>>>0>40){break a}d=b+522|0;c=db-16|0;db=c;c:{if(!zh(a,2)){v[c|0]=0;tC(d,c);break c}Pm(c+8|0,d);zA(c,a,x[c+8>>2],x[c+12>>2])}db=c+16|0;if(y[b+522|0]>128){break a}d=fd(b+522|0);c=db-16|0;db=c;d:{if(!zh(a,512)){BS(b);break d}Gu(c+8|0,b);zA(c,a,x[c+8>>2],x[c+12>>2])}db=c+16|0;c=0;e=1;a=y[d|0];while(1){if((c|0)==512){break a}d=b+c|0;c=c+1|0;if(a>>>0>=y[d|0]){continue}break}e=0}db=b+528|0;return e|0}function lH(a,b){var c=0,d=0,e=0;a:{if(y[b|0]){break a}b=Ew(13618);if(y[b|0]?b:0){break a}b=Ew(D(a,12)+78400|0);if(y[b|0]?b:0){break a}b=Ew(13865);if(y[b|0]?b:0){break a}b=14412}b:{while(1){d=y[b+c|0];if(!(!d|(d|0)==47)){d=23;c=c+1|0;if((c|0)!=23){continue}break b}break}d=c}e=14412;c:{d:{c=y[b|0];e:{f:{if(!(y[b+d|0]|(c|0)==46)){e=b;if((c|0)!=67){break f}}if(!y[e+1|0]){break e}}if(!Vk(e,14412)){break e}if(Vk(e,13351)){break d}}if(!a){c=78472;if(y[e+1|0]==46){break c}}return 0}c=x[116847];if(c){while(1){if(!Vk(e,c+8|0)){break c}c=x[c+32>>2];if(c){continue}break}}c=Nd(36);if(c){x[c+4>>2]=20;x[c>>2]=78368;b=c+8|0;rc(b,e,d);v[b+d|0]=0;x[c+32>>2]=x[116847];x[116847]=c}c=a|c?c:78472}return c}function _6(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;b=db-32|0;db=b;c=Gb(b+20|0);x[23549]=0;W(915,b+8|0);a=x[23549];x[23549]=0;a:{b:{c:{d:{if((a|0)!=1){f=b,g=yb(x[b+8>>2]),x[f+4>>2]=g;d=1;while(1){e=yb(x[b+12>>2]);a=x[b+4>>2];if(!Kb(a,e)){a=_f(Mb(c));Yd(b+8|0);tb(c);break b}if(!d){x[23549]=0;O(916,c|0,14279)|0;a=x[23549];x[23549]=0;if((a|0)==1){break d}a=x[b+4>>2]}x[23549]=0;O(777,c|0,a|0)|0;a=x[23549];x[23549]=0;if((a|0)==1){break d}Bj(b+4|0);d=0;continue}}a=T(0)|0;break c}a=T(0)|0;Yd(b+8|0)}tb(c);Y(a|0)|0;a=0;x[23549]=0;V(914,6926,0,0,0);c=x[23549];x[23549]=0;if((c|0)==1){break a}Z()}db=b+32|0;return a|0}b=N()|0;x[23549]=0;X(17);a=x[23549];x[23549]=0;if((a|0)==1){T(0)|0;Rb();p()}Q(b|0);p()}function m1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=x[b+44>>2];i=x[b+24>>2];if(h>>>0<i>>>0){x[b+44>>2]=i;h=i}m=-1;n=-1;o=f&24;a:{if(!o|(e|0)==1&(o|0)==24){break a}if(h){j=h-Mb(b+32|0)|0;k=j>>31}b:{c:{switch(e|0){case 1:if(f&8){g=x[b+12>>2]-x[b+8>>2]|0;l=g>>31;break b}g=i-x[b+20>>2]|0;l=g>>31;break b;case 0:break b;case 2:break c;default:break a}}g=j;l=k}d=d+l|0;c=c+g|0;d=g>>>0>c>>>0?d+1|0:d;if((d|0)<0|(c>>>0>j>>>0&(d|0)>=(k|0)|(d|0)>(k|0))){break a}e=f&8;d:{if(!(c|d)){break d}if(x[b+12>>2]?0:e){break a}if(!(f&16)){break d}if(!i){break a}}if(e){e=x[b+8>>2];xn(b,e,c+e|0,h)}if(f&16){Mw(b,x[b+20>>2],x[b+28>>2]);_r(b,c)}m=c;n=d}gh(a,m,n)}function eo(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:{if(c){v[b+809|0]=c;break a}c=y[b+809|0]}e=x[a+480180>>2];d=e&202376205?(c&240?-16:15)&c:c;c=x[b+688>>2];b:{if(e&69206029){break b}g=d&255;f=d&15;if((f|0)==15){if(g>>>0>=16){co(a,b,(d&240)>>>4|0,0);return}if(!(v[b+851|0]&1)){break b}c=y[a+480208|0]&2?c:c-60|0;break b}if((g&240)!=240){break b}if(f){bo(a,b,f,0);return}if(!(v[b+851|0]&1)){break b}c=y[a+480208|0]&2?c:c+60|0}c:{if(!(!(v[b+851|0]&1)|y[a+480208|0]&2)&(x[a+1074416>>2]!=1|(e|0)!=524288)){break c}a=d&15;d:{if(a){if((d&255)>>>0>15?e&16777248:0){break c}c=c-(a<<2)|0;break d}c=((d&255)>>>2&60)+c|0}if((e|0)!=1){break c}x[b+88>>2]=x[b+88>>2]|2097152}h=b,i=Ub(c,0,256),x[h+688>>2]=i}function ni(a,b,c,d){var e=0,f=0,g=0;x[a+20>>2]=d;x[a+16>>2]=c;x[a+12>>2]=b;x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=44528;c=a+24|0;x[c>>2]=0;x[c+4>>2]=0;x[c+16>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;b=Nb(a+44|0);d=Nb(b+12|0);e=Nb(b+24|0);f=Nb(b+36|0);x[23549]=0;P(878,b|0,0);g=x[23549];x[23549]=0;if((g|0)==1){a=N()|0;sc(f);sc(e);Ks(d);Ks(b);Q(a|0);p()}w[a+4204>>1]=0;x[a+4196>>2]=1065353216;x[a+4200>>2]=0;d=x[a+16>>2];x[d+946300>>2]=x[d+946300>>2]+1;x[23549]=0;d=R(879,a+92|0)|0;e=x[23549];x[23549]=0;a:{if((e|0)!=1){b=a+4200|0;x[c>>2]=d;d=y[a+4200|0];c=x[a+16>>2];e=x[a+20>>2];while(1){if((e|0)==((c+D(d,160)|0)+906300|0)|d>>>0>248){break a}d=d+1|0;v[b|0]=d;continue}}a=N()|0;BL(b);Q(a|0);p()}return a}function xW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=db-16|0;db=e;nd(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=Nq(a+4|0,a);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=f;c=Nq(a+8|0,a);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+8>>2]=c;v[e+15|0]=127;v[e+14|0]=y[a+15|0];g=b,h=(((y[Sb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[g+30>>1]=h;d=y[a+12|0];if(d>>>0>=16){w[b+34>>1]=32;w[b+28>>1]=d&240}d=(y[a+13|0]|y[a+14|0]<<8)<<1;x[b+24>>2]=d;d=y[a+13|0]|y[a+14|0]<<8?d:16726;x[b+24>>2]=d;g=b,h=(D(Ru(0,y[a+12|0]<<28>>24),d)>>>0)/8363|0,x[g+24>>2]=h;if(c>>>0>f>>>0){w[b+34>>1]=z[b+34>>1]|2}if(y[a+16|0]&132){w[b+34>>1]=z[b+34>>1]|1}db=e+16|0}function Wea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=db-16|0;db=e;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(e+8|0,x[vb(e+4|0,a)>>2]);a:{if(b){x[23549]=0;P(677,a|0,b|0);c=x[23549];x[23549]=0;if((c|0)==1){break a}f=db-16|0;db=f;d=f+4|0;x[d>>2]=a;c=x[a+4>>2];x[d+4>>2]=c;x[d+8>>2]=c+D(b,36);b=x[d+4>>2];g=x[d+8>>2];while(1){if((b|0)==(g|0)){fc(d);db=f+16|0}else{c=Vb(b,0,36);x[c>>2]=0;x[c+4>>2]=0;w[c+22>>1]=0;w[c+24>>1]=0;w[c+26>>1]=0;w[c+28>>1]=0;v[c+21|0]=64;v[c+19|0]=64;v[c+20|0]=100;v[c+15|0]=0;v[c+16|0]=0;v[c+17|0]=0;v[c+18|0]=0;x[c+8>>2]=0;x[c+12>>2]=0;w[c+30>>1]=0;w[c+32>>1]=0;b=b+36|0;x[d+4>>2]=b;continue}break}}b=e+8|0;Hd(b);SQ(b);db=e+16|0;return a|0}a=N()|0;SQ(e+8|0);Q(a|0);p()}function YI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=db-16|0;db=f;a:{b:{c:{d:{e:{if((b|0)>=0){e=x[a+32>>2];if((wp(e)|0)>(b|0)){break e}}a=ac(8);x[23549]=0;b=O(54,f+4|0,10589)|0;c=x[23549];x[23549]=0;if((c|0)==1){break d}a=pc(a,b);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}d=(e+(b<<5)|0)+480280|0;g=c?134218752:0;x[d>>2]=g|x[d>>2]&-134218753;c=(e+D(b,872)|0)+1075080|0;x[c>>2]=x[c>>2]&-134218753|g;c=z[e+480188>>1];e=c>>>0<=256?256:c;b=b+1|0;a=x[a+32>>2];while(1){if((c|0)==(e|0)){break a}d=a+D(c,872)|0;if((b|0)==z[d+1075778>>1]){d=d+1075080|0;x[d>>2]=x[d>>2]&-134218753|g}c=c+1|0;continue}}c=N()|0;jc(a)}Q(c|0)}p()}db=f+16|0}function Np(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=db-16|0;db=d;x[d+12>>2]=b;if(b>>>0<2147483632){a:{if(Mc(a)>>>0>=b>>>0){break a}k=d,l=Bb(x[a+4>>2],y[a+11|0]),x[k+8>>2]=l;b=fk(x[Yc(d+12|0,d+8|0)>>2]);if((Mc(a)|0)==(b|0)){break a}e=db-16|0;db=e;f=Bb(x[a+4>>2],y[a+11|0]);b:{c:{h=Do(b);d:{if(h){i=1;j=b+1|0;g=x[a>>2];b=a;c=f;break d}c=b+1|0;e:{if(Mc(a)>>>0<b>>>0){yi(e+8|0,c);break e}x[23549]=0;P(51,e+8|0,c|0);b=x[23549];x[23549]=0;if((b|0)==1){break c}}j=x[e+12>>2];b=x[e+8>>2];c=y[a+11|0];i=ue(c);g=Mb(a);c=Bb(x[a+4>>2],c)}b=We(b,g,c+1|0);if(i){Eb(g)}if(!h){jg(a,j);re(a,f);zd(a,b);break b}ff(a,f);break b}Y(T(0)|0)|0;Z()}db=e+16|0}db=d+16|0;return}kg();p()}function kba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=db-16|0;db=d;x[d+12>>2]=b;if(b>>>0<1073741808){a:{if(ln(a)>>>0>=b>>>0){break a}k=d,l=Bb(x[a+4>>2],y[a+11|0]),x[k+8>>2]=l;b=Ql(x[Yc(d+12|0,d+8|0)>>2]);if((ln(a)|0)==(b|0)){break a}e=db-16|0;db=e;i=1;f=b+1|0;c=ln(a);g=Bb(x[a+4>>2],y[a+11|0]);b:{c:{j=qp(b);d:{if(j){h=x[a>>2];b=a;c=g;break d}e:{if(b>>>0>c>>>0){hj(e+8|0,f);break e}x[23549]=0;P(1205,e+8|0,f|0);b=x[23549];x[23549]=0;if((b|0)==1){break c}}f=x[e+12>>2];b=x[e+8>>2];c=y[a+11|0];i=ue(c);h=Mb(a);c=Bb(x[a+4>>2],c)}b=gi(b,h,c+1|0);if(i){Eb(h)}if(!j){jg(a,f);re(a,g);zd(a,b);break b}ff(a,g);break b}Y(T(0)|0)|0;Z()}db=e+16|0}db=d+16|0;return}kg();p()}function Py(a,b,c){var d=0,e=0,f=0,g=0;d=db+-64|0;db=d;e=x[a>>2];f=x[e-4>>2];g=x[e-8>>2];x[d+28>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+40>>2]=0;x[d+44>>2]=0;x[d+48>>2]=0;x[d+52>>2]=0;x[d+56>>2]=0;e=0;v[d+59|0]=0;v[d+60|0]=0;v[d+61|0]=0;v[d+62|0]=0;x[d+20>>2]=0;x[d+24>>2]=0;x[d+16>>2]=b;x[d+12>>2]=a;x[d+8>>2]=c;a=a+g|0;a:{if(Kg(f,c,0)){x[d+56>>2]=1;ib[x[x[f>>2]+20>>2]](f,d+8|0,a,a,1,0);e=x[d+32>>2]==1?a:0;break a}ib[x[x[f>>2]+24>>2]](f,d+8|0,a,1,0);b:{switch(x[d+44>>2]){case 0:e=x[d+48>>2]==1?x[d+36>>2]==1?x[d+40>>2]==1?x[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(x[d+32>>2]!=1){if(x[d+48>>2]|x[d+36>>2]!=1|x[d+40>>2]!=1){break a}}e=x[d+24>>2]}db=d- -64|0;return e}function mea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;g=db-16|0;db=g;nd(b,4);w[b+30>>1]=y[a+12|0]<<2;Wf(b+30|0,256);e=y[a+15|0];w[b+34>>1]=32;w[b+28>>1]=e;v[b+37|0]=y[a+13|0];v[b+36|0]=y[a+16|0];f=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[b>>2]=f;c=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);x[b+4>>2]=c;d=(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+c|0;x[b+8>>2]=d;e=y[a+14|0];if(e&16){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;f=f>>>1|0;x[b>>2]=f;e=y[a+14|0]}if(e&32){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;x[b>>2]=f>>>1;e=y[a+14|0]}if(!(!(e&3)|c>>>0>=d>>>0)){w[b+34>>1]=34;w[b+34>>1]=y[a+14|0]&2?38:34}a=Tb(g+4|0,21204);Ce(b+43|0,a);tb(a);db=g+16|0}function XL(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{e=db-48|0;db=e;d=Gb(e+36|0);x[23549]=0;P(869,b|0,e+24|0);g=x[23549];x[23549]=0;if((g|0)!=1){b:{g=x[e+28>>2];f=x[e+24>>2];Ze(d);x[23549]=0;g=!g&f>>>0>=255|g?255:f;P(59,d|0,g|0);f=x[23549];x[23549]=0;if((f|0)==1){break b}c:{while(1){if((g|0)==(h|0)){b=UV(Mb(d),Bb(x[d+4>>2],y[d+11|0]));if((b|0)==-1){break c}x[23549]=0;P(59,d|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){break c}break b}f=uc(d,h);x[23549]=0;O(870,b|0,f|0)|0;f=x[23549];x[23549]=0;if((f|0)!=1){h=h+1|0;continue}break}break b}x[23549]=0;S(11,e+12|0,a|0,d|0);a=x[23549];x[23549]=0;if((a|0)==1){break b}a=e+12|0;zb(c,a);tb(a);tb(d);db=e+48|0;break a}}a=N()|0;tb(d);Q(a|0);p()}}function gaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{d=db-16|0;db=d;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(d+8|0,x[vb(d+4|0,a)>>2]);b:{c=bk(x[b>>2],x[b+4>>2]);if(!c){break b}x[23549]=0;P(402,a|0,c|0);e=x[23549];x[23549]=0;if((e|0)!=1){e=x[b+4>>2];f=x[b>>2];x[23549]=0;Rs(a,f,e,c);c=x[23549];x[23549]=0;if((c|0)!=1){break b}}a=N()|0;ul(d+8|0);Q(a|0);p()}c=d+8|0;Hd(c);ul(c);db=d+16|0;x[a+20>>2]=x[b+20>>2];d=x[b+16>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=d;x[23549]=0;d=O(856,a+24|0,b+24|0)|0;c=x[23549];x[23549]=0;c:{d:{if((c|0)!=1){x[23549]=0;O(53,a+36|0,b+36|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break d}x[a+48>>2]=x[b+48>>2];break a}b=N()|0;break c}b=N()|0;sc(d)}ek(a);Q(b|0);p()}}function Kfa(a){a=a|0;var b=0,c=0,d=0,e=0;c=db-176|0;db=c;b=c+12|0;lh(b,a);x[23549]=0;P(77,c+24|0,b|0);a=x[23549];x[23549]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[23549]=0;a=O(78,c+36|0,c+24|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break e}tb(c+24|0);tb(c+12|0);b=x[x[a>>2]-12>>2];x[23549]=0;d=ca(61)|0;e=x[23549];x[23549]=0;if((e|0)==1){break c}x[23549]=0;S(62,c+8|0,a+b|0,d|0);b=x[23549];x[23549]=0;if((b|0)==1){break c}Xb(c+8|0);x[23549]=0;b=O(79,a|0,c+24|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break c}a=Pk(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);d=z[c+24>>1];mf(b);db=c+176|0;a=(a?0:d)&65535;break a}b=N()|0;break d}b=N()|0;tb(c+24|0)}tb(c+12|0);break b}b=N()|0;mf(a)}Q(b|0);p()}return a|0}function yda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=db-16|0;db=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=e>>>21&2040;n=w[e+39942>>1];o=w[e+39940>>1];p=w[e+39938>>1];e=w[e+39936>>1];f=0;while(1){if((f|0)!=2){g=f+m|0;x[(f<<2)+b>>2]=(((D(v[g|0],p)+D(v[g-2|0],e)|0)+D(v[g+2|0],o)|0)+D(v[g+4|0],n)<<8)/16384;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Qb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;db=b+16|0}function jm(a,b,c){var d=0,e=0,f=0;d=Gb(a);a=y[b+11|0];e=x[b+4>>2];x[23549]=0;P(45,d|0,Oc(e,a)|0);a=x[23549];x[23549]=0;if((a|0)!=1){a:{while(1){if(Oc(x[b+4>>2],y[b+11|0])>>>0>f>>>0){e=x[_i(b,f)>>2];a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if((e|0)==x[(a<<2)+c>>2]){x[23549]=0;P(46,d|0,a<<24>>24);a=x[23549];x[23549]=0;if((a|0)!=1){break b}break a}else{a=a+1|0;continue}}break}d:{while(1){if((a|0)==32){break d}if((e|0)!=x[(a<<2)+c>>2]){a=a+1|0;continue}break}x[23549]=0;P(46,d|0,a<<24>>24);a=x[23549];x[23549]=0;if((a|0)!=1){break b}break a}x[23549]=0;P(46,d|0,63);a=x[23549];x[23549]=0;if((a|0)!=1){break b}break a}f=f+1|0;continue}break}return}}a=N()|0;tb(d);Q(a|0);p()}function rO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=db-112|0;db=f;x[f+108>>2]=0;e=ao(a,e&65535,d,c,f+108|0);c=y[b+790|0];if(!x[f+108>>2]){d=(c|0)==15;h=d&!y[b+792|0];e=e<<8;a:{if(e){x[b+664>>2]=e;break a}e=0;if(d){break a}e=x[b+664>>2]}h=h?0:y[b+836|0]<<16}if((c|0)==15){c=y[b+792|0];b:{if(!c){c=x[b+76>>2];x[f+4>>2]=1;g=x[Yc(f+4|0,f+108|0)>>2]<<3;e=yka(c,0,e,0);d=(256<<g>>>1|0)+e|0;c=hb;c=d>>>0<e>>>0?c+1|0:c;e=g+8|0;g=d;d=e&31;if((e&63)>>>0>=32){e=0;c=c>>>d|0}else{e=c>>>d|0;c=((1<<d)-1&c)<<32-d|g>>>d}e=Qc(c,e);break b}lR(f+4|0);if(c>>>0>9){break b}c=x[b+104>>2];if(!c){break b}e=x[xb(c+68|0,y[b+792|0]-1|0)>>2]+e|0}x[b+664>>2]=e}fo(a,b,e+h|0);db=f+112|0}function O1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=db-32|0;db=d;e=x[a+28>>2];x[d+16>>2]=e;f=x[a+20>>2];x[d+28>>2]=c;x[d+24>>2]=b;b=f-e|0;x[d+20>>2]=b;f=b+c|0;i=2;b=d+16|0;a:{while(1){b:{c:{d:{if(!Yw(xa(x[a+60>>2],b|0,i|0,d+12|0)|0)){g=x[d+12>>2];if((g|0)==(f|0)){break d}if((g|0)>=0){break c}break b}if((f|0)!=-1){break b}}b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];a=c;break a}h=x[b+4>>2];j=h>>>0<g>>>0;e=(j<<3)+b|0;h=g-(j?h:0)|0;x[e>>2]=h+x[e>>2];b=(j?12:4)+b|0;x[b>>2]=x[b>>2]-h;f=f-g|0;i=i-j|0;b=e;continue}break}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a>>2]=x[a>>2]|32;a=0;if((i|0)==2){break a}a=c-x[b+4>>2]|0}db=d+32|0;return a|0}function yD(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-1641380927){break a}b=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);if(b>>>0<36){break a}c=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);if(c>>>0<36){break a}d=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);if(d>>>0<36){break a}e=y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24);if(e-1>>>0>858993458){break a}f=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);if(f-1>>>0>536870910){break a}a=y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24);if(D(e,-5)-1>>>0<b>>>0|a-1>>>0>1073741822|(f<<3^-1)>>>0<c>>>0){break a}g=(a<<2^-1)>>>0>=d>>>0}return g}function pW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=db-208|0;db=d;if(!Ju(c,a)){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0}_B(c,d+16|0,D(y[a+4|0],3));a:{if(y[a+4|0]<2){break a}c=db-16|0;db=c;x[c+12>>2]=64;x[c+8>>2]=255;e=y[Cb(c+12|0,c+8|0)|0];db=c+16|0;v[d+12|0]=e;ah(b,y[Sb(a+4|0,d+12|0)|0]);v[b+13|0]=y[a+2|0];v[b+14|0]=y[a+3|0];a=y[a+1|0];v[b+15|0]=a;v[b+16|0]=a;e=x[b>>2];f=ne(e,x[b+4>>2]);a=0;while(1){if((a|0)==(f|0)){break a}b:{if(!a){b=y[d+18|0];c=xb(e,0);break b}g=z[xb(e,a-1|0)>>1];x[d+12>>2]=1;b=(d+16|0)+D(a,3)|0;x[d+8>>2]=(v[b+1|0]&1)<<8|y[b|0];h=Re(d+12|0,d+8|0);c=xb(e,a);w[c>>1]=z[h>>1]+g;b=y[b+2|0]}v[c+2|0]=b;a=a+1|0;continue}}db=d+208|0}function Vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=db-16|0;db=e;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];g=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=g;k=b+24|0;g=x[a+8>>2];l=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=(x[e+12>>2]<<1)+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=(((((D(w[f+4>>1],w[b+10>>1])+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/2|0)+((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)/2|0)|0)/16384|0;x[c>>2]=x[c>>2]+D(b,i);x[c+4>>2]=x[c+4>>2]+D(b,h);Qb(e+8|0,g,l);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;db=e+16|0}function $g(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=db+-64|0;db=f;a:{b:{if((b|0)==65535|c-1025>>>0<4294966272){break b}d=x[a>>2];e=x[a+4>>2];if(se(d,e,b)){break b}c:{d:{if(kk(d,e)>>>0<=b>>>0){d=dy(f+12|0,a);x[23549]=0;S(187,a|0,b+1|0,d|0);e=x[23549];x[23549]=0;if((e|0)==1){break d}Nj(d);d=x[a>>2]}x[23549]=0;P(197,Rf(d,b)|0,c|0);c=x[23549];x[23549]=0;e:{if((c|0)!=1){c=Rf(x[a>>2],b);x[c+16>>2]=0;x[c+20>>2]=0;c=x[a>>2];x[23549]=0;W(198,Rf(c,b)|0);c=x[23549];x[23549]=0;if((c|0)!=1){break e}}b=T(92296)|0;a=eb;break c}a=Rf(x[a>>2],b);g=Kb(x[a>>2],x[a+4>>2]);break b}b=T(92296)|0;a=eb;Nj(d)}if(($(92296)|0)!=(a|0)){break a}Y(b|0)|0;Z()}db=f- -64|0;return g|0}Q(b|0);p()}function aM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=E(0),j=E(0),k=0,l=E(0);g=db-16|0;db=g;e=w[d>>1];f=w[d+2>>1];if(!(!z[b>>1]|(e|0)>(f|0)|(!(B[c>>2]>E(0))|(f-e|0)>32766))){w[a>>1]=3;f=a+4|0;Dc(f);w[a+28>>1]=65472;x[g+12>>2]=1065353216;eM(f,g+12|0);x[a+32>>2]=0;w[a+30>>1]=0;Dc(a+16|0);h=w[d>>1];w[a+28>>1]=h;e=db-16|0;db=e;w[e+14>>1]=z[b>>1];w[e+12>>1]=32767;b=w[Uc(e+14|0,e+12|0)>>1];db=e+16|0;w[a+30>>1]=b;i=E(F(B[c>>2]));B[a+32>>2]=i;i=qe(i,E(E(1)/E(b|0)));Yk(f,(w[d+2>>1]-h|0)+1|0);b=x[a+4>>2];c=w[a+28>>1];e=w[d+2>>1];d=w[d>>1];while(1){if((d|0)>(e|0)){Cp(a)}else{j=qe(i,E(d|0));k=xb(b,d-c|0),l=j,B[k>>2]=l;d=d+1|0;continue}break}h=1}db=g+16|0;return h|0}function jca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;h=db-16|0;db=h;c=jf(a,c);ae(h,x[a+28>>2]);i=a;a:{if(!c){d=0;if(ed(a,5)){break a}}f=x[a+28>>2];a=db-16|0;db=a;x[a+12>>2]=0;aI(f,a+12|0,1);e=x[a+12>>2];d=e>>>2&3;v[a+11|0]=d;if(d){v[a+4|0]=3;d=y[Sb(a+4|0,a+11|0)|0];v[a+4|0]=0;v[a|0]=0;v[a+10|0]=0;b:{if(!d){break b}hi(f,a+4|0);if((d|0)==1){break b}hi(f,a);if(d>>>0<3){break b}hi(f,a+10|0);g=y[a+10|0]<<24}e=e&255|(y[a+4|0]<<8|y[a|0]<<16|g)}d=e>>>4|0;x[a+4>>2]=d;x[a>>2]=1e6;Mx(b,x[Cb(a+4|0,a)>>2]);e=0;while(1){g=Bb(x[b+4>>2],y[b+11|0]);if(g>>>0<=e>>>0){if((d|0)!=(g|0)){Sl(f,d-g|0)}db=a+16|0}else{Lk(f,uc(b,e),1);e=e+1|0;continue}break}d=c}cf(i,d);db=h+16|0}function Uea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=db-16|0;db=e;i=e,j=$j(b),x[i+4>>2]=j;d=db-16|0;db=d;g=a;c=Ud(a);a:{if(c){f=gc(g);while(1){a=c;c=a+13|0;if(zt(b,c)){f=a;c=x[a>>2];if(c){continue}break a}if(!zt(c,b)){break a}f=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=gc(g);f=a}x[d+12>>2]=a;b=x[f>>2];if(!b){c=db-16|0;db=c;a=gc(g);h=rh(d,Hc(20),Ag(c+8|0,a));b=x[h>>2];a=x[e+4>>2];a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[b+17|0]=0;v[b+13|0]=a;v[b+14|0]=a>>>8;v[b+15|0]=a>>>16;v[b+16|0]=a>>>24;i=gc(h),j=1,v[i+4|0]=j;db=c+16|0;Yg(g,x[d+12>>2],f,x[d>>2]);b=Zd(d);ol(d);h=1}Xg(e+8|0,x[vb(d,b)>>2],h);db=d+16|0;db=e+16|0;return x[e+8>>2]+17|0}function wP(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=ot(b);e=db-16|0;db=e;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(e+8|0,x[vb(e+4|0,a)>>2]);x[23549]=0;P(738,a|0,2048);c=x[23549];x[23549]=0;a:{if((c|0)!=1){h=db-16|0;db=h;g=gr(h+4|0,a,2048);c=x[g+4>>2];j=x[g+8>>2];while(1){if((c|0)==(j|0)){fc(g);db=h+16|0}else{x[c>>2]=0;x[c+4>>2]=0;c=c+8|0;x[g+4>>2]=c;continue}break}c=e+8|0;Hd(c);nt(c);db=e+16|0;break a}a=N()|0;nt(e+8|0);Q(a|0);p()}while(1){b:{d=1;if((f|0)!=1024){if((f|0)==2048){break b}d=+(f-1024|0);k=ot(M(d*d*-9.5367431640625e-7+1)*b);d=d*.0372006759294457;d=k*ui(d)/(i*d)}l=Qe(x[a>>2],f),m=d*.011841342921061943,C[l>>3]=m;f=f+1|0;continue}break}}function jY(a){a=a|0;var b=0,c=0,d=0,e=0;c=db-176|0;db=c;b=c+12|0;lh(b,a);x[23549]=0;P(77,c+24|0,b|0);a=x[23549];x[23549]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[23549]=0;a=O(78,c+36|0,c+24|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break e}tb(c+24|0);tb(c+12|0);b=x[x[a>>2]-12>>2];x[23549]=0;d=ca(61)|0;e=x[23549];x[23549]=0;if((e|0)==1){break c}x[23549]=0;S(62,c+8|0,a+b|0,d|0);b=x[23549];x[23549]=0;if((b|0)==1){break c}Xb(c+8|0);x[23549]=0;b=O(82,a|0,c+24|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break c}a=Pk(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);d=x[c+24>>2];mf(b);db=c+176|0;a=a?0:d;break a}b=N()|0;break d}b=N()|0;tb(c+24|0)}tb(c+12|0);break b}b=N()|0;mf(a)}Q(b|0);p()}return a|0}function g5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=db-32|0;db=d;e=Nb(a);a=0;c=x[b+24>>2];c=lt(x[c+484344>>2],x[c+484348>>2]);x[23549]=0;P(167,e|0,c|0);c=x[23549];x[23549]=0;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){c=x[b+24>>2];f=x[c+484344>>2];if(lt(f,x[c+484348>>2])>>>0<=a>>>0){break b}x[23549]=0;P(996,d+8|0,Yb(f,a)|0);c=x[23549];x[23549]=0;if((c|0)!=1){c=x[b+24>>2];x[23549]=0;S(983,d+20|0,c|0,d+8|0);c=x[23549];x[23549]=0;if((c|0)==1){break e}x[23549]=0;P(169,e|0,d+20|0);c=x[23549];x[23549]=0;if((c|0)==1){break d}a=a+1|0;tb(d+20|0);tb(d+8|0);continue}break}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(d+20|0)}tb(d+8|0);break a}db=d+32|0;return}a=N()|0}Yd(e);Q(a|0);p()}function kX(){var a=0,b=0,c=0,d=0;a=PC(x[(x[x[116714]-12>>2]+466856|0)+28>>2],10);c=db-16|0;db=c;x[23549]=0;b=O(12,c+8|0,466856)|0;d=x[23549];x[23549]=0;a:{b:{c:{d:{if((d|0)!=1){e:{if(!vd(y[b|0])){break e}d=Fm(c+4|0,466856);x[23549]=0;a=O(20,d|0,a|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){if(x[a>>2]){break e}a=x[x[116714]-12>>2];x[23549]=0;P(15,a+466856|0,1);a=x[23549];x[23549]=0;if((a|0)!=1){break e}}a=T(0)|0;jk(b);break d}jk(b);break c}a=T(0)|0}Y(a|0)|0;b=x[x[116714]-12>>2];x[23549]=0;W(16,b+466856|0);b=x[23549];x[23549]=0;if((b|0)==1){break b}Z()}db=c+16|0;break a}c=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(c|0);p()}T(0)|0;Rb();p()}Tq(466856)}function D6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=db-32|0;db=d;x[23549]=0;W(927,a|0);e=x[23549];x[23549]=0;a:{b:{c:{if((e|0)==1){break c}x[23549]=0;W(928,b|0);e=x[23549];x[23549]=0;if((e|0)==1){break c}x[23549]=0;W(928,c|0);f=x[23549];x[23549]=0;e=1;if((f|0)==1){break c}f=x[a+24>>2];b=mc(d+24|0,b);c=mc(d+16|0,c);g=x[c>>2];c=x[c+4>>2];x[23549]=0;h=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=h;DF(949,f,d+8|0,g,c);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,5448,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();e=0}db=d+32|0;return e|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function HT(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=db-16|0;db=g;d=vb(g+12|0,x[a+4>>2]);c=vb(g+8|0,x[a>>2]);f=x[vb(g+4|0,x[b+4>>2])>>2];h=db-16|0;db=h;i=h+8|0;e=db-32|0;db=e;Od(e+24|0,x[d>>2],x[c>>2]);j=e+16|0;c=x[e+24>>2];k=x[e+28>>2];d=db-16|0;db=d;x[d+8>>2]=f;x[d+12>>2]=c;while(1){if(sd(c,k)){c=Gf(c);f=Gf(x[d+8>>2]);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[f|0]=c;v[f+1|0]=c>>>8;v[f+2|0]=c>>>16;v[f+3|0]=c>>>24;c=fj(d+12|0);fj(d+8|0);c=x[c>>2];continue}break}vc(j,c,d+8|0);db=d+16|0;d=x[e+16>>2];x[e+12>>2]=x[e+20>>2];vc(i,d,e+12|0);db=e+32|0;db=h+16|0;x[b+4>>2]=x[h+12>>2];Pb(a,b+4|0);Pb(a+4|0,b+8|0);Pb(wb(a),kc(b));x[b>>2]=x[b+4>>2];db=g+16|0}function Jy(a,b,c,d){var e=0,f=0,g=0;a:{if(!d){break a}if(c){v[b+815|0]=c;break a}c=y[b+815|0]}e=x[a+480180>>2];d=e&1048580;c=d?(c&240?-16:15)&c:c;b:{c:{d:{if(!d){d=c&240;e:{f:{g:{h:{c=c&15;if((c|0)==15){a=x[a+480208>>2]&4096;if(!d){break h}if(!a){break b}c=0-(d>>>2|0)|0;break d}a=x[a+480208>>2]&4096;if(!c|(d|0)!=240){break g}if(!a){break b}c=c<<2;break c}d=0;if(!a){break f}break b}if(a){break b}if(!c){break e}}c=c<<2;if(!d|!(e&16777248)){break c}break b}c=0-(d>>>2|0)|0;break d}if(y[a+480209|0]&16){break b}d=c&240;c=d?d>>>2|0:0-(c<<2&60)|0;if(!Ob(a+1074312|0,56)){break d}c=c>>2}if(!c){break b}}a=x[b+692>>2];w[b+784>>1]=0;f=b,g=Ub(a+c|0,0,256),x[f+692>>2]=g}}function OH(a){a=a|0;var b=0,c=0,d=0,e=0;d=db-16|0;db=d;a:{b:{if(!x[(x[x[a>>2]-12>>2]+a|0)+24>>2]){break b}x[23549]=0;c=O(1084,d+8|0,a|0)|0;b=x[23549];x[23549]=0;c:{if((b|0)!=1){d:{if(!vd(y[c|0])){break d}b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[23549]=0;b=R(1085,b|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=x[x[a>>2]-12>>2];x[23549]=0;W(1086,a+b|0);b=x[23549];x[23549]=0;if((b|0)!=1){break d}}b=T(0)|0;NH(c);break c}NH(c);break b}b=T(0)|0}Y(b|0)|0;c=x[x[a>>2]-12>>2];x[23549]=0;W(16,a+c|0);c=x[23549];x[23549]=0;if((c|0)==1){break a}Z()}db=d+16|0;return a|0}a=N()|0;x[23549]=0;X(17);c=x[23549];x[23549]=0;if((c|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function wfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=db-160|0;db=d;b=-1;a:{if(!Gl(a,80)){break a}b:{c:{if(!ml(a,60)){break c}if(!ER(a,d+140|0)){break c}c=15;if(Lt(d+140|0,15)){break b}}if(!Gl(a,144)){break a}b=0;if(!ml(a,124)){break a}if(!ER(a,d+140|0)){break a}c=31;if(!Lt(d+140|0,31)){break a}}MB(a);b=0;d:{while(1){if((b&65535)>>>0>=c>>>0){break d}b=b+1|0;if(CR(a)>>>0<=131072){continue}break}b=0;break a}b=-1;if(!dd(a,D(c,30)|20)){break a}c=db-16|0;db=c;e=d+10|0;GS(c+8|0,e);f=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){dd(a,x[c+12>>2])}db=c+16|0;a=(f|0)==(g|0);if(!a){tA(e)}if(!a){break a}b=DR(y[d+10|0])}db=d+160|0;return b|0}function dp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{f=db-16|0;db=f;g=f+4|0;e=db-32|0;db=e;c=Ye(e+20|0,1,0);b:{c:{d:{while(1){d=Mb(c);Ns(e+12|0,d,Bb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[e+16>>2]){break d}d=$f(Bb(x[c+4>>2],y[c+11|0]));x[23549]=0;P(58,c|0,d|0);d=x[23549];x[23549]=0;if((d|0)!=1){continue}break}break c}b=x[e+12>>2];d=Mb(c);x[23549]=0;P(59,c|0,b-d|0);b=x[23549];x[23549]=0;e:{if((b|0)!=1){x[23549]=0;P(71,g|0,c|0);b=x[23549];x[23549]=0;if((b|0)!=1){break e}break c}break c}tb(c);db=e+32|0;break b}a=N()|0;tb(c);Q(a|0);p()}x[23549]=0;P(70,a|0,g|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(f+4|0);db=f+16|0;break a}a=N()|0;tb(f+4|0);Q(a|0);p()}}function TU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{f=db-16|0;db=f;g=f+4|0;e=db-32|0;db=e;c=Ye(e+20|0,1,0);b:{c:{d:{while(1){d=Mb(c);Ax(e+12|0,d,Bb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[e+16>>2]){break d}d=$f(Bb(x[c+4>>2],y[c+11|0]));x[23549]=0;P(58,c|0,d|0);d=x[23549];x[23549]=0;if((d|0)!=1){continue}break}break c}b=x[e+12>>2];d=Mb(c);x[23549]=0;P(59,c|0,b-d|0);b=x[23549];x[23549]=0;e:{if((b|0)!=1){x[23549]=0;P(71,g|0,c|0);b=x[23549];x[23549]=0;if((b|0)!=1){break e}break c}break c}tb(c);db=e+32|0;break b}a=N()|0;tb(c);Q(a|0);p()}x[23549]=0;P(70,a|0,g|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(f+4|0);db=f+16|0;break a}a=N()|0;tb(f+4|0);Q(a|0);p()}}function Wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=db-16|0;db=e;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];g=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=g;k=b+24|0;g=x[a+8>>2];l=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=x[e+12>>2]+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=((((D(v[f+2|0],w[b+10>>1])+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8>>1)+(((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])<<8>>1)|0)/16384|0;x[c>>2]=x[c>>2]+D(b,i);x[c+4>>2]=x[c+4>>2]+D(b,h);Qb(e+8|0,g,l);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;db=e+16|0}function Tq(a){a=a|0;var b=0,c=0,d=0,e=0;d=db-16|0;db=d;a:{b:{if(!x[(x[x[a>>2]-12>>2]+a|0)+24>>2]){break b}x[23549]=0;c=O(12,d+8|0,a|0)|0;b=x[23549];x[23549]=0;c:{if((b|0)!=1){d:{if(!vd(y[c|0])){break d}b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[23549]=0;b=R(21,b|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=x[x[a>>2]-12>>2];x[23549]=0;P(15,a+b|0,1);b=x[23549];x[23549]=0;if((b|0)!=1){break d}}b=T(0)|0;jk(c);break c}jk(c);break b}b=T(0)|0}Y(b|0)|0;c=x[x[a>>2]-12>>2];x[23549]=0;W(16,a+c|0);c=x[23549];x[23549]=0;if((c|0)==1){break a}Z()}db=d+16|0;return a|0}a=N()|0;x[23549]=0;X(17);c=x[23549];x[23549]=0;if((c|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function n1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=db-16|0;db=f;a:{b:{if(!qc(b,-1)){i=x[a+8>>2];j=x[a+12>>2];d=x[a+24>>2];if((d|0)==x[a+28>>2]){c=-1;if(!(y[a+48|0]&16)){break a}k=x[a+44>>2];h=x[a+20>>2];x[23549]=0;g=a+32|0;P(46,g|0,0);e=x[23549];x[23549]=0;if((e|0)==1){break b}e=Mc(g);x[23549]=0;P(59,g|0,e|0);e=x[23549];x[23549]=0;if((e|0)==1){break b}c=Mb(g);Mw(a,c,Bb(x[a+36>>2],y[a+43|0])+c|0);_r(a,d-h|0);x[a+44>>2]=x[a+20>>2]+(k-h|0);d=x[a+24>>2]}x[f+12>>2]=d+1;d=x[Yc(f+12|0,a+44|0)>>2];x[a+44>>2]=d;if(y[a+48|0]&8){c=Mb(a+32|0);xn(a,c,c+(j-i|0)|0,d)}c=TH(a,b<<24>>24);break a}c=Lw(b);break a}Y(T(0)|0)|0;Z()}db=f+16|0;return c|0}function vda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=db-16|0;db=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+8>>2];h=(x[b+12>>2]<<1)+i|0;e=e>>>21&2040;e=(((D(w[h>>1],w[e+39938>>1])+D(w[h-2>>1],w[e+39936>>1])|0)+D(w[h+2>>1],w[e+39940>>1])|0)+D(w[h+4>>1],w[e+39942>>1])|0)/16384|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Qb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;db=b+16|0}function rn(a,b,c,d,e,f,g,h,i,j,k){var l=0,m=0,n=0;a:{b:{l=x[d>>2];if((l|0)!=(c|0)){break b}m=43;n=a&255;if((n|0)!=y[k+24|0]){m=45;if(y[k+25|0]!=(n|0)){break b}}x[d>>2]=c+1;v[c|0]=m;break a}c:{if(!(!Bb(g,h)|(a|0)!=(f|0))){h=0;a=x[j>>2];if((a-i|0)>159){break c}b=x[e>>2];x[j>>2]=a+4;x[a>>2]=b;break a}h=-1;a=oi(k,k+26|0,a)-k|0;if((a|0)>23){break c}d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(a|0)<22){break d}if((c|0)==(l|0)|(l-c|0)>2|y[l-1|0]!=48){break c}x[e>>2]=0;x[d>>2]=l+1;v[l|0]=y[a+81792|0];return 0}x[d>>2]=l+1;v[l|0]=y[a+81792|0];x[e>>2]=x[e>>2]+1;h=0}return h}x[e>>2]=0;return 0}function Cba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=db-80|0;db=d;e=Nf(d+52|0);x[23549]=0;g=O(774,b|0,e|0)|0;f=x[23549];x[23549]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23549]=0;R(775,a|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){break b}}break a}g=x[e+4>>2];x[23549]=0;S(176,d+12|0,b|0,g|0);f=x[23549];x[23549]=0;if((f|0)==1){break a}f=d+12|0;h=hc(d+32|0,f);Zc(e+8|0,h);ub(h);ub(f);d:{if(c>>>0<2){break d}c=g&1;if(!c){break d}x[23549]=0;O(174,b|0,2-c|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break d}break a}wl(a,e)}Gd(e);db=d+80|0;return}a=N()|0;Gd(e);Q(a|0);p()}function on(a,b,c,d,e,f,g,h,i,j,k){var l=0,m=0;a:{b:{l=x[d>>2];if((l|0)!=(c|0)){break b}m=43;if(x[k+96>>2]!=(a|0)){m=45;if(x[k+100>>2]!=(a|0)){break b}}x[d>>2]=c+1;v[c|0]=m;break a}c:{if(!(!Bb(g,h)|(a|0)!=(f|0))){h=0;a=x[j>>2];if((a-i|0)>159){break c}b=x[e>>2];x[j>>2]=a+4;x[a>>2]=b;break a}h=-1;f=vw(k,k+104|0,a)-k|0;if((f|0)>92){break c}a=f>>2;d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<88){break d}if((c|0)==(l|0)|(l-c|0)>2|y[l-1|0]!=48){break c}x[e>>2]=0;x[d>>2]=l+1;v[l|0]=y[a+81792|0];return 0}x[d>>2]=l+1;v[l|0]=y[a+81792|0];x[e>>2]=x[e>>2]+1;h=0}return h}x[e>>2]=0;return 0}function yp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=db-16|0;db=f;g=f+4|0;e=db-32|0;db=e;c=Ye(e+20|0,1,0);a:{b:{c:{while(1){d=Mb(c);Ns(e+12|0,d,Bb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[e+16>>2]){break c}d=$f(Bb(x[c+4>>2],y[c+11|0]));x[23549]=0;P(58,c|0,d|0);d=x[23549];x[23549]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Mb(c);x[23549]=0;P(59,c|0,b-d|0);b=x[23549];x[23549]=0;d:{if((b|0)!=1){x[23549]=0;P(60,g|0,c|0);b=x[23549];x[23549]=0;if((b|0)!=1){break d}break b}break b}tb(c);db=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}x[23549]=0;P(57,a|0,g|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(f+4|0);db=f+16|0;return}a=N()|0;tb(f+4|0);Q(a|0);p()}function D9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=db-16|0;db=f;g=f+4|0;e=db-32|0;db=e;c=Ye(e+20|0,1,0);a:{b:{c:{while(1){d=Mb(c);Ns(e+12|0,d,Bb(x[c+4>>2],y[c+11|0])+d|0,y[b|0]);if(!x[e+16>>2]){break c}d=$f(Bb(x[c+4>>2],y[c+11|0]));x[23549]=0;P(58,c|0,d|0);d=x[23549];x[23549]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Mb(c);x[23549]=0;P(59,c|0,b-d|0);b=x[23549];x[23549]=0;d:{if((b|0)!=1){x[23549]=0;P(60,g|0,c|0);b=x[23549];x[23549]=0;if((b|0)!=1){break d}break b}break b}tb(c);db=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}x[23549]=0;P(57,a|0,g|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(f+4|0);db=f+16|0;return}a=N()|0;tb(f+4|0);Q(a|0);p()}function Qia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=x[a>>2];d=Aq(c,x[a+4>>2]);if(d>>>0<b>>>0){f=db-32|0;db=f;c=b-d|0;b=x[wb(a)>>2];e=x[a+4>>2];a:{if(c>>>0<=(b-e|0)/48>>>0){d=db-16|0;db=d;b=sV(d+4|0,a,c);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){fc(b);db=d+16|0}else{KT(a);a=a+48|0;x[b+4>>2]=a;continue}break}break a}b=wb(a);d=pV(f+12|0,qV(a,Aq(x[a>>2],e)+c|0),Aq(x[a>>2],x[a+4>>2]),b);e=db-16|0;db=e;b=e+4|0;x[b>>2]=x[d+8>>2];g=x[d+8>>2];x[b+8>>2]=d+8;x[b+4>>2]=D(c,48)+g;c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){KT(c);c=x[b>>2]+48|0;x[b>>2]=c;continue}break}Kd(b);db=e+16|0;oV(a,d);nV(d)}db=f+32|0;return}if(b>>>0<d>>>0){Dd(a,c+D(b,48)|0)}}function Lia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=b;c=db-48|0;db=c;d=a;a:{if(gu(x[d>>2],x[d+8>>2])){x[g>>2]=0;break a}PT(c+16|0,c+32|0);lc(c+24|0,x[d>>2],x[d+8>>2],x[c+16>>2],x[c+20>>2]);h=x[c+28>>2];i=y[c+32|0];f=i&127;x[g>>2]=f;a=f;b=0;while(1){if(a){b=b+1|0;a=a>>>1|0;continue}break}a=b;e=1;while(1){b=(D(h,7)+a|0)+D(e,-7)|0;b:{while(1){if(i<<24>>24>=0|e>>>0>=h>>>0){break b}i=y[(c+32|0)+e|0];f=i&127|f<<7;x[g>>2]=f;a=a+7|0;e=e+1|0;if((h|0)!=(e|0)){continue}break}Zb(d,h);PT(c+8|0,c+32|0);lc(c+24|0,x[d>>2],x[d+8>>2],x[c+8>>2],x[c+12>>2]);h=x[c+28>>2];f=x[g>>2];e=0;a=b;continue}break}Zb(d,e);if(a>>>0<33){break a}x[g>>2]=-1}db=c+48|0}function jia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=db-32|0;db=d;x[d+28>>2]=0;ak(a,d+28|0);a:{b:{i=x[d+28>>2];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Gb(d+16|0);x[23549]=0;w[d+14>>1]=0;e=U(437,a|0,g|0,255)|0;h=x[23549];x[23549]=0;if((h|0)==1){break b}if(!e){break d}x[23549]=0;P(426,a|0,d+14|0);e=x[23549];x[23549]=0;if((e|0)==1){break b}x[23549]=0;S(11,d|0,c|0,g|0);e=x[23549];x[23549]=0;if((e|0)!=1){x[23549]=0;e=O(438,b|0,d+14|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break e}zb(e,d);tb(d);tb(g);f=f+1|0;continue}break}f=N()|0;break a}f=N()|0;tb(d);break a}tb(g)}db=d+32|0;return}f=N()|0}tb(g);Q(f|0);p()}function wda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=db-16|0;db=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+8>>2];h=x[b+12>>2]+i|0;e=e>>>21&2040;e=(((D(v[h|0],w[e+39938>>1])+D(v[h-1|0],w[e+39936>>1])|0)+D(v[h+1|0],w[e+39940>>1])|0)+D(v[h+2|0],w[e+39942>>1])<<8)/16384|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Qb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;db=b+16|0}function vF(a,b,c,d){var e=0,f=0,g=0;f=db-32|0;db=f;x[23549]=0;W(927,a|0);e=x[23549];x[23549]=0;a:{b:{c:{d:{e:{f:{if((e|0)==1){break f}x[23549]=0;W(928,b|0);e=x[23549];x[23549]=0;if((e|0)==1){break f}g=x[a+24>>2];x[23549]=0;e=O(54,f+8|0,b|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break e}x[23549]=0;S(d|0,f+20|0,g|0,e|0);b=x[23549];x[23549]=0;if((b|0)==1){break d}a=f+20|0;b=_f(Mb(a));tb(a);tb(e);break b}b=T(0)|0;break c}b=T(0)|0;break c}b=T(0)|0;tb(e)}Y(b|0)|0;b=0;x[23549]=0;V(914,c|0,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z()}db=f+32|0;return b}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function mK(a,b){var c=0,d=0,e=0,f=0,g=0;a:{f=db-16|0;db=f;g=f+4|0;e=db-32|0;db=e;c=Ye(e+20|0,1,0);b:{c:{d:{while(1){d=Mb(c);Ax(e+12|0,d,Bb(x[c+4>>2],y[c+11|0])+d|0,z[b>>1]);if(!x[e+16>>2]){break d}d=$f(Bb(x[c+4>>2],y[c+11|0]));x[23549]=0;P(58,c|0,d|0);d=x[23549];x[23549]=0;if((d|0)!=1){continue}break}break c}b=x[e+12>>2];d=Mb(c);x[23549]=0;P(59,c|0,b-d|0);b=x[23549];x[23549]=0;e:{if((b|0)!=1){x[23549]=0;P(71,g|0,c|0);b=x[23549];x[23549]=0;if((b|0)!=1){break e}break c}break c}tb(c);db=e+32|0;break b}a=N()|0;tb(c);Q(a|0);p()}x[23549]=0;P(70,a|0,g|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(f+4|0);db=f+16|0;break a}a=N()|0;tb(f+4|0);Q(a|0);p()}}function G2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=db-32|0;db=d;h=Gb(a);f=Gb(d+20|0);a=1;a:{b:{c:{while(1){e=a&65535;c=x[b+24>>2];if(e>>>0>z[c+480192>>1]){if(!(i&1)){break c}x[23549]=0;P(236,h|0,f|0);a=x[23549];x[23549]=0;if((a|0)!=1){break c}a=N()|0;break a}c=VM(c,e);x[23549]=0;c=O(54,d+8|0,c|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break b}e=xd(x[d+12>>2],y[d+19|0]);x[23549]=0;g=O(777,f|0,c|0)|0;j=x[23549];x[23549]=0;d:{if((j|0)==1){break d}x[23549]=0;O(916,g|0,21179)|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}i=e^1|i;tb(c);a=a+1|0;continue}break}a=N()|0;tb(c);break a}tb(f);db=d+32|0;return}a=N()|0}tb(f);tb(h);Q(a|0);p()}function vK(a,b){var c=0,d=0,e=0,f=0,g=0;a:{f=db-16|0;db=f;g=f+4|0;e=db-32|0;db=e;c=Ye(e+20|0,1,0);b:{c:{d:{while(1){d=Mb(c);Ax(e+12|0,d,Bb(x[c+4>>2],y[c+11|0])+d|0,y[b|0]);if(!x[e+16>>2]){break d}d=$f(Bb(x[c+4>>2],y[c+11|0]));x[23549]=0;P(58,c|0,d|0);d=x[23549];x[23549]=0;if((d|0)!=1){continue}break}break c}b=x[e+12>>2];d=Mb(c);x[23549]=0;P(59,c|0,b-d|0);b=x[23549];x[23549]=0;e:{if((b|0)!=1){x[23549]=0;P(71,g|0,c|0);b=x[23549];x[23549]=0;if((b|0)!=1){break e}break c}break c}tb(c);db=e+32|0;break b}a=N()|0;tb(c);Q(a|0);p()}x[23549]=0;P(70,a|0,g|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(f+4|0);db=f+16|0;break a}a=N()|0;tb(f+4|0);Q(a|0);p()}}function hK(a,b){var c=0,d=0,e=0,f=0,g=0;c=x[a>>2];x[a>>2]=b;if(c){x[23549]=0;W(790,c|0);a=x[23549];x[23549]=0;a:{if((a|0)!=1){d=x[c+4>>2];if(d){e=db-16|0;db=e;f=vb(e+12|0,d);a=x[f>>2];if(x[a>>2]){g=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(g|0)){b=b-4|0;Lf(b);continue}break}x[a+4>>2]=g;a=x[f>>2];b=x[a>>2];Qh(a);Eb(b)}db=e+16|0;Eb(d)}x[c+4>>2]=0;tN(c+1298408|0);Fy(c+1298344|0);tb(c+1298332|0);tb(c+1298320|0);tb(c+1298308|0);Ey(c+1298304|0);Dy(c+1298300|0);gt(c+1298264|0);Sy(c+1074376|0);b=c+946300|0;a=c+906300|0;while(1){b=_s(b-160|0);if((a|0)!=(b|0)){continue}break}Cz(c+484360|0);mN(c+484344|0);sc(c+480248|0);break a}T(0)|0;Rb();p()}Eb(c)}}function iia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=db-32|0;db=d;w[d+30>>1]=0;Mf(a,d+30|0);a:{b:{i=z[d+30>>1];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Gb(d+16|0);x[23549]=0;w[d+14>>1]=0;e=O(439,a|0,g|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break b}if(!e){break d}x[23549]=0;P(426,a|0,d+14|0);e=x[23549];x[23549]=0;if((e|0)==1){break b}x[23549]=0;S(11,d|0,c|0,g|0);e=x[23549];x[23549]=0;if((e|0)!=1){x[23549]=0;e=O(438,b|0,d+14|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break e}zb(e,d);tb(d);tb(g);f=f+1|0;continue}break}f=N()|0;break a}f=N()|0;tb(d);break a}tb(g)}db=d+32|0;return}f=N()|0}tb(g);Q(f|0);p()}function Zda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=db-16|0;db=b;e=x[a+40>>2];f=x[a+36>>2];j=x[a+16>>2];h=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=h;k=x[a+32>>2];l=x[a+28>>2];h=x[a+8>>2];m=x[a+12>>2];while(1){if(d){d=d-1|0;i=x[b+8>>2];i=((((x[b+12>>2]&2147483647)<<1|i>>>31)&2147483646)<<1)+j|0;g=0;while(1){if((g|0)!=2){x[(g<<2)+b>>2]=w[(g<<1)+i>>1];g=g+1|0;continue}break}f=f+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],f>>12);e=e+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],e>>12);Qb(b+8|0,h,m);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=e;x[a+20>>2]=f>>12;x[a+36>>2]=f;x[a+24>>2]=e>>12;db=b+16|0}function Eba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=db-80|0;db=d;e=Nf(d+52|0);x[23549]=0;c=O(770,b|0,e|0)|0;f=x[23549];x[23549]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23549]=0;R(771,a|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){break b}}break a}c=x[e+4>>2];x[23549]=0;c=$b(c);c=c?c:-1;S(176,d+12|0,b|0,c|0);f=x[23549];x[23549]=0;if((f|0)==1){break a}f=d+12|0;g=hc(d+32|0,f);Zc(e+8|0,g);ub(g);ub(f);d:{c=c&1;if(!c){break d}x[23549]=0;O(174,b|0,2-c|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break d}break a}wl(a,e)}Gd(e);db=d+80|0;return}a=N()|0;Gd(e);Q(a|0);p()}function D$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=db-16|0;db=k;l=j;a:{if(a){a=k+4|0;b=BG(b);Ck(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;Bk(a,b);zb(i,a);tb(a);Fh(a,b);zb(h,a);tb(a);m=d,n=Qi(b),v[m|0]=n;m=e,n=Ri(b),v[m|0]=n;Mg(a,b);zb(f,a);tb(k+4|0);Gh(a,b);zb(g,a);tb(k+4|0);a=Ak(b);break a}a=k+4|0;b=zG(b);Ck(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;Bk(a,b);zb(i,a);tb(a);Fh(a,b);zb(h,a);tb(a);m=d,n=Qi(b),v[m|0]=n;m=e,n=Ri(b),v[m|0]=n;Mg(a,b);zb(f,a);tb(k+4|0);Gh(a,b);zb(g,a);tb(k+4|0);a=Ak(b)}x[l>>2]=a;db=k+16|0}function F2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=db-32|0;db=c;h=Gb(a);f=Gb(c+20|0);a=1;a:{b:{c:{while(1){d=a&65535;e=x[b+24>>2];if(d>>>0>z[e+480190>>1]){if(!(i&1)){break c}x[23549]=0;P(236,h|0,f|0);a=x[23549];x[23549]=0;if((a|0)!=1){break c}a=N()|0;break a}x[23549]=0;e=O(54,c+8|0,WM(e,d)|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break b}d=xd(x[c+12>>2],y[c+19|0]);x[23549]=0;g=O(777,f|0,e|0)|0;j=x[23549];x[23549]=0;d:{if((j|0)==1){break d}x[23549]=0;O(916,g|0,21179)|0;g=x[23549];x[23549]=0;if((g|0)==1){break d}i=d^1|i;tb(e);a=a+1|0;continue}break}a=N()|0;tb(e);break a}tb(f);db=c+32|0;return}a=N()|0}tb(f);tb(h);Q(a|0);p()}function w$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=db-16|0;db=k;l=j;a:{if(a){a=k+4|0;b=wG(b);Ck(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;Bk(a,b);Li(i,a);Ec(a);Fh(a,b);Li(h,a);Ec(a);m=d,n=Qi(b),x[m>>2]=n;m=e,n=Ri(b),x[m>>2]=n;Mg(a,b);zb(f,a);tb(a);Gh(a,b);Li(g,a);Ec(k+4|0);a=Ak(b);break a}a=k+4|0;b=vG(b);Ck(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;Bk(a,b);Li(i,a);Ec(a);Fh(a,b);Li(h,a);Ec(a);m=d,n=Qi(b),x[m>>2]=n;m=e,n=Ri(b),x[m>>2]=n;Mg(a,b);zb(f,a);tb(a);Gh(a,b);Li(g,a);Ec(k+4|0);a=Ak(b)}x[l>>2]=a;db=k+16|0}function hA(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=db-16|0;db=g;h=x[a>>2];a:{if(Pc(h,x[a+4>>2])>>>0<=b>>>0){break a}b:{c:{switch(c|0){case 0:if((d|0)>=0){i=Db(h,b),j=d^128,v[i|0]=j}c=g+8|0;Fb(c,x[a+24>>2],b);Dh(c,0);break b;case 2:i=Db(h,b),j=128,v[i|0]=j;c=g+8|0;Fb(c,x[a+24>>2],b);Dh(c,1);break b;case 4:break c;default:break b}}i=Db(h,b),j=128,v[i|0]=j;c=g+8|0;Fb(c,x[a+24>>2],b);Dh(c,0)}if(y[e|0]){break a}c=x[f+4>>2];if(qc(x[f>>2],c)){break a}c=Nt(c);if(y[Db(x[c>>2],b)|0]==y[Db(x[a>>2],b)|0]){Fb(g+8|0,x[c+24>>2],b);c=Ib(x[x[g+8>>2]>>2],x[g+12>>2]);Fb(g,x[a+24>>2],b);if((Ib(x[x[g>>2]>>2],x[g+4>>2])|0)==(c|0)){break a}}v[e|0]=1}db=g+16|0}function iE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=db-16|0;db=g;e=Mb(b);d=Bb(x[b+4>>2],y[b+11|0]);i=Mb(c);j=Bb(x[c+4>>2],y[c+11|0]);f=-1;a:{if(!d){break a}h=d+e|0;d=e;while(1){if((d|0)==(h|0)){break a}if(hq(i,j,y[d|0])){d=d+1|0;continue}break}f=d-e|0}b:{c:{if((f|0)!=-1){c=vb(g+12|0,od(b));d=vb(g+8|0,Ie(od(b),f));fD(b,x[c>>2],x[d>>2]);break c}f=Oc(x[b+4>>2],y[b+11|0]);if(!f){break c}e=Mb(b);i=Bb(x[b+4>>2],y[b+11|0]);j=Mb(c);d=-1;h=Bb(x[c+4>>2],y[c+11|0]);if(h){c=e+i|0;d:{while(1){if((c|0)==(e|0)){break d}c=c-1|0;if(!hq(j,h,y[c|0])){continue}break}d=c-e|0}}if((f-1|0)!=(d|0)){break c}Gb(a);break b}ad(a,b)}db=g+16|0}function saa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=db-80|0;db=d;e=Nf(d+52|0);x[23549]=0;g=O(846,b|0,e|0)|0;f=x[23549];x[23549]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23549]=0;R(847,a|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){break b}}break a}g=x[e+4>>2];x[23549]=0;S(176,d+12|0,b|0,g|0);f=x[23549];x[23549]=0;if((f|0)==1){break a}f=d+12|0;h=hc(d+32|0,f);Zc(e+8|0,h);ub(h);ub(f);d:{if(!(g&1)|c>>>0<2){break d}x[23549]=0;O(174,b|0,1)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break d}break a}wl(a,e)}Gd(e);db=d+80|0;return}a=N()|0;Gd(e);Q(a|0);p()}function Gba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=db-80|0;db=d;e=Nf(d+52|0);x[23549]=0;c=O(766,b|0,e|0)|0;f=x[23549];x[23549]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23549]=0;R(767,a|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){break b}}break a}c=x[e+4>>2];x[23549]=0;c=$b(c);S(176,d+12|0,b|0,c|0);f=x[23549];x[23549]=0;if((f|0)==1){break a}f=d+12|0;g=hc(d+32|0,f);Zc(e+8|0,g);ub(g);ub(f);d:{c=c&1;if(!c){break d}x[23549]=0;O(174,b|0,2-c|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break d}break a}wl(a,e)}Gd(e);db=d+80|0;return}a=N()|0;Gd(e);Q(a|0);p()}function yy(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=db-16|0;db=e;c=x[a>>2];if(!qc(c,x[a+4>>2])){d=yb(c);x[e+12>>2]=d;c=yb(x[a+4>>2]);while(1){if(Kb(d,c)){To(d,4194304,67108864);f=x[d>>2];g=f+g|0;b=g>>>0<f>>>0?b+1|0:b;d=x[Ae(e+12|0)>>2];continue}else{f=x[a>>2];c=oc(f,x[a+4>>2]);k=e,l=yb(f),x[k+8>>2]=l;d=c<<24;g=Bka(g,b,c,0);c=g;h=((hb&1)<<31|c>>>1)&2147483647;i=yb(x[a+4>>2]);while(1){b=x[e+8>>2];if(Kb(b,i)){f=b;c=x[b>>2];b=c>>>8|0;c=h+(c<<24)|0;b=b+j|0;b=Qc(Bka(c,c>>>0<h>>>0?b+1|0:b,g,j),hb);x[f>>2]=b;d=d-b|0;Ae(e+8|0);continue}else{b=x[a>>2];if(!oc(b,x[a+4>>2])){$u();p()}x[b>>2]=x[b>>2]+d}break}}break}}db=e+16|0}function _I(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=db-16|0;db=d;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((wp(a)|0)>(b|0)){break d}}a=ac(8);x[23549]=0;d=O(54,d+4|0,10589)|0;b=x[23549];x[23549]=0;if((b|0)==1){break c}a=pc(a,d);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}b=N()|0;tb(d);break b}if(c<0|c>1){a=ac(8);x[23549]=0;d=O(54,d+4|0,11610)|0;b=x[23549];x[23549]=0;if((b|0)!=1){a=pc(a,d);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}b=N()|0;tb(d);break b}b=N()|0;jc(a);break b}e=(a+D(b,872)|0)+1075740|0,f=pm(c*64),x[e>>2]=f;db=d+16|0;return}b=N()|0;jc(a)}Q(b|0)}p()}function R3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=db+-64|0;db=f;d=f+16|0;h=db-16|0;db=h;i=uP(h+8|0);l=f+4|0;while(1){if((j|0)==12){db=h+16|0}else{g=db+-64|0;db=g;c=x[i+4>>2];e=x[i>>2];a:{if((c|0)==(e|0)){break a}c=(c-e|0)+1|0;if(!c){c=RJ(SJ(g+8|0,32));break a}e=G(c);e=SJ(g+8|0,(c<<e&2147483647?32:31)-e|0);while(1){k=RJ(e);if(c>>>0<=k>>>0){continue}break}c=x[i>>2]+k|0}db=g- -64|0;m=xb(d,j),n=c,x[m>>2]=n;j=j+1|0;continue}break}d=CP(l,d,GP(d));yP(a,d);um(d);db=f- -64|0;d=vx(a+120|0,a,b);v[d+20|0]=1;x[23549]=0;P(1047,a|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){a=N()|0;Jn(d);Q(a|0);p()}return a|0}function _da(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=db-16|0;db=b;e=x[a+40>>2];f=x[a+36>>2];j=x[a+16>>2];h=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=h;k=x[a+32>>2];l=x[a+28>>2];h=x[a+8>>2];m=x[a+12>>2];while(1){if(d){d=d-1|0;i=x[b+8>>2];i=(((x[b+12>>2]&2147483647)<<1|i>>>31)&-2)+j|0;g=0;while(1){if((g|0)!=2){x[(g<<2)+b>>2]=v[g+i|0]<<8;g=g+1|0;continue}break}f=f+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],f>>12);e=e+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],e>>12);Qb(b+8|0,h,m);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=e;x[a+20>>2]=f>>12;x[a+36>>2]=f;x[a+24>>2]=e>>12;db=b+16|0}function lv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=db-16|0;db=f;v[f+15|0]=d;v[b+12|0]=y[b+12|0]&240|y[a|0]&15;i=a+1|0;e=f+15|0;ah(b,y[Sb(i,e)|0]);g=y[Sb(a+2|0,e)|0];v[b+13|0]=g;k=b,l=Vd(y[a+3|0],g,d),v[k+14|0]=l;e=y[Sb(a+4|0,e)|0];v[b+15|0]=e;k=b,l=Vd(y[a+5|0],e,d),v[k+16|0]=l;g=x[b>>2];b=0;while(1){v[f+14|0]=25;if(b>>>0<y[Sb(f+14|0,i)|0]){e=D(b,3)+a|0;h=Ub(y[e+6|0]+c<<24>>24,0,64);d=xb(g,b);v[d+2|0]=h;e=y[e+7|0]|y[e+8|0]<<8;w[d>>1]=e;a:{if(!b){break a}h=xb(g,b-1|0);j=z[h>>1];if(e>>>0>255|e>>>0>=j>>>0){break a}e=e|j&65280;w[d>>1]=e;if(z[h>>1]<=(e&65535)>>>0){break a}w[d>>1]=e+256}b=b+1|0;continue}break}db=f+16|0}function w5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=db-32|0;db=e;f=Nb(a);a=z[x[b+24>>2]+480192>>1];x[23549]=0;P(167,f|0,a|0);c=x[23549];x[23549]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){d=a&65535;c=x[b+24>>2];if(d>>>0>z[c+480192>>1]){break b}c=VM(c,d);x[23549]=0;c=O(54,e+8|0,c|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){d=x[b+24>>2];x[23549]=0;S(983,e+20|0,d|0,c|0);d=x[23549];x[23549]=0;if((d|0)==1){break e}x[23549]=0;P(169,f|0,e+20|0);d=x[23549];x[23549]=0;if((d|0)==1){break d}tb(e+20|0);tb(c);a=a+1|0;continue}break}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(e+20|0)}tb(c);break a}db=e+32|0;return}a=N()|0}Yd(f);Q(a|0);p()}function iR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=db-16|0;db=f;d=vb(f+12|0,x[a+4>>2]);c=vb(f+8|0,x[a>>2]);g=x[vb(f+4|0,x[b+4>>2])>>2];h=db-16|0;db=h;i=h+8|0;e=db-32|0;db=e;Od(e+24|0,x[d>>2],x[c>>2]);j=e+16|0;c=x[e+24>>2];k=x[e+28>>2];d=db-16|0;db=d;x[d+8>>2]=g;x[d+12>>2]=c;while(1){if(sd(c,k)){c=dh(c);g=dh(x[d+8>>2]);x[g+8>>2]=x[c+8>>2];l=x[c+4>>2];x[g>>2]=x[c>>2];x[g+4>>2]=l;c=Cj(d+12|0);Cj(d+8|0);c=x[c>>2];continue}break}vc(j,c,d+8|0);db=d+16|0;d=x[e+16>>2];x[e+12>>2]=x[e+20>>2];vc(i,d,e+12|0);db=e+32|0;db=h+16|0;x[b+4>>2]=x[h+12>>2];Pb(a,b+4|0);Pb(a+4|0,b+8|0);Pb(wb(a),kc(b));x[b>>2]=x[b+4>>2];db=f+16|0}function V6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=db-16|0;db=e;i=e,j=$j(b),x[i+4>>2]=j;c=db-16|0;db=c;g=a;d=Ud(a);a:{if(d){f=gc(g);while(1){a=d;d=a+16|0;if(it(b,d)){f=a;d=x[a>>2];if(d){continue}break a}if(!it(d,b)){break a}f=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=gc(g);f=a}x[c+12>>2]=a;b=x[f>>2];if(!b){a=db-16|0;db=a;b=gc(g);b=rh(c,Hc(40),Ag(a+8|0,b));Gb(ad(x[b>>2]+16|0,x[e+4>>2])+12|0);i=gc(b),j=1,v[i+4|0]=j;db=a+16|0;Yg(g,x[c+12>>2],f,x[c>>2]);b=Zd(c);a=x[c>>2];x[c>>2]=0;if(a){if(y[gc(c)+4|0]){lm(a+16|0)}Eb(a)}h=1}Xg(e+8|0,x[vb(c,b)>>2],h);db=c+16|0;a=td(x[e+8>>2]);db=e+16|0;return a+12|0}function tT(a){var b=0,c=0,d=0,e=0,f=0;b=db-32|0;db=b;e=b,f=$b(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+788|0,x[e>>2]=f;x[b+4>>2]=0;e=b,f=$b(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24)),x[e+8>>2]=f;x[b+12>>2]=0;c=$b(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24));x[b+16>>2]=c?c:52;x[b+20>>2]=0;e=b,f=$b(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))+80|0,x[e+24>>2]=f;x[b+28>>2]=0;a=b;d=Qe(a,4);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+8|0;if((d|0)==(c|0)){break a}a=fv(x[a>>2],x[a+4>>2],x[c>>2],x[c+4>>2])?c:a;continue}}db=b+32|0;c=x[a>>2];b=c-52|0;hb=x[a+4>>2]-(c>>>0<52)|0;return b}function _4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=db-32|0;db=e;f=Nb(a);a=z[x[b+24>>2]+480190>>1];x[23549]=0;P(167,f|0,a|0);d=x[23549];x[23549]=0;a=1;a:{if((d|0)!=1){b:{c:{d:{e:{while(1){c=a&65535;d=x[b+24>>2];if(c>>>0>z[d+480190>>1]){break b}x[23549]=0;d=O(54,e+8|0,WM(d,c)|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){c=x[b+24>>2];x[23549]=0;S(983,e+20|0,c|0,d|0);c=x[23549];x[23549]=0;if((c|0)==1){break e}x[23549]=0;P(169,f|0,e+20|0);c=x[23549];x[23549]=0;if((c|0)==1){break d}tb(e+20|0);tb(d);a=a+1|0;continue}break}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(e+20|0)}tb(d);break a}db=e+32|0;return}a=N()|0}Yd(f);Q(a|0);p()}function iI(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=db-208|0;db=f;x[f+204>>2]=c;c=f+160|0;Vb(c,0,40);x[f+200>>2]=x[f+204>>2];a:{if((hI(0,b,f+200|0,f+80|0,c,d,e)|0)<0){e=-1;break a}i=x[a+76>>2]>=0;g=x[a>>2];if(x[a+72>>2]<=0){x[a>>2]=g&-33}b:{c:{d:{if(!x[a+48>>2]){x[a+48>>2]=80;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;h=x[a+44>>2];x[a+44>>2]=f;break d}if(x[a+16>>2]){break c}}c=-1;if(eW(a)){break b}}c=hI(a,b,f+200|0,f+80|0,f+160|0,d,e)}if(h){ib[x[a+36>>2]](a,0,0)|0;x[a+48>>2]=0;x[a+44>>2]=h;x[a+28>>2]=0;b=x[a+20>>2];x[a+16>>2]=0;x[a+20>>2]=0;c=b?c:-1}b=a;a=x[a>>2];x[b>>2]=a|g&32;e=a&32?-1:c;if(!i){break a}}db=f+208|0;return e}function UY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if(Kg(a,x[b+8>>2],f)){iw(b,c,d,e);return}g=y[b+53|0];i=x[a+12>>2];v[b+53|0]=0;h=y[b+52|0];v[b+52|0]=0;ew(x[a+16>>2],x[a+20>>2],b,c,d,e,f);j=y[b+53|0];l=g|j;k=y[b+52|0];h=h|k;g=a+24|0;i=(a+16|0)+(i<<3)|0;a:{if(g>>>0>=i>>>0){break a}while(1){if(y[b+54|0]){break a}b:{if(k){if(x[b+24>>2]==1){break a}if(y[a+8|0]&2){break b}break a}if(!j){break b}if(!(v[a+8|0]&1)){break a}}w[b+52>>1]=0;ew(x[g>>2],x[g+4>>2],b,c,d,e,f);j=y[b+53|0];l=j|l;k=y[b+52|0];h=k|h;g=g+8|0;if(i>>>0>g>>>0){continue}break}}v[b+53|0]=(l&255)!=0;v[b+52|0]=(h&255)!=0}function AL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=db-16|0;db=e;Bh(e+8|0,b);f=db-16|0;db=f;Ng(f+8|0,x[e+8>>2],x[e+12>>2]);g=x[f+8>>2];b=x[f+12>>2];h=db-16|0;db=h;k=h,l=yb(a),x[k+12>>2]=l;a=b;b=db-16|0;db=b;j=x[h+12>>2];c=j;d=x[c+8>>2];c=x[c+12>>2];i=c;a:{if((c|0)<0){break a}c=x[j+4>>2];if(!i&d>>>0>c>>>0|i){break a}x[b+8>>2]=c-d;x[b+12>>2]=0-(i+(d>>>0>c>>>0)|0);x[b>>2]=a;x[b+4>>2]=0;c=ZB(b+8|0,b);if((ez(x[c>>2],x[c+4>>2])|0)!=(a|0)){break a}_g(g,a+g|0,d+x[j>>2]|0);d=x[h+12>>2];g=d;c=x[d+8>>2];d=x[d+12>>2];i=a;a=a+c|0;d=i>>>0>a>>>0?d+1|0:d;x[g+8>>2]=a;x[g+12>>2]=d}db=b+16|0;db=h+16|0;db=f+16|0;db=e+16|0}function gba(a){a=a|0;var b=0,c=0,d=0;c=a+1298224|0;b=a+1074992|0;while(1){if((b|0)==(c|0)){Zs(a+484344|0);Ze(a+1298308|0);Ze(a+1298320|0);Ze(a+1298332|0);Dc(a+1298408|0);b=a+900380|0;c=a+484380|0;while(1){if((b|0)==(c|0)){a:{c=a+901404|0;while(1){if((b|0)==(c|0)){c=a+946300|0;b=a+906300|0;while(1){if((b|0)==(c|0)){break a}_V(b);b=b+160|0;continue}}d=x[b>>2];if(d){Eb(cu(d))}x[b>>2]=0;b=b+4|0;continue}}}else{vm(c);c=c+104|0;continue}break}x[a+480180>>2]=0;x[a+480184>>2]=0;a=a+480186|0;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;w[a+6>>1]=0}else{x[b+104>>2]=0;x[b+656>>2]=0;x[b+76>>2]=0;x[b+16>>2]=0;b=b+872|0;continue}break}}function gQ(a,b,c){a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}v[a+798|0]=0;return}v[a+798|0]=1;return}v[a+798|0]=2;return}v[a+798|0]=3;return}v[a+730|0]=y[a+730|0]&254;return}v[a+730|0]=y[a+730|0]|1;return}v[a+738|0]=y[a+738|0]&254;return}v[a+738|0]=y[a+738|0]|1;return}v[a+746|0]=y[a+746|0]&254;return}v[a+746|0]=y[a+746|0]|1;return}if((c|0)!=16777216){break a}c=a;a=y[a+746|0];v[c+746|0]=(b|0)==13?a&238|1:a|17}}function Gfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=db-32|0;db=d;nd(b,0);f=d+8|0;Xh(f,1,a);c=d+20|0;Bc(c,f);Ce(b+43|0,c);tb(c);x[b>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[b+4>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[b+8>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);x[b+24>>2]=y[a+62|0]|y[a+63|0]<<8;vq(b,+((y[a+60|0]^8)-120|0)/192);v[d+20|0]=y[a+61|0];v[d+8|0]=64;g=b,h=y[Sb(c,f)|0]<<2,w[g+30>>1]=h;w[b+34>>1]=0;c=y[a+47|0];if(c&4){w[b+34>>1]=1;x[b>>2]=x[b>>2]>>>1;e=1;c=y[a+47|0]}if(c&32){e=e|4;w[b+34>>1]=e;c=y[a+47|0]}if(c<<24>>24<0){w[b+34>>1]=e|2}db=d+32|0}function iB(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=db-16|0;db=e;d=(c<<3)+a|0;f=y[d+356|0];v[b+12|0]=y[b+12|0]&248|f&1|f<<1&4|f>>>1&2;ah(b,Vd(y[d+352|0],2,16));v[b+13|0]=y[d+354|0];v[b+14|0]=y[d+355|0];d=y[d+353|0];v[b+15|0]=d;v[b+16|0]=d;d=0;w[e+14>>1]=0;f=((c|0)!=0)<<1;h=x[b>>2];j=ne(h,x[b+4>>2]);k=(c<<6)+a|0;c=((c|0)==2?-1:0)&255;while(1){if((d|0)==(j|0)){hB(b,32);db=e+16|0}else{a=k+(d<<2)|0;w[e+12>>1]=y[a+160|0]|y[a+161|0]<<8;g=Ve(e+14|0,e+12|0);i=xb(h,d);g=z[g>>1];w[i>>1]=g;w[e+14>>1]=g+1;v[e+11|0]=(c^y[a+162|0])>>>f;v[e+10|0]=64;l=i,m=y[Sb(e+11|0,e+10|0)|0],v[l+2|0]=m;d=d+1|0;continue}break}}function _ga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=E(0),h=0,i=0,j=0,k=0,l=0,m=0;c=db-16|0;db=c;a:{b:{d=x[b+8>>2];if((d|0)==x[a+8>>2]){f=x[a+4>>2];e=x[b+4>>2];if((f|0)!=(e|0)){break b}x[c+12>>2]=d;x[c+8>>2]=d;d=x[Cb(c+12|0,c+8|0)>>2];x[c+12>>2]=e;x[c+8>>2]=e;e=x[Cb(c+12|0,c+8|0)>>2];i=x[a>>2];j=x[b>>2];b=0;c:while(1){a=0;if((b|0)==(d|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue c}else{k=(D(b,f)+a|0)+i|0;g=Rh(E(Fd(B[eq(j,a,b)>>2],E(-1))*E(128)));d:{if(E(F(g))<E(2147483648)){h=~~g;break d}h=-2147483648}l=k,m=VS(h),v[l|0]=m;a=a+1|0;continue}}}_(16924,8881,27,9408);p()}_(16874,8881,28,9408);p()}db=c+16|0}function Raa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=db-16|0;db=h;f=c;e=db-16|0;db=e;g=b;d=Ud(b);a:{if(d){c=gc(g);while(1){b=d;d=b+16|0;if(fz(f,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!fz(d,f)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break}break a}b=gc(g);c=b}x[e+12>>2]=b;b=x[c>>2];if(!b){b=db-16|0;db=b;d=gc(g);d=rh(e,Hc(28),Ag(b+8|0,d));i=x[d>>2];x[23549]=0;P(824,i+16|0,f|0);f=x[23549];x[23549]=0;b:{if((f|0)!=1){j=gc(d),k=1,v[j+4|0]=k;db=b+16|0;break b}a=N()|0;CM(d);Q(a|0);p()}Yg(g,x[e+12>>2],c,x[e>>2]);b=Zd(e);CM(e);i=1}c=h+8|0;Xg(c,x[vb(e,b)>>2],i);db=e+16|0;eQ(a,c);db=h+16|0}function sM(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=db-16|0;db=h;v[h+15|0]=b;v[h+14|0]=10;ah(g,y[Sb(h+15|0,h+14|0)|0]);v[g+15|0]=c;v[g+16|0]=c;v[g+14|0]=e;v[g+13|0]=d;j=x[g>>2];k=ne(j,x[g+4>>2]);b=0;a:{while(1){if((b|0)==(k|0)){b:{b=y[g+12|0]&-2|a&1;if(a&2){break b}b=b&251;break a}}else{m=xb(j,b);l=D(b,3)+f|0;i=(y[l|0]|y[l+1|0]<<8)>>>4|0;w[m>>1]=i;c:{if(b){n=z[xb(j,b-1|0)>>1];if(i>>>0>=n>>>0){break c}i=n+1|0}else{i=0}o=xb(j,b),p=i,w[o>>1]=p}o=m,p=Vd(y[l+2|0],0,64),v[o+2|0]=p;b=b+1|0;continue}break}b=b&-5|(c>>>0<=k>>>0)<<2}v[g+12|0]=(d>>>0<=e>>>0?a&4:0)?b&-3|(d>>>0<=k>>>0)<<1:b&253;db=h+16|0}function Vr(a,b,c,d){var e=0,f=0,g=0,h=0;g=d?d:467380;d=x[g>>2];a:{b:{c:{if(!b){if(d){break c}return 0}e=-2;if(!c){break b}d:{if(d){e=c;break d}d=y[b|0];f=d<<24>>24;if((f|0)>=0){if(a){x[a>>2]=d}return(f|0)!=0}if(!x[x[116055]>>2]){e=1;if(!a){break b}x[a>>2]=f&57343;return 1}d=d-194|0;if(d>>>0>50){break c}d=x[(d<<2)+81584>>2];e=c-1|0;if(!e){break a}b=b+1|0}f=y[b|0];h=f>>>3|0;if((h-16|(d>>26)+h)>>>0>7){break c}while(1){e=e-1|0;d=f-128|d<<6;if((d|0)>=0){x[g>>2]=0;if(a){x[a>>2]=d}return c-e|0}if(!e){break a}b=b+1|0;f=y[b|0];if((f&192)==128){continue}break}}x[g>>2]=0;x[23424]=25;e=-1}return e}x[g>>2]=d;return-2}function $ga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=E(0),h=0,i=0,j=0,k=0,l=0;c=db-16|0;db=c;a:{b:{d=x[b+8>>2];if((d|0)==x[a+8>>2]){f=x[a+4>>2];e=x[b+4>>2];if((f|0)!=(e|0)){break b}x[c+12>>2]=d;x[c+8>>2]=d;h=x[Cb(c+12|0,c+8|0)>>2];x[c+12>>2]=e;x[c+8>>2]=e;e=x[Cb(c+12|0,c+8|0)>>2];i=x[a>>2];j=x[b>>2];b=0;c:while(1){a=0;if((b|0)==(h|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue c}else{g=Rh(E(Fd(B[eq(j,a,b)>>2],E(-1))*E(32768)));d:{if(E(F(g))<E(2147483648)){d=~~g;break d}d=-2147483648}d=Sc(d);k=WS(i,f,a,b),l=d,w[k>>1]=l;a=a+1|0;continue}}}_(16924,8881,27,9408);p()}_(16874,8881,28,9408);p()}db=c+16|0}function qi(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=c*d;k=b*e;h=j+k;l=b*d;m=c*e;i=l-m;a:{if(!ti(i)){break a}if(!ti(h)){break a}f=df(b);g=df(c);n=f|g;b:{if((n|0)!=1){break b}b=Nh(f?1:0,b);c=Nh(g?1:0,c);if(ti(d)){d=Nh(0,d)}if(!ti(e)){break b}e=Nh(0,e)}f=df(d);g=df(e);c:{if(f|g){d=Nh(f?1:0,d);e=Nh(g?1:0,e);if(ti(b)){b=Nh(0,b)}if(!ti(c)){break c}c=Nh(0,c);break c}if(n){break c}d:{if(df(l)){break d}if(df(m)){break d}if(df(k)){break d}if(!df(j)){break a}}if(ti(b)){b=Nh(0,b)}if(ti(c)){c=Nh(0,c)}if(ti(d)){d=Nh(0,d)}if(!ti(e)){break c}e=Nh(0,e)}h=(b*e+d*c)*Infinity;i=(b*d-e*c)*Infinity}fl(a,i,h)}function oz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=db-16|0;db=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);g=x[vb(f+4|0,x[b+4>>2])>>2];h=db-16|0;db=h;i=h+8|0;e=db-32|0;db=e;Od(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=db-16|0;db=c;x[c+8>>2]=g;x[c+12>>2]=d;while(1){if(sd(d,k)){d=Xo(d);g=Xo(x[c+8>>2]);l=x[d+4>>2];x[g>>2]=x[d>>2];x[g+4>>2]=l;d=fr(c+12|0);fr(c+8|0);d=x[d>>2];continue}break}vc(j,d,c+8|0);db=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];vc(i,c,e+12|0);db=e+32|0;db=h+16|0;x[b+4>>2]=x[h+12>>2];Pb(a,b+4|0);Pb(a+4|0,b+8|0);Pb(wb(a),kc(b));x[b>>2]=x[b+4>>2];db=f+16|0}function yha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=db-16|0;db=e;i=e,j=$j(b),x[i+4>>2]=j;f=z[b>>1];d=db-16|0;db=d;g=a;c=Ud(a);a:{if(c){b=gc(g);while(1){a=c;c=z[a+14>>1];if(yo(f,c)){b=a;c=x[a>>2];if(c){continue}break a}if(!yo(c,f)){break a}b=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=gc(g);b=a}x[d+12>>2]=a;a=x[b>>2];if(!a){a=db-16|0;db=a;c=gc(g);f=rh(d,Hc(20),Ag(a+8|0,c));c=x[f>>2];h=z[x[e+4>>2]>>1];w[c+16>>1]=0;w[c+14>>1]=h;i=gc(f),j=1,v[i+4|0]=j;db=a+16|0;Yg(g,x[d+12>>2],b,x[d>>2]);a=Zd(d);ol(d);h=1}Xg(e+8|0,x[vb(d,a)>>2],h);db=d+16|0;a=iq(x[e+8>>2]);db=e+16|0;return a+2|0}function l7(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=db-80|0;db=d;x[d+76>>2]=c;c=x[a>>2];e=x[a+4>>2];f=x[a+12>>2];x[d+48>>2]=x[a+8>>2];x[d+52>>2]=f;x[d+40>>2]=c;x[d+44>>2]=e;a=Xd(d+32|0);c=x[d+52>>2];x[d+16>>2]=x[d+48>>2];x[d+20>>2]=c;x[23549]=0;c=x[d+44>>2];x[d+8>>2]=x[d+40>>2];x[d+12>>2]=c;c=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=c;S(911,d+56|0,d+8|0,d|0);a=x[23549];x[23549]=0;a:{b:{if((a|0)!=1){a=x[Vf(d+28|0,d+76|0)>>2];x[23549]=0;b=+ta(912,d+56|0,+b,a|0);a=x[23549];x[23549]=0;if((a|0)==1){break b}ub(d+56|0);xe(d+76|0);db=d+80|0;return+b}a=N()|0;break a}a=N()|0;ub(d+56|0)}xe(d+76|0);Q(a|0);p()}function ks(a,b,c){var d=0,e=0;d=a,e=Vi(E(E(B[c+1792>>2]*E(75038))+E(E(E(B[c+2048>>2]-B[c+1536>>2])*E(37489))+E(E(E(B[c+1280>>2]+B[c+2304>>2])*E(6574))+E(E(E(B[c+2560>>2]-B[c+1024>>2])*E(5153))+E(E(E(B[c+768>>2]+B[c+2816>>2])*E(2037))+E(E(E(B[c+3072>>2]-B[c+512>>2])*E(459))+E(E(E(B[c+256>>2]+B[c+3328>>2])*E(213))+E(E(B[c+3584>>2]-B[c>>2])*E(29)))))))))),w[d>>1]=e;d=(b<<5)+a|0,e=Vi(E(E(B[c+8>>2]*E(-5))+E(E(B[c+520>>2]*E(146))+E(E(B[c+1032>>2]*E(-45))+E(E(B[c+1544>>2]*E(-9975))+E(E(B[c+2056>>2]*E(64019))+E(E(B[c+2568>>2]*E(9727))+E(E(B[c+3080>>2]*E(1567))+E(B[c+3592>>2]*E(104)))))))))),w[d>>1]=e}function b0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=db-32|0;db=f;x[f+28>>2]=b;a:{if(!(v[c+4|0]&1)){c=ib[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}Nc(f+16|0,x[c+28>>2]);x[23549]=0;a=R(1116,x[f+16>>2])|0;b=x[23549];x[23549]=0;b:{if((b|0)!=1){Xb(f+16|0);c:{if(e){Gh(f+16|0,a);break c}Fh(f+16|0,a)}g=f,h=od(f+16|0),x[g+12>>2]=h;while(1){a=Hk(f+16|0);b=x[f+12>>2];if(!Kb(b,a)){c=x[f+28>>2];Ec(f+16|0);break a}a=x[b>>2];x[23549]=0;O(1130,f+28|0,a|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){Ae(f+12|0);continue}break}c=N()|0;Ec(f+16|0);break b}c=N()|0;Xb(f+16|0)}Q(c|0);p()}db=f+32|0;return c|0}function WR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=db-16|0;db=c;x[a>>2]=0;x[a+4>>2]=0;Xj(a+8|0,0);d=x[b+4>>2];if(d){Wq(a,d);tm(c+8|0,x[b>>2]);bq(c,x[b>>2],x[b+4>>2]);b=db-32|0;db=b;d=x[c+8>>2];j=x[c>>2];e=x[a+4>>2];g=x[c+12>>2];k=x[c+4>>2];f=e+UR(d,g,j,k)|0;x[a+4>>2]=f;a:{b:{if(!e){h=f-1|0;break b}h=f-1|0;if((h^e-1)>>>0>31){break b}x[b+24>>2]=d;x[b+28>>2]=g;i=x[a>>2];break a}i=x[a>>2];x[i+((f>>>0>=33?h>>>5|0:0)<<2)>>2]=0;x[b+24>>2]=d;x[b+28>>2]=g}Qo(b+16|0,i,e);d=x[b+28>>2];x[b>>2]=x[b+24>>2];x[b+4>>2]=d;VR(b+8|0,b,j,k,x[b+16>>2],x[b+20>>2]);db=b+32|0}db=c+16|0;return a|0}function l0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=db-32|0;db=f;x[f+28>>2]=b;a:{if(!(v[c+4|0]&1)){c=ib[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}Nc(f+16|0,x[c+28>>2]);x[23549]=0;a=R(1099,x[f+16>>2])|0;b=x[23549];x[23549]=0;b:{if((b|0)!=1){Xb(f+16|0);c:{if(e){Gh(f+16|0,a);break c}Fh(f+16|0,a)}g=f,h=od(f+16|0),x[g+12>>2]=h;while(1){a=tf(f+16|0);b=x[f+12>>2];if(!Kb(b,a)){c=x[f+28>>2];tb(f+16|0);break a}a=v[b|0];x[23549]=0;O(20,f+28|0,a|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){Oe(f+12|0);continue}break}c=N()|0;tb(f+16|0);break b}c=N()|0;Xb(f+16|0)}Q(c|0);p()}db=f+32|0;return c|0}function KY(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=db-32|0;db=k;n=x[c>>2];l=x[c+8>>2];m=x[c+4>>2];c=k;x[c+8>>2]=m;x[c+12>>2]=l;x[c+24>>2]=m;x[c+28>>2]=l;x[c+20>>2]=n;x[c+16>>2]=d;x[23549]=0;d=x[c+20>>2];x[c>>2]=x[c+16>>2];x[c+4>>2]=d;a=Fa(1023,a|0,b|0,c|0)|0;b=x[23549];x[23549]=0;a:{b:{if((b|0)==1){Y(T(0)|0)|0;x[23549]=0;ea(910,10298,e|0,f|0,g|0,h|0,i|0,j|0);a=x[23549];x[23549]=0;if((a|0)==1){break b}Z();a=-255}db=k+32|0;break a}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}return a|0}function Nda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=db-16|0;db=b;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];f=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=f;f=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=e>>>18|0;n=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+k|0;e=0;while(1){if((e|0)!=2){g=(e<<1)+n|0;h=w[g>>1];x[(e<<2)+b>>2]=h+((D(w[g+4>>1]-h|0,m)|0)/16384|0);e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],i);Qb(b+8|0,f,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;db=b+16|0}function $x(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0);f=db-16|0;db=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);h=x[vb(f+4|0,x[b+4>>2])>>2];g=db-16|0;db=g;i=g+8|0;e=db-32|0;db=e;Od(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=db-16|0;db=c;x[c+8>>2]=h;x[c+12>>2]=d;while(1){if(sd(d,k)){d=Gf(d);l=Gf(x[c+8>>2]),m=B[d>>2],B[l>>2]=m;d=fj(c+12|0);fj(c+8|0);d=x[d>>2];continue}break}vc(j,d,c+8|0);db=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];vc(i,c,e+12|0);db=e+32|0;db=g+16|0;x[b+4>>2]=x[g+12>>2];Pb(a,b+4|0);Pb(a+4|0,b+8|0);Pb(wb(a),kc(b));x[b>>2]=x[b+4>>2];db=f+16|0}function WE(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=db-16|0;db=g;e=g+4|0;v[e+8|0]=1;x[e+4>>2]=c;x[e>>2]=a;h=y[e+8|0];a=x[e>>2];i=x[e+4>>2];j=Mb(b);b=Bb(x[b+4>>2],y[b+11|0]);d=db-16|0;db=d;x[d+8>>2]=b;x[d+12>>2]=i;b=a;e=x[Cb(d+12|0,d+8|0)>>2];f=e;while(1){a:{if(!f){f=0;break a}c=y[j|0];v[b|0]=c;if(!c){break a}j=j+1|0;b=b+1|0;f=f-1|0;continue}break}b:{if((h-1&255)>>>0<=1){v[d+7|0]=0;am(b,((b+i|0)-e|0)+f|0,d+7|0);break b}if((h-3&255)>>>0>1){break b}v[d+6|0]=32;am(b,((b+i|0)-e|0)+f|0,d+6|0)}c:{switch(h-1|0){case 0:case 3:v[(x[d+12>>2]+a|0)-1|0]=0;break;default:break c}}db=d+16|0;db=g+16|0}function Zba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=db+-64|0;db=c;f=tP(a,1<<b-1);x[f+12>>2]=b;b=1<<b;h=-6.283185307179586/+(b>>>0);a=1;g=b>>>2|0;b=g;while(1){if(b){e=x[10521];d=c+32|0;x[d+8>>2]=x[10520];x[d+12>>2]=e;e=x[10519];x[d>>2]=x[10518];x[d+4>>2]=e;qz(d,h*+(b>>>0));oP(c+48|0,C[c+32>>3],C[c+40>>3]);d=_c(x[f>>2],a);e=x[c+60>>2];x[d+8>>2]=x[c+56>>2];x[d+12>>2]=e;e=x[c+52>>2];x[d>>2]=x[c+48>>2];x[d+4>>2]=e;b=b>>>1|0;a=a<<1;continue}break}a=fl(c+16|0,1,0);b=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=b;b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;jy(f,0,g,c);db=c- -64|0;return f|0}function Yg(a,b,c,d){var e=0,f=0;x[d+8>>2]=b;x[d>>2]=0;x[d+4>>2]=0;x[c>>2]=d;b=x[x[a>>2]>>2];if(b){x[a>>2]=b;d=x[c>>2]}f=x[gc(a)>>2];v[d+12|0]=(f|0)==(d|0);while(1){a:{if((d|0)==(f|0)){break a}c=x[d+8>>2];if(y[c+12|0]){break a}b:{if(qh(c)){b=x[c+8>>2];e=x[b+4>>2];if(!(!e|y[e+12|0])){break b}if(!qh(d)){pq(c);c=x[c+8>>2]}v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;oq(b);break a}b=x[c+8>>2];e=x[b>>2];if(!(!e|y[e+12|0])){break b}if(qh(d)){oq(c);c=x[c+8>>2]}v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;pq(b);break a}v[c+12|0]=1;d=b;v[d+12|0]=(d|0)==(f|0);v[e+12|0]=1;continue}break}a=wb(a);x[a>>2]=x[a>>2]+1}function uw(a,b,c,d,e){var f=0,g=0;f=db-16|0;db=f;Nc(f+12|0,b);x[23549]=0;b=R(1115,x[f+12>>2])|0;g=x[23549];x[23549]=0;a:{if((g|0)==1){break a}x[23549]=0;V(1126,b|0,81792,81824,c|0);b=x[23549];x[23549]=0;if((b|0)==1){break a}x[23549]=0;b=R(1116,x[f+12>>2])|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}x[23549]=0;c=R(1127,b|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break a}x[d>>2]=c;x[23549]=0;c=R(1124,b|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break a}x[e>>2]=c;x[23549]=0;P(1125,a|0,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Xb(f+12|0);db=f+16|0;return}a=N()|0;Xb(f+12|0);Q(a|0);p()}function mm(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=1;j=d&2147483647;l=j;k=(j|0)==2147418112;a:{if(k&!c?a|b:k&(c|0)!=0|j>>>0>2147418112){break a}j=h&2147483647;k=(j|0)==2147418112;if(k&!g?e|f:k&(g|0)!=0|j>>>0>2147418112){break a}if(!(a|e|(c|g)|(b|f|(j|l)))){return 0}i=d&h;if((i|0)>0|(i|0)>=0){i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g|(b^f|d^h))!=0}i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}i=(a^e|c^g|(b^f|d^h))!=0}return i}function ah(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=db-32|0;db=e;b=b-c|0;c=x[wb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){c=db-16|0;db=c;b=oh(c+4|0,a,b);a=x[b+4>>2];d=x[b+8>>2];while(1){if((a|0)==(d|0)){fc(b);db=c+16|0}else{jv(a);a=a+4|0;x[b+4>>2]=a;continue}break}break a}c=wb(a);c=Jf(e+12|0,eg(a,oc(x[a>>2],d)+b|0),oc(x[a>>2],x[a+4>>2]),c);f=db-16|0;db=f;b=Bl(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){jv(d);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}Kd(b);db=f+16|0;kv(a,c);If(c)}db=e+32|0;return}if(b>>>0<c>>>0){Dd(a,d+(b<<2)|0)}}function Cn(a,b,c){var d=0,e=0,f=0,g=0;d=db-16|0;db=d;v[a|0]=0;a:{e=x[b>>2];f=x[e-12>>2]+b|0;b:{if(!x[f+16>>2]){f=x[f+72>>2];if(f){Tq(f);e=x[b>>2]}c:{if(c){break c}c=x[e-12>>2]+b|0;if(!(y[c+5|0]&16)){break c}Nc(d+12|0,x[c+28>>2]);x[23549]=0;f=R(18,x[d+12>>2])|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}Xb(d+12|0);c=Fm(d+8|0,b);e=xc(d+4|0);while(1){d:{if(Og(c,e)){break d}g=Mk(x[c>>2]);if(!ih(x[f+8>>2],1,g)){break d}Tl(c);continue}break}if(Og(c,e)){qj(x[x[b>>2]-12>>2]+b|0,6)}e=x[b>>2]}v[a|0]=!x[(x[e-12>>2]+b|0)+16>>2];break b}qj(f,4)}db=d+16|0;return a}a=N()|0;Xb(d+12|0);Q(a|0);p()}function CI(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(Ne(a)){cc(a,31);return 0}g=a,h=Ne(a),v[g+1375|0]=h;d=Ui(a);b=Ui(a);Ui(a);g=a,h=Ui(a),x[g+1112>>2]=h;Ui(a);c=Ne(a);x[a+1116>>2]=c;if(!cx(a,a+1120|0,c)){cc(a,10);return 0}x[a+1404>>2]=-2;a:{if((b&d)==-1){break a}b=x[a+1116>>2];while(1){if((b|0)<=0){break a}b=b-1|0;if(y[(b+a|0)+1120|0]==255){continue}break}x[a+1408>>2]=d;x[a+1404>>2]=b}if(y[a+1377|0]){b=0;e=x[a+1116>>2];f=(e|0)>0?e:0;c=0;while(1){if((b|0)!=(f|0)){c=y[(a+b|0)+1120|0]+c|0;b=b+1|0;continue}break}x[a- -64>>2]=d;x[a+60>>2]=(x[a+56>>2]+(c+e|0)|0)+27}x[a+1380>>2]=0;return 1}function yw(a,b,c,d,e){var f=0,g=0;f=db-16|0;db=f;Nc(f+12|0,b);x[23549]=0;b=R(18,x[f+12>>2])|0;g=x[23549];x[23549]=0;a:{if((g|0)==1){break a}x[23549]=0;V(1113,b|0,81792,81824,c|0);b=x[23549];x[23549]=0;if((b|0)==1){break a}x[23549]=0;b=R(1099,x[f+12>>2])|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}x[23549]=0;c=R(1114,b|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break a}v[d|0]=c;x[23549]=0;c=R(1111,b|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break a}v[e|0]=c;x[23549]=0;P(1112,a|0,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Xb(f+12|0);db=f+16|0;return}a=N()|0;Xb(f+12|0);Q(a|0);p()}function sk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=db-16|0;db=e;f=a+36|0;c=x[a+32>>2];a:{b:{while(1){if((b|0)<=(c|0)){break b}c:{d=x[a+20>>2];if(d>>>0>=A[a+24>>2]){tn(e,f,VD(f));pd(e+8|0,a,x[e>>2],x[e+4>>2]);c=x[e+12>>2];x[a+24>>2]=c;x[a+20>>2]=0;if(!c){break c}d=0;c=x[a+32>>2]}x[a+20>>2]=d+1;g=y[(a+d|0)+36|0];d=c+8|0;x[a+32>>2]=d;x[a+28>>2]=x[a+28>>2]|g<<c;c=d;continue}break}a=ac(8);x[23549]=0;b=R(153,a|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break a}b=N()|0;jc(a);Q(b|0);p()}x[a+32>>2]=c-b;d=a;a=x[a+28>>2];x[d+28>>2]=a>>>b;db=e+16|0;return a&(-1<<b^-1)}da(b|0,30544,154);p()}function Oda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=db-16|0;db=b;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];f=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=f;f=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=e>>>10&4194048;n=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+k|0;e=0;while(1){if((e|0)!=2){g=e+n|0;h=v[g|0];x[(e<<2)+b>>2]=((D(v[g+2|0]-h|0,m)|0)/16384|0)+(h<<8);e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],i);Qb(b+8|0,f,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;db=b+16|0}function Wja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=db-16|0;db=c;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(c+8|0,x[vb(c+4|0,a)>>2]);a:{b:{if(b){x[23549]=0;P(306,a|0,b|0);d=x[23549];x[23549]=0;if((d|0)==1){break b}e=db-16|0;db=e;d=Bq(e+4|0,a,b);b=x[d+4>>2];f=x[d+8>>2];while(1){if((b|0)==(f|0)){fc(d);db=e+16|0}else{v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+4|0]=6;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=8;v[b+3|0]=4;b=b+6|0;x[d+4>>2]=b;continue}break}}b=c+8|0;Hd(b);ul(b);db=c+16|0;break a}a=N()|0;ul(c+8|0);Q(a|0);p()}v[a+16|0]=6;x[a+12>>2]=2015363072;return a|0}function uY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a:{g=db+-64|0;db=g;vk(g+16|0,c);x[23549]=0;c=g+28|0;P(99,c|0,d|0);d=x[23549];x[23549]=0;b:{c:{d:{if((d|0)==1){break d}x[23549]=0;c=g+40|0;P(99,c|0,e|0);d=x[23549];x[23549]=0;if((d|0)==1){break d}x[23549]=0;c=g+52|0;P(99,c|0,f|0);d=x[23549];x[23549]=0;if((d|0)==1){break d}Rv(g+8|0,g+16|0);x[23549]=0;V(100,a|0,b|0,x[g+8>>2],x[g+12>>2]);a=x[23549];x[23549]=0;if((a|0)==1){break c}vE(g+16|0);db=g- -64|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(g+16|0)){continue}break}break b}a=N()|0;vE(g+16|0)}Q(a|0);p()}}function xV(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=y[e|0];if(!i){break a}j=2240>>>d&d>>>0<12;g=D(c,-6);k=(d-2&255)>>>0>2;while(1){if(!b){break a}c=a;a=c+g|0;f=y[a+3|0];b:{c:{if(!((f-2&255)>>>0>2|k)){f=1;if(y[(c+g|0)+5|0]<224){break c}break a}f=!(1<<f&2240)|(!j|f>>>0>11)?(d|0)==(f|0):1;if(k){break b}}h=c+g|0;if((y[h+2|0]-11&255)>>>0>2){break b}if(y[h+4|0]){break a}}d:{if(!j){break d}h=c+g|0;if((y[h+2|0]-3&255)>>>0>3){break d}if(y[h+4|0]){break a}}b=b-1|0;if(!f){continue}c=y[(c+g|0)+5|0];if(c?(c|0)!=(i|0):0){break a}if((c|0)!=(i|0)){continue}break}v[e|0]=0}}function K6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-32|0;db=c;x[23549]=0;W(927,a|0);d=x[23549];x[23549]=0;a:{b:{c:{if((d|0)==1){break c}x[23549]=0;W(928,b|0);d=x[23549];x[23549]=0;if((d|0)==1){break c}d=x[a+24>>2];b=mc(c+12|0,b);x[23549]=0;e=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=e;V(940,c+20|0,d|0,c|0,1);b=x[23549];x[23549]=0;if((b|0)==1){break c}a=c+20|0;b=_f(Mb(a));tb(a);break b}Y(T(0)|0)|0;b=0;x[23549]=0;V(914,5476,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z()}db=c+32|0;return b|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Yfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;f=db-32|0;db=f;a:{c=x[a+12>>2];b:{if((c|0)==(b|0)){break b}d=b>>>0>c>>>0;c=D(z[x[x[a+48>>2]+12>>2]+480188>>1],d?b-c|0:c-b|0);e=yb(x[a+4>>2]);c:{if(d){e=vb(f+28|0,e);d=f+22|0;Uh(d);e=x[e>>2];x[23549]=0;V(601,a|0,e|0,c|0,d|0);c=x[23549];x[23549]=0;if((c|0)!=1){break c}a=T(92296)|0;if((eb|0)!=($(92296)|0)){break a}Y(a|0)|0;Z();break b}c=vb(f+16|0,kB(e,c));e=x[vb(f+12|0,yb(x[a+4>>2]))>>2];d=x[c>>2];c=x[a>>2];c=D(Ts(d,yb(c)),6)+c|0;if(Kb(d,e)){Dd(a,fy(c+D(Ts(e,d),6)|0,x[a+4>>2],c))}yb(c)}x[a+12>>2]=b}db=f+32|0;return}Q(a|0);p()}function xD(a){var b=0,c=0,d=0;b=db-16|0;db=b;x[b+4>>2]=D(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24),5)+(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24));x[b+8>>2]=(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24))+((y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24))<<3);x[b+12>>2]=(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))+((y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24))<<2);a=b+4|0;d=xb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=jq(x[a>>2],x[c>>2])?c:a;continue}}db=b+16|0;return x[a>>2]-36|0}function ae(a,b){var c=0,d=0,e=0;c=db-32|0;db=c;a=gh(a,-1,-1);a:{b:{if(vd(y[Cn(c+31|0,b,1)|0])){d=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[23549]=0;P(93,c+8|0,d|0);d=x[23549];x[23549]=0;c:{if((d|0)!=1){d=x[c+12>>2];x[a>>2]=x[c+8>>2];x[a+4>>2]=d;d=x[c+20>>2];x[a+8>>2]=x[c+16>>2];x[a+12>>2]=d;break c}Y(T(0)|0)|0;e=1;Bn(x[x[b>>2]-12>>2]+b|0,1);if(x[(x[x[b>>2]-12>>2]+b|0)+20>>2]&1){x[23549]=0;X(91);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}qj(x[x[b>>2]-12>>2]+b|0,e)}db=c+32|0;return}T(0)|0;Rb()}p()}function qI(a,b){var c=0,d=0,e=0,f=0,g=0;if(!y[464112]){f=464113,g=Ma()|0,v[f|0]=g;v[464112]=1}a:{b:{c:{d:{switch(a|0){case 0:break b;case 1:case 4:break d;default:break c}}if(!y[464113]){break c}d=+Ba();break a}x[23424]=28;return-1}d=+Sa()}c=d/1e3;e:{if(F(c)<0x8000000000000000){e=~~c>>>0;a=F(c)>=1?~~(c>0?H(J(c*2.3283064365386963e-10),4294967295):K((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break e}a=-2147483648}x[b>>2]=e;x[b+4>>2]=a;c=(d-(+(yka(e,a,1e3,0)>>>0)+ +(hb|0)*4294967296))*1e3*1e3;f:{if(F(c)<2147483648){a=~~c;break f}a=-2147483648}x[b+8>>2]=a;return 0}function IY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=c;c=db-16|0;db=c;x[23549]=0;W(927,a|0);e=x[23549];x[23549]=0;a:{b:{c:{d:{if((e|0)==1){break d}x[23549]=0;W(928,b|0);e=x[23549];x[23549]=0;if((e|0)==1){break d}e=x[a+24>>2];b=mc(c+8|0,b);x[23549]=0;g=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=g;DF(948,e,c,f,d);d=x[23549];x[23549]=0;b=1;if((d|0)!=1){break c}}Y(T(0)|0)|0;x[23549]=0;V(914,8540,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break b}Z();b=0}db=c+16|0;break a}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}return b|0}function vL(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a=ni(a,b,c,d);v[a+4260|0]=e;x[a>>2]=46468;c=Nb(a+4264|0);d=Nb(a+4276|0);x[a+4328>>2]=0;b=a+4320|0;x[b>>2]=0;x[b+4>>2]=0;x[a+4312>>2]=0;x[a+4316>>2]=0;b=a+4208|0;f=xb(b,0),g=1056964608,x[f>>2]=g;f=xb(b,1),g=1036831949,x[f>>2]=g;f=xb(b,2),g=1038174126,x[f>>2]=g;f=xb(b,3),g=1065353216,x[f>>2]=g;f=xb(b,4),g=1061158912,x[f>>2]=g;f=xb(b,5),g=1059082943,x[f>>2]=g;f=xb(b,6),g=1061997773,x[f>>2]=g;x[23549]=0;P(878,a+44|0,2);b=x[23549];x[23549]=0;if((b|0)!=1){mi(a);return a|0}b=N()|0;sc(d);sc(c);yf(a);Q(b|0);p()}function PL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=db-16|0;db=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);h=x[vb(f+4|0,x[b+4>>2])>>2];g=db-16|0;db=g;i=g+8|0;e=db-32|0;db=e;Od(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=db-16|0;db=c;x[c+8>>2]=h;x[c+12>>2]=d;while(1){if(sd(d,k)){d=NL(d);rc(NL(x[c+8>>2]),d,2048);d=ML(c+12|0);ML(c+8|0);d=x[d>>2];continue}break}vc(j,d,c+8|0);db=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];vc(i,c,e+12|0);db=e+32|0;db=g+16|0;x[b+4>>2]=x[g+12>>2];Pb(a,b+4|0);Pb(a+4|0,b+8|0);Pb(wb(a),kc(b));x[b>>2]=x[b+4>>2];db=f+16|0}function IN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=db-16|0;db=e;a:{if(x[a+480180>>2]!=1){break a}c=y[b+846|0];if(!c){break a}d=x[b+104>>2];if(!d){break a}if(!Sd(x[d>>2],x[d+20>>2])){break a}f=z[d+34>>1];if(!(f&10)){break a}c=y[b+847|0]+y[(c&15)+33456|0]|0;v[b+847|0]=c;if(c<<24>>24>=0){break a}v[b+847|0]=0;h=f&2;c=x[(h?4:12)+d>>2];g=b;b=x[b+760>>2]+1|0;b=b>>>0<x[(h?8:16)+d>>2]-c>>>0?b:0;x[g+760>>2]=b;g=x[d+20>>2];c=b+c|0;b=rk(f);dc(e+8|0,g+D(c,b)|0,b);b=x[e+8>>2];f=Db(b,x[e+12>>2]);while(1){if((b|0)==(f|0)){dj(d,a)}else{v[b|0]=y[b|0]^-1;b=b+1|0;continue}break}}db=e+16|0}function Mda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=db-16|0;db=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+12>>2]+i|0;h=v[e|0];e=((D(v[e+1|0]-h|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(h<<8)|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Qb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;db=b+16|0}function oV(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=db-16|0;db=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);h=x[vb(f+4|0,x[b+4>>2])>>2];g=db-16|0;db=g;i=g+8|0;e=db-32|0;db=e;Od(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=db-16|0;db=c;x[c+8>>2]=h;x[c+12>>2]=d;while(1){if(sd(d,k)){d=AB(d);rc(AB(x[c+8>>2]),d,48);d=lV(c+12|0);lV(c+8|0);d=x[d>>2];continue}break}vc(j,d,c+8|0);db=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];vc(i,c,e+12|0);db=e+32|0;db=g+16|0;x[b+4>>2]=x[g+12>>2];Pb(a,b+4|0);Pb(a+4|0,b+8|0);Pb(wb(a),kc(b));x[b>>2]=x[b+4>>2];db=f+16|0}function haa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=db-16|0;db=f;x[f+12>>2]=b;a:{if(Ys(a)>>>0>=b>>>0){e=x[a>>2];g=kk(e,x[a+4>>2]);x[f+8>>2]=g;d=x[Cb(f+12|0,f+8|0)>>2];while(1){if(d){d=d-1|0;e=mM(e,c)+52|0;continue}break}if(b>>>0>g>>>0){cy(a,b-g|0,c);break a}kM(a,x[a>>2]+D(b,52)|0);break a}if(x[a>>2]){Zs(a);d=x[a>>2];Ys(a);Eb(d);h=wb(a),i=0,x[h>>2]=i;x[a>>2]=0;x[a+4>>2]=0}e=jM(a,b);d=db-16|0;db=d;if(eh(82595524)>>>0<e>>>0){Rc();p()}iM(d+8|0,e);e=x[d+8>>2];x[a+4>>2]=e;x[a>>2]=e;h=wb(a),i=e+D(x[d+12>>2],52)|0,x[h>>2]=i;db=d+16|0;cy(a,b,c)}db=f+16|0}function e7(a){a=a|0;var b=0;b=7914;a:{b:{c:{switch(a-277|0){default:if((a|0)==357){break b}d:{if((a|0)!=257){if((a|0)==267){break d}if(a){break a}b=21204;break a}b=7947;break a}b=17142;break a;case 0:b=4952;break a;case 9:b=7970;break a;case 10:b=7984;break a;case 11:b=5329;break a;case 12:b=5349;break a;case 19:b=7996;break a;case 20:b=7928;break a;case 21:b=12688;break a;case 22:b=12011;break a;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 23:break c}}b=5960;break a}b=7881}return _f(b)|0}function Lda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=db-16|0;db=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=(x[b+12>>2]<<1)+i|0;h=w[e>>1];e=h+((D(w[e+2>>1]-h|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Qb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;db=b+16|0}function O0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=db-32|0;db=c;d=y[a+52|0];a:{if(qc(b,-1)){if(d){break a}b=x[a+48>>2];e=a,f=qc(b,-1)^1,v[e+52|0]=f;break a}b:{if(!d){break b}v[c+19|0]=x[a+48>>2]<<24>>24;c:{d:{e:{d=c+20|0;switch(Zr(x[a+36>>2],x[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((Xr(v[d|0],x[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}v[a+52|0]=1;x[a+48>>2]=b}db=c+32|0;return b|0}function JY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=db-16|0;db=d;x[23549]=0;W(927,a|0);c=x[23549];x[23549]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[23549]=0;W(928,b|0);c=x[23549];x[23549]=0;if((c|0)==1){break d}c=x[a+24>>2];b=mc(d+8|0,b);x[23549]=0;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=EF(c,d,1);e=x[23549];x[23549]=0;c=hb;if((e|0)!=1){break c}}Y(T(0)|0)|0;x[23549]=0;V(914,8571,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break b}Z();b=0;c=0}db=d+16|0;a=c;break a}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}eb=a;return b|0}function S0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=db-32|0;db=c;a:{b:{c:{if(qc(b,-1)){break c}v[c+23|0]=b<<24>>24;if(y[a+44|0]){d=-1;if((dk(c+23|0,1,1,x[a+32>>2])|0)==1){break c}break a}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=Zr(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((dk(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((dk(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}d=Lw(b);break a}d=-1}db=c+32|0;return d|0}function G6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=db-16|0;db=d;x[23549]=0;W(927,a|0);e=x[23549];x[23549]=0;a:{b:{c:{if((e|0)==1){break c}x[23549]=0;W(928,b|0);e=x[23549];x[23549]=0;if((e|0)==1){break c}e=x[a+24>>2];b=mc(d+8|0,b);x[23549]=0;f=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=f;V(945,e|0,d|0,(c|0)!=0|0,1);c=x[23549];x[23549]=0;b=1;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,9888,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();b=0}db=d+16|0;return b|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function vx(a,b,c){var d=0,e=0,f=0,g=0;e=db-16|0;db=e;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(e+8|0,x[vb(e+4|0,a)>>2]);a:{b:{if(c){x[23549]=0;P(1044,a|0,c|0);d=x[23549];x[23549]=0;if((d|0)==1){break b}f=db-16|0;db=f;d=oh(f+4|0,a,c);c=x[d+4>>2];g=x[d+8>>2];while(1){if((c|0)==(g|0)){fc(d);db=f+16|0}else{x[c>>2]=0;xc(c);c=c+4|0;x[d+4>>2]=c;continue}break}}c=e+8|0;Hd(c);Bg(c);db=e+16|0;break a}a=N()|0;Bg(e+8|0);Q(a|0);p()}e=a;a=0;c=0;d=db-16|0;db=d;f=d+12|0;while(1){if(a>>>0<32){a=a+48|0;c=kN(b);continue}break}x[f>>2]=c;Yn(f);db=d+16|0;x[e+12>>2]=x[f>>2];return e}function t$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;h=db-16|0;db=h;e=Bb(x[a+4>>2],y[a+11|0]);d=ln(a);g=ne(b,c);a:{if(!g){break a}b:{f=Mb(a);if(f>>>0<=b>>>0){f=(Bb(x[a+4>>2],y[a+11|0])<<2)+f>>>0>=b>>>0}else{f=0}if(!f){if(d-e>>>0<g>>>0){uG(a,d,(e-d|0)+g|0,e,e)}d=Mb(a)+(e<<2)|0;while(1){if((b|0)==(c|0)){break b}zd(d,x[b>>2]);b=b+4|0;d=d+4|0;continue}}b=fH(h+4|0,b,c);c=Mb(b);e=y[b+11|0];d=x[b+4>>2];x[23549]=0;U(1151,a|0,c|0,Bb(d,e)|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){Ec(b);break a}a=N()|0;Ec(b);Q(a|0);p()}zd(d,0);Wg(a,e+g|0)}db=h+16|0;return a|0}function qr(a,b){a=a|0;b=b|0;var c=0,d=0;d=db-16|0;db=d;a=Gb(a);a:{b:{c:{switch(b|0){case 0:x[23549]=0;b=O(1,d+4|0,15477)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}zb(a,b);tb(b);break b;case 1:x[23549]=0;b=O(1,d+4|0,15502)|0;c=x[23549];x[23549]=0;if((c|0)!=1){zb(a,b);tb(b);break b}break a;case 2:x[23549]=0;b=O(1,d+4|0,15450)|0;c=x[23549];x[23549]=0;if((c|0)!=1){zb(a,b);tb(b);break b}break a;case 3:break c;default:break b}}x[23549]=0;b=O(1,d+4|0,15424)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}zb(a,b);tb(b)}db=d+16|0;return}b=N()|0;tb(a);Q(b|0);p()}function fQ(a,b){var c=0,d=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+14|0]=5;w[a+12>>1]=0;x[a+8>>2]=128;x[a>>2]=256;x[a+4>>2]=64;x[a+28>>2]=0;v[a+27|0]=60;x[a+40>>2]=0;x[a+44>>2]=0;v[a+33|0]=2;v[a+34|0]=0;v[a+35|0]=0;v[a+36|0]=2;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=255;v[a+26|0]=0;v[a+32|0]=0;Gz(a+48|0);Gz(a+68|0);Gz(a+88|0);tt(a+492|0);tt(a+524|0);Mm(a,0,0);Lm(a,0,0);x[a+40>>2]=0;x[a+44>>2]=0;du(a,b);b=a+108|0;d=sA(b);c=1;while(1){if((b|0)!=(d|0)){v[b|0]=c;c=c+1|0;b=b+1|0;continue}break}return a}function A8(a){a=a|0;var b=0,c=0;c=db-16|0;db=c;b=x[x[a+16>>2]+24620>>2];b=Cc(zka(yka(b,b>>31,3840,0),hb,1e3,0),hb);x[a+4316>>2]=b;x[23549]=0;x[c+12>>2]=0;S(884,a+4264|0,b|0,c+12|0);b=x[23549];x[23549]=0;a:{b:{c:{if((b|0)!=1){d:{if(!y[a+4260|0]){break d}b=x[a+4316>>2];x[23549]=0;x[c+12>>2]=0;S(884,a+4276|0,b|0,c+12|0);b=x[23549];x[23549]=0;if((b|0)!=1){break d}b=T(92296)|0;break c}x[c+12>>2]=0;b=c+12|0;sL(a+4288|0,b);x[c+12>>2]=0;sL(a+4300|0,b);break b}b=T(92296)|0}if((eb|0)!=($(92296)|0)){break a}Y(b|0)|0;x[a+4316>>2]=0;Z()}db=c+16|0;return}Q(b|0);p()}function Z0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=db-32|0;db=c;a:{b:{c:{if(zn(b)){break c}x[c+20>>2]=b;if(y[a+44|0]){d=-1;if((dk(c+20|0,4,1,x[a+32>>2])|0)==1){break c}break a}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=Zr(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((dk(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((dk(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}d=zn(b)?0:b;break a}d=-1}db=c+32|0;return d|0}function Vha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=db-48|0;db=e;c=x[a+8>>2];d=x[a>>2];x[23549]=0;c=U(142,d|0,c|0,1)|0;d=x[23549];x[23549]=0;a:{if((d|0)==1){break a}b:{if(!c){break b}x[23549]=0;W(458,b|0);c=x[23549];x[23549]=0;if((c|0)==1){break a}x[23549]=0;c=R(192,a|0)|0;d=x[23549];x[23549]=0;c:{if((d|0)!=1){while(1){if(!(c&255)){break b}x[23549]=0;d=O(459,a|0,e+15|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break c}f=y[e+15|0];if(d&f>>>0<64){rc(ET(x[b>>2],f),e+15|0,33)}c=c-1|0;continue}}break a}break a}ub(a);db=e+48|0;return}b=N()|0;ub(a);Q(b|0);p()}function F6(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=db-16|0;db=e;x[23549]=0;W(927,a|0);d=x[23549];x[23549]=0;a:{b:{c:{if((d|0)==1){break c}x[23549]=0;W(928,b|0);d=x[23549];x[23549]=0;if((d|0)==1){break c}d=x[a+24>>2];b=mc(e+8|0,b);x[23549]=0;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;Va(947,d|0,e|0,+c,1);d=x[23549];x[23549]=0;b=1;if((d|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,5867,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();b=0}db=e+16|0;return b|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function oS(a){var b=0,c=0,d=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1196314451){break a}c=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);if(c>>>0<1108){break a}b=a+1104|0;if((c-1108|0)!=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))|c>>>0>262144){break a}c=a+1094|0;if(y[c|0]|y[c+1|0]<<8){break a}b=a+1096|0;if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))-5>>>0<4294967292){break a}if(!Tt(a+8|0)){break a}a=a+40|0;while(1){d=(a|0)==(c|0);if(d|y[a+32|0]>15|y[a+33|0]>64){break a}b=Tt(a);a=a+34|0;if(b){continue}break}}return d}function ifa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=db-16|0;db=d;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[23549]=0;P(648,a|0,b|0);c=x[23549];x[23549]=0;if((c|0)==1){break a}f=db-16|0;db=f;c=f+4|0;x[c>>2]=a;e=x[a+4>>2];x[c+4>>2]=e;x[c+8>>2]=e+D(b,9);b=x[c+4>>2];e=x[c+8>>2];while(1){if((b|0)==(e|0)){fc(c);db=f+16|0}else{v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;b=b+9|0;x[c+4>>2]=b;continue}break}}b=d+8|0;Hd(b);Jt(b);db=d+16|0;return a|0}a=N()|0;Jt(d+8|0);Q(a|0);p()}function V0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=db-32|0;db=c;d=y[a+52|0];a:{if(zn(b)){if(d){break a}b=x[a+48>>2];e=a,f=zn(b)^1,v[e+52|0]=f;break a}b:{if(!d){break b}x[c+16>>2]=x[a+48>>2];c:{d:{e:{d=c+20|0;switch(Zr(x[a+36>>2],x[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((Xr(v[d|0],x[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}v[a+52|0]=1;x[a+48>>2]=b}db=c+32|0;return b|0}function dB(a,b){var c=0,d=0;a:{b:{c:{d:{e:{f:{g:{h:{d=y[a+3|0];switch(d|0){case 9:break d;case 10:break e;case 16:case 17:break g;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break h;default:break a}}if(!y[a|0]){break a}switch(d|0){case 9:break d;case 10:break e;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break f;case 16:case 17:break g;default:break c}}c=8;break c}c=y[a|0];if(!(c&7)){break c}}c=b+1>>>1|0;b=((d|0)==10)<<4;break b}c=16}c=D(c>>>3|0,b);b=((d|0)==10)<<4}c=b+D(rq(y[a+1|0]),c)|0}return c}function Kaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=db-48|0;db=d;c=d+28|0;mj(c,b,1819307379);Zc(a+40|0,c);ub(c);mj(c,b,1953721961);Zc(a+60|0,c);ub(c);mj(c,b,543520099);Zc(a+120|0,c);ub(c);mj(c,b,1414744396);x[23549]=0;c=O(354,c|0,13548)|0;e=x[23549];x[23549]=0;a:{if((e|0)!=1){b:{if(c){x[23549]=0;S(747,d+8|0,d+28|0,2);c=x[23549];x[23549]=0;if((c|0)==1){break b}c=d+8|0;Rt(a+140|0,c);_d(c)}x[23549]=0;S(748,d+8|0,b|0,1634890872);b=x[23549];x[23549]=0;if((b|0)!=1){break a}}}a=N()|0;ub(d+28|0);Q(a|0);p()}b=a+80|0;a=d+8|0;Zc(b,a);ub(a);ub(d+28|0);db=d+48|0}function M9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;a:{e=db-48|0;db=e;d=x[a+28>>2];dn(x[x[d>>2]-12>>2]+d|0,0);h=x[x[b>>2]+4>>2];if(h){i=x[a+28>>2];f=e+32|0;g=x[a+12>>2];d=x[a+8>>2]+h|0;g=h>>>0>d>>>0?g+1|0:g;f=gh(f,d,g);d=x[f+12>>2];x[e+8>>2]=x[f+8>>2];x[e+12>>2]=d;d=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=d;Gj(i,e)}d=e+16|0;ae(d,x[a+28>>2]);xz(x[a+28>>2],c,x[x[b>>2]+8>>2]);c=x[b>>2];b=jn(d,Db(x[a+32>>2],x[c>>2]),z[c+12>>1]);x[23549]=0;O(873,a|0,c|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){Ab(b);db=e+48|0;break a}a=N()|0;Ab(b);Q(a|0);p()}}function pca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=db-16|0;db=g;h=z[c>>1];i=c;e=db-16|0;db=e;f=b;d=Ud(b);a:{if(d){c=gc(f);while(1){b=d;d=z[b+14>>1];if(Cl(h,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!Cl(d,h)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break}break a}b=gc(f);c=b}x[e+12>>2]=b;b=x[c>>2];if(!b){b=db-16|0;db=b;d=gc(f);d=rh(e,Hc(16),Ag(b+8|0,d));tj(x[d>>2]+14|0,z[i>>1]);k=gc(d),l=1,v[k+4|0]=l;db=b+16|0;Yg(f,x[e+12>>2],c,x[e>>2]);b=Zd(e);ol(e);j=1}c=g+8|0;Xg(c,x[vb(e,b)>>2],j);db=e+16|0;eQ(a,c);db=g+16|0}function gja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=db-16|0;db=f;g=z[nk(x[a>>2],x[a+4>>2],b)>>1];a:{b:{if(!Dq(a,b)){break b}c=x[a+24>>2];d=yb(x[c+484360>>2]);x[f+12>>2]=d;h=yb(x[c+484364>>2]);while(1){if(!Kb(d,h)){break b}e=0;i=vl(x[d>>2],x[d+4>>2]);while(1){if((e|0)!=(i|0)){c:{if(!((a|0)!=(d|0)|(b|0)!=(e|0))|z[_b(x[d>>2],e)>>1]!=(g|0)){break c}c=vS(x[a+24>>2]+484344|0,g);if((c|0)==65535){break c}j=nk(x[a>>2],x[a+4>>2],b),k=c,w[j>>1]=k;break a}e=e+1|0;continue}break}d=x[Wp(f+12|0)>>2];continue}}c=g}db=f+16|0;return c&65535}function QC(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=db-16|0;db=f;x[f+8>>2]=e;x[f+12>>2]=d;Ze(a);Np(a,c);d=0;e=0;a:while(1){if(c>>>0>d>>>0){i=c-d|0;x[f+4>>2]=i;g=x[Cb(f+12|0,f+4|0)>>2];h=g+e|0;l=e>>>0>h>>>0?e:h;j=Du(Yt(a,b+d|0,g),1,13);while(1)if((e|0)==(l|0)){x[f+4>>2]=i-g;e=h+1|0;d=x[Cb(f+8|0,f+4|0)>>2]+(d+g|0)|0;continue a}else{b:{c:{d:{k=v[uc(j,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}m=uc(j,e),n=32,v[m|0]=n}e=e+1|0;continue}}break}db=f+16|0}function fs(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0;h=db-240|0;db=h;x[h+236>>2]=d;x[h+232>>2]=c;x[h>>2]=a;a:{b:{c:{d:{if((c|0)!=1){j=a;k=1;break d}j=a;k=1;if(d){break d}i=a;break c}while(1){i=j-x[(e<<2)+g>>2]|0;if((Fn(i,a,b)|0)<=0){i=j;break c}e:{if(!((e|0)<2|f)){f=x[((e<<2)+g|0)-8>>2];l=j-4|0;if((Fn(l,i,b)|0)>=0){break e}if((Fn(l-f|0,i,b)|0)>=0){break e}}x[(k<<2)+h>>2]=i;c=oI(c,d);gs(h+232|0,c);k=k+1|0;e=c+e|0;f=0;j=i;d=x[h+236>>2];c=x[h+232>>2];if(d|(c|0)!=1){continue}break b}break}i=j;break b}if(f){break a}}nI(h,k);_w(i,b,e,g)}db=h+240|0}function N6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=db-16|0;db=c;x[23549]=0;W(927,a|0);d=x[23549];x[23549]=0;a:{b:{c:{if((d|0)==1){break c}x[23549]=0;W(928,b|0);d=x[23549];x[23549]=0;if((d|0)==1){break c}d=x[a+24>>2];b=mc(c+8|0,b);x[23549]=0;f=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=f;e=+ma(938,d|0,c|0,1);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,5904,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();e=0}db=c+16|0;return+e}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function P6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=db-16|0;db=d;x[23549]=0;W(927,a|0);c=x[23549];x[23549]=0;a:{b:{c:{if((c|0)==1){break c}x[23549]=0;W(928,b|0);c=x[23549];x[23549]=0;if((c|0)==1){break c}c=x[a+24>>2];b=mc(d+8|0,b);x[23549]=0;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=U(934,c|0,d|0,1)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,9919,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();b=0}db=d+16|0;return b|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function gx(a,b,c){var d=0,e=0,f=E(0),g=E(0),h=E(0),i=E(0),j=0,k=E(0),l=E(0),m=E(0);e=db-32|0;db=e;g=B[a+24>>2];f=B[a+12>>2];h=B[a+48>>2];i=B[a+36>>2];FI(E(-B[a>>2]),E(g+f),E(h+i),e+20|0);FI(B[a+60>>2],E(h-i),E(g-f),e+8|0);B[e+12>>2]=-B[e+12>>2];a=0;while(1){if((a|0)!=3){d=a<<2;j=d+c|0;g=B[j>>2];f=B[d+(e+20|0)>>2];h=B[d+70304>>2];i=B[d+70316>>2];k=B[d+(e+8|0)>>2];B[j>>2]=E(f*h)-E(i*k);j=b+d|0;l=B[(0-a<<2)+70312>>2];d=5-a<<2;m=B[d+70304>>2];f=E(E(f*i)+E(k*h));B[j>>2]=E(g*l)-E(m*f);B[b+d>>2]=E(g*m)+E(f*l);a=a+1|0;continue}break}db=e+32|0}function Hz(a,b){var c=0,d=0,e=0,f=0,g=0;d=db-16|0;db=d;c=x[a>>2];a:{if(!qc(c,x[a+4>>2])){w[c>>1]=0;pf(c+2|0,b);f=d,g=Yj(yb(x[a>>2]),1),x[f+12>>2]=g;while(1){e=yb(x[a+4>>2]);c=x[d+12>>2];if(Kb(c,e)){f=c,g=z[Ve(c,Yj(c,-1))>>1],w[f>>1]=g;pf(c+2|0,b);$Q(d+12|0);continue}else{pf(a+14|0,ne(x[a>>2],x[a+4>>2])-1&255);pf(a+13|0,y[a+14|0]);pf(a+16|0,ne(x[a>>2],x[a+4>>2])-1&255);pf(a+15|0,y[a+16|0]);if(y[a+17|0]==255){break a}pf(a+17|0,ne(x[a>>2],x[a+4>>2])-1&255);break a}}}v[a+17|0]=255;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0}db=d+16|0}function VC(a){var b=0,c=0,d=0,e=0,f=0;a:{b:{if((y[a|0]|y[a+1|0]<<8)!=26217){if((y[a|0]|y[a+1|0]<<8)!=20042){break a}if(y[a+110|0]<=64){break b}break a}if(y[a+110|0]>64){break a}}if(v[a+112|0]<0|y[a+111|0]>128){break a}c=a+110|0;b=a+2|0;while(1){if((b|0)==(c|0)){while(1){b=(e|0)==128;if(b){break a}c=a+e|0;d=v[c+113|0];if((d|0)<-2){break a}f=y[c+241|0];if(!f&(d|0)>=0|f>>>0>15){break a}e=e+1|0;if(y[c+369|0]<64){continue}break a}}c:{if((y[b|0]-1&255)>>>0>30){break c}d=d+1|0;if((d&255)>>>0<=40){break c}return 0}b=b+1|0;continue}}return b}function AN(a,b,c,d){var e=0,f=0;e=db-16|0;db=e;a:{b:{c:{if(!d){break c}d=c>>31;d=(d^c)-d|0;if(d>>>0<224){break c}Fb(e+8|0,a+1074312|0,3);if(Ib(x[x[e+8>>2]>>2],x[e+12>>2])){break c}if(!(v[(D(b,872)+a|0)+1075843|0]&1)){break a}c=D(d&15,c>>31|(c|0)!=0);c=d>>>0>239?c<<2:c;break b}if(v[(D(b,872)+a|0)+1075843|0]&1){Fb(e+8|0,a+1074312|0,3);if(!Ib(x[x[e+8>>2]>>2],x[e+12>>2])){break a}}c=c<<2}if(!c){break a}f=D(b,872)+a|0;d=x[f+1075648>>2];a=at(a,x[f+1075080>>2],d);if(!a){break a}ib[x[x[a>>2]+84>>2]](a,c,(d?y[d+33|0]:13)<<24>>24,b)}db=e+16|0}function zda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=db-16|0;db=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+8>>2];f=(x[b+12>>2]<<1)+i|0;e=e>>>21&2040;e=(((D(w[f>>1],w[e+39938>>1])+D(w[f-2>>1],w[e+39936>>1])|0)+D(w[f+2>>1],w[e+39940>>1])|0)+D(w[f+4>>1],w[e+39942>>1])|0)/16384|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Qb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;db=b+16|0}function N9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=db-48|0;db=f;e=x[a+28>>2];dn(x[x[e>>2]-12>>2]+e|0,0);i=x[x[b>>2]+4>>2];if(i){j=x[a+28>>2];g=f+32|0;h=x[a+12>>2];e=x[a+8>>2]+i|0;h=i>>>0>e>>>0?h+1|0:h;g=gh(g,e,h);e=x[g+12>>2];x[f+8>>2]=x[g+8>>2];x[f+12>>2]=e;e=x[g+4>>2];x[f>>2]=x[g>>2];x[f+4>>2]=e;Gj(j,f)}e=f+16|0;ae(e,x[a+28>>2]);XL(d,x[a+28>>2],c);c=x[b>>2];b=jn(e,Db(x[a+32>>2],x[c>>2]),z[c+12>>1]);x[23549]=0;O(873,a|0,c|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){Ab(b);db=f+48|0;return}a=N()|0;Ab(b);Q(a|0);p()}function L9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=db-48|0;db=f;e=x[a+28>>2];dn(x[x[e>>2]-12>>2]+e|0,0);i=x[x[b>>2]+4>>2];if(i){j=x[a+28>>2];g=f+32|0;h=x[a+12>>2];e=x[a+8>>2]+i|0;h=i>>>0>e>>>0?h+1|0:h;g=gh(g,e,h);e=x[g+12>>2];x[f+8>>2]=x[g+8>>2];x[f+12>>2]=e;e=x[g+4>>2];x[f>>2]=x[g>>2];x[f+4>>2]=e;Gj(j,f)}e=f+16|0;ae(e,x[a+28>>2]);UL(c,x[a+28>>2],d);c=x[b>>2];b=jn(e,Db(x[a+32>>2],x[c>>2]),z[c+12>>1]);x[23549]=0;O(873,a|0,c|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){Ab(b);db=f+48|0;return}a=N()|0;Ab(b);Q(a|0);p()}function Daa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{f=db-32|0;db=f;a=Nb(a);b:{c:{d:{e:{while(1){e=x[b+8>>2];g=x[b>>2];x[23549]=0;e=U(142,g|0,e|0,8)|0;g=x[23549];x[23549]=0;if((g|0)==1){break c}if(e){x[23549]=0;S(844,f+4|0,b|0,c|0);e=x[23549];x[23549]=0;if((e|0)==1){break e}x[23549]=0;P(845,a|0,f+4|0);e=x[23549];x[23549]=0;if((e|0)==1){break d}e=f+4|0;Gd(e);g=e;e=Cm(x[a+4>>2]);zi(g,x[e>>2],x[e+4>>2]);if(x[f+4>>2]!=(d|0)){continue}}break}db=f+32|0;break a}b=N()|0;break b}b=N()|0;Gd(f+4|0);break b}b=N()|0}_d(a);Q(b|0);p()}}function Cia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=x[a>>2];d=bk(e,x[a+4>>2]);if(d>>>0<b>>>0){e=db-32|0;db=e;d=b-d|0;b=x[wb(a)>>2];f=x[a+4>>2];a:{if(d>>>0<=(b-f|0)/6>>>0){aB(a,d,c);break a}b=wb(a);b=ZT(e+12|0,XA(a,bk(x[a>>2],f)+d|0),bk(x[a>>2],x[a+4>>2]),b);YT(b,d,c);c=db-16|0;db=c;d=vb(c+12|0,x[a+4>>2]);f=vb(c+8|0,x[a>>2]);g=vb(c+4|0,x[b+4>>2]);h=b,i=VT(x[d>>2],x[f>>2],x[g>>2]),x[h+4>>2]=i;Pb(a,b+4|0);Pb(a+4|0,b+8|0);Pb(wb(a),kc(b));x[b>>2]=x[b+4>>2];db=c+16|0;XT(b)}db=e+32|0;return}if(b>>>0<d>>>0){Dd(a,e+D(b,6)|0)}}function tR(a,b,c,d,e){var f=0;f=y[(y[a+3|0]&15)+27088|0];v[a+3|0]=f;a:{b:{switch(f-11|0){case 0:b=y[a+5|0];c=b&15;if(c){v[a+5|0]=c;return}v[a+5|0]=b&240;return;case 3:c=y[a+5|0];c=D(c&240,10)|c&15;v[a+5|0]=c;f=c&255;c=z[d>>1];if(!(f|(c|0)==65535)){v[a+5|0]=c;v[a+3|0]=12;w[d>>1]=65535}tc(e,b);return;case 1:w[d>>1]=y[a+5|0];x[e>>2]=63;v[a+3|0]=0;return;case 5:b=y[a+5|0];if(c>>>0<=20){c=((b&255)>>>0)/10|0;b=c<<4|D(c,-10)+b;v[a+5|0]=b}if(b&255){break a}v[a+3|0]=0;return;case 7:break a;default:break b}}if(y[a+5|0]){break a}v[a+3|0]=0}}function eba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=db-208|0;db=e;w[a+480212>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;pN(a+946304|0);d=e+48|0;Vb(d,0,160);d=vN(d);x[23549]=0;f=a+906300|0;S(797,f|0,f+4e4|0,d|0);f=x[23549];x[23549]=0;a:{if((f|0)!=1){_s(d);d=le(e+28|0,b);x[23549]=0;f=x[d+12>>2];x[e+16>>2]=x[d+8>>2];x[e+20>>2]=f;x[e+24>>2]=x[d+16>>2];f=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=f;a=U(798,a|0,e+8|0,c|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){a=N()|0;break a}ub(b);db=e+208|0;return a|0}a=N()|0;_s(d)}ub(b);Q(a|0);p()}function fN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=db-16|0;db=e;x[e+12>>2]=16777216;h=e+12|0;d=x[a>>2];c=oc(d,x[a+4>>2]);a:{if(c>>>0<b>>>0){f=db-32|0;db=f;b=b-c|0;c=x[wb(a)>>2];d=x[a+4>>2];b:{if(b>>>0<=c-d>>2>>>0){BC(a,b,h);break b}c=wb(a);c=Jf(f+12|0,eg(a,oc(x[a>>2],d)+b|0),oc(x[a>>2],x[a+4>>2]),c);g=db-16|0;db=g;b=Bl(g+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){no(d,x[h>>2]);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}Kd(b);db=g+16|0;lo(a,c);If(c)}db=f+32|0;break a}if(b>>>0<c>>>0){Dd(a,d+(b<<2)|0)}}yy(a);db=e+16|0}function MW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=db-32|0;db=e;nd(b,0);f=e+8|0;Xh(f,1,a+33|0);d=e+20|0;Bc(d,f);Ce(b+43|0,d);tb(d);g=y[a+50|0]|y[a+51|0]<<8|(y[a+52|0]<<16|y[a+53|0]<<24);x[b>>2]=g;x[b+24>>2]=y[a+54|0]|y[a+55|0]<<8;v[e+20|0]=y[a+56|0];v[e+8|0]=64;h=b,i=y[Sb(d,f)|0]<<2,w[h+30>>1]=i;d=y[a+57|0]|y[a+58|0]<<8|(y[a+59|0]<<16|y[a+60|0]<<24);x[b+4>>2]=d;f=y[a+61|0]|y[a+62|0]<<8|(y[a+63|0]<<16|y[a+64|0]<<24);c=c?d?g:f:f;x[b+8>>2]=c;if(!(!y[a|0]|c>>>0<=d+2>>>0|c>>>0>g>>>0)){w[b+34>>1]=z[b+34>>1]|2}db=e+32|0}function Lk(a,b,c){var d=0,e=0;e=db-16|0;db=e;x[a+4>>2]=0;d=4;a:{b:{c:{if(!vd(y[Cn(e+15|0,a,1)|0])){break c}d=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[23549]=0;b=U(92,d|0,b|0,c|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){x[a+4>>2]=b;d=(b|0)!=(c|0)?6:0;break c}Y(T(0)|0)|0;d=1;Bn(x[x[a>>2]-12>>2]+a|0,1);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[23549]=0;X(91);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}qj(x[x[a>>2]-12>>2]+a|0,d);db=e+16|0;return a}T(0)|0;Rb()}p()}function hga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=db-80|0;db=d;e=Nf(d+52|0);x[23549]=0;c=O(588,b|0,e|0)|0;f=x[23549];x[23549]=0;a:{b:{c:{d:{if((f|0)!=1){if(c){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23549]=0;R(589,a|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){break a}}break c}c=x[e+4>>2];x[23549]=0;S(176,d+12|0,b|0,(c>>>0>=9?c-8|0:0)|0);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}a=N()|0;Gd(e);Q(a|0);p()}b=d+12|0;c=hc(d+32|0,b);Zc(e+8|0,c);ub(c);ub(b);wl(a,e)}Gd(e);db=d+80|0}function VT(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=db-16|0;db=e;g=e+8|0;d=db-32|0;db=d;Od(d+24|0,a,b);h=d+16|0;b=x[d+24>>2];i=x[d+28>>2];a=db-16|0;db=a;x[a+8>>2]=c;x[a+12>>2]=b;while(1){if(sd(b,i)){b=UT(b);c=UT(x[a+8>>2]);f=y[b+4|0]|y[b+5|0]<<8;v[c+4|0]=f;v[c+5|0]=f>>>8;b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;b=TT(a+12|0);TT(a+8|0);b=x[b>>2];continue}break}vc(h,b,a+8|0);db=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];vc(g,a,d+12|0);db=d+32|0;db=e+16|0;return x[e+12>>2]}function GL(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=0;Ox(a);c=Fd(c,E(0));a:{switch(b|0){case 0:B[a+4220>>2]=c;return;case 1:B[a+4224>>2]=c;return;case 2:B[a+4228>>2]=c;Ms(a);return;case 3:v[a+4240|0]=c>=E(.5);Ms(a);return;case 4:b=db-16|0;db=b;e=b,f=Oh(E(c*E(32))),x[e+12>>2]=f;x[b+8>>2]=0;x[b+4>>2]=5;d=x[sj(b+12|0,b+8|0,b+4|0)>>2];db=b+16|0;x[a+4232>>2]=d;return;case 5:v[a+4241|0]=c>=E(.5);return;case 6:v[a+4242|0]=c>=E(.5);return;case 7:v[a+4244|0]=c>=E(.5);return;case 8:if(c==E(0)){Nx(a)}C[a+4256>>3]=c;break;default:break a}}}function eX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=db-16|0;db=c;x[c+12>>2]=x[x[a+1060>>2]>>2]-x[a+1064>>2];x[c+8>>2]=16384;d=x[Cb(c+12|0,c+8|0)>>2];x[a+1072>>2]=d;x[c+4>>2]=17;while(1){a:{if(!d){break a}e=x[c+4>>2];if((e|0)>17){break a}f=1<<e-1;d=sk(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}_q(c+4|0,sk(a,4));break b}if(e>>>0>16){break c}e=f-8|0;if((e|0)>(d|0)|(d|0)>(f+7|0)){break d}_q(c+4|0,d-e|0);break b}jD(a,d,f,b);break b}e=d&(f^-1);if(d&f){x[c+4>>2]=e+1;break b}jD(a,e,0,b)}d=x[a+1072>>2];continue}break}db=c+16|0}function Iba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(x[a+4>>2]!=x[wb(a)>>2]){d=db-16|0;db=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+7;KO(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+7;fc(c);db=d+16|0;return}f=db-32|0;db=f;g=wb(a);h=f+12|0;e=hz(x[a>>2],x[a+4>>2])+1|0;c=db-16|0;db=c;x[c+12>>2]=e;a:{d=eh(613566756);if(e>>>0<=d>>>0){e=iz(a);if(e>>>0<d>>>1>>>0){x[c+8>>2]=e<<1;d=x[Yc(c+8|0,c+12|0)>>2]}db=c+16|0;break a}Rc();p()}c=NO(h,d,hz(x[a>>2],x[a+4>>2]),g);KO(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+7;MO(a,c);LO(c);db=f+32|0}function Kha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=db-80|0;db=d;c=Nf(d+52|0);x[23549]=0;e=O(463,b|0,c|0)|0;f=x[23549];x[23549]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23549]=0;R(464,a|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){break a}}break c}e=z[c+2>>1]|z[c+4>>1]<<16;x[23549]=0;S(176,d+12|0,b|0,e|0);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}a=N()|0;Gd(c);Q(a|0);p()}b=d+12|0;e=hc(d+32|0,b);Zc(c+8|0,e);ub(e);ub(b);vT(a,c)}Gd(c);db=d+80|0}function Ada(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=db-16|0;db=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+8>>2];f=x[b+12>>2]+i|0;e=e>>>21&2040;e=(((D(v[f|0],w[e+39938>>1])+D(v[f-1|0],w[e+39936>>1])|0)+D(v[f+1|0],w[e+39940>>1])|0)+D(v[f+2|0],w[e+39942>>1])<<8)/16384|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Qb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;db=b+16|0}function z_(a){a=a|0;if(y[467808]){return x[116951]}if(!y[468912]){v[468912]=1}ld(468624,88056);ld(468636,88088);ld(468648,88124);ld(468660,88148);ld(468672,88172);ld(468684,88188);ld(468696,88208);ld(468708,88228);ld(468720,88256);ld(468732,88296);ld(468744,88328);ld(468756,88364);ld(468768,88400);ld(468780,88416);ld(468792,88432);ld(468804,88448);ld(468816,88172);ld(468828,88464);ld(468840,88480);ld(468852,88496);ld(468864,88512);ld(468876,88528);ld(468888,88544);ld(468900,88560);v[467808]=1;x[116951]=468624;return 468624}function sR(a){var b=0,c=0;a:{if((y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24))!=1297236819){break a}b=y[a+28|0]|y[a+29|0]<<8;b:{if(b>>>0<=63){if((b|0)==26){break b}break a}if(b>>>0>2112){break a}}b=y[a+42|0];if(b>>>0>64&(b|0)!=88|(y[a+48|0]|y[a+49|0]<<8)>>>0>64|(y[a+50|0]|y[a+51|0]<<8)>>>0>96){break a}b=y[a+52|0]|y[a+53|0]<<8;if(b>>>0>129&(b|0)!=257|(y[a+30|0]|y[a+31|0]<<8)|(y[a+38|0]|y[a+39|0]<<8|(y[a+40|0]<<16|y[a+41|0]<<24)|(y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1)){break a}c=vR(a+20|0)}return c}function dX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=db-16|0;db=c;x[c+12>>2]=x[x[a+1060>>2]>>2]-x[a+1064>>2];x[c+8>>2]=32768;d=x[Cb(c+12|0,c+8|0)>>2];x[a+1072>>2]=d;x[c+4>>2]=9;while(1){a:{if(!d){break a}e=x[c+4>>2];if((e|0)>9){break a}f=1<<e-1;d=sk(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}_q(c+4|0,sk(a,3));break b}if(e>>>0>8){break c}e=f-4|0;if((e|0)>(d|0)|(d|0)>(f+3|0)){break d}_q(c+4|0,d-e|0);break b}iD(a,d,f,b);break b}e=d&(f^-1);if(d&f){x[c+4>>2]=e+1;break b}iD(a,e,0,b)}d=x[a+1072>>2];continue}break}db=c+16|0}function WI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=db-16|0;db=d;a:{b:{c:{a=x[a+32>>2];e=ys(a);d:{if(!e){if(xs(a)>>>0<=b>>>0){break d}a=_j(a,b+1&65535);w[a+34>>1]=z[a+34>>1]&64511|(c?1024:0);break b}if(b>>>0<e>>>0){break c}}a=ac(8);x[23549]=0;b=O(54,d+4|0,5941)|0;c=x[23549];x[23549]=0;e:{if((c|0)!=1){a=pc(a,b);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break e}c=N()|0;jc(a)}Q(c|0);p()}a=x[(a+(b<<2)|0)+900384>>2];if(!a){break b}v[a+15|0]=y[a+15|0]&253|(c?2:0)}db=d+16|0;return}p()}function bea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=db-16|0;db=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];f=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=f;f=x[a+8>>2];k=x[a+12>>2];while(1){if(d){g=x[b+8>>2];g=((((x[b+12>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+j|0;e=0;while(1){if((e|0)!=2){x[(e<<2)+b>>2]=w[(e<<1)+g>>1];e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Qb(b+8|0,f,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;db=b+16|0}function Sja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;nd(b,0);g=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[b>>2]=g;e=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);x[b+12>>2]=e;f=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);x[b+16>>2]=f;c=y[a+12|0]|y[a+13|0]<<8;w[b+32>>1]=64;x[b+24>>2]=c;c=y[a+14|0];w[b+30>>1]=c?c+1|0:256;d=z[b+34>>1]&32767|!y[a+14|0]<<15;w[b+34>>1]=d;c=y[a+15|0];if(!(!(c&1)|e>>>0>=f>>>0)){d=d|8;w[b+34>>1]=d;c=y[a+15|0]}if(c&2){x[b+16>>2]=f>>>1;x[b+12>>2]=e>>>1;x[b>>2]=g>>>1;w[b+34>>1]=d|1}}function Qd(a){var b=0,c=0,d=0;d=db-16|0;db=d;b=d+4|0;x[b+4>>2]=1109;x[b>>2]=a;x[b+8>>2]=0;c=db-16|0;db=c;if(x[a>>2]!=-1){a:{b=vb(c+8|0,of(c+12|0,b));while(1){if(x[a>>2]==1){continue}break}b:{if(!x[a>>2]){zd(a,1);b=x[x[b>>2]>>2];x[23549]=0;W(1110,b|0);b=x[23549];x[23549]=0;if((b|0)==1){break b}x[a>>2]=-1}break a}Y(T(0)|0)|0;zd(a,0);x[23549]=0;X(91);a=x[23549];x[23549]=0;c:{if((a|0)==1){a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){break c}T(0)|0;Rb()}p()}Q(a|0);p()}}db=c+16|0;db=d+16|0;return x[a+4>>2]-1|0}function Fi(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=db-16|0;db=f;o(+b);g=j(1)|0;d=j(0)|0;c=g&2147483647;e=c+-1048576|0;a:{if((e|0)==2145386495|e>>>0<2145386495){h=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){h=d<<28;c=(g&15)<<28|d>>>4;d=g>>>4|2147418112;break a}if(!(c|d)){c=0;d=0;break a}e=c;c=c?G(c):G(d)+32|0;zf(f,d,e,0,0,c+49|0);i=x[f>>2];h=x[f+4>>2];e=15372-c<<16;c=x[f+8>>2];d=e|x[f+12>>2]^65536}x[a>>2]=i;x[a+4>>2]=h;x[a+8>>2]=c;x[a+12>>2]=g&-2147483648|d;db=f+16|0}function mca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{c=db-16|0;db=c;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(c+8|0,x[vb(c+4|0,a)>>2]);b:{d=Ic(x[b>>2],x[b+4>>2]);if(!d){break b}x[23549]=0;P(581,a|0,d|0);e=x[23549];x[23549]=0;if((e|0)!=1){e=x[b+4>>2];f=x[b>>2];x[23549]=0;Az(a,f,e,d);d=x[23549];x[23549]=0;if((d|0)!=1){break b}}a=N()|0;ll(c+8|0);Q(a|0);p()}d=c+8|0;Hd(d);ll(d);db=c+16|0;x[23549]=0;O(3,a+12|0,b+12|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){x[a+24>>2]=x[b+24>>2];w[a+28>>1]=z[b+28>>1];break a}b=N()|0;id(a);Q(b|0);p()}}function Ufa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{d=db-32|0;db=d;a=Nb(a);b:{c:{d:{e:{while(1){c=x[b+8>>2];e=x[b>>2];x[23549]=0;c=U(142,e|0,c|0,8)|0;e=x[23549];x[23549]=0;if((e|0)==1){break c}if(c){x[23549]=0;P(618,d+4|0,b|0);c=x[23549];x[23549]=0;if((c|0)==1){break e}x[23549]=0;P(619,a|0,d+4|0);c=x[23549];x[23549]=0;if((c|0)==1){break d}c=d+4|0;Gd(c);e=c;c=Cm(x[a+4>>2]);zi(e,x[c>>2],x[c+4>>2]);if(x[d+4>>2]!=1413891155){continue}}break}db=d+32|0;break a}b=N()|0;break b}b=N()|0;Gd(d+4|0);break b}b=N()|0}_d(a);Q(b|0);p()}}function Nga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=db-608|0;db=f;b=db-16|0;db=b;d=f+8|0;ES(b+8|0,d);c=x[b+12>>2];md(b,a,x[b+8>>2],x[b+12>>2]);e=x[b+4>>2];if((e|0)==(c|0)){dd(a,x[b+12>>2])}db=b+16|0;c=(c|0)==(e|0);if(!c){DS(d)}b=-1;a:{if(!c){break a}b=0;if(!FS(f+8|0)){break a}b=-1;if(!zh(a,1024)){break a}b=0;d=db-1024|0;db=d;c=db-16|0;db=c;uA(c+8|0,d);e=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((e|0)==(g|0)){dd(a,x[c+12>>2])}db=c+16|0;if((e|0)==(g|0)){b=vA(d,0)>>>0<17}db=d+1024|0}db=f+608|0;return b|0}function E5(a){a=a|0;var b=0,c=0;x[23549]=0;W(927,a|0);b=x[23549];x[23549]=0;if((b|0)!=1){a=x[a+24>>2];b=x[a+24>>2];c=z[b+1074448>>1];a:{if(c>>>0>=cj(Wb(x[b+484360>>2],y[b+484376|0]))>>>0){a=z[x[a+24>>2]+1074446>>1];break a}a=x[a+24>>2];b=z[_b(x[Wb(x[a+484360>>2],y[a+484376|0])>>2],c)>>1];a=Gm(x[a+484344>>2],x[a+484348>>2],b)?b:-1}return a|0}Y(T(0)|0)|0;x[23549]=0;V(914,9649,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function n7(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;v[a+4202|0]=1;c=Uj(E(E(A[x[a+16>>2]+24620>>2])*E(.04500000178813934)));d=Uj(E(E(c>>>0)*E(1.1892070770263672)));e=Uj(E(E(d>>>0)*E(1.1892070770263672)));h=Uj(E(E(e>>>0)*E(1.1892070770263672)));f=Uj(E(E(c+e>>>0)*E(.11546666920185089)));g=Uj(E(E(d+h>>>0)*E(.11546666920185089)));b=a+4272|0;i=xb(b,0),j=c-f|0,x[i>>2]=j;i=xb(b,1),j=e-f|0,x[i>>2]=j;i=xb(b,2),j=d-g|0,x[i>>2]=j;i=xb(b,3),j=h-g|0,x[i>>2]=j;i=xb(b,4),j=f,x[i>>2]=j;i=xb(b,5),j=g,x[i>>2]=j;UK(a);SK(a)}function O5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-32|0;db=c;e=Nb(a);a=0;a:{b:{c:{d:{e:{while(1){d=x[b+24>>2];if(z[d+480188>>1]<=a>>>0){break a}x[23549]=0;P(982,c+8|0,(d+(a<<5)|0)+480289|0);d=x[23549];x[23549]=0;if((d|0)!=1){d=x[b+24>>2];x[23549]=0;S(983,c+20|0,d|0,c+8|0);d=x[23549];x[23549]=0;if((d|0)==1){break e}x[23549]=0;P(169,e|0,c+20|0);d=x[23549];x[23549]=0;if((d|0)==1){break d}a=a+1|0;tb(c+20|0);tb(c+8|0);continue}break}a=N()|0;break b}a=N()|0;break c}a=N()|0;tb(c+20|0)}tb(c+8|0)}Yd(e);Q(a|0);p()}db=c+32|0}function Hx(a,b){var c=0;if(b>>>0<=999999){if(b>>>0<=9999){if(b>>>0<=99){if(b>>>0<=9){return Ap(a,b)}return Xk(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return Xk(Ap(c,a),D(a,-100)+b|0)}return Gx(a,b)}if(b>>>0<=99999){c=a;a=(b>>>0)/1e4|0;return Gx(Ap(c,a),D(a,-1e4)+b|0)}return Ex(a,b)}if(b>>>0<=99999999){if(b>>>0<=9999999){c=a;a=(b>>>0)/1e6|0;return Ex(Ap(c,a),D(a,-1e6)+b|0)}return Hs(a,b)}if(b>>>0<=999999999){c=a;a=(b>>>0)/1e8|0;return Hs(Ap(c,a),D(a,-1e8)+b|0)}c=a;a=(b>>>0)/1e8|0;return Hs(Xk(c,a),D(a,-1e8)+b|0)}function EN(a,b,c){var d=0,e=0,f=0,g=0;d=db-16|0;db=d;a:{if(b){v[c|0]=b;break a}b=y[c|0]}e=x[a+480180>>2];c=e&1048580?(b&240?-16:15)&b:b;b=c&15;c=c&255;b:{c:{d:{if(!((b|0)!=15|c>>>0<16)){if(!(y[a+480209|0]&16)){break b}b=c>>>3&30;break d}f=x[a+480208>>2]&4096;g=c&240;if(!(!b|(g|0)!=240)){if(!f){break b}b=0-(b<<1)|0;break c}if(f){break b}if(g){if(e&59314208?b:0){break b}b=c>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}a=a+1074456|0;x[d+12>>2]=x[a>>2]+(b<<!(e&59314208));ke(d+12|0,0,256);x[a>>2]=x[d+12>>2]}db=d+16|0}function Mja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=db-32|0;db=c;nd(b,0);e=c+8|0;Xh(e,1,a);d=c+20|0;Bc(d,e);Ce(b+43|0,d);tb(d);x[b+24>>2]=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);w[b+34>>1]=z[b+34>>1]&65533|(y[a+13|0]|y[a+14|0]<<8)<<1&2;x[b>>2]=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);x[b+4>>2]=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);x[b+8>>2]=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);v[c+20|0]=y[a+15|0];v[c+8|0]=64;f=b,g=y[Sb(d,e)|0]<<2,w[f+30>>1]=g;db=c+32|0}function Jfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=db-80|0;db=c;d=Nf(c+52|0);x[23549]=0;e=O(625,b|0,d|0)|0;f=x[23549];x[23549]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23549]=0;R(626,a|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){break a}}break c}e=x[d+4>>2];x[23549]=0;S(176,c+12|0,b|0,e|0);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}a=N()|0;Gd(d);Q(a|0);p()}b=c+12|0;e=hc(c+32|0,b);Zc(d+8|0,e);ub(e);ub(b);wl(a,d)}Gd(d);db=c+80|0}function y5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=db-16|0;db=b;a:{c=x[a+36>>2];d=x[a+40>>2];b:{if(Kb(c,d)){xc(b+12|0);break b}Nn(b,a);x[23549]=0;c=R(986,b|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break a}x[b+12>>2]=c;Yf(b);d=x[a+40>>2];c=x[a+36>>2]}c=(f=a+36|0,g=x[b+12>>2],h=Kb(c,d),h?f:g);a=x[a+8>>2];c:{if((a|0)==-1){f=b,g=yb(x[c>>2]),x[f>>2]=g;a=yb(x[c+4>>2]);while(1){c=x[b>>2];if(!Kb(c,a)){break c}e=e+C[c>>3];qJ(b);continue}}e=C[nl(x[c>>2],a)>>3]}Qk(b+12|0);db=b+16|0;return+e}a=N()|0;Yf(b);Q(a|0);p()}function l_(a){a=a|0;if(y[467800]){return x[116949]}if(!y[468608]){v[468608]=1}Wc(468320,4975);Wc(468332,4966);Wc(468344,10725);Wc(468356,10473);Wc(468368,5202);Wc(468380,11510);Wc(468392,5059);Wc(468404,5550);Wc(468416,8784);Wc(468428,8767);Wc(468440,8775);Wc(468452,8794);Wc(468464,9956);Wc(468476,13104);Wc(468488,8857);Wc(468500,7612);Wc(468512,5202);Wc(468524,9645);Wc(468536,10361);Wc(468548,10737);Wc(468560,9147);Wc(468572,6404);Wc(468584,5433);Wc(468596,13022);v[467800]=1;x[116949]=468320;return 468320}function cea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=db-16|0;db=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];f=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=f;f=x[a+8>>2];k=x[a+12>>2];while(1){if(d){g=x[b+8>>2];g=(((x[b+12>>2]&2147483647)<<1|g>>>31)&-2)+j|0;e=0;while(1){if((e|0)!=2){x[(e<<2)+b>>2]=v[e+g|0]<<8;e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Qb(b+8|0,f,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;db=b+16|0}function _Y(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Kg(a,x[b+8>>2],e)){hw(b,c,d);return}a:{if(Kg(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;b:{if(x[b+44>>2]==4){break b}w[b+52>>1]=0;a=x[a+8>>2];ib[x[x[a>>2]+20>>2]](a,b,c,c,1,e);if(y[b+53|0]){x[b+44>>2]=3;if(!y[b+52|0]){break b}break a}x[b+44>>2]=4}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}a=x[a+8>>2];ib[x[x[a>>2]+24>>2]](a,b,c,d,e)}}function $P(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=b?33:32;c=y[a+16|0];k=c?-1:1;l=c?1:-1;e=x[a+8>>2]-1|0;m=c?e-(y[a+17|0]!=0&(e|0)!=0)|0:0;f=x[a+12>>2];n=(f|0)>0?f:0;o=c?0:e;h=x[a>>2]+D(f,62)|0;d=b?1:-1;p=D(f,d)<<1;c=e;a:while(1){if((i|0)!=(j|0)){g=D(c,f);q=x[a+4>>2];b=0;while(1)if((b|0)==(n|0)){b:{if((c|0)==(e|0)){b=m;g=k;if((d|0)>0){break b}}b=c+d|0;c=!c&(d|0)<0;b=c?o:b;g=c?l:d}h=h+p|0;i=i+1|0;c=b;d=g;continue a}else{w[(b<<1)+h>>1]=z[q+(b+g<<1)>>1];b=b+1|0;continue}}break}}function qD(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=db-16|0;db=e;f=x[b+16>>2];x[a+4>>2]=0;x[a>>2]=f;a:{if(!f){break a}c=b+80|0;d=x[b+84>>2];if(d>>>0<=15){d=x[c>>2]}else{x[e+12>>2]=d-16;d=x[Yc(c,e+12|0)>>2]}x[a+8>>2]=d;c=x[b+88>>2];if(!(c&2)|!y[b+794|0]){break a}d=c;c=x[b+104>>2];b:{c:{if(!oD(d,c)){d=x[b+84>>2];break c}d=x[b+84>>2];if(x[b+80>>2]!=x[c+12>>2]){break c}b=1;if(x[c+16>>2]==(d|0)){break b}}b=0;if(x[c+8>>2]!=(d|0)){break a}}g=a,h=D((x[c>>2]-d|0)+(b?112:48)|0,rk(z[c+34>>1]))+f|0,x[g+4>>2]=h}db=e+16|0}function iu(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=db-16|0;db=g;x[g+12>>2]=0;x[g+8>>2]=a;h=db-16|0;db=h;c=ec(h+8|0,x[g+8>>2],x[g+12>>2]);f=db-16|0;db=f;b=120;x[f+12>>2]=120;d=x[c+4>>2];a:{if(!d){d=x[c>>2];break a}e=32-d|0;x[f+8>>2]=e;b=x[c>>2];i=x[b>>2];j=e;e=x[Cb(f+8|0,f+12|0)>>2];x[b>>2]=(-1<<d&-1>>>j-e^-1)&i;i=x[f+12>>2];d=b+4|0;x[c>>2]=d;b=i-e|0}e=d;d=b>>>5|0;bD(e,d);b=b&31;x[f+12>>2]=b;if(b){e=c;c=x[c>>2]+(d<<2)|0;x[e>>2]=c;x[c>>2]=x[c>>2]&(-1>>>32-b^-1)}db=f+16|0;db=h+16|0;db=g+16|0;return a}function wga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;dc(c+8|0,b,26);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0}}function UE(a,b,c,d){var e=0,f=0,g=0;e=db-80|0;db=e;f=Nf(e+52|0);x[23549]=0;d=O(d|0,b|0,f|0)|0;g=x[23549];x[23549]=0;a:{b:{c:{d:{if((g|0)!=1){if(d){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23549]=0;R(c|0,a|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){break a}}break c}c=x[f+4>>2];x[23549]=0;S(176,e+12|0,b|0,$b(c)|0);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}a=N()|0;Gd(f);Q(a|0);p()}b=e+12|0;c=hc(e+32|0,b);Zc(f+8|0,c);ub(c);ub(b);wl(a,f)}Gd(f);db=e+80|0}function im(a,b,c,d){var e=0;a:{e=a+1074312|0;if(Ob(e,84)){break a}b:{if(y[a+480209|0]&64){break b}if((d|0)!=8){if(!Ob(e,10)){break b}}x[b+88>>2]=x[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0>=64?64:c)<<2;break d;default:break e}}if(!(x[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}x[b+88>>2]=x[b+88>>2]|256;c=128}x[b+692>>2]=c}w[b+784>>1]=0;x[b+88>>2]=x[b+88>>2]|2097152;if(!Ob(e,10)){break a}v[b+831|0]=0;w[b+778>>1]=0}}function aH(a,b,c,d){var e=0,f=0,g=0;e=db-16|0;db=e;a:{b:{if((a|0)!=(b|0)){c:{g=x[23424];x[23424]=0;yd();a=$G(a,e+12|0,d);d=hb;d:{f=x[23424];if(f){if(x[e+12>>2]!=(b|0)){break c}if((f|0)!=68){break d}x[c>>2]=4;b=2147483647;if(!!a&(d|0)>=0|(d|0)>0){break a}break b}x[23424]=g;if(x[e+12>>2]==(b|0)){break d}break c}if((d|0)<0&a>>>0<=2147483647|(d|0)<-1){x[c>>2]=4;break b}if((d|0)>=0&a>>>0>=2147483648|(d|0)>0){x[c>>2]=4;b=2147483647;break a}b=a;break a}}x[c>>2]=4;b=0;break a}b=-2147483648}db=e+16|0;return b}function eia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(x[a+4>>2]!=x[wb(a)>>2]){c=db-16|0;db=c;a=Pv(c+4|0,a);d=x[a+4>>2];x[23549]=0;P(442,d|0,b|0);b=x[23549];x[23549]=0;a:{if((b|0)!=1){x[a+4>>2]=x[a+4>>2]+12;fc(a);db=c+16|0;break a}b=N()|0;fc(a);Q(b|0);p()}return}d=db-32|0;db=d;c=wb(a);c=Hl(d+12|0,ep(a,Cd(x[a>>2],x[a+4>>2])+1|0),Cd(x[a>>2],x[a+4>>2]),c);e=x[c+8>>2];x[23549]=0;P(442,e|0,b|0);b=x[23549];x[23549]=0;b:{if((b|0)!=1){x[c+8>>2]=x[c+8>>2]+12;Ov(a,c);wr(c);db=d+32|0;break b}a=N()|0;wr(c);Q(a|0);p()}}function zF(a,b,c,d,e){var f=0,g=0,h=0;g=db-16|0;db=g;h=Gb(a);a=0;a:{b:{c:{d:{while(1){f=x[b>>2];if(Cd(f,x[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){f=$d(f,0);break e}x[23549]=0;O(d|0,h|0,c|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break b}f=$d(x[b>>2],a)}x[23549]=0;P(e|0,g+4|0,f|0);f=x[23549];x[23549]=0;if((f|0)!=1){x[23549]=0;O(d|0,h|0,g+4|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break d}a=a+1|0;tb(g+4|0);continue}break}a=N()|0;break a}a=N()|0;tb(g+4|0);break a}db=g+16|0;return}a=N()|0}tb(h);Q(a|0);p()}function tO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=-1;a:{if(!(y[b+851|0]&2)){break a}d=x[a+480208>>2]&8192;b:{c:{f=x[b+656>>2];if(f){c=y[f+22|0];if(ue(c)){g=b,h=rj(c),v[g+838|0]=h;c=1}else{c=!d}d=y[f+21|0];if(ue(d)){g=b,h=rj(d),v[g+837|0]=h;break c}if(c){break c}break b}c=!d;x[b+776>>2]=0;x[b+780>>2]=0;break b}c=1;d=y[f+25|0];if((d|0)==255){break b}v[b+845|0]=d}d:{if(y[b+837|0]>=127){if(Ob(a+1074312|0,36)&c){break d}break a}if(!c){break a}}e=Rp(a,b,1,256);if((e|0)<0){break a}e=y[b+837|0]>>>1|0}return e}function Nfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=db-32|0;db=e;nd(b,0);d=e+8|0;lB(d,a+1|0);c=e+20|0;Bc(c,d);Ce(b+43|0,c);tb(c);x[b+24>>2]=y[a+73|0]|y[a+74|0]<<8|(y[a+75|0]<<16|y[a+76|0]<<24);c=y[a+54|0]|y[a+55|0]<<8|(y[a+56|0]<<16|y[a+57|0]<<24);x[b>>2]=c;x[b+4>>2]=y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24);d=y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24);if(d){x[b+8>>2]=d+1}w[b+30>>1]=(y[a+68|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;tc(b+8|0,c);tc(b+4|0,x[b+8>>2]);db=e+32|0}function $da(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=db-16|0;db=b;e=x[a+40>>2];f=x[a+36>>2];i=x[a+16>>2];g=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=g;j=x[a+32>>2];k=x[a+28>>2];g=x[a+8>>2];l=x[a+12>>2];while(1){if(d){h=w[(x[b+12>>2]<<1)+i>>1];f=f+k|0;x[c>>2]=x[c>>2]+D(h,f>>12);e=e+j|0;x[c+4>>2]=x[c+4>>2]+D(e>>12,h);Qb(b+8|0,g,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=e;x[a+20>>2]=f>>12;x[a+36>>2]=f;x[a+24>>2]=e>>12;db=b+16|0}function em(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}i=d;h=64-f|0;g=h&31;if((h&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|e<<g;j=i<<g}i=b;b=f&31;if((f&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function xl(a,b,c){var d=0;d=512;a:{if(b){break a}d=0;if(!(y[a+35|0]&2)){break a}Po(a)}d=z[a+34>>1]&-513|d;w[a+34>>1]=d;if(b){x[a>>2]=4;w[a+34>>1]=d&65470;zg(a);b=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[a+76|0]=b;v[a+77|0]=b>>>8;v[a+78|0]=b>>>16;v[a+79|0]=b>>>24;b=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a+68|0]=c;v[a+69|0]=c>>>8;v[a+70|0]=c>>>16;v[a+71|0]=c>>>24;v[a+72|0]=b;v[a+73|0]=b>>>8;v[a+74|0]=b>>>16;v[a+75|0]=b>>>24}}function c5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=E(0);x[23549]=0;W(927,a|0);d=x[23549];x[23549]=0;a:{if((d|0)==1){break a}x[23549]=0;W(998,c|0);d=x[23549];x[23549]=0;if((d|0)==1){break a}d=x[a+24>>2];e=B[d+48>>2];d=x[d+24>>2];x[23549]=0;b=Ua(999,d|0,E(e),b|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break a}x[c>>2]=b;return 1}Y(T(0)|0)|0;x[23549]=0;V(914,10236,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function b7(a){a=a|0;var b=0,c=0,d=0;b=db-32|0;db=b;a:{b:{if(!a){a=_f(21204);break b}x[23549]=0;c=O(54,b+8|0,a|0)|0;a=x[23549];x[23549]=0;c:{d:{if((a|0)!=1){x[23549]=0;P(913,b+20|0,c|0);a=x[23549];x[23549]=0;if((a|0)==1){break d}d=b+20|0;a=_f(Mb(d));tb(d);tb(c);break b}a=T(0)|0;break c}a=T(0)|0;tb(c)}Y(a|0)|0;a=0;x[23549]=0;V(914,10865,0,0,0);c=x[23549];x[23549]=0;if((c|0)==1){break a}Z()}db=b+32|0;return a|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function aea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=db-16|0;db=b;e=x[a+40>>2];f=x[a+36>>2];i=x[a+16>>2];g=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=g;j=x[a+32>>2];k=x[a+28>>2];g=x[a+8>>2];l=x[a+12>>2];while(1){if(d){h=v[x[b+12>>2]+i|0]<<8;f=f+k|0;x[c>>2]=x[c>>2]+D(h,f>>12);e=e+j|0;x[c+4>>2]=x[c+4>>2]+D(e>>12,h);Qb(b+8|0,g,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=e;x[a+20>>2]=f>>12;x[a+36>>2]=f;x[a+24>>2]=e>>12;db=b+16|0}function VI(a,b){a=a|0;b=b|0;var c=0,d=0;d=db-16|0;db=d;a:{b:{c:{a=x[a+32>>2];c=ys(a);d:{if(!c){if(xs(a)>>>0<=b>>>0){break d}c=(y[_j(a,b+1&65535)+35|0]&4)>>>2|0;break b}if(b>>>0<c>>>0){break c}}a=ac(8);x[23549]=0;b=O(54,d+4|0,5941)|0;c=x[23549];x[23549]=0;e:{if((c|0)!=1){a=pc(a,b);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break e}c=N()|0;jc(a)}Q(c|0);p()}a=x[(a+(b<<2)|0)+900384>>2];c=1;if(!a){break b}c=(y[a+15|0]&2)>>>1|0}db=d+16|0;return c|0}p()}function eY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=db-48|0;db=f;dp(f+12|0,c);x[23549]=0;c=f+24|0;P(125,c|0,d|0);d=x[23549];x[23549]=0;b:{c:{d:{if((d|0)==1){break d}x[23549]=0;c=f+36|0;P(125,c|0,e|0);d=x[23549];x[23549]=0;if((d|0)==1){break d}kE(f+4|0,f+12|0);x[23549]=0;V(100,a|0,b|0,x[f+4>>2],x[f+8>>2]);a=x[23549];x[23549]=0;if((a|0)==1){break c}rr(f+12|0);db=f+48|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(f+12|0)){continue}break}break b}a=N()|0;rr(f+12|0)}Q(a|0);p()}}function jo(a){var b=0,c=0,d=0,e=0;d=z[x[a+4>>2]+28>>1]>>>(!y[a+77|0]<<1)|0;b=((d&3)<<4)+27888|0;x[a+40>>2]=b;e=z[a+24>>1];d=d>>>2|0;c=e+d|0;w[a+36>>1]=c>>>0<12?1:1<<c-12;c=12-c|0;c=c>>>0<=12?c:0;w[a+32>>1]=c;w[a+34>>1]=-1<<c^-1;if((e|0)==15){w[a+36>>1]=4095}x[a+52>>2]=b;x[a+64>>2]=b;b=d+z[a+26>>1]|0;w[a+48>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;c=b>>>0<=12?b:0;w[a+44>>1]=c;b=d+z[a+30>>1]|0;w[a+60>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;b=b>>>0<=12?b:0;w[a+56>>1]=b;w[a+46>>1]=-1<<c^-1;w[a+58>>1]=-1<<b^-1}function iY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=db-32|0;db=c;a:{b:{c:{d:{if(f=xd(x[b+4>>2],y[b+11|0]),g=1,h=x[b+12>>2],h?f:g){Gb(a);break d}d=Bb(x[b+4>>2],y[b+11|0]);e=Pf(13974);sl(We(We(Mb(Vw(c+20|0,d+e|0)),Mb(b),d)+d|0,13974,e)+e|0,1,0);x[23549]=0;P(118,c+8|0,b+12|0);b=x[23549];x[23549]=0;if((b|0)==1){break c}x[23549]=0;S(2,a|0,c+20|0,c+8|0);a=x[23549];x[23549]=0;if((a|0)==1){break b}tb(c+8|0);tb(c+20|0)}db=c+32|0;return}b=N()|0;break a}b=N()|0;tb(c+8|0)}tb(c+20|0);Q(b|0);p()}function M5(a){a=a|0;var b=0,c=0,d=0,e=0;c=db-32|0;db=c;e=Nb(a);Rd(c+24|0);a=0;b=x[c+28>>2];d=x[c+24>>2];x[23549]=0;P(167,e|0,kJ(d,b)|0);b=x[23549];x[23549]=0;a:{if((b|0)!=1){b:{while(1){b=x[c+24>>2];if((kJ(b,x[c+28>>2])|0)<=(a|0)){db=c+32|0;return}b=x[b+(a<<3)>>2];x[23549]=0;b=O(54,c+12|0,b|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){x[23549]=0;P(169,e|0,b|0);d=x[23549];x[23549]=0;if((d|0)==1){break b}tb(b);a=a+1|0;continue}break}a=N()|0;break a}a=N()|0;tb(b);break a}a=N()|0}Yd(e);Q(a|0);p()}function uia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=db-32|0;db=c;e=c+12|0;f=Nb(e+8|0);x[23549]=0;d=R(188,b|0)|0;g=x[23549];x[23549]=0;a:{b:{if((g|0)==1){break b}x[23549]=0;S(233,e|0,b|0,d|0);d=x[23549];x[23549]=0;if((d|0)==1){break b}d=x[e>>2];x[23549]=0;O(174,b|0,d|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break a}}a=N()|0;bc(f);Q(a|0);p()}Kq(c+4|0,e);x[23549]=0;S(417,a|0,x[c+4>>2],x[c+8>>2]);a=x[23549];x[23549]=0;if((a|0)!=1){Jc(c+12|0);db=c+32|0;return}a=N()|0;Jc(c+12|0);Q(a|0);p()}function QI(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=db-32|0;db=d;C[d+24>>3]=c;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[23549]=0;d=O(54,d+8|0,10589)|0;a=x[23549];x[23549]=0;if((a|0)==1){break c}a=pc(b,d);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break b}a=x[a+32>>2];x[d+8>>2]=0;x[d+12>>2]=-1074790400;x[d>>2]=0;x[d+4>>2]=1072693248;e=(a+D(b,872)|0)+1075684|0,f=pm(C[wg(d+24|0,d+8|0,d)>>3]*128+128),x[e>>2]=f;db=d+32|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function Mr(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=db-16|0;db=i;a:{b:{if(!a){break b}h=x[e+12>>2];g=c-b|0;if((g|0)>0){g=g>>>2|0;if((Ho(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>0){f=NG(i+4|0,b,f);h=Mb(f);x[23549]=0;h=U(1133,a|0,h|0,b|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break a}Ec(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>0){b=b>>>2|0;if((Ho(a,c,b)|0)!=(b|0)){break b}}MB(e);j=a}db=i+16|0;return j|0}a=N()|0;Ec(f);Q(a|0);p()}function TM(a,b){var c=0,d=0,e=0,f=0,g=0;d=db-32|0;db=d;a:{f=b-1&65535;if(f>>>0>3998){break a}c=D(b,104)+a|0;e=c+484380|0;if(!Sd(x[e>>2],x[c+484400>>2])){break a}g=a+1298224|0;c=a+1074992|0;while(1){if((c|0)==(g|0)){vm(e);x[e>>2]=0;a=(D(b,104)+a|0)+484414|0;w[a>>1]=z[a>>1]&65470;x[d+24>>2]=0;x[d+8>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d>>2]=0;x[d+4>>2]=0;xl(e,0,d);break a}if(x[c+104>>2]==(e|0)){x[c+76>>2]=0;x[c>>2]=0;x[c+4>>2]=0;x[c+16>>2]=0}c=c+872|0;continue}}db=d+32|0;return f>>>0<3999}function RJ(a){var b=0,c=0,d=0,e=0,f=0;while(1){d=x[a+16>>2];if(d>>>0<=e>>>0){while(1){if(!(A[a+12>>2]<=d>>>0)){while(1){f=By(x[a>>2]);e=hb;c=x[a+36>>2];if((e|0)==(c|0)&A[a+32>>2]<=f>>>0|e>>>0>c>>>0){continue}break}c=b;b=x[a+8>>2];b=(f&x[a+48>>2])+(b>>>0<31?c<<b+1:0)|0;d=d+1|0;continue}break}}else{while(1){f=By(x[a>>2]);d=hb;c=x[a+28>>2];if((d|0)==(c|0)&A[a+24>>2]<=f>>>0|d>>>0>c>>>0){continue}break}c=b;b=x[a+8>>2];b=(f&x[a+40>>2])+(b>>>0<32?c<<b:0)|0;e=e+1|0;continue}break}return b}function aQ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;i=b?33:32;c=x[a+8>>2]-1|0;e=x[a+12>>2];f=x[a>>2]+D(e,31)|0;g=b?1:-1;d=g;a:while(1){b:{b=0;if((h|0)==(i|0)){break b}while(1)if((b|0)>=(e|0)){b=x[a+8>>2]-1|0;c:{if(!((b|0)!=(c|0)|(d|0)<=0)){if(!y[a+16|0]){d=1;c=0;break c}d=-1;c=c-(y[a+17|0]!=0&(c|0)!=0)|0;break c}if(!((d|0)>=0|c)){c=y[a+16|0];d=c?1:-1;c=c?0:b;break c}c=c+d|0}f=D(e,g)+f|0;h=h+1|0;continue a}else{v[b+f|0]=y[x[a+4>>2]+(D(c,e)+b|0)|0];b=b+1|0;e=x[a+12>>2];continue}}break}}function yaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=db-32|0;db=e;f=e+8|0;tl(f,2,a+2|0);d=e+20|0;Bc(d,f);zc(b+492|0,d);f=b+236|0;g=c+1|0;tb(d);c=0;while(1){if((c|0)==120){x[b>>2]=(y[a+223|0]|y[a+224|0]<<8)<<5;a=a+158|0;sM(y[a|0]&15,y[a+1|0]&15,y[a+2|0]&15,y[a+3|0]&15,y[a+4|0]&15,a+5|0,b+48|0);sM(y[a|0]>>>4|0,y[a+1|0]>>>4|0,y[a+2|0]>>>4|0,y[a+3|0]>>>4|0,y[a+4|0]>>>4|0,a+35|0,b+68|0);db=e+32|0}else{d=y[(a+c|0)+31|0];h=_b(f,c),i=d+g|0,w[h>>1]=i;c=c+1|0;continue}break}}function jS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-32|0;db=c;a:{if(!y[b+8|0]){while(1){if((d|0)==8){x[c+24>>2]=0;x[c+28>>2]=0;d=ec(c+8|0,c+24|0,8);e=x[d>>2];lc(c+16|0,x[a>>2],x[a+8>>2],e,x[d+4>>2]);d=0;if(!(x[c+24>>2]!=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))|x[c+28>>2]!=(y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24))|x[c+20>>2]!=8)){Zb(a,8);d=1}db=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17053,8977,413,13012);p()}_(17032,8977,411,13012);p()}return d|0}function z$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;g=db-16|0;db=g;e=Bb(x[a+4>>2],y[a+11|0]);d=Mc(a);f=ri(b,c);a:{if(!f){break a}b:{if(!Wx(a,b)){if(d-e>>>0<f>>>0){cm(a,d,(e-d|0)+f|0,e,e,0,0)}d=Mb(a)+e|0;while(1){if((b|0)==(c|0)){break b}hd(d,y[b|0]);b=b+1|0;d=d+1|0;continue}}b=vg(g+4|0,b,c);c=Mb(b);e=y[b+11|0];d=x[b+4>>2];x[23549]=0;U(1144,a|0,c|0,Bb(d,e)|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){tb(b);break a}a=N()|0;tb(b);Q(a|0);p()}hd(d,0);Wg(a,e+f|0)}db=g+16|0;return a|0}function zf(a,b,c,d,e,f){var g=0,h=0,i=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;d=f&31;if((f&63)>>>0>=32){h=g<<d;i=0}else{h=(1<<d)-1&g>>>32-d|e<<d;i=g<<d}g=b;e=64-f|0;d=e&31;if((e&63)>>>0>=32){e=0;b=c>>>d|0}else{e=c>>>d|0;b=((1<<d)-1&c)<<32-d|g>>>d}d=i|b;e=e|h;b=f&31;if((f&63)>>>0>=32){h=g<<b;b=0}else{h=(1<<b)-1&g>>>32-b|c<<b;b=g<<b}c=h}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function mM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a|0)!=(b|0)){c=db-16|0;db=c;d=x[b>>2];f=x[b+4>>2];e=bk(d,f);a:{if(e>>>0<=tu(a)>>>0){g=f;h=x[a>>2];i=bk(h,x[a+4>>2]);j=i>>>0>=e>>>0;if(!j){x[c+12>>2]=d;x[c+12>>2]=x[c+12>>2]+D(i,6);g=x[c+12>>2]}d=fy(d,g,h);if(!j){Rs(a,g,f,e-bk(x[a>>2],x[a+4>>2])|0);break a}Dd(a,d);break a}nM(a);kU(a,XA(a,e));Rs(a,d,f,e)}db=c+16|0}x[a+12>>2]=x[b+12>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=x[b+20>>2];lM(a+24|0,b+24|0);Aj(a+36|0,b+36|0);return a}function d3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=db-16|0;db=f;e=f+4|0;x[e+4>>2]=1;h=e,i=Hc(56),x[h+8>>2]=i;c=db-16|0;db=c;d=Zo(x[e+8>>2]);x[d>>2]=60864;g=x[b+12>>2];x[c+8>>2]=x[b+8>>2];x[c+12>>2]=g;g=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=g;b=Zm(kc(d));x[b>>2]=61228;Nb(b+4|0);v[b+20|0]=0;x[b+16>>2]=0;x[b>>2]=61028;d=x[c+4>>2];x[b+24>>2]=x[c>>2];x[b+28>>2]=d;d=x[c+12>>2];x[b+32>>2]=x[c+8>>2];x[b+36>>2]=d;v[b+40|0]=0;db=c+16|0;b=a;a=$o(e);_o(b,kc(a),a);_m(e);db=f+16|0}function OW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=db-32|0;db=d;nd(b,0);e=d+8|0;Xh(e,1,a+33|0);c=d+20|0;Bc(c,e);Ce(b+43|0,c);tb(c);f=y[a+50|0]|y[a+51|0]<<8;x[b>>2]=f;x[b+24>>2]=y[a+52|0]|y[a+53|0]<<8;v[d+20|0]=y[a+54|0];v[d+8|0]=64;g=b,h=y[Sb(c,e)|0]<<2,w[g+30>>1]=h;e=y[a+55|0]|y[a+56|0]<<8;x[b+4>>2]=e;c=y[a+57|0]|y[a+58|0]<<8;x[b+8>>2]=c;a:{if((c|0)==65535){x[b+4>>2]=0;x[b+8>>2]=0;break a}if(!y[a|0]|c>>>0<=e+2>>>0|c>>>0>f>>>0){break a}w[b+34>>1]=z[b+34>>1]|2}db=d+32|0}function Iv(a){var b=0,c=0,d=0;if(A[a+4>>2]<A[wb(a)>>2]){b=db-16|0;db=b;a=JD(b+4|0,a);c=x[a+4>>2];x[23549]=0;W(156,c|0);c=x[23549];x[23549]=0;a:{if((c|0)!=1){x[a+4>>2]=x[a+4>>2]+36;fc(a);db=b+16|0;break a}b=N()|0;fc(a);Q(b|0);p()}return}c=db-32|0;db=c;b=wb(a);b=HD(c+12|0,ID(a,er(x[a>>2],x[a+4>>2])+1|0),er(x[a>>2],x[a+4>>2]),b);d=x[b+8>>2];x[23549]=0;W(156,d|0);d=x[23549];x[23549]=0;b:{if((d|0)!=1){x[b+8>>2]=x[b+8>>2]+36;GD(a,b);xv(b);db=c+32|0;break b}a=N()|0;xv(b);Q(a|0);p()}}function u3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=db-16|0;db=c;a:{d=Oh(E(B[a+24>>2]*E(65536)));if((d|0)==65536){break a}i=x[b+4>>2];j=x[b+8>>2];k=d>>31;b:while(1){if((g|0)==(j|0)){break a}l=x[b+4>>2];m=x[b>>2];e=0;while(1)if((e|0)==(i|0)){g=g+1|0;continue b}else{h=Kh(m,l,e,g);f=x[h>>2];f=zka(yka(f,f>>31,d,k),hb,65536,0);n=h,o=Cc(f,hb),x[n>>2]=o;e=e+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;FJ(a,c);db=c+16|0}function jN(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=x[a+104>>2];d=(g<<3)+a|0;b=((g+7>>>0)%12<<3)+a|0;f=x[b>>2];e=x[b+4>>2];b=x[a+100>>2];j=b;h=x[a+96>>2];a:{if(!(b|h)){c=x[d+4>>2];b=x[d>>2];i=(c|0)==(e|0)&b>>>0>f>>>0|e>>>0<c>>>0;break a}c=x[d+4>>2];b=x[d>>2];i=!(e|f)|((c|0)==(e|0)&b>>>0>=f>>>0|e>>>0<c>>>0)}c=c+j|0;b=b+h|0;c=b>>>0<h>>>0?c+1|0:c;x[d>>2]=f-b;x[d+4>>2]=e-(c+(b>>>0>f>>>0)|0)&65535;x[a+104>>2]=(g+1>>>0)%12;x[a+96>>2]=i;x[a+100>>2]=0;hb=x[d+4>>2];return x[d>>2]}function V2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;e=Zo(a);x[e>>2]=60364;a=x[b+12>>2];x[c+8>>2]=x[b+8>>2];x[c+12>>2]=a;a=c;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;b=kc(e);c=db-16|0;db=c;d=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=d;d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;d=sJ(c);b=Zm(b);v[b+8|0]=0;x[b+4>>2]=d;x[b>>2]=60764;Nb(b+12|0);x[b>>2]=60528;d=x[a+4>>2];x[b+24>>2]=x[a>>2];x[b+28>>2]=d;d=x[a+12>>2];x[b+32>>2]=x[a+8>>2];x[b+36>>2]=d;db=c+16|0;db=a+16|0;return e|0}function D3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=db-16|0;db=c;a:{d=Oh(E(B[a+24>>2]*E(65536)));if((d|0)==65536){break a}i=x[b+4>>2];j=x[b+8>>2];k=d>>31;b:while(1){if((g|0)==(j|0)){break a}l=x[b+4>>2];m=x[b>>2];e=0;while(1)if((e|0)==(i|0)){g=g+1|0;continue b}else{h=Kh(m,l,e,g);f=x[h>>2];f=zka(yka(f,f>>31,d,k),hb,65536,0);n=h,o=Cc(f,hb),x[n>>2]=o;e=e+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;MJ(a,c);db=c+16|0}function jy(a,b,c,d){var e=0,f=0,g=0,h=0;e=db-48|0;db=e;a:{if(!c){b=_c(x[a>>2],b);a=x[d+12>>2];x[b+8>>2]=x[d+8>>2];x[b+12>>2]=a;a=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=a;break a}f=x[d+12>>2];x[e+24>>2]=x[d+8>>2];x[e+28>>2]=f;f=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=f;f=c>>>1|0;jy(a,b,f,e+16|0);g=C[d>>3];h=C[d+8>>3];d=_c(x[a>>2],c);qi(e+32|0,g,h,C[d>>3],C[d+8>>3]);d=x[e+44>>2];x[e+8>>2]=x[e+40>>2];x[e+12>>2]=d;d=x[e+36>>2];x[e>>2]=x[e+32>>2];x[e+4>>2]=d;jy(a,b|c,f,e)}db=e+48|0}function cia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=db-16|0;db=e;i=e,j=$j(b),x[i+4>>2]=j;g=z[b>>1];c=db-16|0;db=c;f=a;d=Ud(a);a:{if(d){b=gc(f);while(1){a=d;d=z[a+16>>1];if(yo(g,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!yo(d,g)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=gc(f);b=a}x[c+12>>2]=a;a=x[b>>2];if(!a){eU(c,f,e+4|0);Yg(f,x[c+12>>2],b,x[c>>2]);a=Zd(c);dU(c);h=1}Xg(e+8|0,x[vb(c,a)>>2],h);db=c+16|0;a=td(x[e+8>>2]);db=e+16|0;return a+4|0}function $L(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=db-16|0;db=e;i=e,j=$j(b),x[i+4>>2]=j;g=z[b>>1];c=db-16|0;db=c;f=a;d=Ud(a);a:{if(d){b=gc(f);while(1){a=d;d=z[a+16>>1];if(aq(g,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!aq(d,g)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=gc(f);b=a}x[c+12>>2]=a;a=x[b>>2];if(!a){eU(c,f,e+4|0);Yg(f,x[c+12>>2],b,x[c>>2]);a=Zd(c);dU(c);h=1}Xg(e+8|0,x[vb(c,a)>>2],h);db=c+16|0;a=td(x[e+8>>2]);db=e+16|0;return a+4|0}function K5(a,b){a=a|0;b=b|0;var c=E(0),d=0,e=E(0);x[23549]=0;W(927,a|0);d=x[23549];x[23549]=0;if((d|0)!=1){a=x[x[a+24>>2]+24>>2];if(!((b|0)<0|z[a+480188>>1]<=b>>>0)){a=a+D(b,872)|0;c=E(E(y[a+1075834|0])*E(.0078125));e=E(c*c);c=E(E(y[a+1075835|0])*E(.0078125));c=E(M(E(e+E(c*c))))}return E(c)}Y(T(0)|0)|0;x[23549]=0;V(914,9275,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Vv(a,b,c,d,e,f,g,h){var i=0;a:{i=db-48|0;db=i;vk(i+12|0,c);x[23549]=0;c=i+24|0;P(h|0,c|0,d|0);d=x[23549];x[23549]=0;b:{c:{d:{if((d|0)==1){break d}x[23549]=0;c=i+36|0;P(g|0,c|0,e|0);d=x[23549];x[23549]=0;if((d|0)==1){break d}kE(i+4|0,i+12|0);x[23549]=0;V(f|0,a|0,b|0,x[i+4>>2],x[i+8>>2]);a=x[23549];x[23549]=0;if((a|0)==1){break c}rr(i+12|0);db=i+48|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(i+12|0)){continue}break}break b}a=N()|0;rr(i+12|0)}Q(a|0);p()}}function o9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ni(a,b,c,d);x[a>>2]=44296;b=Nb(a+4208|0);x[a+4236>>2]=-1;x[a+4240>>2]=0;x[a+4228>>2]=1049926264;x[a+4232>>2]=0;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;v[a+4244|0]=0;Vb(a+4248|0,0,48);x[23549]=0;X(787);c=x[23549];x[23549]=0;a:{if((c|0)==1){break a}e=a,f=qN(),x[e+4296>>2]=f;Ms(a);Ls(a);x[23549]=0;P(878,a+44|0,2);c=x[23549];x[23549]=0;if((c|0)==1){break a}mi(a);return a|0}c=N()|0;bc(b);yf(a);Q(c|0);p()}function gM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=db-16|0;db=f;a:{b:{c:{d=Mc(a);e=ri(b,c);if(d>>>0<e>>>0){if(Wx(a,b)){break c}g=d;h=e-d|0;d=Bb(x[a+4>>2],y[a+11|0]);cm(a,g,h,d,0,d,0)}d=Mb(a);while(1){if((b|0)==(c|0)){break b}hd(d,y[b|0]);b=b+1|0;d=d+1|0;continue}}b=vg(f+4|0,b,c);c=Mb(b);d=y[b+11|0];e=x[b+4>>2];x[23549]=0;S(56,a|0,c|0,Bb(e,d)|0);c=x[23549];x[23549]=0;if((c|0)!=1){tb(b);break a}a=N()|0;tb(b);Q(a|0);p()}hd(d,0);Wg(a,e)}db=f+16|0;return a|0}function Aj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((a|0)!=(b|0)){if(!ue(y[a+11|0])){c=y[b+11|0];if(!ue(c)){d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];return}d=Mb(b);b=Bb(x[b+4>>2],c);a:{if(b>>>0<=10){ff(a,b);hd(We(a,d,b)+b|0,0);break a}e=a;a=rj(y[a+11|0]);gq(e,10,b-10|0,a,0,a,b,d)}return}d=Mb(b);b=Bb(x[b+4>>2],y[b+11|0]);c=mk(x[a+8>>2]);b:{if(b>>>0<c>>>0){c=x[a>>2];re(a,b);hd(We(c,d,b)+b|0,0);break b}e=a;a=x[a+4>>2];gq(e,c-1|0,(b-c|0)+1|0,a,0,a,b,d)}}}function XS(a,b,c,d){var e=0,f=0;f=db-16|0;db=f;e=z[c>>1];while(1){a:{e=e<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){if(!ef(a,f+15|0)){break a}e=y[f+15|0];w[c>>1]=e<<1|1;v[b|0]=e>>>7;w[c>>1]=y[c|0]}v[d|0]=y[b|0]+(y[d|0]<<1);e=z[c>>1]<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){if(!ef(a,f+14|0)){break a}e=y[f+14|0];w[c>>1]=e<<1|1;v[b|0]=e>>>7;e=y[c|0];w[c>>1]=e;if(y[b|0]){continue}break a}if(y[b|0]){continue}}break}db=f+16|0}function tF(a,b,c,d,e,f,g,h){var i=0,j=0;i=db-16|0;db=i;x[23549]=0;W(927,a|0);j=x[23549];x[23549]=0;a:{b:{if((j|0)!=1){c:{j=x[a+24>>2];x[23549]=0;ea(h|0,i+4|0,j|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=x[23549];x[23549]=0;if((b|0)==1){break c}a=i+4|0;b=_f(Mb(a));tb(a);break b}}Y(T(0)|0)|0;b=0;x[23549]=0;V(914,g|0,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z()}db=i+16|0;return b}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Iq(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=db-16|0;db=i;a:{b:{if(!a){break b}g=x[e+12>>2];h=c-b|0;if((h|0)>0){if((Ho(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>0){f=Ye(i+4|0,b,f);g=Mb(f);x[23549]=0;g=U(22,a|0,g|0,b|0)|0;h=x[23549];x[23549]=0;if((h|0)==1){break a}tb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>0){if((Ho(a,c,b)|0)!=(b|0)){break b}}MB(e);j=a}db=i+16|0;return j|0}a=N()|0;tb(f);Q(a|0);p()}function H$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;c=db-128|0;db=c;x[c+12>>2]=c+116;d=c+16|0;FG(x[a+8>>2],d,c+12|0,e,f,g);f=db-16|0;db=f;h=f+8|0;a=db-32|0;db=a;An(a+24|0,d,x[c+12>>2]);i=a+16|0;e=x[a+24>>2];g=x[a+28>>2];d=db-16|0;db=d;x[d+12>>2]=b;while(1){if((e|0)!=(g|0)){QH(d+12|0,v[e|0]);e=e+1|0;continue}break}vc(i,g,d+12|0);db=d+16|0;b=x[a+16>>2];x[a+12>>2]=x[a+20>>2];vc(h,b,a+12|0);db=a+32|0;db=f+16|0;db=c+128|0;return x[f+12>>2]}function i5(a,b){a=a|0;b=b|0;var c=0,d=0;x[23549]=0;W(927,a|0);c=x[23549];x[23549]=0;if((c|0)!=1){a=x[a+24>>2];c=-1;a:{if((b|0)<0){break a}d=x[a+24>>2];if(cj(Wb(x[d+484360>>2],y[d+484376|0]))>>>0<=b>>>0){break a}a=x[a+24>>2];c=z[_b(x[Wb(x[a+484360>>2],y[a+484376|0])>>2],b)>>1]}return c|0}Y(T(0)|0)|0;x[23549]=0;V(914,9684,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function ZG(a,b,c,d){var e=0,f=0,g=0,h=0;e=db-16|0;db=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=y[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=x[23424];x[23424]=0;yd();a=zw(a,e+12|0,d);d=hb;g=x[23424];e:{if(g){if(x[e+12>>2]!=(b|0)){break c}if(!d&a>>>0>65535|d|(g|0)==68){break e}break b}x[23424]=h;if(x[e+12>>2]!=(b|0)){break c}if(!d&a>>>0<65536){break b}}x[c>>2]=4;a=65535;break a}}x[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}db=e+16|0;return a&65535}function sF(a,b,c,d,e,f,g){var h=0,i=0;h=db-16|0;db=h;x[23549]=0;W(927,a|0);i=x[23549];x[23549]=0;a:{b:{if((i|0)!=1){c:{i=x[x[a+24>>2]+24>>2];x[23549]=0;ia(g|0,h+4|0,i|0,b|0,c|0,d|0,e|0);b=x[23549];x[23549]=0;if((b|0)==1){break c}a=h+4|0;b=_f(Mb(a));tb(a);break b}}Y(T(0)|0)|0;b=0;x[23549]=0;V(914,f|0,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z()}db=h+16|0;return b}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function fO(a,b){var c=0,d=0,e=0,f=0,g=0;a:{if(y[b+791|0]!=27){a=v[b+831|0];break a}e=a+1074312|0;c=Ob(e,21);d=a;a=y[b+821|0];a=sy(d,y[b+828|0],c?a:a+16>>>2|0);b:{if(!(!Ob(e,45)|y[b+828|0]!=3)){c=y[b+821|0];c:{if(!(!c|c>>>0>=y[b+829|0])){a=y[b+832|0];d=c+1|0;break c}v[b+832|0]=a;d=1}v[b+821|0]=d;a=a<<24>>24;break b}v[b+821|0]=y[b+821|0]+y[b+829|0]}if(!Ob(e,47)){break a}v[b+831|0]=a}if(a){f=b,g=Ub(x[b+684>>2]+((D(y[b+830|0],a)+2|0)/8|0)|0,0,256),x[f+684>>2]=g}}function eM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<=127){f=db-32|0;db=f;c=128-c|0;e=x[wb(a)>>2];d=x[a+4>>2];a:{if(c>>>0<=e-d>>2>>>0){ay(a,c,b);break a}e=wb(a);d=Jf(f+12|0,eg(a,oc(x[a>>2],d)+c|0),oc(x[a>>2],x[a+4>>2]),e);g=db-16|0;db=g;c=Bl(g+4|0,d+8|0,c);e=x[c>>2];while(1){if(x[c+4>>2]!=(e|0)){Qs(e,B[b>>2]);e=x[c>>2]+4|0;x[c>>2]=e;continue}break}Kd(c);db=g+16|0;$x(a,d);If(d)}db=f+32|0;return}if((c|0)!=128){Dd(a,d+512|0)}}function EA(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==y[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}if(!(y[a|0]==(b&255)|c>>>0<4)){d=D(b&255,16843009);while(1){e=d^x[a>>2];if((e^-1)&e-16843009&-2139062144){break b}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}b=b&255;while(1){if((b|0)==y[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function efa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db+-64|0;db=c;rm(c+52|0,b);ge(c+24|0,x[c+52>>2],x[c+56>>2]);b=Xd(c+16|0);x[23549]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=Xf(152,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[23549];x[23549]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[23549]=0;S(670,b|0,d|0,Pc(e,a)>>>5|0);a=x[23549];x[23549]=0;if((a|0)==1){a=N()|0;vi(d);ub(b);break a}ub(b);bc(c+52|0);db=c- -64|0;return}a=N()|0}bc(c+52|0);Q(a|0);p()}
function HM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;a:{if((c|0)<2){break a}i=c-2>>>1|0;e=d-a|0;if((i|0)<e>>1){break a}g=e+1|0;f=(g<<1)+a|0;e=e+2|0;if((e|0)<(c|0)){h=e;e=_k(b,z[f>>1],z[f+2>>1]);g=e?h:g;f=e?f+2|0:f}if(_k(b,z[f>>1],z[d>>1])){break a}j=z[d>>1];while(1){b:{e=d;d=f;w[e>>1]=z[f>>1];if((g|0)>(i|0)){break b}e=g<<1;g=e|1;f=(g<<1)+a|0;e=e+2|0;if((e|0)<(c|0)){h=e;e=_k(b,z[f>>1],z[f+2>>1]);g=e?h:g;f=e?f+2|0:f}if(!_k(b,z[f>>1],j)){continue}}break}w[d>>1]=j}}function bfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db+-64|0;db=c;rm(c+52|0,b);ge(c+24|0,x[c+52>>2],x[c+56>>2]);b=Xd(c+16|0);x[23549]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=Xf(152,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[23549];x[23549]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[23549]=0;S(671,b|0,d|0,Pc(e,a)>>>2|0);a=x[23549];x[23549]=0;if((a|0)==1){a=N()|0;sc(d);ub(b);break a}ub(b);bc(c+52|0);db=c- -64|0;return}a=N()|0}bc(c+52|0);Q(a|0);p()}function afa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db+-64|0;db=c;rm(c+52|0,b);ge(c+24|0,x[c+52>>2],x[c+56>>2]);b=Xd(c+16|0);x[23549]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=Xf(152,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[23549];x[23549]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[23549]=0;S(672,b|0,d|0,Pc(e,a)>>>8|0);a=x[23549];x[23549]=0;if((a|0)==1){a=N()|0;Gt(d);ub(b);break a}ub(b);bc(c+52|0);db=c- -64|0;return}a=N()|0}bc(c+52|0);Q(a|0);p()}function NH(a){var b=0,c=0;a:{b=x[a+4>>2];b=x[x[b>>2]-12>>2]+b|0;b:{if(!x[b+24>>2]|x[b+16>>2]|!(y[b+5|0]&32)){break b}if(cI()){break b}b=x[a+4>>2];b=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[23549]=0;b=R(1085,b|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=x[a+4>>2];b=x[x[a>>2]-12>>2];x[23549]=0;W(1086,a+b|0);a=x[23549];x[23549]=0;if((a|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;X(17);a=x[23549];x[23549]=0;if((a|0)==1){break a}}return}T(0)|0;Rb();p()}function Mfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=db-32|0;db=d;nd(b,0);e=d+8|0;lB(e,a+1|0);c=d+20|0;Bc(c,e);Ce(b+43|0,c);tb(c);x[b+24>>2]=y[a+78|0]|y[a+79|0]<<8;c=y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24);x[b>>2]=c;x[b+4>>2]=y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24);x[b+8>>2]=y[a+66|0]|y[a+67|0]<<8|(y[a+68|0]<<16|y[a+69|0]<<24);w[b+30>>1]=(y[a+73|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;tc(b+8|0,c);tc(b+4|0,x[b+8>>2]);db=d+32|0}function $ea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db+-64|0;db=c;rm(c+52|0,b);ge(c+24|0,x[c+52>>2],x[c+56>>2]);b=Xd(c+16|0);x[23549]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=Xf(152,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[23549];x[23549]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[23549]=0;S(673,b|0,d|0,Pc(e,a)>>>4|0);a=x[23549];x[23549]=0;if((a|0)==1){a=N()|0;ql(d);ub(b);break a}ub(b);bc(c+52|0);db=c- -64|0;return}a=N()|0}bc(c+52|0);Q(a|0);p()}function K1(){var a=0,b=0,c=0,d=0,e=0,f=0;c=db-48|0;db=c;if(qI(0,c+24|0)){ds(x[23424],12532);p()}b=Ph(c+16|0,x[c+24>>2],x[c+28>>2]);f=dI(c+8|0,x[c+32>>2]/1e3|0);d=db-16|0;db=d;e=db-16|0;db=e;a=Ph(e+8|0,yka(x[b>>2],x[b+4>>2],1e6,0),hb);b=x[a>>2];a=x[a+4>>2];db=e+16|0;x[d>>2]=b;x[d+4>>2]=a;a=x[d>>2];e=a+x[f>>2]|0;f=x[f+4>>2]+x[d+4>>2]|0;b=Ph(d+8|0,e,a>>>0>e>>>0?f+1|0:f);a=x[b>>2];db=d+16|0;b=Ph(c+40|0,a,x[b+4>>2]);a=x[b>>2];db=c+48|0;hb=x[b+4>>2];return a|0}function jk(a){var b=0,c=0;a:{b=x[a+4>>2];b=x[x[b>>2]-12>>2]+b|0;b:{if(!x[b+24>>2]|x[b+16>>2]|!(y[b+5|0]&32)){break b}if(cI()){break b}b=x[a+4>>2];b=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[23549]=0;b=R(21,b|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=x[a+4>>2];b=x[x[a>>2]-12>>2];x[23549]=0;P(15,a+b|0,1);a=x[23549];x[23549]=0;if((a|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;X(17);a=x[23549];x[23549]=0;if((a|0)==1){break a}}return}T(0)|0;Rb();p()}function OF(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=db-16|0;db=i;if(1073741806-b>>>0>=c>>>0){k=Mb(a);j=i+4|0;if(b>>>0<=536870886){x[i+12>>2]=b<<1;x[i+4>>2]=b+c;c=Ql(x[Yc(i+4|0,i+12|0)>>2])+1|0}else{c=1073741807}hj(j,c);c=x[i+4>>2];if(e){gi(c,k,e)}if(g){gi(c+(e<<2)|0,h,g)}j=e+f|0;h=d-j|0;if((d|0)!=(j|0)){d=e<<2;gi((d+c|0)+(g<<2)|0,(d+k|0)+(f<<2)|0,h)}if((b|0)!=1){Eb(k)}zd(a,c);jg(a,x[i+8>>2]);b=a;a=h+(e+g|0)|0;re(b,a);zd(c+(a<<2)|0,0);db=i+16|0;return}kg();p()}function yO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=db-16|0;db=d;j=d,k=$j(b),x[j+4>>2]=k;c=db-16|0;db=c;g=Ny(a,c+12|0,y[b|0],x[b+4>>2]);b=x[g>>2];if(!b){e=db-16|0;db=e;b=gc(a);h=rh(c,Hc(28),Ag(e+8|0,b));b=x[h>>2];f=x[d+4>>2];i=x[f>>2];f=x[f+4>>2];x[b+24>>2]=0;x[b+16>>2]=i;x[b+20>>2]=f;j=gc(h),k=1,v[j+4|0]=k;db=e+16|0;Yg(a,x[c+12>>2],g,x[c>>2]);b=Zd(c);ol(c);e=1}Xg(d+8|0,x[vb(c,b)>>2],e);db=c+16|0;a=td(x[d+8>>2]);db=d+16|0;return a+8|0}function Yaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=db-16|0;db=e;d=z[a+30>>1];if(d){b=Xx(b<<16>>16,d<<16>>16)}w[e+14>>1]=b;a=a+52|0;a:{if(!xd(x[c+4>>2],y[c+11|0])){Aj($L(a,e+14|0),c);break a}b=Yx(a,e+14|0);if(!xg(b,Bf(a))){break a}c=db-16|0;db=c;b=x[vb(c+8|0,b)>>2];d=db-16|0;db=d;f=Vg(vb(d+12|0,b));if((b|0)==x[a>>2]){x[a>>2]=x[f>>2]}g=wb(a);x[g>>2]=x[g>>2]-1;dQ(x[gc(a)>>2],b);a=x[f>>2];db=d+16|0;lj(td(b));Eb(b);vb(c+12|0,a);db=c+16|0}db=e+16|0}function W9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);e=db-16|0;db=e;f=jf(a,c);ae(e,x[a+28>>2]);h=a;a:{if(!f){c=0;if(ed(a,5)){break a}}c=0;d=db-16|0;db=d;g=x[a+28>>2];yk(g,d+8|0);i=d,j=Qc(x[d+8>>2],x[d+12>>2]),x[i+4>>2]=j;x[d>>2]=256;Yk(b,x[Cb(d+4|0,d)>>2]);a=x[b>>2];while(1){if(oc(a,x[b+4>>2])>>>0<=c>>>0){db=d+16|0}else{x[d+4>>2]=0;Bp(g,d+4|0);a=x[b>>2];i=xb(a,c),k=B[d+4>>2],B[i>>2]=k;c=c+1|0;continue}break}c=f}cf(h,c);db=e+16|0}function RO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;i=pz(x[a+24>>2],y[a+32|0]);g=cj(i);j=65535;a:{while(1){if((d|0)==(g|0)){d=g;a=-1;break a}b:{c:{if(!Dq(i,d&65535)){break c}e=x[a>>2];if(Cd(e,x[a+4>>2])>>>0<=d>>>0){break b}f=0;h=$d(e,d);while(1){d:{e=x[h+4>>2];if(e>>>0>f>>>0){if(!eA(x[h>>2],f)){break d}e=x[h+4>>2]}if((f|0)==(e|0)){break b}break c}f=f+1|0;continue}}d=d+1|0;continue}break}j=d;a=0}w[b>>1]=j;x[c>>2]=a;return d>>>0<g>>>0|0}function WG(a,b,c,d){var e=0,f=0,g=0,h=0;e=db-16|0;db=e;a:{if((a|0)!=(b|0)){b:{c:{f=y[a|0];if((f|0)!=45){break c}a=a+1|0;if((b|0)!=(a|0)){break c}break b}h=x[23424];x[23424]=0;yd();a=zw(a,e+12|0,d);d=hb;d:{g=x[23424];if(g){if(x[e+12>>2]!=(b|0)){break b}if((g|0)!=68){break d}x[c>>2]=4;b=-1;a=-1;break a}x[23424]=h;if(x[e+12>>2]==(b|0)){break d}break b}c=(f|0)==45;b=c?0-a|0:a;a=c?0-(d+((a|0)!=0)|0)|0:d;break a}}x[c>>2]=4;b=0;a=0}db=e+16|0;hb=a;return b}function J1(){var a=0,b=0,c=0,d=0,e=0,f=0;c=db-48|0;db=c;if(qI(1,c+24|0)){ds(x[23424],12569);p()}b=Ph(c+16|0,x[c+24>>2],x[c+28>>2]);f=dI(c+8|0,x[c+32>>2]);d=db-16|0;db=d;e=db-16|0;db=e;a=Ph(e+8|0,yka(x[b>>2],x[b+4>>2],1e9,0),hb);b=x[a>>2];a=x[a+4>>2];db=e+16|0;x[d>>2]=b;x[d+4>>2]=a;a=x[d>>2];e=a+x[f>>2]|0;f=x[f+4>>2]+x[d+4>>2]|0;b=Ph(d+8|0,e,a>>>0>e>>>0?f+1|0:f);a=x[b>>2];db=d+16|0;b=Ph(c+40|0,a,x[b+4>>2]);a=x[b>>2];db=c+48|0;hb=x[b+4>>2];return a|0}function uW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=db-16|0;db=d;a:{b:{if(!zh(a,7)){break b}c=0;if(!rC(a,17396)){break a}if(!zh(a,1)){break b}c=-1;if(!dd(a,Jq(a))){break a}c=db-16|0;db=c;f=d+9|0;Jo(c+8|0,f);e=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){dd(a,x[c+12>>2])}db=c+16|0;e=(e|0)==(g|0);if(!e){Mu(f)}c=-1;if(!e){break a}c=0;if(!eC(y[d+9|0],y[d+10|0])){break a}c=Ge(a,b,dC(d+9|0),hb);break a}c=-1}db=d+16|0;return c|0}function Qda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=db-16|0;db=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+12>>2]+i|0;f=v[e|0];e=((D(v[e+1|0]-f|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(f<<8)|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Qb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;db=b+16|0}function DC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=Ic(d,x[a+4>>2]);if(c>>>0<b>>>0){e=db-32|0;db=e;b=b-c|0;c=x[wb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>1>>>0){uC(a,b);break a}c=wb(a);c=uj(e+12|0,vj(a,Ic(x[a>>2],d)+b|0),Ic(x[a>>2],x[a+4>>2]),c);f=db-16|0;db=f;b=So(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){nv(d);d=x[b>>2]+2|0;x[b>>2]=d;continue}break}Kd(b);db=f+16|0;Rq(a,c);Di(c)}db=e+32|0;return}if(b>>>0<c>>>0){Dd(a,d+(b<<1)|0)}}function j3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=db-16|0;db=f;d=db-32|0;db=d;Od(d+24|0,a,b);h=d+16|0;e=x[d+24>>2];g=x[d+28>>2];b=db-16|0;db=b;x[b+12>>2]=c;a:{while(1){if((e|0)==(g|0)){break a}c=Tb(b,x[e>>2]);x[23549]=0;O(1054,b+12|0,c|0)|0;i=x[23549];x[23549]=0;if((i|0)!=1){tb(c);e=e+4|0;continue}break}a=N()|0;tb(c);Q(a|0);p()}vc(h,g,b+12|0);db=b+16|0;b=x[d+16>>2];x[d+12>>2]=x[d+20>>2];vc(f+8|0,Zx(a,b),d+12|0);db=d+32|0;db=f+16|0}function Dja(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=db-16|0;db=d;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(d+8|0,x[vb(d+4|0,a)>>2]);x[23549]=0;W(328,a|0);b=x[23549];x[23549]=0;if((b|0)!=1){e=db-16|0;db=e;b=e+4|0;x[b>>2]=a;c=x[a+4>>2];x[b+4>>2]=c;x[b+8>>2]=c+32768;c=x[b+4>>2];f=x[b+8>>2];while(1){if((c|0)==(f|0)){fc(b);db=e+16|0}else{w[c>>1]=0;w[c+2>>1]=0;c=c+4|0;x[b+4>>2]=c;continue}break}b=d+8|0;Hd(b);Bg(b);db=d+16|0;return a|0}a=N()|0;Bg(d+8|0);Q(a|0);p()}function I1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=db-32|0;db=e;x[e+16>>2]=b;d=x[a+48>>2];x[e+20>>2]=c-((d|0)!=0);f=x[a+44>>2];x[e+28>>2]=d;x[e+24>>2]=f;a:{b:{if(Yw(ab(x[a+60>>2],e+16|0,2,e+12|0)|0)){b=32}else{d=x[e+12>>2];if((d|0)>0){break b}b=d?32:16}x[a>>2]=b|x[a>>2];break a}g=d;f=x[e+20>>2];if(f>>>0>=d>>>0){break a}d=x[a+44>>2];x[a+4>>2]=d;x[a+8>>2]=d+(g-f|0);if(x[a+48>>2]){x[a+4>>2]=d+1;v[(b+c|0)-1|0]=y[d|0]}g=c}db=e+32|0;return g|0}function Pda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=db-16|0;db=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=(x[b+12>>2]<<1)+i|0;f=w[e>>1];e=f+((D(w[e+2>>1]-f|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Qb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;db=b+16|0}function HE(a,b,c,d,e){var f=0,g=0,h=0;a:{f=db-32|0;db=f;h=Nb(a);b:{c:{d:{e:{while(1){a=x[b+8>>2];g=x[b>>2];x[23549]=0;a=U(142,g|0,a|0,8)|0;g=x[23549];x[23549]=0;if((g|0)==1){break c}if(!a){break d}x[23549]=0;S(e|0,f+4|0,b|0,c|0);a=x[23549];x[23549]=0;if((a|0)!=1){x[23549]=0;P(d|0,h|0,f+4|0);a=x[23549];x[23549]=0;if((a|0)==1){break e}Gd(f+4|0);continue}break}a=N()|0;break b}a=N()|0;Gd(f+4|0);break b}db=f+32|0;break a}a=N()|0}_d(h);Q(a|0);p()}}function hp(a,b,c,d,e){var f=0,g=0,h=0;a:{f=db-32|0;db=f;h=Nb(a);b:{c:{d:{e:{while(1){a=x[b+8>>2];g=x[b>>2];x[23549]=0;a=U(142,g|0,a|0,e|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break c}if(!a){break d}x[23549]=0;P(d|0,f+4|0,b|0);a=x[23549];x[23549]=0;if((a|0)!=1){x[23549]=0;P(c|0,h|0,f+4|0);a=x[23549];x[23549]=0;if((a|0)==1){break e}Gd(f+4|0);continue}break}a=N()|0;break b}a=N()|0;Gd(f+4|0);break b}db=f+32|0;break a}a=N()|0}_d(h);Q(a|0);p()}}function _f(a){var b=0,c=0,d=0;d=_p(Pf(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){b=y[a|0];break b}if(a&3){while(1){b=y[a|0];v[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=x[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){x[c>>2]=b;b=x[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}v[c|0]=b;if(!(b&255)){break a}while(1){b=y[a+1|0];v[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function Ji(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=Pc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=db-32|0;db=e;b=b-c|0;c=x[wb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>>0){wF(a,b);break a}c=wb(a);c=Ol(e+12|0,Ek(a,Pc(x[a>>2],d)+b|0),Pc(x[a>>2],x[a+4>>2]),c);f=db-16|0;db=f;b=bw(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){tg(d);d=x[b>>2]+1|0;x[b>>2]=d;continue}break}Kd(b);db=f+16|0;mp(a,c);Ml(c)}db=e+32|0;return}if(b>>>0<c>>>0){Dd(a,b+d|0)}}function Es(a){var b=0,c=0,d=0,e=0;a:{while(1){if(!a){b=0;if(x[23418]){b=Es(x[23418])}if(!x[23344]){break a}c=b|c;a=x[23344];continue}break}d=x[a+76>>2]>=0;b:{c:{if(x[a+20>>2]==x[a+28>>2]){break c}ib[x[a+36>>2]](a,0,0)|0;if(x[a+20>>2]){break c}b=-1;if(d){break b}break a}b=x[a+8>>2];e=x[a+4>>2];if((b|0)!=(e|0)){b=e-b|0;ib[x[a+40>>2]](a,b,b>>31,1)|0}b=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;if(!d){break a}}}return b|c}function k9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=db-16|0;db=e;FL(e+8|0,a,0);c=x[e+12>>2];if(c){b=x[a+20>>2];x[b+148>>2]=-1;a=x[e+8>>2];d=a;a=Db(a,c);f=db-16|0;db=f;g=ri(d,a);b=b+4|0;a:{if(g>>>0<=pn(b)>>>0){c=a;h=x[b>>2];i=Pc(h,x[b+4>>2]);j=i>>>0>=g>>>0;if(!j){x[f+12>>2]=d;_M(f+12|0,i);c=x[f+12>>2]}d=_g(d,c,h);if(!j){YA(b,c,a,g-Pc(x[b>>2],x[b+4>>2])|0);break a}Dd(b,d);break a}pu(b);pk(b,Ek(b,g));YA(b,d,a,g)}db=f+16|0}db=e+16|0}function hY(a,b){a=a|0;b=b|0;var c=0;a=Gb(a);a:{if(y[b+16|0]){x[23549]=0;O(119,a|0,4886)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}}if(y[b+17|0]){x[23549]=0;O(119,a|0,12398)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}}if(xd(x[a+4>>2],y[a+11|0])){x[23549]=0;O(119,a|0,9950)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}}if(y[b+18|0]){x[23549]=0;O(119,a|0,10977)|0;b=x[23549];x[23549]=0;if((b|0)==1){break a}}return}b=N()|0;tb(a);Q(b|0);p()}function cfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=db-4096|0;db=c;rm(a,b);a:while(1){if(Pc(x[a>>2],x[a+4>>2])>>>12>>>0>e>>>0){f=e<<12;b=0;d=0;while(1)if((b|0)==2048){h=f|2048;b=0;while(1){g=x[a>>2];if((b|0)!=2048){d=y[Db(g,b+h|0)|0]+d|0;i=Db(c,b<<1),j=d,v[i|0]=j;b=b+1|0;continue}break}Et(c,Wz(c),Ie(yb(g),f));e=e+1|0;continue a}else{d=y[Db(x[a>>2],b+f|0)|0]+d|0;i=Db(c,b<<1|1),j=d,v[i|0]=j;b=b+1|0;continue}}break}db=c+4096|0}function zt(a,b){var c=0,d=0,e=0,f=0,g=0;d=db-32|0;db=d;e=d+16|0;OQ(e,a,a+1|0,a+2|0,a+3|0);OQ(d,b,b+1|0,b+2|0,b+3|0);db=d+32|0;a=y[x[e>>2]];b=y[x[d>>2]];c=1;a:{if(a>>>0<b>>>0){break a}c=0;if(a>>>0>b>>>0){break a}a=v[x[e+4>>2]];b=v[x[d+4>>2]];c=1;b:{if((a|0)<(b|0)){break b}c=0;if((a|0)>(b|0)){break b}f=x[e+12>>2];g=x[d+12>>2];a=y[x[d+8>>2]];b=y[x[e+8>>2]];c=1;c:{if(a>>>0>b>>>0){break c}c=0;if(a>>>0<b>>>0){break c}c=y[f|0]<y[g|0]}}}return c}function xM(a,b,c,d,e,f,g,h){var i=0,j=0;i=db-16|0;db=i;x[i+12>>2]=d;a:{if(!(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24))){break a}x[i+8>>2]=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);j=b;b=x[Cb(i+8|0,i+12|0)>>2];x[j>>2]=b;b=Vd(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24),b,d);x[c>>2]=((h^1)&b>>>0<d>>>0)+b;b=z[e>>1]|f;w[e>>1]=b;if((y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))!=1){break a}w[e>>1]=b|g}db=i+16|0}function nc(a,b){var c=0,d=0,e=0;c=x[a+1396>>2];if((c|0)>=0){a:{b:{if((b|0)<=(c|0)){break b}if((b|0)>24){return nc(a,24)+(nc(a,b-24|0)<<24)|0}if(!c){x[a+1392>>2]=0}while(1){if((b|0)<=(c|0)){break b}c=-1;e=js(a);d=0;if((e|0)==-1){break a}d=x[a+1396>>2];c=d+8|0;x[a+1396>>2]=c;x[a+1392>>2]=x[a+1392>>2]+(e<<d);continue}}if((b|0)>(c|0)){_(9960,13048,1632,6771);p()}d=x[a+1392>>2];x[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}x[a+1396>>2]=c}return d}function nu(a,b){var c=0,d=0,e=0,f=0,g=0;e=(y[Db(a,0)|0]&15)<<8|y[Db(a,1)|0];c=0;a:{if(!e){break a}c=0;if((e|0)==4095){break a}while(1){c=108;if((d|0)==84){break a}b:{c=z[(d<<1)+32896>>1];if(c>>>0<=e>>>0){if(!d|(e|0)==(c|0)|(z[(d<<1)+32894>>1]-e|0)>=(e-c|0)){break b}c=d+24|0;break a}d=d+1|0;continue}break}c=d+25|0}v[b|0]=c;d=y[Db(a,2)|0];f=b,g=y[Db(a,0)|0]&16|d>>>4,v[f+1|0]=g;f=b,g=y[Db(a,2)|0]&15,v[f+3|0]=g;f=b,g=y[Db(a,3)|0],v[f+5|0]=g}function Ww(a,b){a:{if(a){if(b>>>0<=127){break a}b:{if(!x[x[116055]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){v[a+1|0]=b&63|128;v[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){v[a+2|0]=b&63|128;v[a|0]=b>>>12|224;v[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){v[a+3|0]=b&63|128;v[a|0]=b>>>18|240;v[a+2|0]=b>>>6&63|128;v[a+1|0]=b>>>12&63|128;return 4}}x[23424]=25;a=-1}else{a=1}return a}v[a|0]=b;return 1}function UO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=db-16|0;db=e;j=e,k=$j(b),x[j+4>>2]=k;c=db-16|0;db=c;f=mz(a,c+12|0,z[b>>1],x[b+4>>2]);b=x[f>>2];if(!b){b=db-16|0;db=b;d=gc(a);g=rh(c,Hc(36),Ag(b+8|0,d));d=x[g>>2]+16|0;h=x[e+4>>2];i=x[h+4>>2];x[d>>2]=x[h>>2];x[d+4>>2]=i;Nb(d+8|0);j=gc(g),k=1,v[j+4|0]=k;db=b+16|0;Yg(a,x[c+12>>2],f,x[c>>2]);b=Zd(c);ZO(c);d=1}Xg(e+8|0,x[vb(c,b)>>2],d);db=c+16|0;a=td(x[e+8>>2]);db=e+16|0;return a+8|0}function Oea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=db-16|0;db=c;d=Xc(c+12|0,16,1,1,0);x[c+8>>2]=0;nd(a,0);wc(b);a:{b:{if(Oq(b,13540)){Vc(b,12);if(!Io(b)){Oo(d,2)}Vc(b,24);break b}if(Bi(b,13422)){wc(b);x[c+8>>2]=4;e=1;break a}hd(d,8)}e=0}f=a,g=(rf(b)>>>0)/(D(y[d|0],rq(y[d+1|0]))>>>3>>>0)|0,x[f>>2]=g;b=lg(d,a,b);if(!(!b|!e)){d=x[a+20>>2];f=c,g=pj(x[a>>2],z[a+34>>1]),x[f+4>>2]=g;Vb(d,0,x[Cb(c+8|0,c+4|0)>>2])}db=c+16|0;return(b|0)!=0|0}function JT(a,b){var c=0,d=0,e=0,f=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=db-32|0;db=e;b=b-c|0;c=x[wb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){TA(a,b);break a}c=wb(a);c=Jf(e+12|0,eg(a,oc(x[a>>2],d)+b|0),oc(x[a>>2],x[a+4>>2]),c);f=db-16|0;db=f;b=Bl(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Dm(d);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}Kd(b);db=f+16|0;HT(a,c);If(c)}db=e+32|0;return}if(b>>>0<c>>>0){Dd(a,d+(b<<2)|0)}}function s2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a+32|0;Aj(c,b);x[a+44>>2]=0;b=x[a+48>>2];if(b&8){b=Mb(c)+Bb(x[a+36>>2],y[a+43|0])|0;x[a+44>>2]=b;d=Mb(c);xn(a,d,d,b);b=x[a+48>>2]}a:{if(!(b&16)){break a}b=Bb(x[a+36>>2],y[a+43|0]);e=a,f=b+Mb(c)|0,x[e+44>>2]=f;Mx(c,Mc(c));c=Mb(c);Mw(a,c,Bb(x[a+36>>2],y[a+43|0])+c|0);if(!(y[a+48|0]&3)){break a}while(1){if((b|0)<0){_r(a,2147483647);b=b-2147483647|0;continue}break}if(!b){break a}_r(a,b)}}function MY(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;x[23549]=0;m=a;a=b;b=0;a=Ga(1022,m|b,a|0,c|0,d|0,b|e,f|0)|0;b=x[23549];x[23549]=0;a:{b:{if((b|0)==1){Y(T(0)|0)|0;x[23549]=0;ea(910,8741,g|0,h|0,i|0,j|0,k|0,l|0);a=x[23549];x[23549]=0;if((a|0)==1){break b}Z();a=-255}break a}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}return a|0}function yk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=db-16|0;db=e;x[b>>2]=0;x[b+4>>2]=0;v[e+15|0]=0;Ih(a,e+15|0);c=y[e+15|0];f=(c&252)>>>2|0;i=-1<<(c&3)^-1;while(1){x[b>>2]=f;x[b+4>>2]=d;if(!h&(g|0)==(i|0)){db=e+16|0}else{v[e+15|0]=0;Ih(a,e+15|0);d=x[b>>2];j=x[b+4>>2];f=y[e+15|0];c=h;g=g+1|0;h=g?c:c+1|0;k=d;c=(g<<3)-2|0;d=c&31;if((c&63)>>>0>=32){c=f<<d;d=0}else{c=(1<<d)-1&f>>>32-d;d=f<<d}f=k|d;d=c|j;continue}break}}function n6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;x[23549]=0;W(952,a|0);f=x[23549];x[23549]=0;a:{b:{if((f|0)!=1){f=x[a+28>>2];g=x[x[f>>2]+72>>2];x[23549]=0;b=Pa(g|0,f|0,b|0,c|0,+d,+e)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,11156,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function n4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=db-48|0;db=b;x[b+40>>2]=e;x[b+44>>2]=f;c=ec(b+32|0,c,d);d=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=d;a:{a=Ws(a,b+8|0,b+40|0);if(a+1>>>0>=3){a=ac(8);x[23549]=0;b=O(54,b+20|0,7955)|0;c=x[23549];x[23549]=0;b:{if((c|0)!=1){a=pc(a,b);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;jc(a)}Q(c|0);p()}db=b+48|0;return a|0}p()}function Zga(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=db-16|0;db=g;a:{if(z[a+480192>>1]<b>>>0){break a}b=x[((b<<2)+a|0)+900380>>2];if(!b){break a}h=g+4|0;oT(h,b);j=g,k=yb(x[g+4>>2]),x[j>>2]=k;h=Kf(h);i=z[a+480190>>1];while(1){b=x[g>>2];if(!Kb(b,h)){KA(g+4|0);break a}b=z[iq(b)>>1];if(b>>>0<=i>>>0){b=D(b,104)+a|0;v[b+484421|0]=f;v[b+484418|0]=c;v[b+484420|0]=e;v[b+484419|0]=d}Vg(g);continue}}db=g+16|0}function eca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a>>2];d=hg(e,x[a+4>>2]);if(d>>>0<b>>>0){e=db-32|0;db=e;a:{b:{d=b-d|0;b=x[wb(a)>>2];f=x[a+4>>2];c:{if(d>>>0<=b-f>>5>>>0){Bz(a,d,c);break c}b=wb(a);b=xt(e+12|0,$p(a,hg(x[a>>2],f)+d|0),hg(x[a>>2],x[a+4>>2]),b);x[23549]=0;S(730,b|0,d|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}OP(a,b);yz(b)}db=e+32|0;break a}a=N()|0;yz(b);Q(a|0);p()}return}if(b>>>0<d>>>0){PP(a,e+(b<<5)|0)}}function H2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=db-48|0;db=e;x[e+44>>2]=d;x[e+40>>2]=d;a=rd(e+12|0,a,e+40|0,e+44|0);x[e+8>>2]=x[a+8>>2];d=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=d;Ke(e+24|0,e);a:{while(1){if((b|0)==(c|0)){break a}x[23549]=0;P(1065,x[e+44>>2],b|0);a=x[23549];x[23549]=0;if((a|0)!=1){x[e+44>>2]=x[e+44>>2]+12;b=b+12|0;continue}break}a=N()|0;oJ(e+24|0);Q(a|0);p()}a=e+24|0;Je(a);b=x[e+44>>2];oJ(a);db=e+48|0;return b|0}function $3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=db-48|0;db=e;x[e+44>>2]=d;x[e+40>>2]=d;a=rd(e+12|0,a,e+40|0,e+44|0);x[e+8>>2]=x[a+8>>2];d=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=d;Ke(e+24|0,e);a:{while(1){if((b|0)==(c|0)){break a}x[23549]=0;P(1036,x[e+44>>2],b|0);a=x[23549];x[23549]=0;if((a|0)!=1){x[e+44>>2]=x[e+44>>2]+16;b=b+16|0;continue}break}a=N()|0;oK(e+24|0);Q(a|0);p()}a=e+24|0;Je(a);b=x[e+44>>2];oK(a);db=e+48|0;return b|0}function kO(a,b,c,d,e){var f=0,g=0,h=0;h=-1;g=d&2147483647;f=(g|0)==2147418112;a:{if(f&!c?a|b:f&(c|0)!=0|g>>>0>2147418112){break a}f=e&2147483647;if(((f|0)==2147418112&0|f>>>0>2147418112)&(f|0)!=2147418112){break a}if(!(a|c|(f|g|b))){return 0}f=d&e;if((f|0)>0|(f|0)>=0){if(((c|0)!=0|(d|0)!=(e|0))&(d|0)<(e|0)){break a}return(a|c|(d^e|b))!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}h=(a|c|(d^e|b))!=0}return h}function nf(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;i=yka(b,c,h,i);h=hb;e=yka(d,e,f,g);i=e+i|0;d=hb+h|0;h=e>>>0>i>>>0?d+1|0:d;j=g;e=0;k=c;d=0;c=yka(g,e,c,d);g=c+i|0;i=hb+h|0;l=g;c=c>>>0>g>>>0?i+1|0:i;g=yka(f,0,b,0);h=hb;i=0;d=yka(f,i,k,d);h=h+d|0;f=hb+i|0;f=d>>>0>h>>>0?f+1|0:f;i=f+l|0;d=c;f=f>>>0>i>>>0?d+1|0:d;c=yka(b,m,j,e)+h|0;e=hb;e=c>>>0<h>>>0?e+1|0:e;h=e+i|0;i=f;x[a+8>>2]=h;x[a+12>>2]=e>>>0>h>>>0?i+1|0:i;x[a>>2]=g;x[a+4>>2]=c}function gq(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=db-16|0;db=i;if(2147483630-b>>>0>=c>>>0){k=Mb(a);j=i+4|0;if(b>>>0<=1073741798){x[i+12>>2]=b<<1;x[i+4>>2]=b+c;c=fk(x[Yc(i+4|0,i+12|0)>>2])+1|0}else{c=2147483631}yi(j,c);c=x[i+4>>2];if(e){We(c,k,e)}if(g){We(c+e|0,h,g)}j=e+f|0;h=d-j|0;if((d|0)!=(j|0)){We((c+e|0)+g|0,(e+k|0)+f|0,h)}if((b|0)!=10){Eb(k)}zd(a,c);jg(a,x[i+8>>2]);b=a;a=h+(e+g|0)|0;re(b,a);hd(a+c|0,0);db=i+16|0;return}kg();p()}function _P(a,b,c,d){var e=0,f=0,g=0;g=db-16|0;db=g;d=Ei(g+4|0,a,d);e=wb(a);a=db+-64|0;db=a;f=x[d+4>>2];x[a+56>>2]=f;x[a+60>>2]=b;x[a+52>>2]=f;e=rd(a+24|0,e,a+52|0,a+56|0);x[a+16>>2]=x[e+8>>2];f=x[e+4>>2];x[a+8>>2]=x[e>>2];x[a+12>>2]=f;Ke(a+36|0,a+8|0);while(1){if(Kb(b,c)){tj(x[a+56>>2],z[b>>1]);b=Se(a+60|0);x[a+56>>2]=x[a+56>>2]+2;b=x[b>>2];continue}break}b=a+36|0;Je(b);c=x[a+56>>2];ik(b);db=a- -64|0;x[d+4>>2]=c;fc(d);db=g+16|0}function jV(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=x[a+1064>>2];a:{while(1){if((b|0)>255){break a}f=(D(b,6)+a|0)+1072|0,g=sk(a,7),v[f|0]=g;d=sk(a,1);e=sk(a,1);c=x[a+1060>>2];if((c|0)>255){break a}b=x[a+1064>>2]+1|0;x[a+1060>>2]=b;x[a+1064>>2]=b;b:{if(d){w[(D(c,6)+a|0)+1068>>1]=b;jV(a);b=x[a+1064>>2];break b}w[(D(c,6)+a|0)+1068>>1]=65535}x[a+1060>>2]=b;if(e){w[(D(c,6)+a|0)+1070>>1]=b;continue}break}w[(D(c,6)+a|0)+1070>>1]=65535}}function Ds(a,b){var c=0,d=0,e=0,f=0,g=0;e=db-16|0;db=e;c=Ud(a);d=gc(a);f=db-16|0;db=f;while(1){if(c){g=it(c+16|0,b);d=g?d:c;c=x[(g?c+4|0:c)>>2];continue}break}c=x[vb(f+12|0,d)>>2];db=f+16|0;a:{if(Kb(c,Kf(a))){if(!it(b,td(c))){break a}}c=Kf(a)}if(!qc(c,Kf(a))){b=x[vb(e+12|0,c)>>2];c=db-16|0;db=c;d=Vg(vb(c+12|0,b));if((b|0)==x[a>>2]){x[a>>2]=x[d>>2]}d=wb(a);x[d>>2]=x[d>>2]-1;dQ(x[gc(a)>>2],b);db=c+16|0;lm(td(b));Eb(b)}db=e+16|0}function XG(a,b,c,d){var e=0,f=0,g=0,h=0;e=db-16|0;db=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=y[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=x[23424];x[23424]=0;yd();a=zw(a,e+12|0,d);d=hb;g=x[23424];e:{if(g){if(x[e+12>>2]!=(b|0)){break c}if((g|0)==68|d){break e}break b}x[23424]=h;if(x[e+12>>2]!=(b|0)){break c}if(!d){break b}}x[c>>2]=4;a=-1;break a}}x[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}db=e+16|0;return a}function q6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[23549]=0;W(952,a|0);e=x[23549];x[23549]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+12>>2];x[23549]=0;b=ba(f|0,e|0,b|0,c|0,d|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,11301,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function jc(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;a:{c=Ln(a);a=c;if(a>>>0<470016&a>>>0>=469504){b=c-4|0;e=x[117374];d=e;while(1){a=d;if(!(!a|(a|0)==470016)){if((KF(a)|0)==(b|0)){w[a+2>>1]=z[c-2>>1]+z[a+2>>1];break a}if((KF(b)|0)==(a|0)){d=c-2|0;w[d>>1]=z[a+2>>1]+z[d>>1];if(!f){x[117374]=b;w[b>>1]=z[a>>1];break a}g=f,h=kw(b),w[g>>1]=h;break a}else{d=lw(z[a>>1]);f=a;continue}}break}g=b,h=kw(e),w[g>>1]=h;x[117374]=b;break a}Eb(c)}}function g3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=db-48|0;db=e;x[e+40>>2]=c;x[e+44>>2]=d;a=ec(e+32|0,a,b);b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;a:{a=Ws(3,e+8|0,e+40|0);if(a+1>>>0>=3){b=ac(8);x[23549]=0;c=O(54,e+20|0,7955)|0;a=x[23549];x[23549]=0;b:{if((a|0)!=1){a=pc(b,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=N()|0;jc(b)}Q(a|0);p()}db=e+48|0;return a|0}p()}function cF(a,b,c,d,e,f){var g=0,h=0;g=db-256|0;db=g;x[g+248>>2]=37;x[g+252>>2]=0;h=g+248|0;Or(h|1,10470,f,x[b+4>>2]);f=yd();x[g>>2]=d;x[g+4>>2]=e;d=g+224|0;e=Lg(d,24,f,h,g)+d|0;f=Pi(d,e,x[b+4>>2]);h=g+20|0;Nc(h,x[b+28>>2]);x[23549]=0;ea(1131,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=x[23549];x[23549]=0;a:{if((d|0)!=1){Xb(g+20|0);a=Mr(a,g+32|0,x[g+28>>2],x[g+24>>2],b,c);db=g+256|0;break a}a=N()|0;Xb(g+20|0);Q(a|0);p()}return a}function rR(a){var b=0,c=0,d=0;b=db-16|0;db=b;x[b+4>>2]=((y[a+48|0]|y[a+49|0]<<8)<<1)+((y[a+32|0]|y[a+33|0]<<8)<<4);x[b+8>>2]=((y[a+50|0]|y[a+51|0]<<8)<<1)+((y[a+34|0]|y[a+35|0]<<8)<<4);x[b+12>>2]=(D(y[a+52|0]|y[a+53|0]<<8,5)+((y[a+36|0]|y[a+37|0]<<8)<<4)|0)+32;a=b+4|0;d=xb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=Ko(x[a>>2],x[c>>2])?c:a;continue}}db=b+16|0;a=x[a>>2];hb=a>>31;return a}function p6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[23549]=0;W(952,a|0);e=x[23549];x[23549]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+8>>2];x[23549]=0;b=ba(f|0,e|0,b|0,c|0,d|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,11337,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function eF(a,b,c,d,e,f){var g=0,h=0;g=db-112|0;db=g;x[g+104>>2]=37;x[g+108>>2]=0;h=g+104|0;Or(h|1,10470,f,x[b+4>>2]);f=yd();x[g>>2]=d;x[g+4>>2]=e;d=g+80|0;e=Lg(d,24,f,h,g)+d|0;f=Pi(d,e,x[b+4>>2]);h=g+20|0;Nc(h,x[b+28>>2]);x[23549]=0;ea(1128,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=x[23549];x[23549]=0;a:{if((d|0)!=1){Xb(g+20|0);a=Iq(a,g+32|0,x[g+28>>2],x[g+24>>2],b,c);db=g+112|0;break a}a=N()|0;Xb(g+20|0);Q(a|0);p()}return a}function EW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=db-16|0;db=d;x[d+12>>2]=-1;if(Eg(a,d+11|0)){x[d+4>>2]=y[d+11|0];f=x[Cb(d+4|0,d+12|0)>>2];c=db+-64|0;db=c;e=c+44|0;Df(e,a,f);g=x[c+44>>2];a=c+20|0;Tf(a,3,Ee(e),g);x[23549]=0;P(208,c+32|0,a|0);a=x[23549];x[23549]=0;a:{if((a|0)!=1){a=c+12|0;ec(a,b,11);b=a;a=c+32|0;Al(b,a);tb(a);Jc(c+44|0);db=c- -64|0;e=!f|(g|0)!=0;break a}a=N()|0;Jc(c+44|0);Q(a|0);p()}}db=d+16|0;return e|0}function Sha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=x[a>>2];c=Ef(d,x[a+4>>2]);if(c>>>0<b>>>0){d=db-32|0;db=d;a:{b:{c=b-c|0;b=x[wb(a)>>2];e=x[a+4>>2];c:{if(c>>>0<=(b-e|0)/20>>>0){AC(a,c);break c}b=wb(a);b=pB(d+12|0,qB(a,Ef(x[a>>2],e)+c|0),Ef(x[a>>2],x[a+4>>2]),b);x[23549]=0;P(462,b|0,c|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}oB(a,b);mu(b)}db=d+32|0;break a}a=N()|0;mu(b);Q(a|0);p()}return}if(b>>>0<c>>>0){wC(a,d+D(b,20)|0)}}function Oq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-32|0;db=c;a:{if(!y[b+7|0]){while(1){if((d|0)==7){d=0;v[c+27|0]=0;v[c+28|0]=0;v[c+29|0]=0;v[c+30|0]=0;x[c+24>>2]=0;e=ec(c+8|0,c+24|0,7);lc(c+16|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=7){break b}if(cd(c+24|0,b,7)){break b}Zb(a,7);d=1}db=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17053,8977,413,13012);p()}_(17032,8977,411,13012);p()}return d|0}function Sf(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=db-16|0;db=d;w[d+12>>1]=65535;w[d+14>>1]=b;f=d+12|0;b=z[Uc(43180,d+14|0)>>1];e=x[a>>2];c=Ic(e,x[a+4>>2]);a:{if(b>>>0>c>>>0){e=db-32|0;db=e;b=b-c|0;c=x[wb(a)>>2];g=x[a+4>>2];b:{if(b>>>0<=c-g>>1>>>0){Lo(a,b,f);break b}c=wb(a);c=uj(e+12|0,vj(a,Ic(x[a>>2],g)+b|0),Ic(x[a>>2],x[a+4>>2]),c);NC(c,b,f);Rq(a,c);Di(c)}db=e+32|0;break a}if(b>>>0<c>>>0){Dd(a,e+(b<<1)|0)}}db=d+16|0}function Hba(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(b|0){case 0:mh(a,0,c);return;case 1:mh(a,1,c);return;case 2:mh(a,2,c);return;case 3:mh(a,3,c);return;case 4:mh(a,4,c);return;case 5:mh(a,5,c);return;case 6:wO(a,23280,c);return;case 7:wO(a,24304,c);return;case 8:mh(a,6,c);return;case 9:mh(a,7,c);return;case 10:mh(a,8,c);return;case 11:mh(a,9,c);return;case 12:mh(a,10,c);return;case 13:mh(a,11,c);return;default:break a}}Gb(a)}function pF(a,b,c,d){var e=0,f=E(0);x[23549]=0;W(927,a|0);e=x[23549];x[23549]=0;if((e|0)!=1){a=x[x[a+24>>2]+24>>2];a:{if((b|0)<0|z[a+480188>>1]<=b>>>0){break a}a=a+D(b,872)|0;if(!(v[a+1075081|0]&1)){break a}f=E(E(y[a+d|0])*E(.0078125))}return f}Y(T(0)|0)|0;x[23549]=0;V(914,c|0,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return E(0)}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function l6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[23549]=0;W(952,a|0);d=x[23549];x[23549]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+64>>2];x[23549]=0;S(f|0,d|0,b|0,(c|0)!=0|0);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,6601,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function kP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=db-16|0;db=g;d=gr(g+4|0,a,d);e=wb(a);a=db-48|0;db=a;f=x[d+4>>2];x[a+44>>2]=f;x[a+40>>2]=f;e=rd(a+12|0,e,a+40|0,a+44|0);x[a+8>>2]=x[e+8>>2];f=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=f;Ke(a+24|0,a);while(1){if((b|0)!=(c|0)){C[x[a+44>>2]>>3]=C[b>>3];x[a+44>>2]=x[a+44>>2]+8;b=b+8|0;continue}break}b=a+24|0;Je(b);c=x[a+44>>2];ik(b);db=a+48|0;x[d+4>>2]=c;fc(d);db=g+16|0}function j6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[23549]=0;W(952,a|0);d=x[23549];x[23549]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+56>>2];x[23549]=0;S(f|0,d|0,b|0,(c|0)!=0|0);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,6655,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Os(a){var b=0,c=0,d=0;b=y[a+4266|0];B[a+4236>>2]=E(b>>>0)*E(.00390625);B[a+4240>>2]=E(256-b|0)*E(.00390625);c=y[a+4267|0];b=y[a+4265|0];B[a+4244>>2]=E(D(c,b)|0)*E(152587890625e-16);d=c|-256;B[a+4256>>2]=E(D(d,b|-256)|0)*E(152587890625e-16);B[a+4252>>2]=E(D(b,d)|0)*E(152587890625e-16);B[a+4248>>2]=E(D(256-b|0,c)|0)*E(152587890625e-16);b=a;c=x[a+4232>>2];a=y[a+4264|0];x[b+4228>>2]=(D(c,(a?a:-89)&255)+250>>>0)/500}function Ge(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=db-16|0;db=e;f=Ig(a);a:{b:{if(!b){i=e,j=Ig(a),x[i+8>>2]=j;x[e+12>>2]=0;break b}g=x[b>>2];b=x[b+4>>2];h=b;x[e+8>>2]=g;x[e+12>>2]=b;a=x[a+12>>2];x[e>>2]=2048;x[e+4>>2]=0;b=a+c|0;d=a>>>0>b>>>0?d+1|0:d;a=Vq(e+8|0,e);c=x[a>>2];a=x[a+4>>2];if(!a&c>>>0>f>>>0|a){a=-1;if(!d&b>>>0<=f>>>0){break b}break a}a=0;if((d|0)==(h|0)&b>>>0>g>>>0|d>>>0>h>>>0){break a}}a=1}db=e+16|0;return a}function Ss(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=db-16|0;db=g;d=oh(g+4|0,a,d);e=wb(a);a=db-48|0;db=a;f=x[d+4>>2];x[a+44>>2]=f;x[a+40>>2]=f;e=rd(a+12|0,e,a+40|0,a+44|0);x[a+8>>2]=x[e+8>>2];f=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=f;Ke(a+24|0,a);while(1){if((b|0)!=(c|0)){no(x[a+44>>2],x[b>>2]);x[a+44>>2]=x[a+44>>2]+4;b=b+4|0;continue}break}b=a+24|0;Je(b);c=x[a+44>>2];ik(b);db=a+48|0;x[d+4>>2]=c;fc(d);db=g+16|0}function P4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=db-16|0;db=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ac(8);x[23549]=0;b=O(54,h+4|0,8098)|0;c=x[23549];x[23549]=0;if((c|0)==1){break c}a=pc(a,b);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}d=N()|0;tb(b);break b}Tk(a,b,4);c=rx(a,c,d,e,f,g);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);db=h+16|0;return c|0}d=N()|0;jc(a)}Q(d|0)}p()}function Az(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=db-16|0;db=g;d=Ei(g+4|0,a,d);e=wb(a);a=db-48|0;db=a;f=x[d+4>>2];x[a+44>>2]=f;x[a+40>>2]=f;e=rd(a+12|0,e,a+40|0,a+44|0);x[a+8>>2]=x[e+8>>2];f=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=f;Ke(a+24|0,a);while(1){if((b|0)!=(c|0)){tj(x[a+44>>2],z[b>>1]);x[a+44>>2]=x[a+44>>2]+2;b=b+2|0;continue}break}b=a+24|0;Je(b);c=x[a+44>>2];ik(b);db=a+48|0;x[d+4>>2]=c;fc(d);db=g+16|0}function A4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=db-16|0;db=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ac(8);x[23549]=0;b=O(54,h+4|0,8098)|0;c=x[23549];x[23549]=0;if((c|0)==1){break c}a=pc(a,b);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}d=N()|0;tb(b);break b}Tk(a,b,4);c=tx(a,c,d,e,f,g);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);db=h+16|0;return c|0}d=N()|0;jc(a)}Q(d|0)}p()}function yI(a){var b=0,c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=E(0),o=E(0),p=0;c=B[a>>2];i=a-16|0;d=B[i>>2];e=E(c+d);b=a-8|0;f=B[b>>2];j=a-24|0;g=B[j>>2];h=E(f+g);B[a>>2]=e+h;B[b>>2]=e-h;b=a-12|0;h=B[b>>2];k=a-28|0;l=B[k>>2];e=E(h+l);p=b;b=a-4|0;m=B[b>>2];a=a-20|0;n=B[a>>2];o=E(m+n);B[p>>2]=o-e;f=E(f-g);g=E(m-n);B[k>>2]=f+g;c=E(c-d);d=E(h-l);B[i>>2]=c+d;B[j>>2]=c-d;B[b>>2]=e+o;B[a>>2]=g-f}function qF(a,b,c,d){var e=0,f=E(0);x[23549]=0;W(927,a|0);e=x[23549];x[23549]=0;if((e|0)!=1){a=x[x[a+24>>2]+24>>2];a:{if((b|0)<0|z[a+480188>>1]<=b>>>0){break a}a=a+D(b,872)|0;if(v[a+1075081|0]&1){break a}f=E(E(y[a+d|0])*E(.0078125))}return f}Y(T(0)|0)|0;x[23549]=0;V(914,c|0,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return E(0)}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Mt(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=db-16|0;db=g;d=Gk(g+4|0,a,d);e=wb(a);a=db-48|0;db=a;f=x[d+4>>2];x[a+44>>2]=f;x[a+40>>2]=f;e=rd(a+12|0,e,a+40|0,a+44|0);x[a+8>>2]=x[e+8>>2];f=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=f;Ke(a+24|0,a);while(1){if((b|0)!=(c|0)){Fk(x[a+44>>2],y[b|0]);x[a+44>>2]=x[a+44>>2]+1;b=b+1|0;continue}break}b=a+24|0;Je(b);c=x[a+44>>2];ik(b);db=a+48|0;x[d+4>>2]=c;fc(d);db=g+16|0}function v1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=db-16|0;db=e;while(1){a:{if((c|0)<=(g|0)){break a}d=x[a+12>>2];f=x[a+16>>2];b:{if(d>>>0<f>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=f-d>>2;x[e+4>>2]=c-g;f=d;d=x[qd(e+12|0,qd(e+8|0,e+4|0))>>2];b=gi(b,f,d);f=d<<2;x[a+12>>2]=f+x[a+12>>2];b=b+f|0;break b}d=ib[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}x[b>>2]=d;d=1;b=b+4|0}g=d+g|0;continue}break}db=e+16|0;return g|0}function qY(a){a=a|0;var b=0,c=0,d=0,e=0;c=db-32|0;db=c;b=Tb(c+8|0,16359);x[23549]=0;S(106,c+20|0,a|0,b|0);a=x[23549];x[23549]=0;a:{if((a|0)!=1){tb(b);a=0;b=0;while(1){d=x[c+20>>2];if(!(b>>>0<=3&Cd(d,x[c+24>>2])>>>0>b>>>0)){Yd(c+20|0);db=c+32|0;return a|0}x[23549]=0;d=R(107,$d(d,b)|0)|0;e=x[23549];x[23549]=0;if((e|0)!=1){a=(d&255)<<24-(b<<3)|a;b=b+1|0;continue}break}a=N()|0;Yd(c+20|0);break a}a=N()|0;tb(b)}Q(a|0);p()}function Bx(a,b,c,d,e){var f=0,g=0;a:{if(!ms(b)){break a}f=x[a+484344>>2];if(!se(f,x[a+484348>>2],b&65535)){break a}b=Yb(f,b);if(x[b+12>>2]<=(c|0)|e>>>0>5|z[a+480188>>1]<=d>>>0|(c|d)<0){break a}b=$c(x[b>>2],x[x[b+48>>2]+12>>2],c,d&65535);b:{c:{switch(e|0){case 1:b=b+1|0;break b;case 2:b=b+2|0;break b;case 3:b=b+3|0;break b;case 4:b=b+4|0;break b;case 0:break b;case 5:break c;default:break a}}b=b+5|0}g=y[b|0]}return g}function v8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ni(a,b,c,d);x[a>>2]=45360;c=Nb(a+4256|0);b=a+4208|0;e=xb(b,0),f=1056964608,x[e>>2]=f;e=xb(b,1),f=1017370378,x[e>>2]=f;e=xb(b,2),f=1028670828,x[e>>2]=f;e=xb(b,3),f=1059760811,x[e>>2]=f;e=xb(b,4),f=1017370378,x[e>>2]=f;e=xb(b,5),f=1065353216,x[e>>2]=f;x[23549]=0;P(878,a+44|0,2);b=x[23549];x[23549]=0;if((b|0)!=1){mi(a);return a|0}b=N()|0;sc(c);yf(a);Q(b|0);p()}function h6(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[23549]=0;W(952,a|0);d=x[23549];x[23549]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+48>>2];x[23549]=0;pa(f|0,d|0,b|0,+c);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,11536,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Z5(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[23549]=0;W(952,a|0);d=x[23549];x[23549]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+96>>2];x[23549]=0;pa(f|0,d|0,b|0,+c);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,11474,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function X5(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[23549]=0;W(952,a|0);d=x[23549];x[23549]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+88>>2];x[23549]=0;pa(f|0,d|0,b|0,+c);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,10916,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function U9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=db-16|0;db=f;c=jf(a,c);ae(f,x[a+28>>2]);a:{b:{if(!c){d=-1;if(!ed(a,5)){break b}break a}d=x[c+8>>2]}g=x[a+28>>2];c:{if(!((d|0)!=4&(d|0)!=-1)){d=db-16|0;db=d;x[d+12>>2]=0;Bp(g,d+12|0);B[b>>2]=B[d+12>>2];db=d+16|0;break c}e=db-32|0;db=e;x[e+28>>2]=0;x[e+24>>2]=d;x[e+20>>2]=4;Sr(e+12|0,g,e+28|0,x[Cb(e+24|0,e+20|0)>>2]);x[b>>2]=0;db=e+32|0}e=c}cf(a,e);db=f+16|0}function U$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=db-208|0;db=a;f=yd();x[a>>2]=e;g=a+176|0;i=Lg(g,20,f,9160,a);e=i+g|0;g=Pi(g,e,x[c+4>>2]);Nc(a+12|0,x[c+28>>2]);x[23549]=0;f=R(1115,x[a+12>>2])|0;h=x[23549];x[23549]=0;if((h|0)!=1){Xb(a+12|0);h=f;f=a+16|0;QG(h,a+176|0,e,f);h=b;b=f+(i<<2)|0;b=Mr(h,f,(e|0)==(g|0)?b:((g-a<<2)+a|0)-688|0,b,c,d);db=a+208|0;return b|0}b=N()|0;Xb(a+12|0);Q(b|0);p()}function H1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=db-16|0;db=e;while(1){a:{if((c|0)<=(f|0)){break a}g=x[a+16>>2];d=x[a+12>>2];b:{if(g>>>0>d>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=g-d;x[e+4>>2]=c-f;g=d;d=x[qd(e+12|0,qd(e+8|0,e+4|0))>>2];b=We(b,g,d);x[a+12>>2]=x[a+12>>2]+d;b=b+d|0;break b}d=ib[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b|0]=d<<24>>24;d=1;b=b+1|0}f=d+f|0;continue}break}db=e+16|0;return f|0}function Rs(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=db-16|0;db=g;d=Bq(g+4|0,a,d);e=wb(a);a=db-48|0;db=a;f=x[d+4>>2];x[a+44>>2]=f;x[a+40>>2]=f;e=rd(a+12|0,e,a+40|0,a+44|0);x[a+8>>2]=x[e+8>>2];f=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=f;Ke(a+24|0,a);while(1){if((b|0)!=(c|0)){hu(x[a+44>>2],b);x[a+44>>2]=x[a+44>>2]+6;b=b+6|0;continue}break}b=a+24|0;Je(b);c=x[a+44>>2];ik(b);db=a+48|0;x[d+4>>2]=c;fc(d);db=g+16|0}function v6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=db-32|0;db=e;x[e+28>>2]=c;c=x[Vf(e+24|0,e+28|0)>>2];x[23549]=0;f=x[b+12>>2];x[e+16>>2]=x[b+8>>2];x[e+20>>2]=f;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;ba(921,a+8|0,e+8|0,c|0,d|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){a=jJ(a);b=iJ(a+88|0);c=hJ(a+92|0);x[a>>2]=61592;x[b>>2]=61704;x[c>>2]=61784;xe(e+28|0);db=e+32|0;return a|0}a=N()|0;xe(e+28|0);Q(a|0);p()}function xI(a,b){var c=0,d=0,e=0;if(!y[b+21|0]){cc(a,21);return-1}if(x[a+1396>>2]<=9){Ok(a)}d=x[a+1392>>2];c=w[(((d&1023)<<1)+b|0)+36>>1];a:{if((c|0)>=0){e=d;d=c&65535;c=y[d+x[b+8>>2]|0];x[a+1392>>2]=e>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:d;break a}c=Vl(a,b)}if(!((c|0)>=x[b+2092>>2]?y[b+23|0]:0)){if(!(!(x[a+1384>>2]?y[a+1376|0]:1)|(c|0)>=0)){cc(a,21)}return c}_(7464,13048,1793,5691);p()}function sy(a,b,c){if(Ob(a+1074312|0,21)){c=c&255;a:{switch((b&3)-1|0){default:return v[c+33664|0];case 0:return 64-(c+1>>>1|0)|0;case 1:return(c>>>0<128)<<6;case 2:break a}}return JM(_n(a))+-64|0}if(z[a+480182>>1]&1032){return v[(c>>>1&31)+32176|0]}a=c&63;b:{switch((b&3)-1|0){default:return v[a+33536|0];case 0:return(a>>>0>=32?255:0)-(a<<2)|0;case 1:return a>>>0<32?127:-127;case 2:break b}}return v[a+33600|0]}function dP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=db-32|0;db=d;x[a+4>>2]=0;a:{if(b){b:{if(wt(a)>>>0>=b>>>0){x[a+4>>2]=b;break b}e=oo(d+20|0);x[23549]=0;f=O(698,a|0,b|0)|0;g=x[23549];x[23549]=0;if((g|0)==1){break a}x[23549]=0;P(699,e|0,f|0);f=x[23549];x[23549]=0;if((f|0)==1){break a}x[e+4>>2]=b;Dt(a,e);He(e)}tm(d+12|0,x[a>>2]);iv(x[d+12>>2],x[d+16>>2],b,y[c|0])}db=d+32|0;return}a=N()|0;He(e);Q(a|0);p()}function dF(a,b,c,d,e){var f=0,g=0,h=0;f=db-144|0;db=f;x[f+136>>2]=37;x[f+140>>2]=0;g=f+136|0;Or(g|1,10637,e,x[b+4>>2]);e=yd();x[f>>2]=d;d=f+123|0;e=Lg(d,13,e,g,f)+d|0;g=Pi(d,e,x[b+4>>2]);h=f+4|0;Nc(h,x[b+28>>2]);x[23549]=0;ea(1131,d|0,g|0,e|0,f+16|0,f+12|0,f+8|0,h|0);d=x[23549];x[23549]=0;a:{if((d|0)!=1){Xb(f+4|0);a=Mr(a,f+16|0,x[f+12>>2],x[f+8>>2],b,c);db=f+144|0;break a}a=N()|0;Xb(f+4|0);Q(a|0);p()}return a}function JX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=db-16|0;db=h;f=h+4|0;x[f+4>>2]=1;j=f,k=Hc(32),x[j+8>>2]=k;e=db-16|0;db=e;g=Zo(x[f+8>>2]);x[g>>2]=43192;g=kc(g);b=Fl(e+8|0,x[b>>2],x[b+4>>2]);d=x[d>>2];c=x[c>>2];i=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=i;b=Zm(g);x[b>>2]=43328;Fl(b+4|0,x[e>>2],x[e+4>>2]);x[b+16>>2]=d;x[b+12>>2]=c;fe(e);db=e+16|0;b=a;a=$o(f);_o(b,kc(a),a);_m(f);db=h+16|0}function n3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=db-16|0;db=c;g=x[a+4>>2];x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;BJ(a,c);a:{if(B[a+24>>2]==E(1)){break a}d=x[b+4>>2];h=x[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=e+g|0;j=x[a+16>>2];k=x[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{f=Kh(k,j,b,i);B[f>>2]=B[a+24>>2]*B[f>>2];b=b+1|0;continue}}}db=c+16|0}function f5(a,b){a=a|0;b=b|0;var c=0,d=0;x[23549]=0;W(927,a|0);c=x[23549];x[23549]=0;if((c|0)!=1){a=x[x[a+24>>2]+24>>2];c=0;a:{if(!ms(b)){break a}d=x[a+484344>>2];if(!se(d,x[a+484348>>2],b&65535)){break a}c=x[Yb(d,b)+12>>2]}return c|0}Y(T(0)|0)|0;x[23549]=0;V(914,6565,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function ex(a){var b=0,c=0,d=0;a:{b:{if(!x[a+1384>>2]){b=x[a+1380>>2];if((b|0)==-1){x[a+1388>>2]=x[a+1116>>2]-1;if(!is(a)){x[a+1384>>2]=1;return 0}if(!(v[a+1375|0]&1)){break b}b=x[a+1380>>2]}d=b+1|0;x[a+1380>>2]=d;c=y[(a+b|0)+1120|0];if((c|0)!=255){x[a+1388>>2]=b;x[a+1384>>2]=1}if(x[a+1116>>2]<=(d|0)){x[a+1380>>2]=-1}if(y[a+1376|0]){break a}v[a+1376|0]=c}return c}cc(a,32);return 0}_(15372,13048,1564,5977);p()}function fF(a,b,c,d,e){var f=0,g=0,h=0;f=db+-64|0;db=f;x[f+56>>2]=37;x[f+60>>2]=0;g=f+56|0;Or(g|1,10637,e,x[b+4>>2]);e=yd();x[f>>2]=d;d=f+43|0;e=Lg(d,13,e,g,f)+d|0;g=Pi(d,e,x[b+4>>2]);h=f+4|0;Nc(h,x[b+28>>2]);x[23549]=0;ea(1128,d|0,g|0,e|0,f+16|0,f+12|0,f+8|0,h|0);d=x[23549];x[23549]=0;a:{if((d|0)!=1){Xb(f+4|0);a=Iq(a,f+16|0,x[f+12>>2],x[f+8>>2],b,c);db=f- -64|0;break a}a=N()|0;Xb(f+4|0);Q(a|0);p()}return a}function Rfa(a){a=a|0;var b=0,c=0,d=0;b=db-16|0;db=b;v[b+15|0]=128;a=wu(a,127,b+15|0);x[23549]=0;v[b+14|0]=64;d=U(540,a+12|0,127,b+14|0)|0;c=x[23549];x[23549]=0;a:{b:{if((c|0)!=1){x[23549]=0;v[b+13|0]=0;O(617,a+24|0,b+13|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break b}x[a+44>>2]=0;x[a+48>>2]=0;x[a+36>>2]=-1;x[a+40>>2]=108855296;w[a+52>>1]=0;db=b+16|0;return a|0}b=N()|0;break a}b=N()|0;bc(d)}bc(a);Q(b|0);p()}function vaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=db-32|0;db=f;d=f+8|0;_e(d,2,a+6|0);e=f+20|0;Bc(e,d);zc(b+492|0,e);d=b+236|0;g=c+1|0;tb(e);c=0;while(1){if((c|0)==128){x[b>>2]=(y[a+226|0]|y[a+227|0]<<8)<<5;gy(a+180|0,b+48|0,0);gy(a+228|0,b+88|0,2);gy(a+276|0,b+68|0,1);if(!(y[a+324|0]|y[a+325|0]<<8)){Nz(d)}db=f+32|0}else{e=y[(a+c|0)+38|0];h=_b(d,c),i=e+g|0,w[h>>1]=i;c=c+1|0;continue}break}}function nja(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;h=db-16|0;db=h;x[h+12>>2]=d;g=Bb(x[a+4>>2],y[a+11|0]);f=Mc(a);a:{if(f-g>>>0>=b>>>0){f=Mb(a);if((c|0)==(g|0)){break a}i=c+f|0;pl(i+b|0,i,g-c|0);break a}cm(a,f,(b+g|0)-f|0,g,c,0,b);f=x[a>>2]}b=b+g|0;Wg(a,b);hd(b+f|0,0);b=c+f|0;while(1){if(Kb(d,e)){hd(b,y[d|0]);b=b+1|0;d=x[Oe(h+12|0)>>2];continue}break}a=Ie(od(a),c);db=h+16|0;return a|0}function gD(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=db-16|0;db=e;f=e+8|0;d=db-32|0;db=d;Od(d+24|0,a,b);g=d+16|0;b=x[d+24>>2];h=x[d+28>>2];a=db-16|0;db=a;x[a+8>>2]=c;x[a+12>>2]=b;while(1){if(sd(b,h)){b=Gf(b);c=Gf(x[a+8>>2]);v[c+2|0]=y[b+2|0];w[c>>1]=z[b>>1];b=fj(a+12|0);fj(a+8|0);b=x[b>>2];continue}break}vc(g,b,a+8|0);db=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];vc(f,a,d+12|0);db=d+32|0;db=e+16|0;return x[e+12>>2]}function c0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=db-96|0;db=a;f=yd();x[a>>2]=e;g=a- -64|0;i=Lg(g,20,f,9160,a);e=i+g|0;g=Pi(g,e,x[c+4>>2]);Nc(a+12|0,x[c+28>>2]);x[23549]=0;f=R(18,x[a+12>>2])|0;h=x[23549];x[23549]=0;if((h|0)!=1){Xb(a+12|0);h=f;f=a+16|0;UG(h,a- -64|0,e,f);h=b;b=f+i|0;b=Iq(h,f,(e|0)==(g|0)?b:((g-a|0)+a|0)-48|0,b,c,d);db=a+96|0;return b|0}b=N()|0;Xb(a+12|0);Q(b|0);p()}function tP(a,b){var c=0,d=0,e=0,f=0;c=db-16|0;db=c;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(b){x[23549]=0;P(740,a|0,b|0);d=x[23549];x[23549]=0;if((d|0)==1){break a}e=db-16|0;db=e;d=fp(e+4|0,a,b);b=x[d+4>>2];f=x[d+8>>2];while(1){if((b|0)==(f|0)){fc(d);db=e+16|0}else{fl(b,0,0);b=b+16|0;x[d+4>>2]=b;continue}break}}b=c+8|0;Hd(b);hP(b);db=c+16|0;return a}a=N()|0;hP(c+8|0);Q(a|0);p()}function o6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23549]=0;W(952,a|0);c=x[23549];x[23549]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+76>>2];x[23549]=0;P(e|0,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,11166,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function W5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23549]=0;W(952,a|0);c=x[23549];x[23549]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+84>>2];x[23549]=0;P(e|0,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,12120,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function V5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23549]=0;W(952,a|0);c=x[23549];x[23549]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+80>>2];x[23549]=0;P(e|0,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,10998,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function PO(a,b,c){a:{switch(b|0){case 0:nh(a,0,c);return;case 1:nh(a,1,c);return;case 2:nh(a,2,c);return;case 3:nh(a,3,c);return;case 4:nh(a,4,c);return;case 5:nh(a,5,c);return;case 6:EO(a,23280,c);return;case 7:EO(a,24304,c);return;case 8:nh(a,6,c);return;case 9:nh(a,7,c);return;case 10:nh(a,8,c);return;case 11:nh(a,9,c);return;case 12:nh(a,10,c);return;case 13:nh(a,11,c);return;default:break a}}Gb(a)}function $5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23549]=0;W(952,a|0);c=x[23549];x[23549]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+16>>2];x[23549]=0;P(e|0,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,12637,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function f6(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[23549]=0;W(952,a|0);c=x[23549];x[23549]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+40>>2];x[23549]=0;na(e|0,c|0,+b);c=x[23549];x[23549]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,11574,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[23549]=0;X(17);d=x[23549];x[23549]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function a6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23549]=0;W(952,a|0);c=x[23549];x[23549]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+20>>2];x[23549]=0;P(e|0,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,9210,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function _5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23549]=0;W(952,a|0);c=x[23549];x[23549]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+100>>2];x[23549]=0;d=+oa(e|0,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,11492,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();d=0}return+d}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function i6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23549]=0;W(952,a|0);c=x[23549];x[23549]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+52>>2];x[23549]=0;d=+oa(e|0,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,11555,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();d=0}return+d}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function d6(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[23549]=0;W(952,a|0);c=x[23549];x[23549]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+32>>2];x[23549]=0;na(e|0,c|0,+b);c=x[23549];x[23549]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,7675,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[23549]=0;X(17);d=x[23549];x[23549]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function b6(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[23549]=0;W(952,a|0);c=x[23549];x[23549]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+24>>2];x[23549]=0;na(e|0,c|0,+b);c=x[23549];x[23549]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,7623,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[23549]=0;X(17);d=x[23549];x[23549]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Y5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23549]=0;W(952,a|0);c=x[23549];x[23549]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+92>>2];x[23549]=0;d=+oa(e|0,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,10936,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();d=0}return+d}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Gy(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+813|0];if(c){v[b+813|0]=d&240|c&15;break a}c=d&15;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Oj(a,b,b+700|0,0-(c<<2)|0,0);if(x[b+700>>2]<65536){break b}if(Ob(a+1074312|0,7)|(x[a+480180>>2]!=4?y[a+480208|0]&16:0)){break b}x[b+700>>2]=65535}}function Bi(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-32|0;db=c;a:{if(!y[b+4|0]){while(1){if((d|0)==4){d=0;x[c+28>>2]=0;e=ec(c+8|0,c+28|0,4);lc(c+20|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);if(!(x[c+24>>2]!=4|x[c+28>>2]!=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24)))){Zb(a,4);d=1}db=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17053,8977,413,13012);p()}_(17032,8977,411,13012);p()}return d|0}function Ay(a,b){a=a|0;b=b|0;var c=E(0),d=0,e=0,f=0;v[a+1074368|0]=b;hN(a+1074332|0,b);f=a+946300|0;a=a+906300|0;while(1){if((a|0)!=(f|0)){b=x[a>>2];if(b){c=E(1);d=x[b+20>>2];if(d){c=E(E(y[d+26|0])*E(.10000000149011612))}c=c<E(.10000000149011612)?E(1):c;if(ib[x[x[b>>2]+136>>2]](b)|0){d=x[b+16>>2];e=d+1074332|0;c=E(E(c/B[e+8>>2])*E(E(A[d+480232>>2])/B[e+20>>2]))}B[b+4196>>2]=c}a=a+160|0;continue}break}}function hD(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=db-16|0;db=e;f=e+8|0;d=db-32|0;db=d;Od(d+24|0,a,b);g=d+16|0;b=x[d+24>>2];h=x[d+28>>2];a=db-16|0;db=a;x[a+8>>2]=c;x[a+12>>2]=b;while(1){if(sd(b,h)){b=Om(b);i=Om(x[a+8>>2]),j=z[b>>1],w[i>>1]=j;b=qk(a+12|0);qk(a+8|0);b=x[b>>2];continue}break}vc(g,b,a+8|0);db=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];vc(f,a,d+12|0);db=d+32|0;db=e+16|0;return x[e+12>>2]}function Q2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=db-32|0;db=e;a:{if(y[b+8|0]){f=x[b+12>>2];h=e,i=Pc(f,x[b+16>>2])-c|0,x[h+28>>2]=i;x[e+24>>2]=x[d+4>>2];g=x[Cb(e+28|0,e+24|0)>>2];f=Ie(yb(f),c);c=Ie(Ie(yb(x[b+12>>2]),c),g);b=x[d>>2];qu(f,c,b);dc(a,b,g);break a}g=x[d+4>>2];d=x[d>>2];x[e+16>>2]=d;x[e+20>>2]=g;f=x[x[b>>2]+40>>2];x[e+8>>2]=d;x[e+12>>2]=g;ib[f|0](a,b,c,e+8|0)}db=e+32|0}function F1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=db-16|0;db=e;while(1){a:{if((c|0)<=(f|0)){break a}g=x[a+28>>2];d=x[a+24>>2];if(g>>>0<=d>>>0){if(((i=a,j=Lh(v[b|0]),h=x[x[a>>2]+52>>2],ib[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{x[e+12>>2]=g-d;x[e+8>>2]=c-f;g=d;d=x[qd(e+12|0,e+8|0)>>2];We(g,b,d);x[a+24>>2]=d+x[a+24>>2];f=f+d|0;b=b+d|0}continue}break}db=e+16|0;return f|0}function m6(a,b){a=a|0;b=b|0;var c=0,d=0;x[23549]=0;W(952,a|0);c=x[23549];x[23549]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+68>>2];x[23549]=0;b=O(d|0,c|0,b|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,6628,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function k6(a,b){a=a|0;b=b|0;var c=0,d=0;x[23549]=0;W(952,a|0);c=x[23549];x[23549]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+60>>2];x[23549]=0;b=O(d|0,c|0,b|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,6679,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Pe(a){var b=0,c=0,d=0;b=db-16|0;db=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=ip(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(HF(a,b)&3){case 0:c=ip(C[b>>3],C[b+8>>3]);break a;case 1:c=-jp(C[b>>3],C[b+8>>3],1);break a;case 2:c=-ip(C[b>>3],C[b+8>>3]);break a;default:break b}}c=jp(C[b>>3],C[b+8>>3],1)}a=c;db=b+16|0;return a}function Ao(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=db-16|0;db=f;x[f+12>>2]=c;a:{if(!Lb(x[b>>2],x[b+8>>2],c)){break a}tc(f+12|0,65535);Sf(a,z[f+12>>1]);c=yb(x[a>>2]);x[f+4>>2]=c;h=yb(x[a+4>>2]);while(1){if(!Kb(c,h)){break a}a=f+11|0;if(!Eg(b,a)){tg(a)}a=y[f+11|0];w[c>>1]=a;g=65535;b:{if((a|0)!=(d|0)){g=65534;if((a|0)!=(e|0)){break b}}w[c>>1]=g}c=x[Se(f+4|0)>>2];continue}}db=f+16|0}function nea(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[wb(a)>>2]){c=db-16|0;db=c;a=Kz(c+4|0,a);uQ(x[a+4>>2],y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24));x[a+4>>2]=x[a+4>>2]+4;fc(a);db=c+16|0;return}d=db-32|0;db=d;c=wb(a);c=Jf(d+12|0,eg(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);uQ(x[c+8>>2],y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24));x[c+8>>2]=x[c+8>>2]+4;HT(a,c);If(c);db=d+32|0}function AG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=db-16|0;db=e;f=e+8|0;d=db-32|0;db=d;Od(d+24|0,a,b);g=d+16|0;b=x[d+24>>2];h=x[d+28>>2];a=db-16|0;db=a;x[a+8>>2]=c;x[a+12>>2]=b;while(1){if(sd(b,h)){b=xG(b);i=xG(x[a+8>>2]),j=y[b|0],v[i|0]=j;b=tG(a+12|0);tG(a+8|0);b=x[b>>2];continue}break}vc(g,b,a+8|0);db=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];vc(f,a,d+12|0);db=d+32|0;db=e+16|0;return x[e+12>>2]}function y4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=db-16|0;db=f;a:{b:{c:{if(!(e?d:0)){a=ac(8);x[23549]=0;b=O(54,f+4|0,8098)|0;c=x[23549];x[23549]=0;if((c|0)==1){break c}a=pc(a,b);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}e=N()|0;tb(b);break b}Tk(a,b,2);c=tx(a,c,d,e,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);db=f+16|0;return c|0}e=N()|0;jc(a)}Q(e|0)}p()}function pt(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=db-16|0;db=e;x[b+40>>2]=0;x[b+44>>2]=0;f=b- -64|0;x[f>>2]=0;x[f+4>>2]=0;x[b+56>>2]=0;x[b+60>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;while(1){if((d|0)==1e4){a:{d=yb(x[c>>2]);x[e+12>>2]=d;f=yb(x[c+4>>2]);while(1){if(!Kb(d,f)){break a}g=d,h=jP(b,C[d>>3]),C[g>>3]=h;d=x[mt(e+12|0)>>2];continue}}}else{jP(b,C[Qe(x[c>>2],0)>>3]);d=d+1|0;continue}break}Zj(a,c);db=e+16|0}function N4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=db-16|0;db=f;a:{b:{c:{if(!(e?d:0)){a=ac(8);x[23549]=0;b=O(54,f+4|0,8098)|0;c=x[23549];x[23549]=0;if((c|0)==1){break c}a=pc(a,b);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}e=N()|0;tb(b);break b}Tk(a,b,2);c=rx(a,c,d,e,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);db=f+16|0;return c|0}e=N()|0;jc(a)}Q(e|0)}p()}function CN(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+814|0];if(c){v[b+814|0]=d&240|c&15;break a}c=d&15;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Oj(a,b,b+700|0,0-c|0,0);if(x[b+700>>2]<65536){break b}if(Ob(a+1074312|0,7)|(x[a+480180>>2]!=4?y[a+480208|0]&16:0)){break b}x[b+700>>2]=65535}}function nF(a,b,c,d,e,f,g,h,i){var j=0;x[23549]=0;W(927,a|0);j=x[23549];x[23549]=0;a:{b:{if((j|0)!=1){j=x[a+24>>2];x[23549]=0;b=qa(i|0,j|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,h|0,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();b=0}return b}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function yF(a,b,c){a=Gb(a);x[23549]=0;P(c|0,a|0,4);c=x[23549];x[23549]=0;a:{b:{if((c|0)==1){break b}x[23549]=0;P(b|0,a|0,32);c=x[23549];x[23549]=0;if((c|0)==1){break b}x[23549]=0;P(b|0,a|0,10);c=x[23549];x[23549]=0;if((c|0)==1){break b}x[23549]=0;P(b|0,a|0,13);c=x[23549];x[23549]=0;if((c|0)==1){break b}x[23549]=0;P(b|0,a|0,9);b=x[23549];x[23549]=0;if((b|0)!=1){break a}}b=N()|0;tb(a);Q(b|0);p()}}function gga(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;b=-1;a:{if(!zh(a,8)){break a}b=db-32|0;db=b;x[b+24>>2]=0;x[b+28>>2]=0;d=ec(b+8|0,b+24|0,8);md(b+16|0,a,x[d>>2],x[d+4>>2]);d=x[b+24>>2]==1096043343&x[b+28>>2]==1196314451&x[b+20>>2]==8;if(d){dd(a,8)}db=b+32|0;b=0;if(!d){break a}b=-1;if(!xj(a,c+8|0)){break a}b=0;if(!$b(x[c+12>>2])){break a}b=!($b(x[c+8>>2])&-2139062144)}db=c+16|0;return b|0}function rC(a,b){var c=0,d=0,e=0;c=db-32|0;db=c;a:{if(!y[b+7|0]){while(1){if((d|0)==7){d=0;v[c+27|0]=0;v[c+28|0]=0;v[c+29|0]=0;v[c+30|0]=0;x[c+24>>2]=0;e=ec(c+8|0,c+24|0,7);md(c+16|0,a,x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=7){break b}if(cd(c+24|0,b,7)){break b}dd(a,7);d=1}db=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17053,8977,413,13012);p()}_(17032,8977,411,13012);p()}return d}function q4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[23549]=0;W(927,a|0);d=x[23549];x[23549]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[23549]=0;S(1021,d|0,b|0,c|0);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,10204,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function XI(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((wp(a)|0)>(b|0)){break d}}b=ac(8);x[23549]=0;c=O(54,c+4|0,10589)|0;a=x[23549];x[23549]=0;if((a|0)==1){break c}a=pc(b,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}db=c+16|0;return(x[(a+D(b,872)|0)+1075080>>2]&134218752)!=0|0}a=N()|0;jc(b)}Q(a|0)}p()}function AU(a){var b=0,c=0,d=0;a:{if((y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24))!=808537417|(y[a+32|0]|y[a+33|0]<<8)>>>0>256|(y[a+49|0]<32|(y[a+36|0]|y[a+37|0]<<8)>>>0>255)){break a}if(v[a+51|0]<4|y[a+50|0]>64){break a}b=a+576|0;a=a- -64|0;while(1){if((a|0)==(b|0)){d=c;break a}b:{switch(y[a+15|0]){case 0:case 1:c=1;break;case 2:break b;default:break a}}a=a+16|0;continue}}return d&1}function M3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=db-16|0;db=e;a:{if(!c){break a}f=Oc(x[b+4>>2],y[b+11|0]);g=f-1|0;h=d<<24>>24;d=0;while(1){if((d|0)==(f|0)){break a}b:{if(!d|(d>>>0)%(c>>>0)){break b}if((d|0)==(g|0)){if(y[uc(b,0)|0]==(Zf(43)&255)){break b}if(y[uc(b,0)|0]==(Zf(45)&255)){break b}}sx(b,x[vb(e+12|0,Ie(od(b),f-d|0))>>2],1,Zf(h))}d=d+1|0;continue}}ad(a,b);db=e+16|0}function LY(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;x[23549]=0;a=Ea(1024,a|0,b|0,c|0,d|0)|0;b=x[23549];x[23549]=0;a:{b:{if((b|0)==1){Y(T(0)|0)|0;x[23549]=0;ea(910,11038,e|0,f|0,g|0,h|0,i|0,j|0);a=x[23549];x[23549]=0;if((a|0)==1){break b}Z();a=-255}break a}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}return a|0}function x3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=db-16|0;db=c;g=x[a+4>>2];x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;HJ(a,c);a:{if(B[a+24>>2]==E(1)){break a}d=x[b+4>>2];h=x[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=e+g|0;j=x[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{f=eq(j,b,i);B[f>>2]=B[a+24>>2]*B[f>>2];b=b+1|0;continue}}}db=c+16|0}function w3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=db-16|0;db=c;a:{if(B[a+24>>2]==E(1)){break a}g=x[b+4>>2];h=x[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=x[b+4>>2];j=x[b>>2];k=+B[a+24>>2];d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{f=Pg(j,i,d,e);C[f>>3]=C[f>>3]*k;d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;GJ(a,c);db=c+16|0}function vea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=db-16|0;db=b;w[b+12>>1]=0;w[b+14>>1]=1;Wf(b+14|0,z[x[x[a+24>>2]+8>>2]+12>>1]);e=b+12|0;d=db-16|0;db=d;c=z[b+14>>1];x[d+12>>2]=c;a:{if(Qm(a)>>>0>=c>>>0){g=x[a>>2];f=Ic(g,x[a+4>>2]);x[d+8>>2]=f;_t(g,x[Cb(d+12|0,d+8|0)>>2],e);if(c>>>0>f>>>0){Lo(a,c-f|0,e);break a}Dd(a,x[a>>2]+(c<<1)|0);break a}ZP(a);nA(a,vj(a,c));Lo(a,c,e)}db=d+16|0;db=b+16|0}function uT(a){var b=0;a:{if(cd(a,13946,3)|(y[a+3|0]-52&255)>>>0<252){break a}if($b(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+788>>>0<840){break a}if($b(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24))>>>0<52){break a}if($b(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24))-1>>>0<51){break a}b=$b(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))>>>0<4294967216}return b}function u4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[23549]=0;W(927,a|0);d=x[23549];x[23549]=0;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[23549]=0;e=+ma(1017,d|0,b|0,c|0);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,5291,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();e=0}return+e}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function t3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=db-16|0;db=c;a:{if(B[a+24>>2]==E(1)){break a}g=x[b+4>>2];h=x[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=x[b+4>>2];j=x[b>>2];k=+B[a+24>>2];d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{f=Pg(j,i,d,e);C[f>>3]=C[f>>3]*k;d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;EJ(a,c);db=c+16|0}function m3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=db-16|0;db=c;a:{if(B[a+24>>2]==E(1)){break a}g=x[b+4>>2];h=x[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=x[b+4>>2];j=x[b>>2];k=+B[a+24>>2];d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{f=Pg(j,i,d,e);C[f>>3]=C[f>>3]*k;d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;AJ(a,c);db=c+16|0}function Qba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=db-16|0;db=c;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(c+8|0,x[vb(c+4|0,a)>>2]);x[23549]=0;W(745,a|0);b=x[23549];x[23549]=0;if((b|0)!=1){e=db-16|0;db=e;d=Ei(e+4|0,a,2304);b=x[d+4>>2];f=x[d+8>>2];while(1){if((b|0)==(f|0)){fc(d);db=e+16|0}else{nv(b);b=b+2|0;x[d+4>>2]=b;continue}break}b=c+8|0;Hd(b);ll(b);db=c+16|0;return a|0}a=N()|0;ll(c+8|0);Q(a|0);p()}function C3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=db-16|0;db=c;a:{if(B[a+24>>2]==E(1)){break a}g=x[b+4>>2];h=x[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=x[b+4>>2];j=x[b>>2];k=+B[a+24>>2];d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{f=Pg(j,i,d,e);C[f>>3]=C[f>>3]*k;d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;LJ(a,c);db=c+16|0}function ui(a){var b=0,c=0;b=db-16|0;db=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=jp(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(HF(a,b)&3){case 0:a=jp(C[b>>3],C[b+8>>3],1);break a;case 1:a=ip(C[b>>3],C[b+8>>3]);break a;case 2:a=-jp(C[b>>3],C[b+8>>3],1);break a;default:break b}}a=-ip(C[b>>3],C[b+8>>3])}db=b+16|0;return a}function g6(a){a=a|0;var b=0,c=0,d=0;x[23549]=0;W(952,a|0);b=x[23549];x[23549]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+44>>2];x[23549]=0;c=+ja(d|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,11592,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function wW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=db-16|0;db=d;x[a>>2]=0;x[a+4>>2]=0;if(!Lb(x[b>>2],x[b+8>>2],c)){c=rf(b)}x[a>>2]=c;c=x[b>>2];a:{if(ib[x[x[c>>2]+16>>2]](c)|0){c=a;a=x[b>>2];e=c,f=(ib[x[x[a>>2]+20>>2]](a)|0)+x[b+8>>2]|0,x[e+4>>2]=f;break a}Ji(a+8|0,x[a>>2]);c=x[a+8>>2];a=x[a+12>>2];if(qc(c,a)){break a}ge(d+8|0,c,a);lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2])}db=d+16|0}function oN(a,b){var c=0,d=0,e=0,f=0;c=x[a>>2];x[a>>2]=b;if(c){d=db-16|0;db=d;b=yb(x[c>>2]);x[d+12>>2]=b;f=yb(x[c+4>>2]);while(1){a:{b:{if(Kb(b,f)){while(1){a=x[b>>2];e=x[a>>2];if(!e){break b}a=x[x[e>>2]+8>>2];x[23549]=0;W(a|0,e|0);a=x[23549];x[23549]=0;if((a|0)!=1){continue}break}T(0)|0;Rb();p()}a=sc(c);db=d+16|0;break a}Ab(a+20|0);Ab(a+8|0);Eb(a);b=x[Ae(d+12|0)>>2];continue}break}Eb(a)}}function e6(a){a=a|0;var b=0,c=0,d=0;x[23549]=0;W(952,a|0);b=x[23549];x[23549]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+36>>2];x[23549]=0;c=+ja(d|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,7692,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function c6(a){a=a|0;var b=0,c=0,d=0;x[23549]=0;W(952,a|0);b=x[23549];x[23549]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+28>>2];x[23549]=0;c=+ja(d|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,7640,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function _V(a){a=a|0;var b=0,c=0,d=0;b=x[a>>2];if(b){ib[x[x[b>>2]+8>>2]](b);x[a>>2]=0}a=a+4|0;Dc(a);b=db-32|0;db=b;a:{b:{d=pn(a);c=Pc(x[a>>2],x[a+4>>2]);c:{if(d>>>0<=c>>>0){break c}x[23549]=0;c=ba(887,b+12|0,c|0,c|0,wb(a)|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){mp(a,c);Ml(c);break c}Y(T(0)|0)|0;x[23549]=0;X(17);a=x[23549];x[23549]=0;if((a|0)==1){break b}}db=b+32|0;break a}T(0)|0;Rb();p()}}function ZI(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((wp(a)|0)>(b|0)){break d}}b=ac(8);x[23549]=0;c=O(54,c+4|0,10589)|0;a=x[23549];x[23549]=0;if((a|0)==1){break c}a=pc(b,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}db=c+16|0;return+(+x[(a+D(b,872)|0)+1075740>>2]*.015625)}a=N()|0;jc(b)}Q(a|0)}p()}function ur(a){var b=0,c=0;Wm(a,1,15075);x[23549]=0;b=ca(112)|0;c=x[23549];x[23549]=0;a:{if((c|0)==1){break a}x[a+12>>2]=b;x[23549]=0;b=ca(113)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}v[a+16|0]=b;x[23549]=0;b=ca(114)|0;c=x[23549];x[23549]=0;if((c|0)==1){break a}v[a+18|0]=0;v[a+17|0]=b;x[23549]=0;W(115,a+20|0);b=x[23549];x[23549]=0;if((b|0)==1){break a}return}b=N()|0;tb(a);Q(b|0);p()}function mx(a,b,c){var d=0,e=0;d=db-32|0;db=d;a:{if(y[a+20|0]){break a}b=b+c|0;b=b>>>0<c>>>0?-1:b;c=x[a+16>>2];if(b>>>0<=c>>>0){break a}b=uJ(b,4096);tJ(a,b-c|0);c=x[a+16>>2];b=ec(d+16|0,Db(x[a+4>>2],c),b-c|0);c=x[x[a>>2]+44>>2];e=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=e;ib[c|0](d+24|0,a,d+8|0);x[a+16>>2]=x[a+16>>2]+x[d+28>>2];if(!(ib[x[x[a>>2]+40>>2]](a)|0)){break a}v[a+20|0]=1}db=d+32|0}function lo(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=db-16|0;db=d;f=vb(d+12|0,x[a+4>>2]);g=vb(d+8|0,x[a>>2]);h=x[vb(d+4|0,x[b+4>>2])>>2];e=db-16|0;db=e;c=db-32|0;db=c;Od(c+24|0,x[f>>2],x[g>>2]);lQ(c+16|0,x[c+24>>2],x[c+28>>2],h);f=x[c+16>>2];x[c+12>>2]=x[c+20>>2];vc(e+8|0,f,c+12|0);db=c+32|0;db=e+16|0;x[b+4>>2]=x[e+12>>2];Pb(a,b+4|0);Pb(a+4|0,b+8|0);Pb(wb(a),kc(b));x[b>>2]=x[b+4>>2];db=d+16|0}function Jja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=db-16|0;db=d;a:{e=ee(a);b:{if(e>>>0>1){break b}c:{if(e){x[23549]=0;S(319,d+4|0,a|0,c|0);a=x[23549];x[23549]=0;if((a|0)!=1){a=d+4|0;zm(b,a);bc(a);break c}a=T(30544)|0;if((eb|0)!=($(30544)|0)){break a}Y(a|0)|0;Z();break b}if(!Lb(x[a>>2],x[a+8>>2],c)){break b}Su(a,b,c)}f=Pc(x[b>>2],x[b+4>>2])>>>0>=c>>>0}db=d+16|0;return f|0}Q(a|0);p()}function FB(a,b,c){var d=0,e=0,f=0;d=x[c+16>>2];a:{if(!d){if(eW(c)){break a}d=x[c+16>>2]}f=x[c+20>>2];if(d-f>>>0<b>>>0){return ib[x[c+36>>2]](c,a,b)|0}b:{if(x[c+80>>2]<0){d=0;break b}e=b;while(1){d=e;if(!d){d=0;break b}e=d-1|0;if(y[e+a|0]!=10){continue}break}e=ib[x[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;f=x[c+20>>2]}rc(f,a,b);x[c+20>>2]=x[c+20>>2]+b;e=b+d|0}return e}function g8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ni(a,b,c,d);x[a>>2]=45968;b=Nb(a+4208|0);x[a+4240>>2]=0;x[a+4244>>2]=0;c=x[c+24620>>2];x[a+4260>>2]=0;x[a+4256>>2]=c;x[a+4236>>2]=0;c=a+4228|0;x[c>>2]=1048550822;x[c+4>>2]=1048550822;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;x[23549]=0;P(878,a+44|0,2);c=x[23549];x[23549]=0;if((c|0)!=1){mi(a);return a|0}c=N()|0;sc(b);yf(a);Q(c|0);p()}function cB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Lb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=3){d=db-16|0;db=d;if(Lb(x[a>>2],x[a+8>>2],b)){while(1){if((c|0)==4){c=x[d+12>>2]}else{v[d+11|0]=0;b:{if(b>>>0>c>>>0){Eg(a,d+11|0);e=v[d+11|0];g=e>>>31|0;break b}e=0-g|0}v[(d+12|0)+c|0]=e;c=c+1|0;continue}break}}db=d+16|0;break a}c=pg(a);Zb(a,b-4|0)}v[f|0]=c}function b4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(c+8|0,x[vb(c+4|0,a)>>2]);a:{d=fh(x[b+4>>2],x[b+8>>2]);if(!d){break a}x[23549]=0;P(1033,a|0,d|0);e=x[23549];x[23549]=0;if((e|0)!=1){e=x[b+8>>2];b=x[b+4>>2];x[23549]=0;V(1034,a|0,b|0,e|0,d|0);a=x[23549];x[23549]=0;if((a|0)!=1){break a}}a=N()|0;qK(c+8|0);Q(a|0);p()}a=c+8|0;Hd(a);qK(a);db=c+16|0}function uja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;dc(c+8|0,b,15);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0}}function mF(a,b,c,d,e,f,g){var h=0;x[23549]=0;W(927,a|0);h=x[23549];x[23549]=0;a:{b:{if((h|0)!=1){h=x[a+24>>2];x[23549]=0;b=fa(g|0,h|0,b|0,c|0,d|0,e|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,f|0,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();b=0}return b}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function lA(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+27|0]=0;v[a+28|0]=0;v[a+29|0]=0;v[a+30|0]=0;v[a+31|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function l3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=db-16|0;db=f;a:{if(!c){break a}g=Oc(x[b+4>>2],y[b+11|0]);h=g-1|0;d=d<<24>>24;while(1){if((e|0)==(g|0)){break a}b:{if(!e|(e>>>0)%(c>>>0)){break b}if((e|0)==(h|0)){if(y[Mb(b)|0]==(Zf(43)&255)){break b}if(y[Mb(b)|0]==(Zf(45)&255)){break b}}zJ(b,x[vb(f+12|0,Ie(od(b),g-e|0))>>2],1,Zf(d))}e=e+1|0;continue}}ad(a,b);db=f+16|0}function VG(a,b,c){var d=0,e=0,f=E(0),g=0,h=E(0);e=db-16|0;db=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[23424];x[23424]=0;yd();d=db-16|0;db=d;Dw(d,a,e+12|0,0);f=eE(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);db=d+16|0;a=x[23424];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[23424]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}db=e+16|0;return f}function R4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=db-16|0;db=e;a:{b:{c:{if(!d){a=ac(8);x[23549]=0;c=O(54,e+4|0,8098)|0;b=x[23549];x[23549]=0;if((b|0)==1){break c}a=pc(a,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Tk(a,b,1);c=rx(a,c,d,0,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);db=e+16|0;return c|0}b=N()|0;jc(a)}Q(b|0)}p()}function PS(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+27|0]=0;v[a+28|0]=0;v[a+29|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function ME(a,b,c,d,e){var f=0,g=0;a:{f=db+-64|0;db=f;Ze(b);g=f+44|0;Df(g,a,c);a=x[f+44>>2];c=f+8|0;Tf(c,e,Ee(g),a);x[23549]=0;P(208,f+20|0,c|0);a=x[23549];x[23549]=0;b:{c:{if((a|0)!=1){x[23549]=0;S(11,f+32|0,d|0,f+20|0);a=x[23549];x[23549]=0;if((a|0)==1){break c}a=f+32|0;zb(b,a);tb(a);tb(f+20|0);Jc(f+44|0);db=f- -64|0;break a}a=N()|0;break b}a=N()|0;tb(f+20|0)}Jc(f+44|0);Q(a|0);p()}}function C4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=db-16|0;db=e;a:{b:{c:{if(!d){a=ac(8);x[23549]=0;c=O(54,e+4|0,8098)|0;b=x[23549];x[23549]=0;if((b|0)==1){break c}a=pc(a,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Tk(a,b,1);c=tx(a,c,d,0,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);db=e+16|0;return c|0}b=N()|0;jc(a)}Q(b|0)}p()}function Uha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;dc(c+8|0,b,14);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0}}function x4(a,b){a=a|0;b=b|0;var c=0,d=0;x[23549]=0;W(927,a|0);c=x[23549];x[23549]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[23549]=0;P(1016,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,10750,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function dea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=db-16|0;db=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];j=x[a+12>>2];while(1){if(d){f=w[(x[b+12>>2]<<1)+i>>1];x[c>>2]=x[c>>2]+D(f,h);x[c+4>>2]=x[c+4>>2]+D(g,f);Qb(b+8|0,e,j);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;db=b+16|0}function Ni(a,b,c,d,e){var f=0,g=0,h=0;f=db-16|0;db=f;x[f+12>>2]=b;b=0;g=6;a:{b:{if(Og(a,f+12|0)){break b}h=Mk(x[a>>2]);g=4;if(!ih(x[d+8>>2],64,h)){break b}b=nn(d,h);while(1){c:{b=b-48|0;h=Tl(a);if(Og(h,f+12|0)|(e|0)<2){break c}g=Mk(x[h>>2]);if(!ih(x[d+8>>2],64,g)){break a}e=e-1|0;b=nn(d,g)+D(b,10)|0;continue}break}g=2;if(!Og(h,f+12|0)){break a}}x[c>>2]=x[c>>2]|g}db=f+16|0;return b}function OI(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=db-16|0;db=d;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[23549]=0;d=O(54,d+4|0,10589)|0;a=x[23549];x[23549]=0;if((a|0)==1){break c}a=pc(b,d);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break b}e=(x[a+32>>2]+D(b,872)|0)+1075766|0,f=Tz(c*32768),w[e>>1]=f;db=d+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function k4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=db-32|0;db=b;c=ec(b+24|0,c,d);d=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=d;a:{a=Ws(a,b,0);if(a+1>>>0>=3){a=ac(8);x[23549]=0;b=O(54,b+12|0,7955)|0;c=x[23549];x[23549]=0;b:{if((c|0)!=1){a=pc(a,b);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;jc(a)}Q(c|0);p()}db=b+32|0;return a|0}p()}function faa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(c+8|0,x[vb(c+4|0,a)>>2]);a:{d=oc(x[b>>2],x[b+4>>2]);if(!d){break a}x[23549]=0;P(214,a|0,d|0);e=x[23549];x[23549]=0;if((e|0)!=1){e=x[b+4>>2];b=x[b>>2];x[23549]=0;Ss(a,b,e,d);b=x[23549];x[23549]=0;if((b|0)!=1){break a}}a=N()|0;Bg(c+8|0);Q(a|0);p()}b=c+8|0;Hd(b);Bg(b);db=c+16|0;return a|0}function Xba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(c+8|0,x[vb(c+4|0,a)>>2]);a:{d=Hg(x[b>>2],x[b+4>>2]);if(!d){break a}x[23549]=0;P(738,a|0,d|0);e=x[23549];x[23549]=0;if((e|0)!=1){e=x[b+4>>2];b=x[b>>2];x[23549]=0;kP(a,b,e,d);b=x[23549];x[23549]=0;if((b|0)!=1){break a}}a=N()|0;nt(c+8|0);Q(a|0);p()}b=c+8|0;Hd(b);nt(b);db=c+16|0;return a|0}function Lfa(a,b){a=a|0;b=b|0;var c=0,d=0;a:{a=cA(a,b);x[23549]=0;c=O(622,a+12|0,b+12|0)|0;d=x[23549];x[23549]=0;b:{c:{if((d|0)!=1){x[23549]=0;O(623,a+24|0,b+24|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break c}c=x[b+40>>2];x[a+36>>2]=x[b+36>>2];x[a+40>>2]=c;w[a+52>>1]=z[b+52>>1];c=x[b+48>>2];x[a+44>>2]=x[b+44>>2];x[a+48>>2]=c;break a}b=N()|0;break b}b=N()|0;bc(c)}bc(a);Q(b|0);p()}}function sja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=db-32|0;db=d;e=Nb(a);a=yb(x[b>>2]);x[d+28>>2]=a;b=yb(x[b+4>>2]);a:{while(1){if(Kb(a,b)){zi(d+8|0,x[a>>2],x[a+4>>2]);if(($b(x[d+8>>2])|0)==(c|0)){f=d+8|0;Go(f,a);x[23549]=0;P(344,e|0,f|0);a=x[23549];x[23549]=0;if((a|0)==1){break a}ub(d+8|0)}a=x[hk(d+28|0)>>2];continue}break}db=d+32|0;return}a=N()|0;ub(d+8|0);kd(e);Q(a|0);p()}function eea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=db-16|0;db=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];j=x[a+12>>2];while(1){if(d){f=v[x[b+12>>2]+i|0]<<8;x[c>>2]=x[c>>2]+D(f,h);x[c+4>>2]=x[c+4>>2]+D(g,f);Qb(b+8|0,e,j);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;db=b+16|0}function cA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(c+8|0,x[vb(c+4|0,a)>>2]);a:{d=Pc(x[b>>2],x[b+4>>2]);if(!d){break a}x[23549]=0;P(307,a|0,d|0);e=x[23549];x[23549]=0;if((e|0)!=1){e=x[b+4>>2];b=x[b>>2];x[23549]=0;Mt(a,b,e,d);b=x[23549];x[23549]=0;if((b|0)!=1){break a}}a=N()|0;Vh(c+8|0);Q(a|0);p()}b=c+8|0;Hd(b);Vh(b);db=c+16|0;return a|0}function A9(a){a=a|0;var b=0,c=0;b=x[a+20>>2];x[b+148>>2]=-1;x[23549]=0;P(274,b+4|0,8);b=x[23549];x[23549]=0;if((b|0)!=1){b=x[a+4264>>2];c=x[x[a+20>>2]+4>>2];a=x[a+4260>>2];v[c|0]=a;v[c+1|0]=a>>>8;v[c+2|0]=a>>>16;v[c+3|0]=a>>>24;v[c+4|0]=b;v[c+5|0]=b>>>8;v[c+6|0]=b>>>16;v[c+7|0]=b>>>24;return}b=T(92296)|0;if((eb|0)==($(92296)|0)){Y(b|0)|0;Dc(x[a+20>>2]+4|0);Z();return}Q(b|0);p()}function s6(a){a=a|0;var b=0;x[23549]=0;W(952,a|0);b=x[23549];x[23549]=0;if((b|0)!=1){x[a+24>>2]=0;b=x[a+28>>2];if(b){ib[x[x[b>>2]+4>>2]](b)}x[a+28>>2]=0;b=x[a+20>>2];if(b){Eb(b);x[a+20>>2]=0}Eb(a);return}Y(T(0)|0)|0;x[23549]=0;V(914,4992,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function fn(a,b,c,d,e,f){var g=0;x[23549]=0;W(927,a|0);g=x[23549];x[23549]=0;a:{b:{if((g|0)!=1){g=x[a+24>>2];x[23549]=0;b=ba(f|0,g|0,b|0,c|0,d|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,e|0,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();b=0}return b}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function TG(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=db-16|0;db=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[23424];x[23424]=0;yd();d=db-16|0;db=d;Dw(d,a,e+12|0,1);f=Lv(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);db=d+16|0;a=x[23424];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[23424]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}db=e+16|0;return f}function IW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=db-16|0;db=d;c=-1;a:{if(!zh(a,7)){break a}c=0;if(!rC(a,11632)){break a}c=db-16|0;db=c;f=d+5|0;oC(c+8|0,f);e=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){dd(a,x[c+12>>2])}db=c+16|0;e=(e|0)==(g|0);if(!e){nC(f)}c=-1;if(!e){break a}c=0;if(!qC(y[d+6|0])){break a}c=Ge(a,b,pC(d+5|0),hb)}db=d+16|0;return c|0}function Tfa(a){a=a|0;var b=0,c=0,d=0,e=0;e=db-16|0;db=e;b=Hc(2500);c=db-2496|0;db=c;ZQ(a,c,c+2496|0);a=0;while(1){if((a|0)==624){x[b+2496>>2]=0;a:{if(x[b>>2]<0){break a}a=1;while(1){if((a|0)!=624){d=a<<2;a=a+1|0;if(!x[b+d>>2]){continue}break a}break}x[b>>2]=-2147483648}db=c+2496|0}else{d=a<<2;x[d+b>>2]=x[c+d>>2];a=a+1|0;continue}break}a=x[of(e+12|0,b)>>2];db=e+16|0;return a|0}function t1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=db-16|0;db=f;while(1){a:{if((c|0)<=(g|0)){break a}d=x[a+24>>2];e=x[a+28>>2];if(d>>>0>=e>>>0){if((ib[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){break a}g=g+1|0;b=b+4|0}else{x[f+12>>2]=e-d>>2;x[f+8>>2]=c-g;e=d;d=x[qd(f+12|0,f+8|0)>>2];gi(e,b,d);e=d<<2;x[a+24>>2]=e+x[a+24>>2];g=g+d|0;b=b+e|0}continue}break}db=f+16|0;return g|0}function hea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=db-16|0;db=d;a:{c=x[b+4>>2];if(!c){break a}w[d>>1]=z[a+480190>>1];w[d+14>>1]=c-1;c=z[Uc(d,d+14|0)>>1];while(1){if(!c){break a}b:{if(eA(x[b>>2],c)){break b}if(TM(a,c&65535)){e=Tb(d,21204);zc(((c<<5)+a|0)+946304|0,e);tb(e)}if(c>>>0<2){break b}e=z[a+480190>>1];if((e|0)!=(c|0)){break b}w[a+480190>>1]=e-1}c=c-1|0;continue}}db=d+16|0}function LS(a,b){var c=0,d=0,e=0;c=db-32|0;db=c;a:{if(!y[b+5|0]){while(1){if((d|0)==5){d=0;v[c+28|0]=0;x[c+24>>2]=0;e=ec(c+8|0,c+24|0,5);lc(c+16|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=5){break b}if(cd(c+24|0,b,5)){break b}Zb(a,5);d=1}db=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17053,8977,413,13012);p()}_(17032,8977,411,13012);p()}return d}function FH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=db-32|0;db=d;e=Tb(d+8|0,c);x[23549]=0;S(1088,d+20|0,b|0,e|0);c=x[23549];x[23549]=0;a:{b:{if((c|0)!=1){x[23549]=0;a=O(1089,a|0,d+20|0)|0;c=x[23549];x[23549]=0;if((c|0)==1){break b}tb(d+20|0);tb(e);x[a>>2]=91568;c=x[b+4>>2];x[a+8>>2]=x[b>>2];x[a+12>>2]=c;db=d+32|0;return a|0}c=N()|0;break a}c=N()|0;tb(d+20|0)}tb(e);Q(c|0);p()}function s4(a,b){a=a|0;b=+b;var c=0;x[23549]=0;W(927,a|0);c=x[23549];x[23549]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[23549]=0;b=+Ta(1018,c|0,+b);c=x[23549];x[23549]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,7504,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();b=0}return+b}a=N()|0;x[23549]=0;X(17);c=x[23549];x[23549]=0;if((c|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Ofa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;$R(a,c+11|0);if((y[c+11|0]|y[c+12|0]<<8|(y[c+13|0]<<16|y[c+14|0]<<24))==1414807888){$R(a,c+11|0);v[b|0]=1;a=0}else{a=1}b=db-16|0;db=b;a:{b:{a=(c+11|0)+a|0;if(a){a=Tb(b+4|0,a);x[23549]=0;d=R(620,a|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break b}tb(a)}db=b+16|0;break a}b=N()|0;tb(a);Q(b|0);p()}db=c+16|0;return d|0}function l9(a,b){a=a|0;b=b|0;var c=E(0);a:{switch(b|0){case 0:return E(B[a+4220>>2]);case 1:return E(B[a+4224>>2]);case 2:return E(B[a+4228>>2]);case 3:return E(y[a+4240|0]?E(1):E(0));case 4:return E(E(E(x[a+4232>>2])*E(.03125)));case 5:return E(y[a+4241|0]?E(1):E(0));case 6:return E(y[a+4242|0]?E(1):E(0));case 7:c=y[a+4244|0]?E(1):E(0);break;default:break a}}return E(c)}function kA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=db-32|0;db=d;e=Nb(a);a=yb(x[b>>2]);x[d+28>>2]=a;b=yb(x[b+4>>2]);a:{while(1){if(Kb(a,b)){zi(d+8|0,x[a>>2],x[a+4>>2]);if(x[d+8>>2]==(c|0)){f=d+8|0;Go(f,a);x[23549]=0;P(344,e|0,f|0);a=x[23549];x[23549]=0;if((a|0)==1){break a}ub(d+8|0)}a=x[hk(d+28|0)>>2];continue}break}db=d+32|0;return}a=N()|0;ub(d+8|0);kd(e);Q(a|0);p()}function eL(a){var b=E(0),c=0,d=E(0);b=B[a+4224>>2];B[a+4260>>2]=M(E(E(1)-E(b*b)));v[a+4264|0]=B[a+4236>>2]>E(.5);d=E(A[a+4256>>2]);b=E(E(E(E(B[a+4228>>2]*E(1999))+E(1))/E(1e3))*d);a:{if(b<E(4294967296)&b>=E(0)){c=~~b>>>0;break a}c=0}x[a+4248>>2]=c;c=a+4252|0;b=E(E(E(E(B[a+4232>>2]*E(1999))+E(1))/E(1e3))*d);b:{if(b<E(4294967296)&b>=E(0)){a=~~b>>>0;break b}a=0}x[c>>2]=a}function My(a,b,c){var d=0,e=0,f=0;f=Gb(a);d=y[b+11|0];e=x[b+4>>2];a=0;x[23549]=0;P(47,f|0,Oc(e,d)|0);d=x[23549];x[23549]=0;if((d|0)!=1){a:{while(1){if(Oc(x[b+4>>2],y[b+11|0])>>>0>a>>>0){d=65533;e=v[uc(b,a)|0];if((e|0)>=-96){d=x[((e&255)<<2)+c>>2]}x[23549]=0;P(48,f|0,d|0);d=x[23549];x[23549]=0;if((d|0)==1){break a}a=a+1|0;continue}break}return}}a=N()|0;Ec(f);Q(a|0);p()}function m5(a){a=a|0;var b=0,c=0;x[23549]=0;W(927,a|0);b=x[23549];x[23549]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[23549]=0;b=R(994,b|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,7176,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();b=0}return b|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function lF(a,b,c,d,e){var f=0;f=db-16|0;db=f;a:{b:{c:{if(!d){a=ac(8);x[23549]=0;c=O(54,f+4|0,8098)|0;b=x[23549];x[23549]=0;if((b|0)==1){break c}a=pc(a,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Tk(a,b,e);c=hF(a,c,e,d,59536,60308);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);db=f+16|0;return c}b=N()|0;jc(a)}Q(b|0)}p()}function kF(a,b,c,d,e){var f=0;f=db-16|0;db=f;a:{b:{c:{if(!d){a=ac(8);x[23549]=0;c=O(54,f+4|0,8098)|0;b=x[23549];x[23549]=0;if((b|0)==1){break c}a=pc(a,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Tk(a,b,e);c=hF(a,c,e,d,58708,59480);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);db=f+16|0;return c}b=N()|0;jc(a)}Q(b|0)}p()}function eJ(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=db-16|0;db=c;a:{b:{c:{if(b<=0|b>4){a=ac(8);x[23549]=0;c=O(54,c+4|0,7752)|0;d=x[23549];x[23549]=0;if((d|0)==1){break c}a=pc(a,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}d=N()|0;tb(c);break b}a=x[a+32>>2];e=a,f=Le(65536/b),x[e+480244>>2]=f;Ip(a);db=c+16|0;return}d=N()|0;jc(a)}Q(d|0)}p()}function cJ(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=db-16|0;db=c;a:{b:{c:{if(b<=0|b>4){a=ac(8);x[23549]=0;c=O(54,c+4|0,7773)|0;d=x[23549];x[23549]=0;if((d|0)==1){break c}a=pc(a,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}d=N()|0;tb(c);break b}a=x[a+32>>2];e=a,f=Le(b*65536),x[e+480240>>2]=f;Ip(a);db=c+16|0;return}d=N()|0;jc(a)}Q(d|0)}p()}function Q3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=db-16|0;db=e;a:{if(!(c&1024)){break a}f=e,g=od(b),x[f+12>>2]=g;c=Oc(x[b+4>>2],y[b+11|0]);b:{if(!c){break b}if(y[uc(b,0)|0]!=(Zf(43)&255)){if(y[uc(b,0)|0]!=(Zf(45)&255)){break b}}d=d+1|0;QJ(e+12|0)}if(c>>>0>=d>>>0){break a}sx(b,x[vb(e+8|0,x[e+12>>2])>>2],d-Oc(x[b+4>>2],y[b+11|0])|0,Zf(48))}ad(a,b);db=e+16|0}function cm(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=db-16|0;db=h;if(2147483631-b>>>0>=c>>>0){j=Mb(a);i=h+4|0;if(b>>>0<=1073741798){x[h+12>>2]=b<<1;x[h+4>>2]=b+c;c=fk(x[Yc(h+4|0,h+12|0)>>2])+1|0}else{c=2147483631}yi(i,c);c=x[h+4>>2];if(e){We(c,j,e)}i=e+f|0;if((i|0)!=(d|0)){We((c+e|0)+g|0,(e+j|0)+f|0,d-i|0)}if((b|0)!=10){Eb(j)}zd(a,c);jg(a,x[h+8>>2]);db=h+16|0;return}kg();p()}function K9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=db-16|0;db=d;c=Hc(64);x[23549]=0;e=R(812,c|0)|0;f=x[23549];x[23549]=0;a:{if((f|0)!=1){c=of(d+8|0,e);e=x[c>>2];x[23549]=0;a=U(876,e|0,a|0,b|0)|0;b=x[23549];x[23549]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}xc(d+12|0);break b}a=N()|0;Lf(c);break a}Vf(d+12|0,c)}Lf(c);db=d+16|0;return x[d+12>>2]}a=N()|0;Eb(c)}Q(a|0);p()}function Ix(a){var b=E(0),c=E(0),d=0,e=E(0),f=0;b=E(A[x[a+16>>2]+24620>>2]);c=E(E(E(ib[x[x[a>>2]+204>>2]](a))*b)/E(1e3));d=a,e=E(E(c*E(ib[x[x[a>>2]+196>>2]](a)))*E(2048)),B[d+4248>>2]=e;d=a,f=Oh(E(E(c+E(2))*E(4096))),x[d+4256>>2]=f;c=E(ib[x[x[a>>2]+208>>2]](a));B[a+4252>>2]=c;b=E(c/b);if(!(ib[x[x[a>>2]+192>>2]](a)|0)){b=nL(E(b*E(3.1415927410125732)))}B[a+4244>>2]=b+b}function I3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;a:{b:{if((Lj(y[a+140|0])|0)!=1){break b}if((aK(a)|0)!=(b|0)){break b}d=a+120|0;ts(y[d+20|0]);b=db-16|0;db=b;x[b+12>>2]=c+15;a=db-16|0;db=a;e=x[14231];x[a+8>>2]=x[14230];x[a+12>>2]=e;e=x[14229];x[a>>2]=x[14228];x[a+4>>2]=e;ib[x[vp(a,Lj(y[d+20|0]))>>2]](b+12|0,d);db=a+16|0;db=b+16|0;break a}$J(a,1,b)}db=c+16|0}function z5(a){a=a|0;var b=0,c=0;x[23549]=0;W(927,a|0);b=x[23549];x[23549]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[23549]=0;c=+ja(985,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[23549]=0;V(914,7576,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function TI(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[23549]=0;c=O(54,c+4|0,10589)|0;a=x[23549];x[23549]=0;if((a|0)==1){break c}a=pc(b,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=x[a+32>>2]+D(b,872)|0;x[a+1075008>>2]=0;x[a+1075068>>2]=0;db=c+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function Mi(a,b,c,d,e){var f=0,g=0,h=0;f=db-16|0;db=f;x[f+12>>2]=b;b=0;g=6;a:{b:{if(Jh(a,f+12|0)){break b}g=4;h=Kk(x[a>>2]);if(!Jk(d,64,h)){break b}b=mn(d,h);while(1){c:{b=b-48|0;h=yn(a);if(Jh(h,f+12|0)|(e|0)<2){break c}g=Kk(x[h>>2]);if(!Jk(d,64,g)){break a}e=e-1|0;b=mn(d,g)+D(b,10)|0;continue}break}g=2;if(!Jh(h,f+12|0)){break a}}x[c>>2]=x[c>>2]|g}db=f+16|0;return b}function mQ(a,b){var c=0,d=0,e=0;c=db-16|0;db=c;d=Gb(a);a=y[b+11|0];e=x[b+4>>2];x[23549]=0;P(45,d|0,Oc(e,a)|0);a=x[23549];x[23549]=0;a:{if((a|0)!=1){a=od(b);x[c+12>>2]=a;b=tf(b);while(1){if(!Kb(a,b)){break a}a=y[a|0];x[23549]=0;P(46,d|0,((a|0)==13?10:a)<<24>>24);a=x[23549];x[23549]=0;if((a|0)!=1){a=x[Oe(c+12|0)>>2];continue}break}}a=N()|0;tb(d);Q(a|0);p()}db=c+16|0}function Wl(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return v[a+71744|0]}if(a>>>0<=511){return v[(a>>>5|0)+71744|0]+5|0}return v[(a>>>10|0)+71744|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return v[(a>>>15|0)+71744|0]+15|0}return v[(a>>>20|0)+71744|0]+20|0}if(a>>>0<=536870911){return v[(a>>>25|0)+71744|0]+25|0}a=v[(a>>>30|0)+71744|0]+30|0}else{a=0}return a}function r3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=db-16|0;db=e;a:{if(!(c&1024)){break a}f=e,g=od(b),x[f+12>>2]=g;c=Oc(x[b+4>>2],y[b+11|0]);b:{if(!c){break b}if(y[Mb(b)|0]!=(Zf(43)&255)){if(y[Mb(b)|0]!=(Zf(45)&255)){break b}}d=d+1|0;QJ(e+12|0)}if(c>>>0>=d>>>0){break a}zJ(b,x[vb(e+8|0,x[e+12>>2])>>2],d-Oc(x[b+4>>2],y[b+11|0])|0,Zf(48))}ad(a,b);db=e+16|0}function l5(a){a=a|0;var b=0,c=0,d=0;b=db-16|0;db=b;a:{c=x[a+36>>2];d=x[a+40>>2];b:{if(Kb(c,d)){xc(b+12|0);break b}Nn(b,a);x[23549]=0;c=R(986,b|0)|0;d=x[23549];x[23549]=0;if((d|0)==1){break a}x[b+12>>2]=c;Yf(b);d=x[a+40>>2];c=x[a+36>>2]}c:{if(Kb(c,d)){a=a+36|0;break c}a=x[b+12>>2];c=x[a>>2]}a=Mn(c,x[a+4>>2]);Qk(b+12|0);db=b+16|0;return a|0}a=N()|0;Yf(b);Q(a|0);p()}function Tr(a,b,c,d){var e=0,f=0,g=0,h=0;e=db-160|0;db=e;g=b?a:e+158|0;x[e+148>>2]=g;a=b-1|0;x[e+152>>2]=a>>>0<=b>>>0?a:0;while(1){v[e+h|0]=0;a=h+1|0;f=a?f:f+1|0;h=a;if(!f&a>>>0<144){continue}break}a=-1;x[e+76>>2]=-1;x[e+36>>2]=1098;x[e+80>>2]=-1;x[e+44>>2]=e+159;x[e+84>>2]=e+148;a:{if((b|0)<0){x[23424]=61;break a}v[g|0]=0;a=iI(e,c,d,1073,1074)}db=e+160|0;return a}function PI(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[23549]=0;c=O(54,c+4|0,10589)|0;a=x[23549];x[23549]=0;if((a|0)==1){break c}a=pc(b,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}db=c+16|0;return+(+(x[(x[a+32>>2]+D(b,872)|0)+1075684>>2]-128|0)*.0078125)}a=N()|0;jc(b)}Q(a|0)}p()}function qg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(!ue(y[b+11|0])){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}c=a;f=x[b>>2];e=db-16|0;db=e;a:{b:{d=x[b+4>>2];c:{if(Do(d)){ff(c,d);break c}if(d>>>0>=2147483632){break b}yi(e+8|0,fk(d)+1|0);b=x[e+8>>2];zd(c,b);jg(c,x[e+12>>2]);re(c,d);c=b}We(c,f,d+1|0);db=e+16|0;break a}kg();p()}return a|0}function Nr(a,b,c){var d=0,e=0;if(c&2048){v[a|0]=43;a=a+1|0}if(c&1024){v[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){v[a|0]=46;v[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}v[a|0]=b;return(d|0)!=260}function NI(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[23549]=0;c=O(54,c+4|0,10589)|0;a=x[23549];x[23549]=0;if((a|0)==1){break c}a=pc(b,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}db=c+16|0;return+(+w[(x[a+32>>2]+D(b,872)|0)+1075766>>1]*30517578125e-15)}a=N()|0;jc(b)}Q(a|0)}p()}function n8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ni(a,b,c,d);x[a>>2]=45596;b=a+4208|0;e=xb(b,0),f=1060320051,x[e>>2]=f;e=xb(b,1),f=1041865114,x[e>>2]=f;e=xb(b,2),f=1065353216,x[e>>2]=f;e=xb(b,3),f=1049951732,x[e>>2]=f;e=xb(b,4),f=1049951732,x[e>>2]=f;x[23549]=0;P(878,a+44|0,2);b=x[23549];x[23549]=0;if((b|0)!=1){mi(a);return a|0}b=N()|0;yf(a);Q(b|0);p()}function i$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a:{if(!ue(y[f+11|0])){b=x[f+4>>2];x[a>>2]=x[f>>2];x[a+4>>2]=b;x[a+8>>2]=x[f+8>>2];break a}e=x[f>>2];d=db-16|0;db=d;b:{c:{c=x[f+4>>2];d:{if(qp(c)){ff(a,c);break d}if(c>>>0>=1073741808){break c}hj(d+8|0,Ql(c)+1|0);b=x[d+8>>2];zd(a,b);jg(a,x[d+12>>2]);re(a,c);a=b}gi(a,e,c+1|0);db=d+16|0;break b}kg();p()}}}function ria(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=db-16|0;db=f;c=jf(a,c);ae(f,x[a+28>>2]);a:{b:{if(!c){d=-1;if(!ed(a,5)){break b}break a}d=x[c+8>>2]}e=x[a+28>>2];c:{d:{switch(d+1|0){case 0:case 2:d=db-32|0;db=d;v[d+31|0]=0;Jj(d+8|0,d+31|0);vn(d+20|0,e,x[d+8>>2],x[d+12>>2]);v[b|0]=y[d+31|0];db=d+32|0;break c;default:break d}}aU(e,b,d)}e=c}cf(a,e);db=f+16|0}function WL(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0);c=db-16|0;db=c;d=0;a:{if(x[(x[x[a>>2]-12>>2]+a|0)+16>>2]){break a}x[c+12>>2]=0;ak(a,c+12|0);e=x[c+12>>2];d=0;if(e>>>0>65535){break a}Yk(b,e);while(1){if((f|0)==(e|0)){d=!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]}else{x[c+8>>2]=0;Bp(a,c+8|0);g=xb(x[b>>2],f),h=B[c+8>>2],B[g>>2]=h;f=f+1|0;continue}break}}a=d;db=c+16|0;return a}function MM(a,b){var c=0,d=0,e=0,f=0;a:{if(z[a+480188>>1]<=b>>>0){break a}b:{c:{c=D(b,872)+a|0;d=y[c+1075783|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(y[a+480209|0]&16)){break a}}e=a+1074376|0;f=(d|0)==32;c=v[c+1075785|0];d:{if((c|0)>=0){d=te(a+901692|0,y[(D(b,872)+a|0)+1075836|0]);break d}d=te(a+902204|0,c&127)}gO(a,e,b,f,d,c&255)}}function co(a,b,c,d){a:{if(x[a+480180>>2]==4){if(c){v[b+810|0]=y[b+810|0]&15|c<<4;break a}c=y[b+810|0]>>>4|0;break a}if(d){if(c){v[b+834|0]=c;break a}c=y[b+834|0];break a}if(c){v[b+810|0]=c;break a}c=y[b+810|0]}b:{if(!(v[b+851|0]&1)){break b}c=x[b+688>>2]+((c&255)<<2)|0;x[b+688>>2]=(c|0)>=256?256:c;if(!(v[a+480180|0]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function aJ(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=db-16|0;db=c;a:{b:{c:{if(b<0|b>1){a=ac(8);x[23549]=0;c=O(54,c+4|0,11610)|0;d=x[23549];x[23549]=0;if((d|0)==1){break c}a=pc(a,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}d=N()|0;tb(c);break b}e=x[a+32>>2]+1074456|0,f=Le(b*256),x[e>>2]=f;db=c+16|0;return}d=N()|0;jc(a)}Q(d|0)}p()}function SR(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28486832|y[a+63|0]!=26){break a}b=y[a+65|0];if(y[a+66|0]|(b|0)!=16&(b|0)!=1|(y[a+64|0]&3|(y[a+78|0]|y[a+79|0]<<8)>>>0>127)){break a}if((y[a+80|0]|y[a+81|0]<<8)>>>0>127){break a}b=a+80|0;a=a+78|0;a=Cl(y[a|0]|y[a+1|0]<<8,y[b|0]|y[b+1|0]<<8)?b:a;c=(y[a|0]|y[a+1|0]<<8)!=0}return c}function PR(a){var b=0;a:{if((y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1179472976|y[a+28|0]!=26|(y[a+40|0]|y[a+41|0]<<8|y[a+30|0]>2)){break a}if(((y[a+38|0]|y[a+39|0]<<8)-33&65535)>>>0<65504|((y[a+32|0]|y[a+33|0]<<8)-257&65535)>>>0<65280|((y[a+34|0]|y[a+35|0]<<8)-256&65535)>>>0<65281){break a}b=((y[a+36|0]|y[a+37|0]<<8)-1&65535)>>>0<128}return b}function lM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if((a|0)!=(b|0)){d=db-16|0;db=d;c=x[b>>2];b=x[b+4>>2];e=ne(c,b);a:{if(e>>>0<=Qh(a)>>>0){f=b;g=x[a>>2];h=oc(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=c;hT(d+12|0,h);f=x[d+12>>2]}c=_g(c,f,g);if(!i){Ss(a,f,b,e-oc(x[a>>2],x[a+4>>2])|0);break a}Dd(a,c);break a}$t(a);Hm(a,eg(a,e));Ss(a,c,b,e)}db=d+16|0}return a}function A_(a){a=a|0;if(y[467792]){return x[116947]}if(!y[468312]){v[468312]=1}ld(468144,87716);ld(468156,87744);ld(468168,87772);ld(468180,87804);ld(468192,87844);ld(468204,87880);ld(468216,87908);ld(468228,87944);ld(468240,87960);ld(468252,87976);ld(468264,87992);ld(468276,88008);ld(468288,88024);ld(468300,88040);v[467792]=1;x[116947]=468144;return 468144}function mga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=db-1120|0;db=d;c=db-16|0;db=c;mS(c+8|0,d+12|0);e=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){dd(a,x[c+12>>2])}db=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!oS(d+12|0)){break a}c=Ge(a,b,nS(y[d+1116|0]|y[d+1117|0]<<8|(y[d+1118|0]<<16|y[d+1119|0]<<24)),hb)}db=d+1120|0;return c|0}function M2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=db-16|0;db=d;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(!c){break a}x[23549]=0;P(1062,a|0,c|0);e=x[23549];x[23549]=0;if((e|0)!=1){x[23549]=0;V(1063,a|0,b|0,$d(b,c)|0,c|0);b=x[23549];x[23549]=0;if((b|0)!=1){break a}}a=N()|0;pJ(d+8|0);Q(a|0);p()}b=d+8|0;Hd(b);pJ(b);db=d+16|0;return a|0}function RV(a,b){var c=0,d=0;b=!x[a+24>>2]|b;x[a+16>>2]=b;if(b&x[a+20>>2]){a=db-16|0;db=a;c=ac(16);b=db-16|0;db=b;if(!y[464256]){v[464256]=1}ec(b+8|0,1,93380);d=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=d;db=b+16|0;b=x[a+12>>2];a=x[a+8>>2];x[23549]=0;a=CF(1090,c,8841,a,b);b=x[23549];x[23549]=0;if((b|0)!=1){da(a|0,77196,1091);p()}a=N()|0;jc(c);Q(a|0);p()}}function _G(a,b,c,d){var e=0,f=0,g=0;e=db-16|0;db=e;a:{if((a|0)!=(b|0)){g=x[23424];x[23424]=0;yd();a=$G(a,e+12|0,d);d=hb;f=x[23424];b:{if(f){if(x[e+12>>2]!=(b|0)){break b}if((f|0)!=68){break a}x[c>>2]=4;b=!!a&(d|0)>=0|(d|0)>0;a=b?-1:0;d=b?2147483647:-2147483648;break a}x[23424]=g;if(x[e+12>>2]==(b|0)){break a}}}x[c>>2]=4;a=0;d=0}db=e+16|0;hb=d;return a}function C6(a){a=a|0;var b=0;x[23549]=0;W(927,a|0);b=x[23549];x[23549]=0;if((b|0)!=1){b=x[a+24>>2];if(b){Eb(Cs(b))}x[a+24>>2]=0;b=x[a+20>>2];if(b){Eb(b);x[a+20>>2]=0}Eb(a);return}Y(T(0)|0)|0;x[23549]=0;V(914,5019,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function xy(a,b,c,d,e,f){var g=0,h=0,i=0;g=db-16|0;db=g;if(2147483631-b>>>0>=c>>>0){h=Mb(a);i=g+4|0;if(b>>>0<=1073741798){x[g+12>>2]=b<<1;x[g+4>>2]=b+c;c=fk(x[Yc(g+4|0,g+12|0)>>2])+1|0}else{c=2147483631}yi(i,c);c=x[g+4>>2];if(e){We(c,h,e)}if((d|0)!=(e|0)){We((c+e|0)+f|0,e+h|0,d-e|0)}if((b|0)!=10){Eb(h)}zd(a,c);jg(a,x[g+8>>2]);db=g+16|0;return}kg();p()}function gF(a,b,c){var d=0;d=db-16|0;db=d;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[23549]=0;c=O(54,d+4|0,10589)|0;a=x[23549];x[23549]=0;if((a|0)==1){break c}a=pc(b,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=(x[a+32>>2]+D(b,872)|0)+1075080|0;x[a>>2]=x[a>>2]|c;db=d+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function fJ(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;a:{b:{c:{if(b-513>>>0<=4294966814){b=ac(8);x[23549]=0;c=O(54,c+4|0,9261)|0;a=x[23549];x[23549]=0;if((a|0)==1){break c}a=pc(b,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}x[x[a+32>>2]+1074420>>2]=D(b,1e4);db=c+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function Ky(a,b,c,d){a:{if(x[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=D(b,872)+a|0;x[c+1075688>>2]=0;d=c+1075e3|0;x[d>>2]=0;x[d+4>>2]=0;c=x[c+1075080>>2]|4096;break b}c=D(b,872)+a|0;x[c+1075680>>2]=0;c=x[c+1075080>>2]}d=D(b,872)+a|0;x[d+1075080>>2]=c|2097152;fm(a,b,255,0);if(!(y[d+1075081|0]&2)){break a}a=x[a+1298300>>2];if(!ud(a)){break a}aj(a,b,0)}}function p4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Gb(a);c=y[b+11|0];e=x[b+4>>2];a=0;x[23549]=0;P(72,d|0,Oc(e,c)|0);c=x[23549];x[23549]=0;if((c|0)!=1){a:{b:{while(1){if(Oc(x[b+4>>2],y[b+11|0])>>>0<=a>>>0){break b}c=v[uc(b,a)|0];x[23549]=0;P(50,d|0,Zf(c)|0);c=x[23549];x[23549]=0;if((c|0)!=1){a=a+1|0;continue}break}break a}return}}a=N()|0;tb(d);Q(a|0);p()}function y6(a,b){a=a|0;b=b|0;var c=0;x[23549]=0;W(927,a|0);c=x[23549];x[23549]=0;a:{b:{if((c|0)!=1){x[a+16>>2]=b;b=x[a+20>>2];if(!b){break b}Eb(b);x[a+20>>2]=0;return}Y(T(0)|0)|0;x[23549]=0;V(914,5601,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z()}return}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function vba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[a>>2]=b;c=db-16|0;db=c;d=Hc(223888);x[23549]=0;b=O(779,d|0,b+1074376|0)|0;e=x[23549];x[23549]=0;a:{if((e|0)!=1){b=x[of(c+12|0,b)>>2];db=c+16|0;break a}a=N()|0;Eb(d);Q(a|0);p()}x[a+4>>2]=b;b=Nb(a+8|0);x[23549]=0;W(548,a|0);c=x[23549];x[23549]=0;if((c|0)!=1){return a|0}c=N()|0;oe(b);XN(a+4|0);Q(c|0);p()}function uG(a,b,c,d,e){var f=0,g=0,h=0;f=db-16|0;db=f;if(1073741807-b>>>0>=c>>>0){h=Mb(a);g=f+4|0;if(b>>>0<=536870886){x[f+12>>2]=b<<1;x[f+4>>2]=b+c;c=Ql(x[Yc(f+4|0,f+12|0)>>2])+1|0}else{c=1073741807}hj(g,c);c=x[f+4>>2];if(e){gi(c,h,e)}if((d|0)!=(e|0)){g=e<<2;gi(c+g|0,h+g|0,d-e|0)}if((b|0)!=1){Eb(h)}zd(a,c);jg(a,x[f+8>>2]);db=f+16|0;return}kg();p()}function np(a,b,c){var d=0,e=0,f=0;d=db-16|0;db=d;Nc(d+12|0,b);x[23549]=0;b=R(1116,x[d+12>>2])|0;e=x[23549];x[23549]=0;a:{if((e|0)==1){break a}x[23549]=0;e=R(1124,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break a}x[c>>2]=e;x[23549]=0;P(1125,a|0,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Xb(d+12|0);db=d+16|0;return}a=N()|0;Xb(d+12|0);Q(a|0);p()}function M0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=x[a+84>>2];f=x[e>>2];d=x[e+4>>2];h=x[a+28>>2];g=x[a+20>>2]-h|0;g=d>>>0<g>>>0?d:g;if(g){rc(f,h,g);f=g+x[e>>2]|0;x[e>>2]=f;d=x[e+4>>2]-g|0;x[e+4>>2]=d}d=c>>>0>d>>>0?d:c;if(d){rc(f,b,d);f=d+x[e>>2]|0;x[e>>2]=f;x[e+4>>2]=x[e+4>>2]-d}v[f|0]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;return c|0}function pp(a,b,c){var d=0,e=0,f=0;d=db-16|0;db=d;Nc(d+12|0,b);x[23549]=0;b=R(1099,x[d+12>>2])|0;e=x[23549];x[23549]=0;a:{if((e|0)==1){break a}x[23549]=0;e=R(1111,b|0)|0;f=x[23549];x[23549]=0;if((f|0)==1){break a}v[c|0]=e;x[23549]=0;P(1112,a|0,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Xb(d+12|0);db=d+16|0;return}a=N()|0;Xb(d+12|0);Q(a|0);p()}function bja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=db-576|0;db=d;c=db-16|0;db=c;yU(c+8|0,d);e=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){dd(a,x[c+12>>2])}db=c+16|0;e=(e|0)==(f|0);if(!e){xU(d)}c=-1;a:{if(!e){break a}c=0;if(!AU(d)){break a}c=Ge(a,b,zU(y[d+34|0]|y[d+35|0]<<8,y[d+36|0]|y[d+37|0]<<8),hb)}db=d+576|0;return c|0}function $7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;b=vL(a,b,c,d,e^1);x[b>>2]=46196;a=b+4208|0;f=xb(a,0),g=1056964608,x[f>>2]=g;f=xb(a,1),g=1065353216,x[f>>2]=g;f=xb(a,2),g=1020054733,x[f>>2]=g;f=xb(a,3),g=1065353216,x[f>>2]=g;f=xb(a,4),g=1056964608,x[f>>2]=g;f=xb(a,5),g=1048406533,x[f>>2]=g;f=xb(a,6),g=1056964608,x[f>>2]=g;return b|0}function m_(a){a=a|0;if(y[467784]){return x[116945]}if(!y[468136]){v[468136]=1}Wc(467968,5181);Wc(467980,5188);Wc(467992,5154);Wc(468004,5162);Wc(468016,5145);Wc(468028,5195);Wc(468040,5172);Wc(468052,9641);Wc(468064,9847);Wc(468076,11152);Wc(468088,12720);Wc(468100,5444);Wc(468112,10647);Wc(468124,6528);v[467784]=1;x[116945]=467968;return 467968}function rM(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1163089229){break a}b=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);if((b|0)!=-1095062050&(b|0)!=-1346458146){break a}b=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);if(!b){break a}c=(b+24|0)==(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))}return c}function gJ(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;a:{b:{c:{if(b-65536>>>0<=4294901760){b=ac(8);x[23549]=0;c=O(54,c+4|0,5789)|0;a=x[23549];x[23549]=0;if((a|0)==1){break c}a=pc(b,c);x[23549]=0;S(105,a|0,61816,931);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}x[x[a+32>>2]+1074416>>2]=b;db=c+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function fD(a,b,c){var d=0,e=0,f=0,g=0;a:{d=he(b,od(a));b=he(c,b);if(Bb(x[a+4>>2],y[a+11|0])>>>0>=d>>>0){if((b|0)==-1){QT(a,d);break a}e=db-16|0;db=e;x[e+12>>2]=b;if(b){f=Bb(x[a+4>>2],y[a+11|0]);g=Mb(a);c=f-d|0;x[e+8>>2]=c;b=x[Cb(e+12|0,e+8|0)>>2];b:{if((c|0)==(b|0)){b=c;break b}d=d+g|0;pl(d,b+d|0,c-b|0)}SA(a,g,f-b|0)}db=e+16|0;break a}mq();p()}}function bo(a,b,c,d){a:{if(x[a+480180>>2]==4){d=y[b+810|0];if(c){v[b+810|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){v[b+834|0]=c;break a}c=y[b+834|0];break a}if(c){v[b+810|0]=c;break a}c=y[b+810|0]}b:{if(!(v[b+851|0]&1)){break b}c=x[b+688>>2]-((c&255)<<2)|0;x[b+688>>2]=(c|0)>0?c:0;if(!(v[a+480180|0]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function iw(a,b,c,d){v[a+53|0]=1;a:{if(x[a+4>>2]!=(c|0)){break a}v[a+52|0]=1;c=x[a+16>>2];b:{if(!c){x[a+36>>2]=1;x[a+24>>2]=d;x[a+16>>2]=b;if((d|0)!=1){break a}if(x[a+48>>2]==1){break b}break a}if((b|0)==(c|0)){c=x[a+24>>2];if((c|0)==2){x[a+24>>2]=d;c=d}if(x[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}x[a+36>>2]=x[a+36>>2]+1}v[a+54|0]=1}}function Ou(a,b,c,d){var e=0,f=0;a:{e=y[a|0];f=y[c|0];b:{if(!(y[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){v[a|0]=(f|0)==5?7:6;break b}if(!(y[b|0]|((f|0)!=11|(e-5&255)>>>0>1))){v[a|0]=(e|0)==5?7:6;v[b|0]=y[d|0];break b}if(!((e|0)!=10|(f|0)!=20|y[d|0]!=159)){v[a|0]=42;break b}if((f|0)!=10|(e|0)!=20|y[b|0]!=159){break a}v[a|0]=42;v[b|0]=y[d|0]}v[c|0]=0}}function xk(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=db-16|0;db=f;x[f+8>>2]=a;x[f+12>>2]=b;h=x[a+8>>2]+120|0;ts(y[h+20|0]);g=db-16|0;db=g;x[g+12>>2]=f+8;e=db-16|0;db=e;i=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=i;d=x[c+4>>2];x[e>>2]=x[c>>2];x[e+4>>2]=d;ib[x[vp(e,Lj(y[h+20|0]))>>2]](g+12|0,h);db=e+16|0;db=g+16|0;x[a+4>>2]=x[a+4>>2]+x[b+8>>2];db=f+16|0}function vf(a,b,c,d){var e=0,f=0,g=0;a:{if(!Bb(x[a+4>>2],y[a+11|0])|(c-b|0)<5){break a}Qr(b,c);e=c-4|0;c=Mb(a);g=c+Bb(x[a+4>>2],y[a+11|0])|0;b:{while(1){c:{a=v[c|0];f=a-127|0;if(b>>>0>=e>>>0){break c}if((a|0)!=x[b>>2]&(f&255)>>>0>=130){break b}b=b+4|0;c=((g-c|0)>1)+c|0;continue}break}if((f&255)>>>0<130|a>>>0>x[e>>2]-1>>>0){break a}}x[d>>2]=4}}function sJ(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=x[a>>2];b:{if(!b){break b}c=x[a+8>>2];if(!c){break b}d=x[a+12>>2];if(!d){break b}a=ib[d|0](b)|0;e=hb;if((e|0)<0){break b}if((ib[c|0](b,0,0,0)|0)<0){break a}if((ib[c|0](b,0,0,2)|0)<0){break a}d=ib[d|0](b)|0;f=hb;ib[c|0](b,a,e,0)|0;if((f|0)<0){break b}g=ez(d,f)}return g}ib[c|0](b,a,e,0)|0;return 0}function kja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=db-112|0;db=d;c=db-16|0;db=c;f=d+14|0;PU(c+8|0,f);e=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){dd(a,x[c+12>>2])}db=c+16|0;e=(e|0)==(g|0);if(!e){OU(f)}c=-1;a:{if(!e){break a}c=0;if(!RU(d+14|0)){break a}c=Ge(a,b,QU(y[d+61|0]|y[d+62|0]<<8),hb)}db=d+112|0;return c|0}function GW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=db-32|0;db=e;Uu(e+8|0,c);c=y[d|0];x[23549]=0;P(232,e+20|0,c|0);c=x[23549];x[23549]=0;b:{c:{if((c|0)!=1){Il(e,e+8|0);x[23549]=0;V(100,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[23549];x[23549]=0;if((a|0)==1){break c}Ah(e+8|0);db=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;Ah(e+8|0)}Q(a|0);p()}}function Xaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=db-16|0;db=b;w[a>>1]=0;c=Nb(a+4|0);d=Nb(a+16|0);x[a+36>>2]=0;e=Gb(a+40|0);f=ig(a+52|0);Dc(c);w[a+28>>1]=65472;x[23549]=0;x[b+12>>2]=1065353216;P(816,c|0,b+12|0);g=x[23549];x[23549]=0;if((g|0)!=1){x[a+32>>2]=0;w[a+30>>1]=0;Dc(d);db=b+16|0;return a|0}a=N()|0;fU(f);tb(e);sc(d);sc(c);Q(a|0);p()}function aZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=db+-64|0;db=d;e=1;a:{if(Kg(a,b,0)){break a}e=0;if(!b){break a}b=Py(b,91904,91952);e=0;if(!b){break a}Vb(d+12|0,0,52);x[d+56>>2]=1;x[d+20>>2]=-1;x[d+16>>2]=a;x[d+8>>2]=b;ib[x[x[b>>2]+28>>2]](b,d+8|0,x[c>>2],1);a=x[d+32>>2];if((a|0)==1){x[c>>2]=x[d+24>>2]}e=(a|0)==1}a=e;db=d- -64|0;return a|0}function ZW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=db-512|0;db=d;c=db-16|0;db=c;f=d+15|0;SC(c+8|0,f);e=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){dd(a,x[c+12>>2])}db=c+16|0;e=(e|0)==(g|0);if(!e){RC(f)}c=-1;a:{if(!e){break a}c=0;if(!VC(d+15|0)){break a}c=Ge(a,b,UC(y[d+125|0],y[d+126|0]),hb)}db=d+512|0;return c|0}function B6(a){a=a|0;var b=0;x[23549]=0;W(927,a|0);b=x[23549];x[23549]=0;a:{b:{if((b|0)!=1){x[a+16>>2]=0;b=x[a+20>>2];if(!b){break b}Eb(b);x[a+20>>2]=0;return}Y(T(0)|0)|0;x[23549]=0;V(914,8814,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z()}return}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function z6(a){a=a|0;var b=0;x[23549]=0;W(927,a|0);b=x[23549];x[23549]=0;a:{b:{if((b|0)!=1){a=x[a+20>>2];if(!a){break b}return _f(a)|0}Y(T(0)|0)|0;x[23549]=0;V(914,12033,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();return 0}return _f(21204)|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function zj(a,b){a:{if((b|0)>=1024){a=a*898846567431158e293;if(b>>>0<2047){b=b-1023|0;break a}a=a*898846567431158e293;b=((b|0)>=3069?3069:b)-2046|0;break a}if((b|0)>-1023){break a}a=a*2004168360008973e-307;if(b>>>0>4294965304){b=b+969|0;break a}a=a*2004168360008973e-307;b=((b|0)<=-2960?-2960:b)+1938|0}l(0,0);l(1,b+1023<<20);return a*+n()}function gE(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1129474426|(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))!=1634291279|(y[a+8|0]|y[a+9|0]<<8)!=14|(!(y[a+12|0]|y[a+13|0]<<8)|(y[a+14|0]|y[a+15|0]<<8|(y[a+16|0]<<16|y[a+17|0]<<24))<=0))){b=(y[a+18|0]|y[a+19|0]<<8|(y[a+20|0]<<16|y[a+21|0]<<24))>>>0>23}return b}function SX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=db-16|0;db=d;x[d>>2]=b;x[d+4>>2]=c;x[d+8>>2]=b;x[d+12>>2]=c;c=db-16|0;db=c;f=db-16|0;db=f;b=f+4|0;x[b+4>>2]=1;h=b,i=Hc(24),x[h+8>>2]=i;e=Zo(x[b+8>>2]);x[e>>2]=61284;YD(kc(e),x[d>>2],x[d+4>>2]);e=c+8|0;g=$o(b);_o(e,kc(g),g);_m(b);db=f+16|0;rg(a,e);fe(e);db=c+16|0;db=d+16|0}function Bt(a,b){var c=0,d=0;if(a-268435457>>>0>=4026531840){a=a+208|0;c=D(a,b);yka(b,0,a,0);a=hb?0:c}else{a=0}a:{if(!a){break a}x[23549]=0;b=R(722,a|0)|0;c=x[23549];x[23549]=0;b:{c:{if((c|0)==1){Y(T(0)|0)|0;x[23549]=0;X(17);c=x[23549];x[23549]=0;b=0;if((c|0)==1){break c}}break b}T(0)|0;Rb();p()}if(!b){break a}d=Vb(b,0,a)- -64|0}return d}function AO(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=db-16|0;db=f;i=x[d+20>>2];h=x[d+52>>2];g=!h|e;v[f+15|0]=g;a:{if(!g|(b|0)!=2){break a}g=c&65535;c=0;while(1){if((c|0)==(g|0)){break a}x[(D(c,872)+d|0)+1380>>2]=0;c=c+1|0;continue}}x[d+24>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d+48>>2]=h;w[d+72>>1]=z[d+74>>1];st(a,i>>>0>1&e&(b|0)==1,f+15|0);db=f+16|0}function rz(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function gm(a,b,c){var d=0,e=0,f=0;e=Gb(a);d=y[b+11|0];f=x[b+4>>2];a=0;x[23549]=0;P(47,e|0,Oc(f,d)|0);d=x[23549];x[23549]=0;if((d|0)!=1){a:{while(1){if(Oc(x[b+4>>2],y[b+11|0])>>>0>a>>>0){d=x[(y[uc(b,a)|0]<<2)+c>>2];x[23549]=0;P(48,e|0,d|0);d=x[23549];x[23549]=0;if((d|0)==1){break a}a=a+1|0;continue}break}return}}a=N()|0;Ec(e);Q(a|0);p()}function KZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}f=1;g=db-16|0;db=g;k=ei(g+12|0,x[a+8>>2]);i=Vr(0,c,d-c|0,b?b:467500);di(k);db=g+16|0;b:{switch(i+2|0){default:f=i;break;case 0:case 1:break a;case 2:break b}}h=h+1|0;j=f+j|0;c=c+f|0;continue}break}return j|0}function Dha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;c=xb(b,c);d=db-16|0;db=d;e=ne(b,c);a:{if(e>>>0<=Qh(a)>>>0){f=c;g=x[a>>2];h=oc(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=b;hT(d+12|0,h);f=x[d+12>>2]}b=_g(b,f,g);if(!i){gT(a,f,c,e-oc(x[a>>2],x[a+4>>2])|0);break a}Dd(a,b);break a}$t(a);Hm(a,eg(a,e));gT(a,b,c,e)}db=d+16|0}function xH(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=db-16|0;db=b;e=b+16|0;a:{while(1){d=x[a+36>>2];c=b+8|0;f=ib[x[x[d>>2]+20>>2]](d,x[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=x[b+4>>2]-c|0;if((dk(g,1,c,x[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=Es(x[a+32>>2])?-1:0}db=b+16|0;return d|0}function e5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;x[23549]=0;W(927,a|0);f=x[23549];x[23549]=0;if((f|0)!=1){return Bx(x[x[a+24>>2]+24>>2],b,c,d,e)|0}Y(T(0)|0)|0;x[23549]=0;V(914,12276,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function CX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=db-32|0;db=e;f=x[b+16>>2];a:{if(f>>>0<=c>>>0){dc(a,x[d>>2],0);break a}g=x[b+12>>2];b=x[b+4>>2];x[e+20>>2]=x[d+4>>2];x[e+16>>2]=f-c;dc(e+24|0,x[d>>2],x[Cb(e+20|0,e+16|0)>>2]);d=x[x[b>>2]+28>>2];f=x[e+28>>2];x[e+8>>2]=x[e+24>>2];x[e+12>>2]=f;ib[d|0](a,b,c+g|0,e+8|0)}db=e+32|0}function CG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=db-16|0;db=d;i=x[b>>2];h=x[a>>2];e=x[gc(a)>>2]==1136;f=x[c>>2];g=f-h|0;f=g>>>0>=2147483647?-1:(h|0)==(f|0)?4:g<<1;g=Qt(e?0:h,f);if(g){if(!e){Zd(a)}x[d+4>>2]=1103;e=pe(d+8|0,g,d+4|0);a=yG(a,e);Kc(e);x[b>>2]=x[a>>2]+(i-h|0);x[c>>2]=x[a>>2]+(f&-4);db=d+16|0;return}Bw();p()}function $2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=db-16|0;db=e;g=x[d+4>>2];mx(b,c,g);f=x[b+16>>2];a:{if(f>>>0<=c>>>0){dc(a,x[d>>2],0);break a}x[e+12>>2]=f-c;x[e+8>>2]=g;d=x[d>>2];f=x[Cb(e+12|0,e+8|0)>>2];yq(e,d,g,0,f);h=x[e>>2];i=x[e+4>>2];qu(Ie(yb(x[b+4>>2]),c),Ie(Ie(yb(x[b+4>>2]),c),i),h);yq(a,d,g,0,f)}db=e+16|0}function jha(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(!b){break a}x[23549]=0;P(533,a|0,b|0);d=x[23549];x[23549]=0;if((d|0)!=1){x[23549]=0;P(534,a|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){break a}}a=N()|0;ZS(c+8|0);Q(a|0);p()}b=c+8|0;Hd(b);ZS(b);db=c+16|0;return a|0}function a1(a){a=a|0;a:{x[23549]=0;R(1093,466520)|0;a=x[23549];x[23549]=0;b:{if((a|0)==1){break b}x[23549]=0;R(1093,466856)|0;a=x[23549];x[23549]=0;if((a|0)==1){break b}x[23549]=0;R(1094,466604)|0;a=x[23549];x[23549]=0;if((a|0)==1){break b}x[23549]=0;R(1094,466940)|0;a=x[23549];x[23549]=0;if((a|0)==1){break b}break a}T(0)|0;Rb();p()}}function QW(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(!b){break a}x[23549]=0;P(215,a|0,b|0);d=x[23549];x[23549]=0;if((d|0)!=1){x[23549]=0;P(216,a|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){break a}}a=N()|0;zC(c+8|0);Q(a|0);p()}b=c+8|0;Hd(b);zC(b);db=c+16|0;return a|0}function P8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ni(a,b,c,d);x[a>>2]=45104;c=Nb(a+4208|0);x[a+4220>>2]=0;x[a+4224>>2]=1056964608;b=a+4228|0;v[b+4|0]=0;v[b+5|0]=4;v[b|0]=69;v[b+1|0]=99;v[b+2|0]=104;v[b+3|0]=111;v[b+6|0]=1;x[23549]=0;P(878,a+44|0,2);b=x[23549];x[23549]=0;if((b|0)!=1){mi(a);Js(a);return a|0}b=N()|0;sc(c);yf(a);Q(b|0);p()}function Lu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=db-32|0;db=e;YB(e+8|0,c);x[23549]=0;P(99,e+20|0,d|0);c=x[23549];x[23549]=0;b:{c:{if((c|0)!=1){Il(e,e+8|0);x[23549]=0;V(100,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[23549];x[23549]=0;if((a|0)==1){break c}Ah(e+8|0);db=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;Ah(e+8|0)}Q(a|0);p()}}function Fu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=yb(x[b>>2]);g=yb(x[b+4>>2]);e=db-16|0;db=e;x[e+12>>2]=d;while(1){a:{if(!Kb(d,g)){break a}f=db-16|0;db=f;zi(f+8|0,x[d>>2],x[d+4>>2]);h=$b(x[f+8>>2]);db=f+16|0;if((c|0)==(h|0)){break a}d=x[hk(e+12|0)>>2];continue}break}db=e+16|0;if(qc(d,yb(x[b+4>>2]))){xh(a);return}Go(a,d)}function caa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=db-16|0;db=e;d=e+4|0;x[d>>2]=x[a+8>>2];f=x[a+8>>2];x[d+8>>2]=a+8;x[d+4>>2]=D(b,52)+f;b=x[d>>2];a:{while(1){if(x[d+4>>2]==(b|0)){break a}x[23549]=0;P(855,b|0,c|0);a=x[23549];x[23549]=0;if((a|0)!=1){b=x[d>>2]+52|0;x[d>>2]=b;continue}break}a=N()|0;Kd(d);Q(a|0);p()}Kd(d);db=e+16|0}function Td(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=db-16|0;db=d;Xm(b);e=a+8|0;f=of(d+12|0,b);a:{b=x[a+8>>2];if(oc(b,x[a+12>>2])>>>0<=c>>>0){x[23549]=0;P(1190,e|0,c+1|0);a=x[23549];x[23549]=0;if((a|0)==1){break a}b=x[e>>2]}a=xb(b,c);b=x[a>>2];if(b){$m(b);a=xb(x[e>>2],c)}g=a,h=Zd(f),x[g>>2]=h;hG(f);db=d+16|0;return}a=N()|0;hG(f);Q(a|0);p()}function Oja(a,b){a=a|0;b=b|0;var c=0;b=db-32|0;db=b;c=-1;a:{if(!yB(a,b+20|0)){break a}c=0;if(!iV(b+20|0)){break a}if((y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24))==1179472708){c=-1;if(!dd(a,4)){break a}}c=-1;if(!xj(a,b+12|0)){break a}c=(y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24))==1196314451}db=b+32|0;return c|0}function Iaa(a){a=a|0;var b=0,c=0;b=db-32|0;db=b;v[b+23|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+26|0]=0;v[b+27|0]=0;v[b+28|0]=0;v[b+29|0]=0;v[b+30|0]=0;x[b+16>>2]=0;x[b+20>>2]=0;c=ec(b,b+16|0,15);lc(b+8|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);c=0;a:{if(x[b+12>>2]!=15){break a}if(cd(b+16|0,8423,15)){break a}Zb(a,15);c=1}db=b+32|0;return c|0}function Gea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=db-16|0;db=d;c=db-16|0;db=c;x[c+12>>2]=4925421;x[c+8>>2]=2147483647;e=Cb(c+12|0,c+8|0);db=c+16|0;if(A[e>>2]<b>>>0){Rc();p()}if(b>>>0>=4925422){wi();p()}c=Hc(D(b,872));x[d+12>>2]=b;x[d+8>>2]=c;b=x[d+8>>2];x[a+4>>2]=b;x[a>>2]=b;f=wb(a),g=b+D(x[d+12>>2],872)|0,x[f>>2]=g;db=d+16|0}function nd(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;vm(a);x[a+16>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=0;x[a+4>>2]=0;w[a+32>>1]=64;x[a+24>>2]=8363;x[a+28>>2]=16777344;x[a+36>>2]=0;v[a+39|0]=0;v[a+40|0]=0;v[a+41|0]=0;v[a+42|0]=0;d=z[a+34>>1]&-25151;w[a+34>>1]=(b|0)==4?d|32:d;b=Tb(c+4|0,21204);Ce(a+43|0,b);tb(b);TQ(a);db=c+16|0}function fy(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=db-16|0;db=e;d=db-32|0;db=d;Od(d+24|0,a,b);b=db-16|0;db=b;f=x[d+28>>2];g=x[d+24>>2];h=f-g|0;i=b,j=uk(c,g,h)+D((h|0)/6|0,6)|0,x[i+12>>2]=j;vc(d+16|0,f,b+12|0);db=b+16|0;a=oM(a,x[d+16>>2]);i=d,j=ey(c,x[d+20>>2]),x[i+12>>2]=j;vc(e+8|0,a,d+12|0);db=d+32|0;db=e+16|0;return x[e+12>>2]}function p5(a){a=a|0;var b=0;x[23549]=0;W(927,a|0);b=x[23549];x[23549]=0;if((b|0)!=1){a=x[x[a+24>>2]+24>>2];return cj(Wb(x[a+484360>>2],y[a+484376|0]))|0}Y(T(0)|0)|0;x[23549]=0;V(914,6826,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function uka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;dc(c+8|0,b,10);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;a=(d|0)==(e|0);if(!a){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0}return a|0}function kca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=db-32|0;db=d;WA(d+8|0,c);x[23549]=0;P(416,d+20|0,43436);c=x[23549];x[23549]=0;b:{c:{if((c|0)!=1){Il(d,d+8|0);x[23549]=0;V(100,a|0,b|0,x[d>>2],x[d+4>>2]);a=x[23549];x[23549]=0;if((a|0)==1){break c}Ah(d+8|0);db=d+32|0;break a}a=N()|0;tb(d+8|0);break b}a=N()|0;Ah(d+8|0)}Q(a|0);p()}}function t6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=db-16|0;db=f;x[f+12>>2]=d;d=x[Vf(f+8|0,f+12|0)>>2];x[23549]=0;fa(925,a+8|0,b|0,c|0,d|0,e|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){a=jJ(a);b=iJ(a+88|0);c=hJ(a+92|0);x[a>>2]=61592;x[b>>2]=61704;x[c>>2]=61784;xe(f+12|0);db=f+16|0;return a|0}a=N()|0;xe(f+12|0);Q(a|0);p()}function Up(a){var b=0,c=0,d=0,e=0,f=0;d=db-16|0;db=d;b=yb(x[a>>2]);f=yb(x[a+4>>2]);e=db-16|0;db=e;x[e+12>>2]=b;while(1){if(Kb(b,f)){c=c+C[b>>3];b=x[mt(e+12|0)>>2];continue}break}db=e+16|0;b=yb(x[a>>2]);x[d+12>>2]=b;c=-c;a=yb(x[a+4>>2]);while(1){if(Kb(b,a)){c=c+C[b>>3];C[b>>3]=c;b=x[mt(d+12|0)>>2];continue}else{db=d+16|0}break}}function Iha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=db+-64|0;db=d;c=db-16|0;db=c;f=d+12|0;sT(c+8|0,f);e=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){dd(a,x[c+12>>2])}db=c+16|0;e=(e|0)==(g|0);if(!e){rT(f)}c=-1;a:{if(!e){break a}c=0;if(!uT(d+12|0)){break a}c=Ge(a,b,tT(d+12|0),hb)}db=d- -64|0;return c|0}function qia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=db-16|0;db=f;c=jf(a,c);ae(f,x[a+28>>2]);a:{if(!c){e=0;if(ed(a,5)){break a}}h=x[a+28>>2];g=db-16|0;db=g;e=Gb(g+4|0);x[23549]=0;ba(411,b|0,h|0,e|0,d|0)|0;b=x[23549];x[23549]=0;b:{if((b|0)!=1){tb(e);db=g+16|0;break b}a=N()|0;tb(e);Q(a|0);p()}e=c}cf(a,e);db=f+16|0}function o5(a){a=a|0;var b=0;x[23549]=0;W(927,a|0);b=x[23549];x[23549]=0;if((b|0)!=1){a=x[x[a+24>>2]+24>>2];return lt(x[a+484344>>2],x[a+484348>>2])|0}Y(T(0)|0)|0;x[23549]=0;V(914,6894,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function XW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=db-48|0;db=d;c=db-16|0;db=c;f=d+10|0;KC(c+8|0,f);e=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){dd(a,x[c+12>>2])}db=c+16|0;e=(e|0)==(g|0);if(!e){JC(f)}c=-1;a:{if(!e){break a}c=0;if(!MC(d+10|0)){break a}c=Ge(a,b,LC(y[d+45|0]),hb)}db=d+48|0;return c|0}function Sia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=db-16|0;db=d;x[d+12>>2]=c;a:{e=Lb(x[b>>2],x[b+8>>2],c<<2);if(!e){break a}tc(d+12|0,65535);Sf(a,z[d+12>>1]);c=yb(x[a>>2]);x[d+4>>2]=c;a=yb(x[a+4>>2]);while(1){if(!Kb(c,a)){break a}f=d+8|0;if(!Wo(b,f)){Dm(f)}w[c>>1]=x[d+8>>2];c=x[Se(d+4|0)>>2];continue}}db=d+16|0;return e|0}function B$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=db-16|0;db=d;i=x[b>>2];h=x[a>>2];e=x[gc(a)>>2]==1136;f=x[c>>2]-h|0;g=f<<1;f=f>>>0>=2147483647?-1:g>>>0<=1?1:g;g=Qt(e?0:h,f);if(g){if(!e){Zd(a)}x[d+4>>2]=1103;e=pe(d+8|0,g,d+4|0);a=yG(a,e);Kc(e);x[b>>2]=x[a>>2]+(i-h|0);x[c>>2]=f+x[a>>2];db=d+16|0;return}Bw();p()}function o1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=x[a+44>>2];c=x[a+24>>2];if(e>>>0<c>>>0){x[a+44>>2]=c;e=c}g=x[a+8>>2];f=x[a+12>>2];d=-1;a:{if(g>>>0>=f>>>0){break a}if(qc(b,-1)){xn(a,g,f-1|0,e);return Lw(b)|0}c=b<<24>>24;if(!(x[a+48>>2]&16)){d=-1;if(!qc(c,v[f-1|0])){break a}}xn(a,g,f-1|0,e);v[x[a+12>>2]]=c;d=b}return d|0}function iL(a){a=a|0;var b=0,c=0;c=db-16|0;db=c;b=x[x[a+16>>2]+24620>>2]/5|0;b=Cc(b,b>>31);x[a+4272>>2]=b;x[23549]=0;x[c+12>>2]=0;S(884,a+4256|0,b<<1,c+12|0);b=x[23549];x[23549]=0;a:{if((b|0)==1){b=T(92296)|0;if((eb|0)!=($(92296)|0)){break a}Y(b|0)|0;x[a+4272>>2]=0;Z()}x[a+4276>>2]=0;x[a+4268>>2]=0;db=c+16|0;return}Q(b|0);p()}function Y6(a){a=a|0;var b=0,c=0,d=0,e=0;b=db-16|0;db=b;a=Nb(a);x[23549]=0;W(917,b+4|0);c=x[23549];x[23549]=0;a:{b:{if((c|0)!=1){c=yb(x[b+4>>2]);d=yb(x[b+8>>2]);e=x[vb(b,a)>>2];x[23549]=0;S(918,c|0,d|0,e|0);c=x[23549];x[23549]=0;if((c|0)==1){break b}sc(b+4|0);db=b+16|0;return}c=N()|0;break a}c=N()|0;sc(b+4|0)}Yd(a);Q(c|0);p()}function BM(a,b,c,d){var e=0,f=0,g=0,h=0;e=db-16|0;db=e;a:{b:{while(1){x[e+12>>2]=b;x[e+8>>2]=d;if(A[Cb(e+12|0,e+8|0)>>2]<=f>>>0){break b}g=Dp(v[Db(a,f)|0]);h=Dp(v[Db(c,f)|0]);if((g|0)!=(h|0)){a=g>>>0<h>>>0?-1:1;break a}f=f+1|0;if(g){continue}break}a=0;break a}a=0;if((b|0)==(d|0)){break a}a=b>>>0<d>>>0?-1:1}db=e+16|0;return a}function $M(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=db-16|0;db=d;e=ri(b,c);a:{if(e>>>0<=pn(a)>>>0){f=c;g=x[a>>2];h=Pc(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=b;_M(d+12|0,h);f=x[d+12>>2]}b=_g(b,f,g);if(!i){Mt(a,f,c,e-Pc(x[a>>2],x[a+4>>2])|0);break a}Dd(a,b);break a}pu(a);pk(a,Ek(a,e));Mt(a,b,c,e)}db=d+16|0}function sx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;b=he(b,od(a));a:{f=Bb(x[a+4>>2],y[a+11|0]);if(b>>>0<=f>>>0){if(c){e=Mc(a);b:{if(e-f>>>0>=c>>>0){e=Mb(a);if((b|0)==(f|0)){break b}g=b+e|0;pl(g+c|0,g,f-b|0);break b}cm(a,e,(c+f|0)-e|0,f,b,0,c);e=x[a>>2]}sl(b+e|0,c,d);b=c+f|0;Wg(a,b);hd(b+e|0,0)}break a}mq();p()}od(a)}function Ffa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=db-608|0;db=d;c=db-16|0;db=c;NR(c+8|0,d);e=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){dd(a,x[c+12>>2])}db=c+16|0;e=(e|0)==(f|0);if(!e){MR(d)}c=-1;a:{if(!e){break a}c=0;if(!PR(d)){break a}c=Ge(a,b,OR(y[d+34|0]|y[d+35|0]<<8),hb)}db=d+608|0;return c|0}function S9(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[wb(a)>>2]){c=db-16|0;db=c;a=oh(c+4|0,a,1);Qs(x[a+4>>2],B[b>>2]);x[a+4>>2]=x[a+4>>2]+4;fc(a);db=c+16|0;return}d=db-32|0;db=d;c=wb(a);c=Jf(d+12|0,eg(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);Qs(x[c+8>>2],B[b>>2]);x[c+8>>2]=x[c+8>>2]+4;$x(a,c);If(c);db=d+32|0}function Rk(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=db-16|0;db=f;x[f+12>>2]=c;while(1){a:{if((a|0)!=(b|0)){c=db-32|0;db=c;d=mc(c+24|0,x[a>>2]);e=x[f+12>>2];g=x[e>>2];e=x[e+4>>2];x[c+16>>2]=g;x[c+20>>2]=e;h=x[d+4>>2];d=x[d>>2];x[c+8>>2]=g;x[c+12>>2]=e;d=Gc(d,h,c+8|0);db=c+32|0;if(!d){break a}b=a}db=f+16|0;return b}a=a+8|0;continue}}function Dia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a>>2];d=Pc(e,x[a+4>>2]);if(d>>>0<b>>>0){e=db-32|0;db=e;b=b-d|0;d=x[wb(a)>>2];f=x[a+4>>2];a:{if(b>>>0<=d-f>>>0){Ro(a,b,c);break a}d=wb(a);d=Ol(e+12|0,Ek(a,Pc(x[a>>2],f)+b|0),Pc(x[a>>2],x[a+4>>2]),d);RT(d,b,c);mp(a,d);Ml(d)}db=e+32|0;return}if(b>>>0<d>>>0){Dd(a,b+e|0)}}function $B(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[wb(a)>>2]){c=db-16|0;db=c;a=Ei(c+4|0,a,1);tj(x[a+4>>2],z[b>>1]);x[a+4>>2]=x[a+4>>2]+2;fc(a);db=c+16|0;return}d=db-32|0;db=d;c=wb(a);c=uj(d+12|0,vj(a,Ic(x[a>>2],x[a+4>>2])+1|0),Ic(x[a>>2],x[a+4>>2]),c);tj(x[c+8>>2],z[b>>1]);x[c+8>>2]=x[c+8>>2]+2;Rq(a,c);Di(c);db=d+32|0}function fZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=db-16|0;db=d;a:{e=x[b>>2];if(ud(e)){f=d+4|0;if(!xd(x[c+4>>2],y[c+11|0])){Kv(c,17347);e=x[b>>2]}b=x[b+4>>2];ib[x[x[b>>2]+24>>2]](f,b,e);x[23549]=0;O(777,c|0,f|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break a}tb(d+4|0)}ad(a,c);db=d+16|0;return}a=N()|0;tb(d+4|0);Q(a|0);p()}function w4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[23549]=0;W(927,a|0);d=x[23549];x[23549]=0;if((d|0)!=1){x[a+16>>2]=0;x[a+12>>2]=c;x[a+8>>2]=b;return}Y(T(0)|0)|0;x[23549]=0;V(914,12897,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function vg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=a;e=db-16|0;db=e;a:{f=ri(b,c);if(f>>>0<2147483632){b:{if(Do(f)){ff(d,f);break b}yi(e+8|0,fk(f)+1|0);g=x[e+8>>2];zd(d,g);jg(d,x[e+12>>2]);re(d,f);d=g}while(1){if((b|0)!=(c|0)){hd(d,y[b|0]);d=d+1|0;b=b+1|0;continue}break}hd(d,0);db=e+16|0;break a}kg();p()}return a|0}function cj(a){var b=0,c=0,d=0,e=0,f=0;b=x[a+4>>2];if(qc(x[a>>2],b)){a=0}else{b=kj(b);e=kj(x[a>>2]);c=db-16|0;db=c;x[c+12>>2]=b;while(1){a:{if(!xg(b,e)){break a}d=db-16|0;db=d;x[d+12>>2]=b;f=qk(d+12|0);db=d+16|0;if(z[x[f>>2]>>1]!=65535){break a}b=x[qk(c+12|0)>>2];continue}break}db=c+16|0;a=JB(yb(x[a>>2]),b)}return a&65535}function s7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ni(a,b,c,d);x[a>>2]=47448;b=a+4208|0;e=xb(b,0),f=1065353216,x[e>>2]=f;e=xb(b,1),f=1065353216,x[e>>2]=f;e=xb(b,2),f=1051372203,x[e>>2]=f;e=xb(b,3),f=0,x[e>>2]=f;x[23549]=0;P(878,a+44|0,2);b=x[23549];x[23549]=0;if((b|0)!=1){mi(a);return a|0}b=N()|0;yf(a);Q(b|0);p()}function lW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=db-1968|0;db=e;c=db-16|0;db=c;f=e+14|0;VB(c+8|0,f);d=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){dd(a,x[c+12>>2])}db=c+16|0;d=(d|0)==(g|0);if(!d){UB(f)}c=-1;a:{if(!d){break a}c=0;if(!WB(e+14|0)){break a}c=Ge(a,b,1024,0)}db=e+1968|0;return c|0}function _aa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=db-16|0;db=c;if(!ud(x[a+1298300>>2])){d=x[a+24620>>2];e=db-16|0;db=e;b=Hc(536);x[23549]=0;d=O(811,b|0,d|0)|0;f=x[23549];x[23549]=0;a:{if((f|0)!=1){b=x[of(e+12|0,d)>>2];db=e+16|0;break a}a=N()|0;Eb(b);Q(a|0);p()}x[c+12>>2]=b;b=a+1298300|0;a=c+12|0;nN(b,Zd(a));Dy(a)}db=c+16|0}function XC(a,b){var c=0,d=0,e=0,f=0;c=db-16|0;db=c;a:{if(b>>>0<3){if(!b){break a}if(!Lb(x[a>>2],x[a+8>>2],b)){break a}while(1)if((d|0)==2){d=z[c+14>>1];break a}else{v[c+13|0]=0;f=(c+14|0)+d|0;if(b>>>0>d>>>0){Eg(a,c+13|0);e=y[c+13|0]}else{e=0}v[f|0]=e;d=d+1|0;continue}}_(11081,8977,136,13890);p()}db=c+16|0;return d&65535}function A7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ni(a,b,c,d);x[a+4272>>2]=1065353216;x[a>>2]=47216;b=a+4208|0;e=xb(b,0),f=1056880300,x[e>>2]=f;e=xb(b,1),f=1050733080,x[e>>2]=f;e=xb(b,2),f=1056964608,x[e>>2]=f;x[23549]=0;P(878,a+44|0,2);b=x[23549];x[23549]=0;if((b|0)!=1){mi(a);return a|0}b=N()|0;yf(a);Q(b|0);p()}function tD(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1179340888|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1213419859){break a}b=$b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24));if(!b){break a}c=($b(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24))|0)!=0&b>>>0>27}return c}function Lha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=db-16|0;db=d;c=d+4|0;x[c>>2]=x[a+8>>2];e=x[a+8>>2];x[c+8>>2]=a+8;x[c+4>>2]=D(b,20)+e;b=x[c>>2];a:{while(1){if(x[c+4>>2]==(b|0)){break a}x[23549]=0;W(217,b|0);a=x[23549];x[23549]=0;if((a|0)!=1){b=x[c>>2]+20|0;x[c>>2]=b;continue}break}a=N()|0;Kd(c);Q(a|0);p()}Kd(c);db=d+16|0}function zS(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=808604749|((y[a+8|0]|y[a+9|0]<<8)-768&65535)>>>0<65280|(((y[a+112|0]|y[a+113|0]<<8)-65&65535)>>>0<65472|(y[a+106|0]|y[a+107|0]<<8)>>>0>256)){break a}if((y[a+122|0]|y[a+123|0]<<8)>>>0>255){break a}b=(y[a+124|0]|y[a+125|0]<<8)>>>0<4e3}return b}function xf(a,b,c){var d=0,e=0;d=db-16|0;db=d;a:{if(A[b+8>>2]<c>>>0){x[23549]=0;V(1053,16970,9008,392,6322);a=x[23549];x[23549]=0;if((a|0)==1){break a}p()}x[d+8>>2]=x[b+8>>2];e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=x[d+4>>2];x[a>>2]=x[d>>2];x[a+4>>2]=b;x[a+8>>2]=x[d+8>>2];x[a+12>>2]=c;db=d+16|0;return}T(0)|0;Rb();p()}function E9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){d=db-32|0;db=d;b=b-c|0;c=x[wb(a)>>2];e=x[a+4>>2];a:{if(b>>>0<=c-e>>2>>>0){Lz(a,b);break a}c=wb(a);c=Jf(d+12|0,eg(a,oc(x[a>>2],e)+b|0),oc(x[a>>2],x[a+4>>2]),c);bM(c,b);lo(a,c);If(c)}db=d+32|0;return}if(b>>>0<c>>>0){Dd(a,d+(b<<2)|0)}}function ky(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=c>=.999?.999:c;h=c*3.141592653589793;i=ot(b);while(1){if((e|0)!=32768){f=((e^-1)<<12&28672)+(e>>>3|0)|0;if((f|0)!=16384){d=+(f-16384|0)*.000244140625;g=h*d;d=ui(g)*ot(M(d*d*-.0625+1)*b)/(i*g)}else{d=1}j=a,k=Tz(c*d*32768),w[j>>1]=k;e=e+1|0;a=a+2|0;continue}break}}function _8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=db-32|0;db=d;x[d+28>>2]=c;x[d+8>>2]=33;e=x[a>>2];f=x[a+8>>2];c=x[Cb(d+28|0,d+8|0)>>2];if(!Lb(e,f,c)){c=rf(a)}e=d+8|0;QA(e,b);f=ec(d+16|0,x[d+8>>2],c);lc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);QA(e,b);Vb(x[d+8>>2]+c|0,0,33-c|0);Zb(a,x[d+28>>2]);db=d+32|0;return c|0}function wJ(a){var b=0,c=0,d=0,e=0;b=db-32|0;db=b;if(!y[a+20|0]){while(1){if(!(ib[x[x[a>>2]+40>>2]](a)|0)){tJ(a,65536);c=ec(b+16|0,Db(x[a+4>>2],x[a+16>>2]),65536);d=x[x[a>>2]+44>>2];e=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=e;ib[d|0](b+24|0,a,b+8|0);x[a+16>>2]=x[a+16>>2]+x[b+28>>2];continue}break}v[a+20|0]=1}db=b+32|0}function VY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Kg(a,x[b+8>>2],e)){hw(b,c,d);return}a:{if(!Kg(a,x[b>>2],e)){break a}if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+20>>2]=c;x[b+32>>2]=d;x[b+40>>2]=x[b+40>>2]+1;if(!(x[b+36>>2]!=1|x[b+24>>2]!=2)){v[b+54|0]=1}x[b+44>>2]=4}}function M8(a){a=a|0;var b=0,c=0,d=0,e=0;c=db-16|0;db=c;x[x[a+20>>2]+148>>2]=-1;Jo(c+8|0,a+4228|0);d=x[a+20>>2];e=x[c+12>>2];b=x[c+8>>2];x[23549]=0;S(896,d+4|0,b|0,Db(b,e)|0);b=x[23549];x[23549]=0;a:{if((b|0)==1){b=T(92296)|0;if((eb|0)!=($(92296)|0)){break a}Y(b|0)|0;Dc(x[a+20>>2]+4|0);Z()}db=c+16|0;return}Q(b|0);p()}function EP(a){a=a|0;var b=0,c=0,d=0;b=db-16|0;db=b;if(y[a+534|0]){while(1){d=c&65535;if(d>>>0>=256){v[a+534|0]=0}else{aj(a,d,1);c=c+1|0;continue}break}}v[b+15|0]=0;Sh(a+8|0,18,b+15|0);_t(a+26|0,18,29258);v[b+14|0]=255;Sh(a+62|0,256,b+14|0);Tg(x[a>>2],x[a+4>>2],65535,261,1);Tg(x[a>>2],x[a+4>>2],65535,260,0);db=b+16|0}function Dga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=db-128|0;db=e;c=db-16|0;db=c;f=e+2|0;yS(c+8|0,f);d=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){dd(a,x[c+12>>2])}db=c+16|0;d=(d|0)==(g|0);if(!d){xS(f)}c=-1;a:{if(!d){break a}c=0;if(!zS(e+2|0)){break a}c=Ge(a,b,256,0)}db=e+128|0;return c|0}function _w(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=db-240|0;db=g;x[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-x[(i<<2)+d>>2]|0;if((Fn(a,f,b)|0)>=0){if((Fn(a,e,b)|0)>=0){break a}}j=f;f=(Fn(f,e,b)|0)>=0;e=f?j:e;x[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}nI(g,h);db=g+240|0}function Tga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=db-16|0;db=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+D(b,24);b=x[c+4>>2];e=x[c+8>>2];a:{while(1){if((b|0)==(e|0)){break a}x[23549]=0;W(539,b|0);a=x[23549];x[23549]=0;if((a|0)!=1){b=b+24|0;x[c+4>>2]=b;continue}break}a=N()|0;fc(c);Q(a|0);p()}fc(c);db=d+16|0}function SL(a){var b=0,c=0,d=0;c=db-32|0;db=c;a:{d=Tx(a);b=wj(x[a>>2],x[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}x[23549]=0;b=ba(882,c+12|0,b|0,b|0,wb(a)|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){PL(a,b);OL(b);break b}Y(T(0)|0)|0;x[23549]=0;X(17);a=x[23549];x[23549]=0;if((a|0)==1){break a}}db=c+32|0;return}T(0)|0;Rb();p()}function RL(a){var b=0,c=0,d=0;c=db-32|0;db=c;a:{d=Qh(a);b=oc(x[a>>2],x[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}x[23549]=0;b=ba(883,c+12|0,b|0,b|0,wb(a)|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){lo(a,b);If(b);break b}Y(T(0)|0)|0;x[23549]=0;X(17);a=x[23549];x[23549]=0;if((a|0)==1){break a}}db=c+32|0;return}T(0)|0;Rb();p()}function Lja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=db-32|0;db=e;c=db-16|0;db=c;f=e+15|0;gC(c+8|0,f);d=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){dd(a,x[c+12>>2])}db=c+16|0;d=(d|0)==(g|0);if(!d){Nu(f)}c=-1;a:{if(!d){break a}c=0;if(!dV(e+15|0)){break a}c=Ge(a,b,72,0)}db=e+32|0;return c|0}function cga(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[wb(a)>>2]){c=db-16|0;db=c;a=Xu(c+4|0,a,1);iS(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+20;fc(a);db=c+16|0;return}d=db-32|0;db=d;c=wb(a);c=pB(d+12|0,qB(a,Ef(x[a>>2],x[a+4>>2])+1|0),Ef(x[a>>2],x[a+4>>2]),c);iS(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+20;oB(a,c);mu(c);db=d+32|0}function YC(a,b){var c=0,d=0,e=0,f=0;c=db-16|0;db=c;a:{if(b>>>0<5){if(!b){break a}if(!Lb(x[a>>2],x[a+8>>2],b)){break a}while(1)if((d|0)==4){d=x[c+12>>2];break a}else{v[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){Eg(a,c+11|0);e=y[c+11|0]}else{e=0}v[f|0]=e;d=d+1|0;continue}}_(11081,8977,136,13890);p()}db=c+16|0;return d}function yJ(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=x[a>>2];a:{if(!c){break a}d=x[a+8>>2];if(!d){break a}e=x[a+12>>2];if(!e){break a}a=ib[e|0](c)|0;f=hb;if((f|0)<0){break a}b=0;b:{if((ib[d|0](c,0,0,0)|0)<0){break b}b=0;if((ib[d|0](c,0,0,2)|0)<0){break b}ib[e|0](c)|0;b=hb;b=(b|0)>0|(b|0)>=0}ib[d|0](c,a,f,0)|0}return b|0}function oja(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[wb(a)>>2]){c=db-16|0;db=c;a=Xu(c+4|0,a,1);rB(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+20;fc(a);db=c+16|0;return}d=db-32|0;db=d;c=wb(a);c=pB(d+12|0,qB(a,Ef(x[a>>2],x[a+4>>2])+1|0),Ef(x[a>>2],x[a+4>>2]),c);rB(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+20;oB(a,c);mu(c);db=d+32|0}function o4(a,b){a=a|0;b=b|0;var c=0;x[23549]=0;W(927,a|0);c=x[23549];x[23549]=0;if((c|0)!=1){x[x[x[a+24>>2]+24>>2]+480272>>2]=b;return 1}Y(T(0)|0)|0;x[23549]=0;V(914,5725,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function lca(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[wb(a)>>2]){c=db-16|0;db=c;a=Mz(c+4|0,a,1);zz(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+32;fc(a);db=c+16|0;return}d=db-32|0;db=d;c=wb(a);c=xt(d+12|0,$p(a,hg(x[a>>2],x[a+4>>2])+1|0),hg(x[a>>2],x[a+4>>2]),c);zz(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+32;OP(a,c);yz(c);db=d+32|0}function ija(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=db-224|0;db=d;c=db-16|0;db=c;HU(c+8|0,d+6|0);e=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){dd(a,x[c+12>>2])}db=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!JU(d+6|0)){break a}c=Ge(a,b,IU(y[d+222|0],y[d+223|0]),hb)}db=d+224|0;return c|0}function GE(a,b,c,d,e,f){var g=0;a:{g=db-32|0;db=g;vk(g+8|0,c);x[23549]=0;P(f|0,g+20|0,d|0);c=x[23549];x[23549]=0;b:{c:{if((c|0)!=1){Il(g,g+8|0);x[23549]=0;V(e|0,a|0,b|0,x[g>>2],x[g+4>>2]);a=x[23549];x[23549]=0;if((a|0)==1){break c}Ah(g+8|0);db=g+32|0;break a}a=N()|0;tb(g+8|0);break b}a=N()|0;Ah(g+8|0)}Q(a|0);p()}}function CV(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[wb(a)>>2]){c=db-16|0;db=c;a=sV(c+4|0,a,1);rV(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+48;fc(a);db=c+16|0;return}d=db-32|0;db=d;c=wb(a);c=pV(d+12|0,qV(a,Aq(x[a>>2],x[a+4>>2])+1|0),Aq(x[a>>2],x[a+4>>2]),c);rV(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+48;oV(a,c);nV(c);db=d+32|0}function pC(a){var b=0,c=0,d=0,e=0;c=y[a+9|0]|y[a+10|0]<<8;d=yka(y[a+3|0],0,18,0);c=c+d|0;b=hb;e=d>>>0>c>>>0?b+1|0:b;d=y[a+6|0]|y[a+7|0]<<8;b=d>>>31|0;d=d<<1;c=d+c|0;b=b+e|0;d=d>>>0>c>>>0?b+1|0:b;a=y[a+4|0]|y[a+5|0]<<8;b=a>>>30|0;e=c;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+3|0;hb=b>>>0<3?a+1|0:a;return b}function m7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=db-16|0;db=d;Nc(a,x[b+28>>2]);x[23549]=0;S(65,d+12|0,b|0,c|0);e=x[23549];x[23549]=0;a:{if((e|0)==1){break a}Xb(d+12|0);b=x[b+24>>2];if(b){x[23549]=0;S(66,d+8|0,b|0,c|0);b=x[23549];x[23549]=0;if((b|0)==1){break a}Xb(d+8|0)}db=d+16|0;return}b=N()|0;Xb(a);Q(b|0);p()}function jfa(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[wb(a)>>2]){c=db-16|0;db=c;a=Pv(c+4|0,a);Yz(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;fc(a);db=c+16|0;return}d=db-32|0;db=d;c=wb(a);c=Hl(d+12|0,ep(a,Cd(x[a>>2],x[a+4>>2])+1|0),Cd(x[a>>2],x[a+4>>2]),c);Yz(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+12;iR(a,c);hR(c);db=d+32|0}function v4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[23549]=0;W(927,a|0);d=x[23549];x[23549]=0;if((d|0)!=1){x[a+4>>2]=c;x[a>>2]=b?b:908;return}Y(T(0)|0)|0;x[23549]=0;V(914,12927,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function lea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=db-32|0;db=d;x[d+28>>2]=c;x[d+8>>2]=4896;e=x[a>>2];f=x[a+8>>2];c=x[Cb(d+28|0,d+8|0)>>2];if(!Lb(e,f,c)){c=rf(a)}e=d+8|0;UA(e,b);f=ec(d+16|0,x[d+8>>2],c);lc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);UA(e,b);Vb(x[d+8>>2]+c|0,0,4896-c|0);Zb(a,x[d+28>>2]);db=d+32|0}function Yx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=db-16|0;db=d;h=z[b>>1];c=Ud(a);e=gc(a);f=db-16|0;db=f;while(1){if(c){g=aq(z[c+16>>1],h);e=g?e:c;c=x[(g?c+4|0:c)>>2];continue}break}c=x[vb(f+12|0,e)>>2];db=f+16|0;a:{if(Kb(c,Kf(a))){if(!aq(z[b>>1],z[td(c)>>1])){break a}}c=Kf(a)}a=x[vb(d+12|0,c)>>2];db=d+16|0;return a}function TE(a,b,c,d,e){var f=0;a:{f=db-32|0;db=f;dp(f+8|0,c);x[23549]=0;P(e|0,f+20|0,d|0);c=x[23549];x[23549]=0;b:{c:{if((c|0)!=1){Il(f,f+8|0);x[23549]=0;V(100,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[23549];x[23549]=0;if((a|0)==1){break c}Ah(f+8|0);db=f+32|0;break a}a=N()|0;tb(f+8|0);break b}a=N()|0;Ah(f+8|0)}Q(a|0);p()}}function PE(a,b,c,d,e){var f=0;a:{f=db-32|0;db=f;TU(f+8|0,c);x[23549]=0;P(e|0,f+20|0,d|0);c=x[23549];x[23549]=0;b:{c:{if((c|0)!=1){Il(f,f+8|0);x[23549]=0;V(100,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[23549];x[23549]=0;if((a|0)==1){break c}Ah(f+8|0);db=f+32|0;break a}a=N()|0;tb(f+8|0);break b}a=N()|0;Ah(f+8|0)}Q(a|0);p()}}function pka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=db-16|0;db=d;x[d+12>>2]=c;a:{if(!Lb(x[b>>2],x[b+8>>2],c<<1)){break a}tc(d+12|0,65535);Sf(a,z[d+12>>1]);c=yb(x[a>>2]);x[d+4>>2]=c;a=yb(x[a+4>>2]);while(1){if(!Kb(c,a)){break a}Qu(b,d+10|0);e=c,f=Hb(z[d+10>>1]),w[e>>1]=f;c=x[Se(d+4|0)>>2];continue}}db=d+16|0}function lX(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[wb(a)>>2]){c=db-16|0;db=c;a=JD(c+4|0,a);vv(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+36;fc(a);db=c+16|0;return}d=db-32|0;db=d;c=wb(a);c=HD(d+12|0,ID(a,er(x[a>>2],x[a+4>>2])+1|0),er(x[a>>2],x[a+4>>2]),c);vv(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+36;GD(a,c);xv(c);db=d+32|0}function Al(a,b){var c=0,d=0,e=0,f=0;c=db-16|0;db=c;d=Mb(b);e=c,f=Oc(x[b+4>>2],y[b+11|0]),x[e+12>>2]=f;x[c+8>>2]=x[a+4>>2]-1;_g(d,d+x[Cb(c+12|0,c+8|0)>>2]|0,x[a>>2]);d=x[a>>2];e=c,f=Oc(x[b+4>>2],y[b+11|0]),x[e+12>>2]=f;a=x[a+4>>2];x[c+8>>2]=a-1;b=x[Cb(c+12|0,c+8|0)>>2];v[c+7|0]=0;am(b+d|0,a+d|0,c+7|0);db=c+16|0}function tea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=db-32|0;db=d;x[d+28>>2]=c;x[d+8>>2]=263;e=x[a>>2];f=x[a+8>>2];c=x[Cb(d+28|0,d+8|0)>>2];if(!Lb(e,f,c)){c=rf(a)}e=d+8|0;sQ(e,b);f=ec(d+16|0,x[d+8>>2],c);lc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);sQ(e,b);Vb(x[d+8>>2]+c|0,0,263-c|0);Zb(a,x[d+28>>2]);db=d+32|0}function pS(a){var b=0,c=0,d=0,e=0,f=0;f=y[a+28|0]|y[a+29|0]<<8;c=yka(y[a+30|0],0,37,0);d=hb;b=yka(y[a+24|0]|y[a+25|0]<<8,0,192,0);c=b+c|0;d=hb+d|0;b=b>>>0>c>>>0?d+1|0:d;a=y[a+26|0];d=a>>>26|0;e=c;c=a<<6;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+f|0;a=b>>>0<e>>>0?a+1|0:a;b=b+192|0;hb=b>>>0<192?a+1|0:a;return b}function cja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=db-16|0;db=d;x[d+8>>2]=c;x[d+12>>2]=-1;if((c|0)!=-1){f=d,g=Bb(x[a+4>>2],y[a+11|0]),x[f>>2]=g;e=x[Cb(d+12|0,d)>>2];x[d+4>>2]=e;a=Un(Mb(a),b,x[Cb(d+4|0,d+8|0)>>2]);a:{if(a){break a}a=-1;if(c>>>0>e>>>0){break a}a=c>>>0<e>>>0}db=d+16|0;return a|0}mq();p()}function Uk(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-32|0;db=c;d=c+8|0;lh(d,b);x[23549]=0;P(1031,c+20|0,d|0);b=x[23549];x[23549]=0;a:{b:{if((b|0)!=1){x[23549]=0;S(1032,a|0,0,c+20|0);a=x[23549];x[23549]=0;if((a|0)==1){break b}Ec(c+20|0);tb(c+8|0);db=c+32|0;return}b=N()|0;break a}b=N()|0;Ec(c+20|0)}tb(c+8|0);Q(b|0);p()}function Rga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=db+-64|0;db=c;b=-1;a:{if(!Gl(a,1084)){break a}ml(a,1080);d=c+60|0;TS(a,d);e=d;d=SS(c+44|0);b=0;if(!RS(e,d)){break a}ml(a,20);b=1;while(1){if((b&65535)>>>0>=32){b=A[d+4>>2]>=f>>>0}else{e=c+14|0;QS(a,e);b=b+1|0;f=AA(e)+f|0;continue}break}}db=c- -64|0;return b|0}function cy(a,b,c){var d=0,e=0,f=0;e=db-16|0;db=e;d=e+4|0;x[d>>2]=a;a=x[a+4>>2];x[d+4>>2]=a;x[d+8>>2]=a+D(b,52);b=x[d+4>>2];f=x[d+8>>2];a:{while(1){if((b|0)==(f|0)){break a}x[23549]=0;P(855,b|0,c|0);a=x[23549];x[23549]=0;if((a|0)!=1){b=b+52|0;x[d+4>>2]=b;continue}break}a=N()|0;fc(d);Q(a|0);p()}fc(d);db=e+16|0}function A5(a){a=a|0;var b=0;x[23549]=0;W(927,a|0);b=x[23549];x[23549]=0;if((b|0)!=1){return A[x[x[a+24>>2]+24>>2]+1074420>>2]/1e4|0}Y(T(0)|0)|0;x[23549]=0;V(914,9228,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function uU(a){var b=0;a:{b:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1297108297){if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=778924148){break a}if((y[a+34|0]|y[a+35|0]<<8)>>>0<=255){break b}break a}if((y[a+34|0]|y[a+35|0]<<8)>>>0>255){break a}}b=(y[a+36|0]|y[a+37|0]<<8)>>>0<4e3}return b}function nfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{d=db-32|0;db=d;e=db-16|0;db=e;f=e,g=Hb(c&65535),w[f+14>>1]=g;c=d+20|0;mK(c,e+14|0);db=e+16|0;Jj(d+12|0,c);x[23549]=0;V(100,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[23549];x[23549]=0;if((a|0)!=1){Ab(d+20|0);db=d+32|0;break a}a=N()|0;Ab(d+20|0);Q(a|0);p()}}function N$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=db-32|0;db=g;h=x[20507];x[g+24>>2]=x[20506];x[g+28>>2]=h;h=x[20505];x[g+16>>2]=x[20504];x[g+20>>2]=h;h=x[20503];x[g+8>>2]=x[20502];x[g+12>>2]=h;h=x[20501];x[g>>2]=x[20500];x[g+4>>2]=h;h=a;a=g+32|0;b=Hj(h,b,c,d,e,f,g,a);db=a;return b|0}function Eha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=db-32|0;db=d;x[d+28>>2]=c;x[d+8>>2]=22;e=x[a>>2];f=x[a+8>>2];c=x[Cb(d+28|0,d+8|0)>>2];if(!Lb(e,f,c)){c=rf(a)}e=d+8|0;ou(e,b);f=ec(d+16|0,x[d+8>>2],c);lc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);ou(e,b);Vb(x[d+8>>2]+c|0,0,22-c|0);Zb(a,x[d+28>>2]);db=d+32|0}function Cha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=db-32|0;db=d;x[d+28>>2]=c;x[d+8>>2]=40;e=x[a>>2];f=x[a+8>>2];c=x[Cb(d+28|0,d+8|0)>>2];if(!Lb(e,f,c)){c=rf(a)}e=d+8|0;GA(e,b);f=ec(d+16|0,x[d+8>>2],c);lc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);GA(e,b);Vb(x[d+8>>2]+c|0,0,40-c|0);Zb(a,x[d+28>>2]);db=d+32|0}function cL(a){var b=0,c=E(0),d=0,e=0;e=x[x[a+16>>2]+24620>>2];b=db-16|0;db=b;x[b+12>>2]=0;x[b+8>>2]=1065353216;c=Rh(E(B[nq(a+4208|0,b+12|0,b+8|0)>>2]*E(999)));a:{if(c<E(4294967296)&c>=E(0)){d=~~c>>>0;break a}d=0}db=b+16|0;b=(e>>>0)/(d+1>>>0)|0;b=b>>>0<=2?2:b;x[a+4216>>2]=b;x[a+4220>>2]=b>>>1;tc(a+4224|0,b)}function Yk(a,b){var c=0,d=0,e=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){d=db-32|0;db=d;b=b-c|0;c=x[wb(a)>>2];e=x[a+4>>2];a:{if(b>>>0<=c-e>>2>>>0){Lz(a,b);break a}c=wb(a);c=Jf(d+12|0,eg(a,oc(x[a>>2],e)+b|0),oc(x[a>>2],x[a+4>>2]),c);bM(c,b);$x(a,c);If(c)}db=d+32|0;return}if(b>>>0<c>>>0){Dd(a,d+(b<<2)|0)}}function NW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=db-32|0;db=d;x[d+28>>2]=c;x[d+8>>2]=65;e=x[a>>2];f=x[a+8>>2];c=x[Cb(d+28|0,d+8|0)>>2];if(!Lb(e,f,c)){c=rf(a)}e=d+8|0;Wu(e,b);f=ec(d+16|0,x[d+8>>2],c);lc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);Wu(e,b);Vb(x[d+8>>2]+c|0,0,65-c|0);Zb(a,x[d+28>>2]);db=d+32|0}function MV(a){var b=0,c=0,d=0,e=0;if(!y[a+12|0]){c=db-16|0;db=c;b=vb(c+12|0,x[x[a+8>>2]>>2]);e=x[vb(c+8|0,x[x[a+4>>2]>>2])>>2];d=db-16|0;db=d;a=x[b>>2];x[d+12>>2]=a;while(1){if(ai(a,e)){b=db-16|0;db=b;x[b+12>>2]=a;a=Cm(x[hk(b+12|0)>>2]);db=b+16|0;Gd(a);a=x[hk(d+12|0)>>2];continue}break}db=d+16|0;db=c+16|0}}function kia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=db-16|0;db=d;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(d+8|0,x[vb(d+4|0,a)>>2]);b:{e=b+c|0;c=ri(b,e);if(c){x[23549]=0;P(329,a|0,c|0);f=x[23549];x[23549]=0;if((f|0)==1){break b}YA(a,b,e,c)}a=d+8|0;Hd(a);Vh(a);db=d+16|0;break a}a=N()|0;Vh(d+8|0);Q(a|0);p()}}function VL(a,b){var c=0,d=0,e=0,f=0,g=E(0);c=db-16|0;db=c;if(!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]){w[c+14>>1]=0;Mf(a,c+14|0);e=z[c+14>>1];Yk(b,e);while(1){if((d|0)!=(e|0)){x[c+8>>2]=0;Bp(a,c+8|0);f=xb(x[b>>2],d),g=B[c+8>>2],B[f>>2]=g;d=d+1|0;continue}break}d=!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]}db=c+16|0;return d}function rfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=db+-64|0;db=d;c=db-16|0;db=c;zu(c+8|0,d);e=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){dd(a,x[c+12>>2])}db=c+16|0;e=(e|0)==(f|0);if(!e){su(d)}c=-1;a:{if(!e){break a}c=0;if(!sR(d)){break a}c=Ge(a,b,rR(d),hb)}db=d- -64|0;return c|0}function _U(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=db-16|0;db=d;e=x[b+4>>2];f=vb(d+12|0,c);g=vb(d+8|0,x[a>>2]);h=vb(d+4|0,x[b+4>>2]);i=b,j=AG(x[f>>2],x[g>>2],x[h>>2]),x[i+4>>2]=j;i=b,j=xq(c,x[a+4>>2],x[b+8>>2]),x[i+8>>2]=j;Pb(a,b+4|0);Pb(a+4|0,b+8|0);Pb(wb(a),kc(b));x[b>>2]=x[b+4>>2];db=d+16|0;return e}function Xia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=db-192|0;db=d;c=db-16|0;db=c;Hq(c+8|0,d);e=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){dd(a,x[c+12>>2])}db=c+16|0;e=(e|0)==(f|0);if(!e){sU(d)}c=-1;a:{if(!e){break a}c=0;if(!uU(d)){break a}c=Ge(a,b,tU(d),hb)}db=d+192|0;return c|0}function Xha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=yb(x[b>>2]);g=yb(x[b+4>>2]);e=db-16|0;db=e;x[e+12>>2]=d;while(1){a:{if(!Kb(d,g)){break a}f=db-16|0;db=f;ST(f+10|0,d);db=f+16|0;if(z[f+10>>1]==(c|0)){break a}d=x[hk(e+12|0)>>2];continue}break}db=e+16|0;if(qc(d,yb(x[b+4>>2]))){xh(a);return}Go(a,d)}function TP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=db-16|0;db=d;e=x[b+4>>2];f=vb(d+12|0,c);g=vb(d+8|0,x[a>>2]);h=vb(d+4|0,x[b+4>>2]);i=b,j=hD(x[f>>2],x[g>>2],x[h>>2]),x[i+4>>2]=j;i=b,j=xq(c,x[a+4>>2],x[b+8>>2]),x[i+8>>2]=j;Pb(a,b+4|0);Pb(a+4|0,b+8|0);Pb(wb(a),kc(b));x[b>>2]=x[b+4>>2];db=d+16|0;return e}function QL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=db-16|0;db=e;Hf(a+12|0,d);a:{if(!b){d=0;b=0;break a}if(b>>>0>=2097152){wi();p()}d=Hc(b<<11);x[e+12>>2]=b;x[e+8>>2]=d;d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<11)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=kc(a),g=b+(d<<11)|0,x[f>>2]=g;db=e+16|0;return a|0}function Ms(a){var b=0,c=0,d=0;b=Dj(+B[a+4228>>2]*8)*.25+-.25;C[a+4248>>3]=b;if(y[a+4240|0]){if(b>45e-5){c=lp(b)/.6931471805599453;b=c-J(c);d=c-b;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=Dj(d+c)*.5}else{b=0}C[a+4248>>3]=b}Ls(a)}function Dl(a,b,c,d,e){var f=0;a:{if(c>>>0>255){break a}b:{switch(d-2|0){case 0:d=D(c,872)+b|0;f=QN(x[d+720>>2],x[d+1272>>2],e);if((f+5&255)>>>0>5){break a}return PN(a,b,c,e);case 1:break b;default:break a}}f=PN(a,b,c,e);if((f+5&255)>>>0>5){break a}a=D(c,872)+b|0;f=QN(x[a+720>>2],x[a+1272>>2],e)}return f}function fH(a,b,c){var d=0,e=0,f=0,g=0;d=a;e=db-16|0;db=e;a:{f=ne(b,c);if(f>>>0<1073741808){b:{if(qp(f)){ff(d,f);break b}hj(e+8|0,Ql(f)+1|0);g=x[e+8>>2];zd(d,g);jg(d,x[e+12>>2]);re(d,f);d=g}while(1){if((b|0)!=(c|0)){zd(d,x[b>>2]);d=d+4|0;b=b+4|0;continue}break}zd(d,0);db=e+16|0;break a}kg();p()}return a}function Tm(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{if(x[c>>2]|x[d>>2]){while(1){if((b|0)==(f|0)){break a}e=x[d>>2];g=x[c>>2];h=c,i=g-gd((gd(0-g|0,31)&255)+g|0,8)|0,x[h>>2]=i;h=d,i=x[d>>2]-gd(e+(gd(0-e|0,31)&255)|0,8)|0,x[h>>2]=i;e=(f<<3)+a|0;x[e>>2]=x[c>>2];x[e+4>>2]=x[d>>2];f=f+1|0;continue}}Vb(a,0,b<<3)}}function JL(a){a=a|0;var b=0,c=0;c=db-16|0;db=c;b=x[a+4232>>2];b=(b>>>1)+(b>>>6)|0;x[a+4220>>2]=b;x[23549]=0;x[c+12>>2]=0;S(884,a+4208|0,b<<1,c+12|0);b=x[23549];x[23549]=0;a:{if((b|0)==1){b=T(92296)|0;if((eb|0)!=($(92296)|0)){break a}Y(b|0)|0;x[a+4220>>2]=0;Z()}x[a+4224>>2]=0;db=c+16|0;return}Q(b|0);p()}function z9(a,b){a=a|0;b=b|0;var c=0;c=x[a+20>>2];b=x[c+4>>2];a:{if(!((Pc(b,x[c+8>>2])|0)!=8|(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))!=1869112133)){c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4260>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[a+4264>>2]=c;break a}Rx(a,a)}Os(a)}function xea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=db-80|0;db=d;c=db-16|0;db=c;NT(c+8|0,d);e=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){dd(a,x[c+12>>2])}db=c+16|0;e=(e|0)==(f|0);if(!e){VA(d)}c=-1;a:{if(!e){break a}c=0;if(!xQ(d)){break a}c=Ge(a,b,wQ(d),hb)}db=d+80|0;return c|0}function hfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=db-16|0;db=d;c=db-16|0;db=c;x[c+12>>2]=477218588;x[c+8>>2]=2147483647;e=Cb(c+12|0,c+8|0);db=c+16|0;if(A[e>>2]<b>>>0){Rc();p()}c=Hc(D(b,9));x[d+12>>2]=b;x[d+8>>2]=c;b=x[d+8>>2];x[a+4>>2]=b;x[a>>2]=b;f=wb(a),g=b+D(x[d+12>>2],9)|0,x[f>>2]=g;db=d+16|0}function Or(a,b,c,d){var e=0;a:{if(!(d&2048)){break a}e=d&74;if(!c|((e|0)==8|(e|0)==64)){break a}v[a|0]=43;a=a+1|0}if(d&512){v[a|0]=35;a=a+1|0}while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;b:{if((e|0)==64){break b}b=d&16384?88:120;if((e|0)==8){break b}b=c?100:117}v[a|0]=b}function MZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=db-16|0;db=f;x[e>>2]=c;a=ow(f+12|0,0,x[a+8>>2]);b=2;a:{if(a+1>>>0<2){break a}c=a-1|0;b=1;if(c>>>0>d-x[e>>2]>>>0){break a}b=f+12|0;while(1){if(c){a=y[b|0];d=x[e>>2];x[e>>2]=d+1;v[d|0]=a;c=c-1|0;b=b+1|0;continue}break}b=0}db=f+16|0;return b|0}function $ja(a,b){a=a|0;b=b|0;var c=0;Au(a,b);Qf(b);a=y[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=y[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48){break a}v[b+3|0]=45;v[b+5|0]=a&15;return}if((a|0)!=64){break a}v[b+3|0]=0;v[b|0]=254;return}v[b+3|0]=20;v[b+5|0]=a&15|160;return}v[b+3|0]=0}}function vt(a){var b=0,c=0;b=x[a+76>>2];a:{if(!((b|0)>=0&(!b|x[116037]!=(b&-1073741825)))){b=x[a+4>>2];if((b|0)!=x[a+8>>2]){x[a+4>>2]=b+1;a=y[b|0];break a}a=Jw(a);break a}b=a+76|0;c=x[b>>2];x[b>>2]=c?c:1073741823;c=x[a+4>>2];b:{if((c|0)!=x[a+8>>2]){x[a+4>>2]=c+1;a=y[c|0];break b}a=Jw(a)}Zd(b)}return a}function oP(a,b,c){var d=0,e=0,f=0,g=0;if(c==0){e=a;b=Ir(b);o(0);a=j(1)|0;f=j(0)|0;o(+c);d=j(1)|0;j(0)|0;l(0,f|0);l(1,a&2147483647|d&-2147483648);fl(e,b,+n());return}a:{if(!df(b)){break a}d=F(c)<Infinity;if(b<0){c=d?c:1;break a}if(d){break a}fl(a,b,df(c)?NaN:c);return}b=Ir(b);g=ui(c);fl(a,b*Pe(c),g*b)}function XO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{e=db-16|0;db=e;b:{c:{if((b|0)==(c|0)){b=a;a=Mb(d);vg(b,a,Bb(x[d+4>>2],y[d+11|0])+a|0);break c}f=e+4|0;PO(f,c,d);x[23549]=0;S(43,a|0,b|0,f|0);a=x[23549];x[23549]=0;if((a|0)==1){break b}Ec(e+4|0)}db=e+16|0;break a}a=N()|0;Ec(e+4|0);Q(a|0);p()}}function zJ(a,b,c,d){var e=0,f=0,g=0;b=he(b,od(a));a:{f=Bb(x[a+4>>2],y[a+11|0]);if(b>>>0<=f>>>0){if(c){e=Mc(a);b:{if(e-f>>>0>=c>>>0){e=Mb(a);if((b|0)==(f|0)){break b}g=b+e|0;pl(g+c|0,g,f-b|0);break b}xy(a,e,(c+f|0)-e|0,f,b,c);e=x[a>>2]}sl(b+e|0,c,d);b=c+f|0;Wg(a,b);hd(b+e|0,0)}break a}mq();p()}od(a)}function rka(a){a=a|0;var b=0,c=0,d=0;c=db-32|0;db=c;b=255;a:{if(bj(x[a>>2],x[a+4>>2])>>>0<=49){b=Dz(c,x[a+12>>2]);x[23549]=0;P(278,a|0,b|0);d=x[23549];x[23549]=0;if((d|0)==1){break a}Tj(b);oj(a,bj(x[a>>2],x[a+4>>2])-1&255);b=bj(x[a>>2],x[a+4>>2])-1|0}db=c+32|0;return b&255}a=N()|0;Tj(b);Q(a|0);p()}function nK(a,b){var c=0,d=0;c=db-32|0;db=c;d=c+8|0;lh(d,b);x[23549]=0;S(1038,c+20|0,0,d|0);b=x[23549];x[23549]=0;a:{b:{if((b|0)!=1){x[23549]=0;P(1039,a|0,c+20|0);a=x[23549];x[23549]=0;if((a|0)==1){break b}Ec(c+20|0);tb(c+8|0);db=c+32|0;return}b=N()|0;break a}b=N()|0;Ec(c+20|0)}tb(c+8|0);Q(b|0);p()}function FU(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28490681|y[a+68|0]!=13|(y[a+69|0]!=10|y[a+70|0]!=26)){break a}if(y[a+76|0]|((y[a+71|0]|y[a+72|0]<<8|(y[a+73|0]<<16|y[a+74|0]<<24))!=1397116231|y[a+75|0]!=1)){break a}b=((y[a+116|0]|y[a+117|0]<<8)-1&65535)>>>0<9}return b}function EB(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=db-32|0;db=f;x[f+8>>2]=c;g=f,h=rf(b),x[g+28>>2]=h;c=f+8|0;Df(c,b,x[Cb(c,f+28|0)>>2]);b=Ee(c);x[23549]=0;aa(225,a|0,b|0,x[f+8>>2],d|0,e|0);a=x[23549];x[23549]=0;if((a|0)!=1){Jc(f+8|0);db=f+32|0;return}a=N()|0;Jc(f+8|0);Q(a|0);p()}function Z7(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=6){c=Fd(c,E(0));a:{b:{switch(b-1|0){case 0:c=Rh(c);if(c==B[xb(a+4208|0,1)>>2]){break a}x[a+4236>>2]=0;B[a+4240>>2]=E(c*E(.5))+E(.5);break a;case 3:break b;default:break a}}c=E(Rh(E(c*E(4)))*E(.25))}d=xb(a+4208|0,b),e=c,B[d>>2]=e;Ix(a)}}function P2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{if(!x[b+28>>2]){c=x[d>>2];break a}e=ib[x[b+32>>2]](x[b+24>>2],c,0,0)|0;c=x[d>>2];if((e|0)<0){break a}d=x[d+4>>2];e=c;while(1){if(!d){break a}f=ib[x[b+28>>2]](x[b+24>>2],e,d)|0;if(!f){break a}g=f+g|0;d=d-f|0;e=e+f|0;continue}}dc(a,c,g)}function E8(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=6){c=Fd(c,E(0));a:{b:{switch(b-3|0){case 0:c=Rh(c);if(c==B[xb(a+4208|0,3)>>2]){break a}x[a+4236>>2]=0;B[a+4240>>2]=E(c*E(.5))+E(.5);break a;case 1:break b;default:break a}}c=E(Rh(E(c*E(4)))*E(.25))}d=xb(a+4208|0,b),e=c,B[d>>2]=e;Ix(a)}}function yf(a){a=a|0;var b=0,c=0;x[a>>2]=44528;b=x[a+12>>2];if(x[b>>2]==(a|0)){x[b>>2]=x[a+4>>2]}b=x[a+20>>2];if(b){x[b>>2]=0;x[a+20>>2]=0}b=x[a+4>>2];if(b){x[b+8>>2]=x[a+8>>2]}c=x[a+8>>2];if(c){x[c+4>>2]=b}x[a+4>>2]=0;x[a+8>>2]=0;b=x[a+16>>2];x[b+946300>>2]=x[b+946300>>2]-1;BL(a+44|0);return a|0}function sq(a){var b=0,c=0;b=db-32|0;db=b;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b>>2]=0;x[b+4>>2]=0;c=a+288|0;Jz(c,pQ(c),b);x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b>>2]=0;x[b+4>>2]=0;a=a+800|0;Jz(a,Wz(a),b);db=b+32|0}function Xl(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=db-16|0;db=d;a:{if(!(c&32)){break a}c=od(b);x[d+12>>2]=c;g=tf(b);while(1){if(!Kb(c,g)){break a}f=Zf(97);e=v[c|0];b:{if((f|0)>(e|0)){break b}if((Zf(122)|0)<(e|0)){break b}h=c,i=(Zf(65)-f|0)+e|0,v[h|0]=i}c=x[Oe(d+12|0)>>2];continue}}ad(a,b);db=d+16|0}function XY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(Kg(a,x[b+8>>2],0)){gw(b,c,d);return}f=x[a+12>>2];JF(x[a+16>>2],x[a+20>>2],b,c,d);e=a+24|0;a=(a+16|0)+(f<<3)|0;a:{if(e>>>0>=a>>>0){break a}while(1){JF(x[e>>2],x[e+4>>2],b,c,d);if(y[b+54|0]){break a}e=e+8|0;if(a>>>0>e>>>0){continue}break}}}function r5(a){a=a|0;var b=0;x[23549]=0;W(927,a|0);b=x[23549];x[23549]=0;if((b|0)!=1){return wp(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[23549]=0;V(914,7019,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function qba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=rc(a,b,614);e=c+616|0;a=0;while(1){d=D(a,872);Mp(d+e|0,(b+d|0)+616|0);a=a+1|0;if((a|0)!=256){continue}break}a=cA(c+223848|0,b+223848|0);x[23549]=0;O(780,c+223860|0,b+223860|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){return c|0}b=N()|0;bc(a);Q(b|0);p()}function q5(a){a=a|0;var b=0;x[23549]=0;W(927,a|0);b=x[23549];x[23549]=0;if((b|0)!=1){return ys(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[23549]=0;V(914,6728,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function n5(a){a=a|0;var b=0;x[23549]=0;W(927,a|0);b=x[23549];x[23549]=0;if((b|0)!=1){return xs(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[23549]=0;V(914,7378,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function H9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ni(a,b,c,d);x[a>>2]=44060;b=Nb(a+4208|0);x[a+4228>>2]=0;x[a+4220>>2]=0;x[a+4224>>2]=0;x[a+4232>>2]=x[c+24620>>2];YV(a+4260|0,80,150,80,255);x[23549]=0;P(878,a+44|0,2);c=x[23549];x[23549]=0;if((c|0)!=1){mi(a);return a|0}c=N()|0;sc(b);yf(a);Q(c|0);p()}function Gq(a,b,c,d,e){var f=0,g=0,h=0;f=db-16|0;db=f;a:{b:{while(1){h=g&255;if(h>>>0>3){break b}if(!Lq(b,c,h>>>0>1)){sh(b,d);sh(c,e);g=g+1|0;continue}break}v[f+15|0]=0;st(a,0,f+15|0);break a}g=a;a=y[b|0];if(th(a)>>>0>th(y[d|0])>>>0){sh(b,d);sh(c,e);a=y[b|0]}st(g,a,c);v[b|0]=0;v[c|0]=0}db=f+16|0}function CL(a){a=a|0;var b=0,c=0,d=0;b=C[a+4264>>3]*+A[x[a+16>>2]+1074376>>2];a:{if(F(b)<0x8000000000000000){d=~~b>>>0;c=F(b)>=1?~~(b>0?H(J(b*2.3283064365386963e-10),4294967295):K((b-+(~~b>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break a}c=-2147483648}C[a+4256>>3]=b-(+(d>>>0)+ +(c|0)*4294967296)}function xF(a,b,c,d,e){var f=0;f=db-32|0;db=f;b=qg(f+8|0,b);x[23549]=0;S(e|0,f+20|0,b|0,c|0);e=x[23549];x[23549]=0;a:{b:{if((e|0)!=1){x[23549]=0;S(d|0,a|0,f+20|0,c|0);a=x[23549];x[23549]=0;if((a|0)==1){break b}tb(f+20|0);tb(b);db=f+32|0;return}c=N()|0;break a}c=N()|0;tb(f+20|0)}tb(b);Q(c|0);p()}function oF(a,b,c){var d=0;x[23549]=0;W(927,a|0);d=x[23549];x[23549]=0;if((d|0)!=1){return z[x[x[a+24>>2]+24>>2]+c>>1]}Y(T(0)|0)|0;x[23549]=0;V(914,b|0,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function fz(a,b){var c=0,d=0,e=0,f=0,g=0;d=db-16|0;db=d;ze(d+8|0,b);f=x[d+8>>2];b=x[d+12>>2];c=db-16|0;db=c;e=Bb(x[a+4>>2],y[a+11|0]);x[c+12>>2]=e;x[c+8>>2]=b;g=Cb(c+12|0,c+8|0);a=Un(Mb(a),f,x[g>>2]);a:{if(a){break a}a=-1;if(b>>>0>e>>>0){break a}a=b>>>0<e>>>0}db=c+16|0;db=d+16|0;return a>>>31|0}function aw(a,b,c){var d=0;x[23549]=0;W(927,a|0);d=x[23549];x[23549]=0;if((d|0)!=1){return x[x[x[a+24>>2]+24>>2]+c>>2]}Y(T(0)|0)|0;x[23549]=0;V(914,b|0,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function G5(a){a=a|0;var b=0;x[23549]=0;W(927,a|0);b=x[23549];x[23549]=0;if((b|0)!=1){return+ZM(x[x[a+24>>2]+24>>2])}Y(T(0)|0)|0;x[23549]=0;V(914,10032,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Pf(a){var b=0,c=0,d=0;a:{b:{b=a;if(!(b&3)){break b}if(!y[a|0]){return 0}while(1){b=b+1|0;if(!(b&3)){break b}if(y[b|0]){continue}break}break a}while(1){c=b;b=b+4|0;d=x[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}while(1){b=c;c=b+1|0;if(y[b|0]){continue}break}}return b-a|0}function qR(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=860902483){break a}if(Hb(y[a+4|0]|y[a+5|0]<<8)>>>0>2|y[a+6|0]>128){break a}if(Hb(y[a+200|0]|y[a+201|0]<<8)>>>0>3999){break a}if(!Hb(y[a+140|0]|y[a+141|0]<<8)){break a}b=(Hb(y[a+148|0]|y[a+149|0]<<8)|0)==50}return b}function Jg(a,b){var c=0,d=0,e=0,f=0;d=db-16|0;db=d;a:{if(!b){b=0;break a}c=b>>31;e=(c^b)-c|0;c=G(e);zf(d,e,0,0,0,c+81|0);e=0+x[d+8>>2]|0;c=(x[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=x[d+4>>2];b=x[d>>2]}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=e;x[a+12>>2]=f;db=d+16|0}function _B(a,b,c){var d=0,e=0,f=0;d=db-32|0;db=d;x[d+28>>2]=c;x[d+8>>2]=192;e=x[a>>2];f=x[a+8>>2];c=x[Cb(d+28|0,d+8|0)>>2];if(!Lb(e,f,c)){c=rf(a)}e=d+8|0;Hq(e,b);f=ec(d+16|0,x[d+8>>2],c);lc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);Hq(e,b);Vb(x[d+8>>2]+c|0,0,192-c|0);Zb(a,x[d+28>>2]);db=d+32|0}function DH(a,b,c){var d=0,e=0,f=0,g=0;d=db-16|0;db=d;a=ws(a);x[a+32>>2]=b;x[a>>2]=77484;Nc(d+12|0,x[a+4>>2]);x[23549]=0;b=R(1095,x[d+12>>2])|0;e=x[23549];x[23549]=0;if((e|0)!=1){Xb(d+12|0);x[a+40>>2]=c;x[a+36>>2]=b;f=a,g=wn(b),v[f+44|0]=g;db=d+16|0;return}b=N()|0;Xb(d+12|0);Pn(a);Q(b|0);p()}function AH(a,b,c){var d=0,e=0,f=0,g=0;d=db-16|0;db=d;a=PH(a);x[a+32>>2]=b;x[a>>2]=77852;Nc(d+12|0,x[a+4>>2]);x[23549]=0;b=R(1096,x[d+12>>2])|0;e=x[23549];x[23549]=0;if((e|0)!=1){Xb(d+12|0);x[a+40>>2]=c;x[a+36>>2]=b;f=a,g=wn(b),v[f+44|0]=g;db=d+16|0;return}b=N()|0;Xb(d+12|0);$r(a);Q(b|0);p()}function mU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=db+-64|0;db=c;d=c+44|0;Df(d,a,32);a=x[c+44>>2];e=c+20|0;Tf(e,2,Ee(d),a);x[23549]=0;P(208,c+32|0,e|0);a=x[23549];x[23549]=0;if((a|0)!=1){a=c+12|0;Nm(a,b);b=a;a=c+32|0;Al(b,a);tb(a);Jc(c+44|0);db=c- -64|0;break a}a=N()|0;Jc(c+44|0);Q(a|0);p()}}function VQ(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=db-16|0;db=e;x[e+12>>2]=6553600;i=e,j=$b(b),x[i+8>>2]=j;f=+(d>>>0)/6553600;g=e+12|0;b=e+8|0;h=wq(f*+A[Cb(g,b)>>2]);x[e+8>>2]=6553600;i=e,j=$b(c),x[i+4>>2]=j;i=e,j=wq(f*+A[Cb(b,e+4|0)>>2]),x[i+12>>2]=j;x[e+8>>2]=d-h;wm(a,h,Cb(b,g));db=e+16|0}function CW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=db-16|0;db=d;x[d+12>>2]=c;a:{if(!Lb(x[b>>2],x[b+8>>2],c<<1)){break a}tc(d+12|0,65535);Sf(a,z[d+12>>1]);c=yb(x[a>>2]);x[d+4>>2]=c;a=yb(x[a+4>>2]);while(1){if(!Kb(c,a)){break a}Qu(b,d+10|0);w[c>>1]=z[d+10>>1];c=x[Se(d+4|0)>>2];continue}}db=d+16|0}function d5(a){a=a|0;var b=0;x[23549]=0;W(927,a|0);b=x[23549];x[23549]=0;if((b|0)!=1){return+C[x[a+24>>2]+16>>3]}Y(T(0)|0)|0;x[23549]=0;V(914,7540,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Z4(a){a=a|0;var b=0;x[23549]=0;W(927,a|0);b=x[23549];x[23549]=0;if((b|0)!=1){return x[x[a+24>>2]+8>>2]}Y(T(0)|0)|0;x[23549]=0;V(914,10780,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return-1}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function UU(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function Jv(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function Dw(a,b,c,d){var e=0,f=0,g=0,h=0;e=db-160|0;db=e;x[e+60>>2]=b;x[e+20>>2]=b;x[e+24>>2]=-1;f=e+16|0;fi(f,0,0);qH(e,f,d,1);d=x[e+8>>2];g=x[e+12>>2];f=x[e>>2];h=x[e+4>>2];if(c){x[c>>2]=((x[e+20>>2]+x[e+136>>2]|0)-x[e+60>>2]|0)+b}x[a+8>>2]=d;x[a+12>>2]=g;x[a>>2]=f;x[a+4>>2]=h;db=e+160|0}function sD(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=x[a+92>>2];e=x[a+96>>2];if(d|e){while(1){if((c|0)==(g|0)){x[a+96>>2]=e;x[a+92>>2]=d}else{f=(g<<3)+b|0;h=x[f>>2];d=d-gd((gd(0-d|0,31)&255)+d|0,8)|0;x[f>>2]=h+d;h=x[f+4>>2];e=e-gd((gd(0-e|0,31)&255)+e|0,8)|0;x[f+4>>2]=h+e;g=g+1|0;continue}break}}}function op(a,b){var c=0,d=0;c=db-16|0;db=c;Nc(c+12|0,a);x[23549]=0;a=R(1115,x[c+12>>2])|0;d=x[23549];x[23549]=0;a:{b:{if((d|0)==1){break b}x[23549]=0;V(1126,a|0,81792,81818,b|0);a=x[23549];x[23549]=0;if((a|0)==1){break b}Xb(c+12|0);db=c+16|0;break a}a=N()|0;Xb(c+12|0);Q(a|0);p()}return b}function dK(a,b,c){var d=0,e=0;while(1){a:{if((a|0)!=(b|0)){e=x[a>>2];d=Pf(e);b:{c:{if((Bb(x[c+4>>2],y[c+11|0])|0)==(d|0)){x[23549]=0;d=U(353,c|0,e|0,d|0)|0;e=x[23549];x[23549]=0;if((e|0)==1){break c}d=!d}else{d=0}break b}T(0)|0;Rb();p()}if(!d){break a}}else{a=b}return a}a=a+8|0;continue}}function Hy(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+813|0];if(c){v[b+813|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Oj(a,b,b+700|0,c<<2,0)}}function dia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=db-16|0;db=d;Ze(b);x[d+12>>2]=0;a:{if(!ak(a,d+12|0)){break a}f=c;c=x[d+12>>2];if(f>>>0<c>>>0){break a}while(1){if((c|0)==(e|0)){e=1;break a}v[d+11|0]=0;if(Ih(a,d+11|0)){Lp(b,v[d+11|0]);e=e+1|0;continue}break}e=0}db=d+16|0;return e|0}function oT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;a=ig(a);b=b+236|0;e=uq(b);a:{while(1){if((b|0)!=(e|0)){d=z[b>>1];w[c+14>>1]=d;if(d){x[23549]=0;S(495,c+4|0,a|0,c+14|0);d=x[23549];x[23549]=0;if((d|0)==1){break a}}b=b+2|0;continue}break}db=c+16|0;return}b=N()|0;KA(a);Q(b|0);p()}function dL(a){a=a|0;var b=0,c=0;c=db-16|0;db=c;b=x[a+4256>>2];x[a+4240>>2]=b<<1;x[23549]=0;x[c+12>>2]=0;S(884,a+4208|0,b<<2,c+12|0);b=x[23549];x[23549]=0;a:{if((b|0)==1){b=T(92296)|0;if((eb|0)!=($(92296)|0)){break a}Y(b|0)|0;x[a+4240>>2]=0;Z()}x[a+4244>>2]=0;db=c+16|0;return}Q(b|0);p()}function vB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=db-32|0;db=e;x[e+8>>2]=c;f=e,g=rf(b),x[f+28>>2]=g;c=e+8|0;Df(c,b,x[Cb(c,e+28|0)>>2]);b=Ee(c);x[23549]=0;V(327,a|0,b|0,x[e+8>>2],d|0);a=x[23549];x[23549]=0;if((a|0)!=1){Jc(e+8|0);db=e+32|0;return}a=N()|0;Jc(e+8|0);Q(a|0);p()}function oba(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(vd(y[b+24|0])){a=ig(a);c=kj(x[b>>2]);d=Bf(b);x[23549]=0;S(783,a|0,c|0,d|0);c=x[23549];x[23549]=0;if((c|0)==1){break a}x[23549]=0;O(782,a+12|0,b+12|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break a}v[a+24|0]=1}return}b=N()|0;VN(a);Q(b|0);p()}function BN(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+814|0];if(c){v[b+814|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Oj(a,b,b+700|0,c,0)}}function fm(a,b,c,d){var e=0,f=0;a:{f=x[(D(b,872)+a|0)+1075648>>2];if(!f){break a}if(!ej(y[f+31|0])){break a}e=y[f+34|0];if((e-1&255)>>>0>249){break a}e=x[(D(e,160)+a|0)+906140>>2];if(!e){break a}ib[x[x[e>>2]+92>>2]](e,f,c,d,b);if(c>>>0>250){break a}w[(D(b,872)+a|0)+1075834>>1]=65535}}function aK(a){var b=0,c=0,d=0,e=0;d=db-16|0;db=d;b=a+120|0;ts(y[b+20|0]);c=db-16|0;db=c;x[c+12>>2]=d+15;a=db-16|0;db=a;e=x[14227];x[a+8>>2]=x[14226];x[a+12>>2]=e;e=x[14225];x[a>>2]=x[14224];x[a+4>>2]=e;b=ib[x[vp(a,Lj(y[b+20|0]))>>2]](c+12|0,b)|0;db=a+16|0;db=c+16|0;db=d+16|0;return b}function _z(a,b,c,d,e){var f=0;a:{f=x[a>>2];if(!Sd(f,x[a+20>>2])|c>>>0>=f>>>0|f-c>>>0<d>>>0){break a}vm(b);b=ro(b,a);x[b+20>>2]=0;x[b>>2]=d;if(!zg(b)){break a}if(x[a>>2]!=(d|0)){cr(b+68|0)}rc(x[b+20>>2],x[a+20>>2]+c|0,d);x[b+8>>2]=e?d:0;x[b+4>>2]=0;w[b+34>>1]=z[b+34>>1]&65533|(e?2:0)}}function yj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=x[a+4>>2];e=x[a+12>>2];i=x[a+8>>2];d=x[a>>2];while(1){if((b|0)!=(f|0)){if(!d){x[a>>2]=8;c=i;if((e|0)!=(c|0)){c=e-1|0;x[a+12>>2]=c}d=8;e=c;c=y[c|0]}g=c;d=d-1|0;x[a>>2]=d;c=g>>>1|0;x[a+4>>2]=c;h=g&1|h<<1;f=f+1|0;continue}break}return h}function gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=db-32|0;db=e;x[e+28>>2]=d;c=jf(a,c);ae(e+8|0,x[a+28>>2]);f=a;a:{if(!c){d=0;if(ed(a,5)){break a}}d=x[a+28>>2];a=0;DC(b,x[e+28>>2]);while(1){if(A[e+28>>2]>a>>>0){NP(d,_b(x[b>>2],a));a=a+1|0;continue}break}d=c}cf(f,d);db=e+32|0}function _L(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=db-16|0;db=d;x[d+12>>2]=b;a:{if(Qh(a)>>>0>=b>>>0){f=x[a>>2];e=oc(f,x[a+4>>2]);x[d+8>>2]=e;ZL(f,x[Cb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){ay(a,b-e|0,c);break a}Dd(a,x[a>>2]+(b<<2)|0);break a}$t(a);Hm(a,eg(a,b));ay(a,b,c)}db=d+16|0}function xh(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;d=db-16|0;db=d;e=db-16|0;db=e;c=e+4|0;x[c+4>>2]=1;g=c,h=Hc(16),x[g+8>>2]=h;b=Zo(x[c+8>>2]);x[b>>2]=42952;g=Zm(kc(b)),h=43084,x[g>>2]=h;b=d+8|0;f=$o(c);_o(b,kc(f),f);_m(c);db=e+16|0;rg(a,b);fe(b);db=d+16|0;x[a+8>>2]=0;Xd(a+12|0);return a}function T3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=db-16|0;db=d;c=d+4|0;Nn(c,a);if(x[b>>2]){Dc(b);a=x[b>>2];Xt(b);Eb(a);e=wb(b),f=0,x[e>>2]=f;x[b>>2]=0;x[b+4>>2]=0}x[b>>2]=x[c>>2];x[b+4>>2]=x[c+4>>2];a=wb(c);e=wb(b),f=x[a>>2],x[e>>2]=f;x[a>>2]=0;x[c>>2]=0;x[c+4>>2]=0;Yf(c);db=d+16|0}function zga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=db-16|0;db=d;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[23549]=0;P(581,a|0,b|0);e=x[23549];x[23549]=0;if((e|0)==1){break a}Lo(a,b,c)}b=d+8|0;Hd(b);ll(b);db=d+16|0;return a|0}a=N()|0;ll(d+8|0);Q(a|0);p()}function Xv(a,b,c,d,e){var f=0,g=0;a:{f=db+-64|0;db=f;g=f+44|0;Df(g,a,e);a=x[f+44>>2];e=f+20|0;Tf(e,d,Ee(g),a);x[23549]=0;P(208,f+32|0,e|0);a=x[23549];x[23549]=0;if((a|0)!=1){a=f+12|0;ec(a,b,c);b=a;a=f+32|0;Al(b,a);tb(a);Jc(f+44|0);db=f- -64|0;break a}a=N()|0;Jc(f+44|0);Q(a|0);p()}}function Lc(a,b,c){var d=0,e=0;d=b^-2147483648;e=a;b=c&31;if((c&63)>>>0>=32){a=0;b=d>>>b|0}else{a=d>>>b|0;b=((1<<b)-1&d)<<32-b|e>>>b}d=c&31;if((c&63)>>>0>=32){c=0;d=-2147483648>>>d|0}else{c=-2147483648>>>d|0;d=((1<<d)-1&-2147483648)<<32-d}e=b-d|0;hb=a-(c+(b>>>0<d>>>0)|0)|0;return e}function qU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=db-16|0;db=d;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[23549]=0;P(402,a|0,b|0);e=x[23549];x[23549]=0;if((e|0)==1){break a}aB(a,b,c)}b=d+8|0;Hd(b);ul(b);db=d+16|0;return a|0}a=N()|0;ul(d+8|0);Q(a|0);p()}function U5(a){a=a|0;var b=0;x[23549]=0;W(952,a|0);b=x[23549];x[23549]=0;a:{if((b|0)==1){Y(T(0)|0)|0;x[23549]=0;V(914,11832,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)==1){break a}Z();a=0}return a|0}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function RW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=db-16|0;db=d;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[23549]=0;P(214,a|0,b|0);e=x[23549];x[23549]=0;if((e|0)==1){break a}BC(a,b,c)}b=d+8|0;Hd(b);Bg(b);db=d+16|0;return a|0}a=N()|0;Bg(d+8|0);Q(a|0);p()}function QK(a,b,c){v[a+12|0]=0;x[c>>2]=0;x[b>>2]=0;x[a+28>>2]=0;x[a+32>>2]=0;w[a+24>>1]=0;x[a+36>>2]=0;x[a+40>>2]=0;x[a+44>>2]=0;x[a+48>>2]=0;PK(a+60|0);PK(a+52|0);Jp(a+49956|0);Jp(a+58148|0);Jp(a+66340|0);Jp(a+74532|0);Vb(a+228|0,0,32768);Vb(a+32996|0,0,512);Vb(a+33508|0,0,16384)}function Pl(a,b){x[a>>2]=0;x[a+4>>2]=0;x[a+20>>2]=0;w[a+16>>1]=65535;x[a+8>>2]=0;x[a+12>>2]=0;x[a+24>>2]=11;x[a+28>>2]=b;Nb(a+32|0);Nb(a+44|0);x[a+72>>2]=0;x[a+76>>2]=0;x[a+64>>2]=0;x[a+56>>2]=0;x[a+60>>2]=0;x[a+80>>2]=0;x[a+84>>2]=0;x[a+88>>2]=0;x[a+92>>2]=0;x[a+96>>2]=0;return a}function NG(a,b,c){var d=0,e=0,f=0;d=a;f=db-16|0;db=f;a:{if(b>>>0<1073741808){b:{if(qp(b)){ff(d,b);break b}hj(f+8|0,Ql(b)+1|0);e=x[f+8>>2];zd(d,e);jg(d,x[f+12>>2]);re(d,b);d=e}e=db-16|0;db=e;x[e+12>>2]=c;cD(d,b,e+12|0);db=e+16|0;zd((b<<2)+d|0,0);db=f+16|0;break a}kg();p()}return a}function AD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=db-16|0;db=d;b:{c:{if(!b){b=a;a=Mb(c);vg(b,a,Bb(x[c+4>>2],y[c+11|0])+a|0);break c}e=d+4|0;PM(e,c);x[23549]=0;S(43,a|0,b|0,e|0);a=x[23549];x[23549]=0;if((a|0)==1){break b}Ec(d+4|0)}db=d+16|0;break a}a=N()|0;Ec(d+4|0);Q(a|0);p()}}function A6(a){a=a|0;var b=0;x[23549]=0;W(927,a|0);b=x[23549];x[23549]=0;if((b|0)!=1){return x[a+16>>2]}Y(T(0)|0)|0;x[23549]=0;V(914,5631,a|0,0,0);a=x[23549];x[23549]=0;if((a|0)!=1){Z();return-1}a=N()|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function q9(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(x[b+4>>2]!=8){break a}b=x[b>>2];if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))!=1869112133){break a}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4260>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[a+4264>>2]=c;Os(a)}}function Tba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=db-16|0;db=d;x[d+12>>2]=b;a:{if(pn(a)>>>0>=b>>>0){f=x[a>>2];e=Pc(f,x[a+4>>2]);x[d+8>>2]=e;Sh(f,x[Cb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){Ro(a,b-e|0,c);break a}Dd(a,x[a>>2]+b|0);break a}pu(a);pk(a,Ek(a,b));Ro(a,b,c)}db=d+16|0}function Oi(a,b,c,d){var e=0,f=0,g=0,h=0;e=db-16|0;db=e;x[e+12>>2]=d;g=ei(e+8|0,b);b=db-16|0;db=b;d=x[e+12>>2];x[b+12>>2]=d;x[b+8>>2]=d;f=-1;d=Tr(0,0,c,d);a:{if((d|0)<0){break a}h=a;d=d+1|0;a=Nd(d);x[h>>2]=a;if(!a){break a}f=Tr(a,d,c,x[b+12>>2])}db=b+16|0;di(g);db=e+16|0;return f}function H8(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(x[b+4>>2]!=8){break a}b=x[b>>2];if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))!=1869112133){break a}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4228>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[a+4232>>2]=c;Js(a)}}function Fr(a,b,c,d,e,f){var g=0,h=0,i=0;g=db-16|0;db=g;Hf(a+12|0,d);a:{if(!b){d=0;b=0;break a}if(b>>>0>=f>>>0){wi();p()}d=Hc(D(b,e));x[g+12>>2]=b;x[g+8>>2]=d;d=x[g+12>>2];b=x[g+8>>2]}x[a>>2]=b;c=b+D(c,e)|0;x[a+8>>2]=c;x[a+4>>2]=c;h=kc(a),i=b+D(d,e)|0,x[h>>2]=i;db=g+16|0;return a}function $s(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!b){break a}i=Ob(a+1074312|0,73)?c- -64|0:c;c=120;g=Zi(a);j=g^-1;e=1;while(1){if(!c){break a}k=c;c=c>>>1|0;h=e+c|0;f=Rg(a,h,i,d);if(!(f>>>0>b>>>0&j)&(!(!f|g)|b>>>0<=f>>>0)){continue}e=h+1|0;c=(c^-1)+k|0;continue}}return e}function aD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=db-16|0;db=d;b:{c:{if(!b){b=a;a=Mb(c);vg(b,a,Bb(x[c+4>>2],y[c+11|0])+a|0);break c}e=d+4|0;PO(e,b,c);x[23549]=0;P(49,a|0,e|0);a=x[23549];x[23549]=0;if((a|0)==1){break b}Ec(d+4|0)}db=d+16|0;break a}a=N()|0;Ec(d+4|0);Q(a|0);p()}}function Rh(a){var b=E(0),c=0,d=0;c=(q(a),j(2));d=c>>>23&255;if(d>>>0<=149){if(d>>>0<=125){return E(a*E(0))}a=(c|0)>=0?a:E(-a);b=E(E(E(a+E(8388608))+E(-8388608))-a);a:{if(b>E(.5)){a=E(E(a+b)+E(-1));break a}a=E(a+b);if(!(b<=E(-.5))){break a}a=E(a+E(1))}a=(c|0)>=0?a:E(-a)}return a}function yP(a,b){var c=0,d=0,e=0,f=0;c=db-96|0;db=c;ZQ(b,c,c+96|0);b=0;while(1){if((b|0)==12){x[a+104>>2]=0;x[a+96>>2]=!(x[a+88>>2]|x[a+92>>2]);x[a+100>>2]=0;db=c+96|0}else{d=b<<3;e=d+a|0;f=c+d|0;d=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=d&65535;b=b+1|0;continue}break}x[a+112>>2]=0}function jD(a,b,c,d){var e=0,f=0,g=0;b=x[a+1076>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1076>>2]=b;c=b+x[a+1080>>2]|0;x[a+1080>>2]=c;e=d;d=x[a+1068>>2];w[e+(d<<1)>>1]=y[a+1084|0]?c:b;x[a+1064>>2]=x[a+1064>>2]+1;f=a,g=Jd(z[x[a+1060>>2]+34>>1])+d|0,x[f+1068>>2]=g;x[a+1072>>2]=x[a+1072>>2]-1}function U2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+60|0;d=Bs(c);x[a>>2]=76944;x[d>>2]=76964;x[a+60>>2]=77004;x[a>>2]=76984;x[a+4>>2]=0;e=c;c=a+8|0;On(e,c);x[a>>2]=76944;x[d>>2]=76964;x[23549]=0;O(80,c|0,b|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){return a|0}a=N()|0;Nk(d);Q(a|0);p()}function L$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=db-16|0;db=g;x[g+12>>2]=b;Nc(g+8|0,x[d+28>>2]);x[23549]=0;b=R(1115,x[g+8>>2])|0;d=x[23549];x[23549]=0;if((d|0)!=1){Xb(g+8|0);IG(a,f+24|0,g+12|0,c,e,b);db=g+16|0;return x[g+12>>2]}a=N()|0;Xb(g+8|0);Q(a|0);p()}function KX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=db-32|0;db=e;x[e+24>>2]=d;x[e+28>>2]=c;x[23549]=0;V(159,e+8|0,b|0,e+28|0,e+24|0);c=x[23549];x[23549]=0;if((c|0)!=1){c=e+16|0;zv(c,x[e+8>>2],x[e+12>>2]);rg(a,c);fe(c);fe(e+8|0);fe(b);db=e+32|0;return}a=N()|0;fe(b);Q(a|0);p()}function K$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=db-16|0;db=g;x[g+12>>2]=b;Nc(g+8|0,x[d+28>>2]);x[23549]=0;b=R(1115,x[g+8>>2])|0;d=x[23549];x[23549]=0;if((d|0)!=1){Xb(g+8|0);HG(a,f+16|0,g+12|0,c,e,b);db=g+16|0;return x[g+12>>2]}a=N()|0;Xb(g+8|0);Q(a|0);p()}function kT(a,b,c,d){var e=0,f=0;e=db-16|0;db=e;x[e+12>>2]=a;a:{if(!(!c|b)){a=Le(+(D(a,d)>>>0)*.25*1e4);break a}if(!(!a|!b)){tc(e+12|0,10);a=D(y[x[e+12>>2]+26864|0],1e4);break a}f=+(a>>>0);if(a-1>>>0<=9){a=Le(733.8401379310345/f*1e4);break a}a=Le(f/.264*1e4)}db=e+16|0;return a}function dka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=db-624|0;db=b;d=-1;c=db-16|0;db=c;e=b+14|0;KV(c+8|0,e);f=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){dd(a,x[c+12>>2])}db=c+16|0;a=(f|0)==(g|0);if(!a){JV(e)}if(a){d=LV(b+14|0)}db=b+624|0;return d|0}function Ifa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=db-160|0;db=b;d=-1;c=db-16|0;db=c;e=b+14|0;RR(c+8|0,e);f=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){dd(a,x[c+12>>2])}db=c+16|0;a=(f|0)==(g|0);if(!a){QR(e)}if(a){d=SR(b+14|0)}db=b+160|0;return d|0}function WV(a){var b=0,c=0,d=0,e=0,f=0;c=db-16|0;db=c;e=Db(a,31),f=0,v[e|0]=f;d=oi(a,mo(a),0);v[c+15|0]=0;d=ri(a,d);am(d+a|0,mo(a),c+15|0);while(1){if((b|0)!=(d|0)){a:{if(v[Db(a,b)|0]>=32){if(y[Db(a,b)|0]!=127){break a}}e=Db(a,b),f=32,v[e|0]=f}b=b+1|0;continue}break}db=c+16|0}function Te(a){var b=0,c=0;b=db-32|0;db=b;v[b+8|0]=0;x[b>>2]=0;x[b+4>>2]=4194432;OC(b+9|0);x[a>>2]=x[b>>2];c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c;c=x[b+16>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=c;c=x[b+24>>2];x[a+20>>2]=x[b+20>>2];x[a+24>>2]=c;v[a+28|0]=y[b+28|0];db=b+32|0}function R$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=db-16|0;db=g;x[g+12>>2]=b;Nc(g+8|0,x[d+28>>2]);x[23549]=0;b=R(18,x[g+8>>2])|0;d=x[23549];x[23549]=0;if((d|0)!=1){Xb(g+8|0);LG(a,f+24|0,g+12|0,c,e,b);db=g+16|0;return x[g+12>>2]}a=N()|0;Xb(g+8|0);Q(a|0);p()}function Q$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=db-16|0;db=g;x[g+12>>2]=b;Nc(g+8|0,x[d+28>>2]);x[23549]=0;b=R(18,x[g+8>>2])|0;d=x[23549];x[23549]=0;if((d|0)!=1){Xb(g+8|0);KG(a,f+16|0,g+12|0,c,e,b);db=g+16|0;return x[g+12>>2]}a=N()|0;Xb(g+8|0);Q(a|0);p()}function L8(a,b){a=a|0;b=b|0;var c=0,d=0;b=db-16|0;db=b;d=x[a+20>>2];c=x[d+4>>2];a:{if(!((Pc(c,x[d+8>>2])|0)!=7|(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))!=1869112133)){c=yb(c);d=yb(x[x[a+20>>2]+8>>2]);Jo(b+8|0,a+4228|0);qu(c,d,x[b+8>>2]);break a}Rx(a,a)}Js(a);db=b+16|0}function Jaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=db-48|0;db=d;Ze(b);e=d+28|0;Df(e,a,c);a=x[d+28>>2];c=d+4|0;Tf(c,1,Ee(e),a);x[23549]=0;P(208,d+16|0,c|0);a=x[23549];x[23549]=0;if((a|0)!=1){a=d+16|0;zb(b,a);tb(a);Jc(d+28|0);db=d+48|0;break a}a=N()|0;Jc(d+28|0);Q(a|0);p()}}function pfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=db-208|0;db=b;d=-1;c=db-16|0;db=c;e=b+4|0;pR(c+8|0,e);f=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){dd(a,x[c+12>>2])}db=c+16|0;a=(f|0)==(g|0);if(!a){oR(e)}if(a){d=qR(b+4|0)}db=b+208|0;return d|0}function eja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=db-160|0;db=b;d=-1;c=db-16|0;db=c;e=b+3|0;EU(c+8|0,e);f=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){dd(a,x[c+12>>2])}db=c+16|0;a=(f|0)==(g|0);if(!a){DU(e)}if(a){d=FU(b+3|0)}db=b+160|0;return d|0}function _ha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=db-16|0;db=b;d=-1;c=db-16|0;db=c;e=b+11|0;Iu(c+8|0,e);f=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){dd(a,x[c+12>>2])}db=c+16|0;a=(f|0)==(g|0);if(!a){FT(e)}if(a){d=GT(b+11|0)}db=b+16|0;return d|0}function Aja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=db-32|0;db=b;d=-1;c=db-16|0;db=c;e=b+10|0;ou(c+8|0,e);f=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){dd(a,x[c+12>>2])}db=c+16|0;a=(f|0)==(g|0);if(!a){UU(e)}if(a){d=VU(b+10|0)}db=b+32|0;return d|0}function ZE(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=db-16|0;db=g;x[g+12>>2]=c;c=g+12|0;tc(c,f);tc(c,65535);h=z[g+12>>1];Sf(a,h);c=0;while(1){if((c|0)==(h|0)){db=g+16|0}else{f=y[b+c|0];i=nk(x[a>>2],x[a+4>>2],c),j=(d|0)==(f|0)?-1:(e|0)==(f|0)?-2:f,w[i>>1]=j;c=c+1|0;continue}break}}function ds(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;d=ac(16);if(!y[469489]){v[469489]=1}a=ec(c+8|0,a,93680);x[23549]=0;e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;a=U(1075,d|0,c|0,b|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){da(a|0,91604,1076);p()}a=N()|0;jc(d);Q(a|0);p()}function bca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=db-16|0;db=d;a=GQ(d+4|0,a+8|0,b);b=x[a>>2];a:{while(1){if(x[a+4>>2]==(b|0)){break a}x[23549]=0;P(725,b|0,c|0);b=x[23549];x[23549]=0;if((b|0)!=1){b=x[a>>2]+32|0;x[a>>2]=b;continue}break}b=N()|0;Kd(a);Q(b|0);p()}Kd(a);db=d+16|0}function PV(a,b){var c=0,d=0,e=0;d=db-16|0;db=d;x[d+12>>2]=b;c=db-16|0;db=c;x[c+12>>2]=153391689;x[c+8>>2]=2147483647;e=Cb(c+12|0,c+8|0);db=c+16|0;c=b;b=x[e>>2];if(c>>>0<=b>>>0){a=KB(a);if(a>>>0<b>>>1>>>0){x[d+8>>2]=a<<1;b=x[Yc(d+8|0,d+12|0)>>2]}db=d+16|0;return b}Rc();p()}function wL(a){a=a|0;var b=0,c=0;c=db-16|0;db=c;b=x[x[a+16>>2]+1074404>>2];x[23549]=0;x[c+12>>2]=0;S(884,a+4208|0,D(b,254)|0,c+12|0);b=x[23549];x[23549]=0;a:{if((b|0)==1){b=T(92296)|0;if((eb|0)!=($(92296)|0)){break a}Y(b|0)|0;Z()}x[a+4220>>2]=0;db=c+16|0;return}Q(b|0);p()}function qea(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(b){x[23549]=0;P(214,a|0,b|0);d=x[23549];x[23549]=0;if((d|0)==1){break a}Lz(a,b)}b=c+8|0;Hd(b);Bg(b);db=c+16|0;return a|0}a=N()|0;Bg(c+8|0);Q(a|0);p()}function qV(a,b){var c=0,d=0,e=0;d=db-16|0;db=d;x[d+12>>2]=b;c=db-16|0;db=c;x[c+12>>2]=89478485;x[c+8>>2]=2147483647;e=Cb(c+12|0,c+8|0);db=c+16|0;c=b;b=x[e>>2];if(c>>>0<=b>>>0){a=mV(a);if(a>>>0<b>>>1>>>0){x[d+8>>2]=a<<1;b=x[Yc(d+8|0,d+12|0)>>2]}db=d+16|0;return b}Rc();p()}function mha(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(b){x[23549]=0;P(532,a|0,b|0);d=x[23549];x[23549]=0;if((d|0)==1){break a}TA(a,b)}b=c+8|0;Hd(b);Bg(b);db=c+16|0;return a|0}a=N()|0;Bg(c+8|0);Q(a|0);p()}function eT(a,b){var c=0,d=0;a:{c=x[b>>2];d=x[b+20>>2];if(!Sd(c,d)){break a}if(x[a+20>>2]==(d|0)){x[a+20>>2]=0;c=x[b>>2]}tc(a,c);c=z[a+34>>1]&-2|w[b+34>>1]&1;w[a+34>>1]=c;w[a+34>>1]=c&65471|z[b+34>>1]&64;if(!zg(a)){break a}rc(x[a+20>>2],x[b+20>>2],pj(x[a>>2],z[a+34>>1]))}}function dE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=db-32|0;db=e;g=x[b+8>>2];f=x[b>>2];Ng(e+16|0,c,d);c=x[x[f>>2]+28>>2];d=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=d;ib[c|0](e+24|0,f,g,e+8|0);Ng(a,x[e+24>>2],x[e+28>>2]);x[b+8>>2]=x[b+8>>2]+x[a+4>>2];db=e+32|0}function aW(a,b){var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>31){break c}d=1<<a;c=1;if(d&-2145904587){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c}function VW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=db-48|0;db=b;d=-1;c=db-16|0;db=c;e=b+7|0;GC(c+8|0,e);f=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){dd(a,x[c+12>>2])}db=c+16|0;a=(f|0)==(g|0);if(!a){FC(e)}if(a){d=HC(b+7|0)}db=b+48|0;return d|0}function N2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=db-32|0;db=e;Ng(e+24|0,b,c);b=rg(e+16|0,d);x[23549]=0;c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;Xf(155,a,x[e+24>>2],x[e+28>>2],e+8|0);a=x[23549];x[23549]=0;if((a|0)!=1){fe(d);db=e+32|0;return}a=N()|0;fe(d);Q(a|0);p()}function tB(a,b,c){var d=0,e=0,f=0,g=0;f=db-16|0;db=f;d=db-32|0;db=d;Od(d+24|0,a,b);a=db-16|0;db=a;e=c;b=x[d+28>>2];c=x[d+24>>2];g=b-c|0;e=e-g|0;x[a+12>>2]=e;uk(e,c,g);vc(d+16|0,b,a+12|0);db=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];vc(f+8|0,a,d+12|0);db=d+32|0;db=f+16|0}function jba(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(ue(c)){c=x[a+4>>2];d=mk(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=1;c=rj(c);if((c|0)!=1){break b}}uG(a,d,1,d,d);c=d}d=x[a>>2];re(a,c+1|0);break a}ff(a,c+1|0);d=a}a=(c<<2)+d|0;zd(a,b);zd(a+4|0,0)}function iD(a,b,c,d){var e=0,f=0;b=x[a+1076>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1076>>2]=b;c=b+x[a+1080>>2]|0;x[a+1080>>2]=c;v[x[a+1068>>2]+d|0]=y[a+1084|0]?c:b;x[a+1064>>2]=x[a+1064>>2]+1;e=a,f=x[a+1068>>2]+Jd(z[x[a+1060>>2]+34>>1])|0,x[e+1068>>2]=f;x[a+1072>>2]=x[a+1072>>2]-1}function fia(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;x[c+12>>2]=b;a:{if(oc(x[a>>2],x[a+4>>2])>>>0>511){break a}if(!ud(b)){break a}x[23549]=0;P(441,a|0,c+12|0);a=x[23549];x[23549]=0;d=b;if((a|0)!=1){break a}a=N()|0;Lf(c+12|0);Q(a|0);p()}Lf(c+12|0);db=c+16|0;return d|0}function fC(a,b,c){var d=0,e=0,f=0;d=db-48|0;db=d;Ze(b);e=d+28|0;Df(e,a,c);a=x[d+28>>2];f=d+4|0;Tf(f,3,Ee(e),a);x[23549]=0;P(208,d+16|0,f|0);e=x[23549];x[23549]=0;if((e|0)!=1){e=b;b=d+16|0;zb(e,b);tb(b);Jc(d+28|0);db=d+48|0;return!c|(a|0)!=0}a=N()|0;Jc(d+28|0);Q(a|0);p()}function Lp(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(ue(c)){c=x[a+4>>2];d=mk(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=10;c=rj(c);if((c|0)!=10){break b}}cm(a,d,1,d,d,0,0);c=d}d=x[a>>2];re(a,c+1|0);break a}ff(a,c+1|0);d=a}a=c+d|0;hd(a,b);hd(a+1|0,0)}function L0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;h=(e-d|0)+b|0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b|0];g=v[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(c|0)!=(h|0)}return a|0}function Dn(a,b,c){var d=0,e=0,f=0;a:{if(!b){d=a;break a}while(1){d=Bka(a,b,10,0);e=hb;a=yka(d,e,246,0)+a|0;c=c-1|0;v[c|0]=a|48;f=b>>>0>9;a=d;b=e;if(f){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;v[c|0]=D(a,246)+d|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function je(a){var b=0,c=0,d=0;o(+a);b=j(1)|0;j(0)|0;d=b>>>20&2047;if(d>>>0<=1074){if(d>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){a=a+c+-1;break a}a=a+c;if(!(c<=-.5)){break a}a=a+1}a=(b|0)>0|(b|0)>=0?a:-a}return a}function Zaa(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(ue(c)){c=x[a+4>>2];d=mk(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=10;c=rj(c);if((c|0)!=10){break b}}xy(a,d,1,d,d,0);c=d}d=x[a>>2];re(a,c+1|0);break a}ff(a,c+1|0);d=a}a=c+d|0;hd(a,b);hd(a+1|0,0)}function Oia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=db-48|0;db=d;e=d+28|0;Df(e,a,c);a=x[d+28>>2];c=d+4|0;Tf(c,2,Ee(e),a);x[23549]=0;P(208,d+16|0,c|0);a=x[23549];x[23549]=0;if((a|0)!=1){a=d+16|0;Em(b,a);tb(a);Jc(d+28|0);db=d+48|0;break a}a=N()|0;Jc(d+28|0);Q(a|0);p()}}function MU(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=db-16|0;db=d;x[d+12>>2]=c;c=d+12|0;tc(c,256);tc(c,65535);f=z[d+12>>1];Sf(a,f);c=0;while(1){if((c|0)==(f|0)){db=d+16|0}else{e=y[b+c|0];g=nk(x[a>>2],x[a+4>>2],c),h=(e|0)==255?-1:(e|0)==254?-2:e,w[g>>1]=h;c=c+1|0;continue}break}}function Gaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=db-48|0;db=d;e=d+28|0;Df(e,a,c);a=x[d+28>>2];c=d+4|0;Tf(c,1,Ee(e),a);x[23549]=0;P(208,d+16|0,c|0);a=x[23549];x[23549]=0;if((a|0)!=1){a=d+16|0;Ce(b,a);tb(a);Jc(d+28|0);db=d+48|0;break a}a=N()|0;Jc(d+28|0);Q(a|0);p()}}function AC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;a=Xu(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];a:{while(1){if((b|0)==(d|0)){break a}x[23549]=0;W(217,b|0);e=x[23549];x[23549]=0;if((e|0)!=1){b=b+20|0;x[a+4>>2]=b;continue}break}b=N()|0;fc(a);Q(b|0);p()}fc(a);db=c+16|0}function uR(a){var b=0,c=0,d=0,e=0;c=db-16|0;db=c;b=yb(x[a>>2]);x[c+12>>2]=b;e=yb(x[a+4>>2]);while(1){a:{d=Kb(b,e);if(!d){break a}a=z[b>>1];b:{if(!((a|0)!=255&(a|0)!=99)){w[b>>1]=65535;break b}if(a>>>0>63){break a}}b=x[Se(c+12|0)>>2];continue}break}db=c+16|0;return d^1}function IV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=db-48|0;db=d;e=d+28|0;Df(e,a,c);a=x[d+28>>2];c=d+4|0;Tf(c,2,Ee(e),a);x[23549]=0;P(208,d+16|0,c|0);a=x[23549];x[23549]=0;if((a|0)!=1){a=d+16|0;zc(b,a);tb(a);Jc(d+28|0);db=d+48|0;break a}a=N()|0;Jc(d+28|0);Q(a|0);p()}}function mj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=yb(x[b>>2]);f=yb(x[b+4>>2]);e=db-16|0;db=e;x[e+12>>2]=d;while(1){a:{if(!Kb(d,f)){break a}if(tV(c,x[d>>2],x[d+4>>2])){break a}d=x[hk(e+12|0)>>2];continue}break}db=e+16|0;if(qc(d,yb(x[b+4>>2]))){xh(a);return}Go(a,d)}function Z8(a){a=a|0;var b=0,c=0,d=0,e=0;b=db-16|0;db=b;x[b+12>>2]=a;x[b+8>>2]=4104;a=0;d=x[b+8>>2];a:{if(d>>>0<4096){break a}c=x[b+12>>2];e=c+7&-8;c=e-c|0;if(c>>>0>d-4096>>>0){break a}x[b+12>>2]=e;x[b+8>>2]=d-c;a=e}if(!a){_(5994,8912,88,7298);p()}db=b+16|0;return a|0}function J$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=db-16|0;db=a;x[a+12>>2]=b;Nc(a+8|0,x[d+28>>2]);x[23549]=0;b=R(1115,x[a+8>>2])|0;d=x[23549];x[23549]=0;if((d|0)!=1){Xb(a+8|0);GG(f+20|0,a+12|0,c,e,b);db=a+16|0;return x[a+12>>2]}b=N()|0;Xb(a+8|0);Q(b|0);p()}function eD(a,b,c){var d=0,e=0,f=0,g=0;d=db-16|0;db=d;e=x[a+4>>2];f=e+b|0;x[a+4>>2]=f;a:{b:{if(!e){g=f-1|0;break b}g=f-1|0;if((g^e-1)>>>0>31){break b}a=x[a>>2];break a}a=x[a>>2];x[a+((f>>>0>=33?g>>>5|0:0)<<2)>>2]=0}Qo(d+8|0,a,e);iv(x[d+8>>2],x[d+12>>2],b,c);db=d+16|0}function e3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{d=db-16|0;db=d;c=d+4|0;x[c+4>>2]=1;f=c,g=Hc(52),x[f+8>>2]=g;e=x[c+8>>2];x[23549]=0;O(1061,e|0,b|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){b=a;a=$o(c);_o(b,kc(a),a);_m(c);db=d+16|0;break a}a=N()|0;_m(c);Q(a|0);p()}}function Js(a){var b=0,c=0,d=E(0);c=y[a+4232|0];if(c>>>0>=5){v[a+4232|0]=0;c=0}if(v[a+4233|0]<0){v[a+4233|0]=127}b=v[a+4234|0];if((b|0)<0){v[a+4234|0]=127;b=127}a:{if((c|0)==3){d=E(E(1)-qe(E(2),E(-E((b&255)+1|0))));break a}d=qe(E(2),E(-E((b&255)>>>0)))}B[a+4224>>2]=d}function Bba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=db-48|0;db=c;d=c+28|0;Df(d,a,32);a=x[c+28>>2];e=c+4|0;Tf(e,1,Ee(d),a);x[23549]=0;P(208,c+16|0,e|0);a=x[23549];x[23549]=0;if((a|0)!=1){a=c+16|0;zc(b,a);tb(a);Jc(c+28|0);db=c+48|0;break a}a=N()|0;Jc(c+28|0);Q(a|0);p()}}function yV(a,b,c){var d=0,e=0;d=db-16|0;db=d;v[d+15|0]=1;v[d+14|0]=a>>>2;a=y[af(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){v[d+13|0]=1;v[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=y[af(d+13|0,d+12|0)|0]}db=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function jp(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-f*e)-b+e*.16666666666666632)}function fca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=db-16|0;db=e;f=jf(a,c);ae(e,x[a+28>>2]);a:{b:{if(!f){c=-1;if(!ed(a,5)){break b}break a}c=x[f+8>>2]}d=x[a+28>>2];c:{d:{switch(c+1|0){case 0:case 2:hi(d,b);break c;default:break d}}aU(d,b,c)}d=f}cf(a,d);db=e+16|0}function dV(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=320012546|(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))!=184619540|y[a+8|0]>1|((y[a+9|0]-1&255)>>>0>7|(y[a+10|0]|y[a+11|0]<<8)>>>0>4096))){b=(y[a+12|0]|y[a+13|0]<<8)>>>0<4097}return b}function X2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(y[b+40|0]){break a}b:{if(!x[b+28>>2]){break b}d=x[c+4>>2];f=x[c>>2];while(1){if(!d){break a}e=ib[x[b+28>>2]](x[b+24>>2],f,d)|0;if(!e){break b}g=e+g|0;d=d-e|0;f=f+e|0;continue}}v[b+40|0]=1}dc(a,x[c>>2],g)}function T0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=Lh(v[b|0]),e=x[x[a>>2]+52>>2],ib[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=dk(b,1,c,x[a+32>>2])}return c|0}function PC(a,b){var c=0,d=0;c=db-16|0;db=c;Nc(c+12|0,a);x[23549]=0;a=R(18,x[c+12>>2])|0;d=x[23549];x[23549]=0;a:{if((d|0)==1){break a}x[23549]=0;a=O(19,a|0,b|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break a}Xb(c+12|0);db=c+16|0;return a}a=N()|0;Xb(c+12|0);Q(a|0);p()}function P$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=db-16|0;db=a;x[a+12>>2]=b;Nc(a+8|0,x[d+28>>2]);x[23549]=0;b=R(18,x[a+8>>2])|0;d=x[23549];x[23549]=0;if((d|0)!=1){Xb(a+8|0);JG(f+20|0,a+12|0,c,e,b);db=a+16|0;return x[a+12>>2]}b=N()|0;Xb(a+8|0);Q(b|0);p()}function iC(a,b,c){var d=0,e=0,f=0;d=db-48|0;db=d;e=d+28|0;Df(e,a,c);a=x[d+28>>2];f=d+4|0;Tf(f,3,Ee(e),a);x[23549]=0;P(208,d+16|0,f|0);e=x[23549];x[23549]=0;if((e|0)!=1){e=b;b=d+16|0;zc(e,b);tb(b);Jc(d+28|0);db=d+48|0;return!c|(a|0)!=0}a=N()|0;Jc(d+28|0);Q(a|0);p()}function vh(a,b){var c=0,d=0,e=0;a:{if(!(v[a+480180|0]&1|b)){break a}e=x[a+24616>>2]&524288;b=0;while(1){if((b|0)==127){break a}c=(b<<5)+a|0;w[c+480286>>1]=64;d=c+480280|0;x[d>>2]=x[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;w[d>>1]=e?c<<8:c?192:64;b=b+1|0;continue}}}function Lt(a,b){a:{b:{if((b|0)!=31){if((b|0)!=15){break b}b=0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1196314451){break b}break a}b=0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=825446227){break a}}b=Hb(y[a+4|0]|y[a+5|0]<<8)>>>0>177}return b}function Bz(a,b,c){var d=0,e=0,f=0;d=db-16|0;db=d;a=Mz(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];a:{while(1){if((b|0)==(e|0)){break a}x[23549]=0;P(725,b|0,c|0);f=x[23549];x[23549]=0;if((f|0)!=1){b=b+32|0;x[a+4>>2]=b;continue}break}b=N()|0;fc(a);Q(b|0);p()}fc(a);db=d+16|0}function p1(a){a=a|0;var b=0,c=0,d=0;c=x[a+44>>2];b=x[a+24>>2];if(c>>>0<b>>>0){x[a+44>>2]=b;c=b}d=-1;a:{if(!(y[a+48|0]&8)){break a}b=x[a+16>>2];if(b>>>0<c>>>0){xn(a,x[a+8>>2],x[a+12>>2],c);b=x[a+16>>2]}a=x[a+12>>2];if(a>>>0>=b>>>0){break a}d=Lh(v[a|0])}return d|0}function Xr(a,b){var c=0,d=0,e=0;d=-1;a:{if((a|0)==-1){break a}e=x[b+76>>2]>=0;b:{c=x[b+4>>2];c:{if(!c){Uw(b);c=x[b+4>>2];if(!c){break c}}if(x[b+44>>2]-8>>>0<c>>>0){break b}}if(!e){break a}return-1}c=c-1|0;x[b+4>>2]=c;v[c|0]=a;x[b>>2]=x[b>>2]&-17;d=a&255}return d}function lP(a,b){var c=0,d=0;x[a+4>>2]=b;x[a>>2]=94204;x[a+20>>2]=0;x[a+24>>2]=0;c=(b>>>5|0)+((b&31)!=0)|0;x[a+12>>2]=c;d=(b>>>0)/(c>>>0)|0;x[a+8>>2]=d;x[a+32>>2]=d>>>0>=31?-1:-1>>>31-d|0;x[a+28>>2]=b>>>0>=c>>>0?-1>>>32-d|0:0;x[a+16>>2]=(D(c,d)-b|0)+c;return a}function Ok(a){var b=0,c=0;a:{b=x[a+1396>>2];if((b|0)>24){break a}if(!b){x[a+1392>>2]=0}while(1){if(y[a+1376|0]?0:x[a+1384>>2]){break a}c=js(a);if((c|0)==-1){break a}b=x[a+1396>>2];x[a+1396>>2]=b+8;x[a+1392>>2]=x[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function xA(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=db-1024|0;db=e;d=db-16|0;db=d;uA(d+8|0,e);f=x[d+12>>2];lc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){Zb(a,x[d+12>>2])}db=d+16|0;if((f|0)==(g|0)){h=vA(e,c)>>>0<=b>>>0}db=e+1024|0;return h}function tU(a){var b=0,c=0,d=0,e=0;d=y[a+32|0]|y[a+33|0]<<8;e=y[a+38|0]|y[a+39|0]<<8;c=y[a+34|0]|y[a+35|0]<<8;b=c+(y[a+36|0]|y[a+37|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=b+e|0;a=(c>>>0>b>>>0?a+1|0:a)<<2|b>>>30;c=d;d=b<<2;b=c+d|0;hb=b>>>0<d>>>0?a+1|0:a;return b}function bn(a,b){var c=0,d=0,e=0,f=0;c=db-16|0;db=c;a:{if(!b){b=0;break a}d=b;b=G(b);zf(c,d,0,0,0,b+81|0);d=0+x[c+8>>2]|0;b=(x[c+12>>2]^65536)+(16414-b<<16)|0;f=e>>>0>d>>>0?b+1|0:b;e=x[c+4>>2];b=x[c>>2]}x[a>>2]=b;x[a+4>>2]=e;x[a+8>>2]=d;x[a+12>>2]=f;db=c+16|0}function XE(a,b,c,d){var e=0;e=db-16|0;db=e;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(e+8|0,x[vb(e+4|0,a)>>2]);a:{if(b){x[23549]=0;P(d|0,a|0,b|0);d=x[23549];x[23549]=0;if((d|0)==1){break a}Ro(a,b,c)}b=e+8|0;Hd(b);Vh(b);db=e+16|0;return a}a=N()|0;Vh(e+8|0);Q(a|0);p()}function R8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;x[a+4>>2]=b;x[a>>2]=0;b=rt(a+8|0,d);x[23549]=0;O(894,a+20|0,c|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){x[a+32>>2]=0;x[a+36>>2]=0;v[a+42|0]=0;v[a+40|0]=0;v[a+41|0]=y[a+41|0]&224|25;return a|0}a=N()|0;Ab(b);Q(a|0);p()}function zN(a,b,c,d){var e=0,f=0,g=0;v[c+851|0]=y[c+851|0]|64;e=a?y[c+813|0]:0;g=(d|0)<0?e:0-e|0;f=(+(a>>>0)+1)*+(d|0)/+(b>>>0);a:{if(F(f)<2147483648){e=~~f;break a}e=-2147483648}x[c+852>>2]=g+(e+x[c+852>>2]|0);b=(a+1|0)==(b|0)?d:e;a=b>>31;v[c+813|0]=(a^b)-a}function w9(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0),f=0,g=E(0);d=db-16|0;db=d;f=d,g=E(E(ib[x[x[a>>2]+48>>2]](a,b))+c),B[f+12>>2]=g;c=E(0);e=B[d+12>>2];a:{if(!(e<E(0))){c=E(1);if(!(e>E(1))){break a}}B[d+12>>2]=c}ib[x[x[a>>2]+44>>2]](a,b,B[d+12>>2]);db=d+16|0}function mz(a,b,c,d){var e=0,f=0,g=0;e=Ud(a);a:{if(e){f=gc(a);while(1){a=e;e=z[a+16>>1];g=x[a+20>>2];if(el(c,d,e,g)){f=a;e=x[a>>2];if(e){continue}break a}if(!el(e,g,c,d)){break a}f=a+4|0;e=x[a+4>>2];if(e){continue}break}break a}a=gc(a);f=a}x[b>>2]=a;return f}function iT(a,b,c){var d=0,e=0;e=Bb(x[a+4>>2],y[a+11|0]);d=Mc(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Mb(a);if(e){pl(c+d|0,d,e);b=(b>>>0>=d>>>0?d+e>>>0>b>>>0?c:0:0)+b|0}b=pl(d,b,c);c=c+e|0;Wg(a,c);hd(b+c|0,0);return a}gq(a,d,(c+e|0)-d|0,e,0,0,c,b)}return a}function Vp(a,b,c,d){var e=0,f=0,g=0;a:{e=gl(a,b);if((e|0)==255){break a}g=x[a>>2];if(Sj(g)){break a}f=$d(a+318|0,e);e=DP(e);if(v[Db(f,10)|0]&1|d){Tg(g,x[a+4>>2],b,e- -64|0,BP(c,y[Db(f,2)|0]))}if(d){break a}Tg(x[a>>2],x[a+4>>2],b,e+67|0,BP(c,y[Db(f,3)|0]))}}function Ny(a,b,c,d){var e=0,f=0,g=0;e=Ud(a);a:{if(e){f=gc(a);while(1){a=e;e=y[a+16|0];g=x[a+20>>2];if(Wn(c,d,e,g)){f=a;e=x[a>>2];if(e){continue}break a}if(!Wn(e,g,c,d)){break a}f=a+4|0;e=x[a+4>>2];if(e){continue}break}break a}a=gc(a);f=a}x[b>>2]=a;return f}function bia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=db-16|0;db=c;Ze(b);v[c+15|0]=0;a:{if(!Ih(a,c+15|0)){break a}f=y[c+15|0];d=1;while(1){if((e&255)==(f|0)){break a}v[c+14|0]=0;if(Ih(a,c+14|0)){Lp(b,v[c+14|0]);e=e+1|0;continue}break}d=0}db=c+16|0;return d|0}function T7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ni(a,b,c,d);x[a>>2]=46692;b=a+4208|0;e=xb(b,0),f=1017370378,x[e>>2]=f;e=xb(b,1),f=0,x[e>>2]=f;x[23549]=0;P(878,a+44|0,2);b=x[23549];x[23549]=0;if((b|0)!=1){mi(a);return a|0}b=N()|0;yf(a);Q(b|0);p()}function QE(a,b,c){var d=0;d=db-16|0;db=d;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);Id(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[23549]=0;P(c|0,a|0,b|0);c=x[23549];x[23549]=0;if((c|0)==1){break a}wF(a,b)}b=d+8|0;Hd(b);Vh(b);db=d+16|0;return a}a=N()|0;Vh(d+8|0);Q(a|0);p()}function I0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=x[b>>2];g=x[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function Uw(a){var b=0,c=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;if(x[a+20>>2]!=x[a+28>>2]){ib[x[a+36>>2]](a,0,0)|0}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;b=x[a>>2];if(b&4){x[a>>2]=b|32;return-1}c=x[a+44>>2]+x[a+48>>2]|0;x[a+8>>2]=c;x[a+4>>2]=c;return b<<27>>31}function RE(a,b,c,d){var e=0,f=0;a:{e=db-48|0;db=e;f=e+28|0;Df(f,a,d);a=x[e+28>>2];d=e+4|0;Tf(d,c,Ee(f),a);x[23549]=0;P(208,e+16|0,d|0);a=x[23549];x[23549]=0;if((a|0)!=1){a=e+16|0;Ce(b,a);tb(a);Jc(e+28|0);db=e+48|0;break a}a=N()|0;Jc(e+28|0);Q(a|0);p()}}function ega(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;a:{if(!Lb(x[b>>2],x[b+8>>2],8)){w[c>>1]=0;b=4;while(1){if(b){d=y[c|0]|y[c+1|0]<<8;v[a|0]=d;v[a+1|0]=d>>>8;b=b-1|0;a=a+2|0;continue}break}break a}Vm(c+8|0,a);pd(c,b,x[c+8>>2],x[c+12>>2])}db=c+16|0}function Z3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=db-32|0;db=d;e=d+4|0;Uk(e,c);c=d+16|0;x[c>>2]=b;ad(c+4|0,e);x[23549]=0;P(1037,a+4|0,c|0);a=x[23549];x[23549]=0;if((a|0)!=1){lj(d+16|0);tb(d+4|0);db=d+32|0;return}a=N()|0;lj(d+16|0);tb(d+4|0);Q(a|0);p()}function XV(a,b,c){var d=0,e=0;d=db-48|0;db=d;Ze(b);e=d+28|0;Df(e,a,c);a=x[d+28>>2];c=d+4|0;Tf(c,2,Ee(e),a);x[23549]=0;P(208,d+16|0,c|0);a=x[23549];x[23549]=0;if((a|0)!=1){a=d+16|0;zb(b,a);tb(a);Jc(d+28|0);db=d+48|0;return}a=N()|0;Jc(d+28|0);Q(a|0);p()}function CH(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=db-16|0;db=e;h=vb(e+8|0,x[x[b>>2]-12>>2]+b|0),i=b,x[h+4>>2]=i;b=d;while(1){if(b){d=x[e+12>>2];g=Hh(b);Lk(d,c+f|0,g);d=x[x[e+12>>2]+4>>2];b=b-d|0;f=d+f|0;if((d|0)==(g|0)){continue}}break}dc(a,c,f);db=e+16|0}function AV(a,b,c){var d=0,e=0;d=db-16|0;db=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}v[d+15|0]=1;v[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=y[af(d+15|0,d+14|0)|0]}a=e;db=d+16|0;return a&255}function oK(a){var b=0,c=0,d=0,e=0;if(!y[a+12|0]){b=db-16|0;db=b;d=vb(b+12|0,x[x[a+8>>2]>>2]);e=x[vb(b+8|0,x[x[a+4>>2]>>2])>>2];c=db-16|0;db=c;a=x[d>>2];x[c+12>>2]=a;while(1){if(sd(a,e)){lj(wk(a));a=x[Jl(c+12|0)>>2];continue}break}db=c+16|0;db=b+16|0}}function oJ(a){var b=0,c=0,d=0,e=0;if(!y[a+12|0]){b=db-16|0;db=b;d=vb(b+12|0,x[x[a+8>>2]>>2]);e=x[vb(b+8|0,x[x[a+4>>2]>>2])>>2];c=db-16|0;db=c;a=x[d>>2];x[c+12>>2]=a;while(1){if(sd(a,e)){Ab(dh(a));a=x[Cj(c+12|0)>>2];continue}break}db=c+16|0;db=b+16|0}}function mE(){var a=0,b=0,c=0;b=db-16|0;db=b;a=Tb(b+4|0,14956);a:{if(!Oc(x[a+4>>2],y[a+11|0])){break a}c=1;if((sg(a,14304)|0)!=-1){break a}if((sg(a,16387)|0)!=-1){break a}if((sg(a,13491)|0)!=-1){break a}c=(sg(a,13534)|0)!=-1}tb(a);db=b+16|0;return c|0}function jX(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-48|0;db=c;d=-1;a:{if(!uD(a,c+12|0)){break a}d=0;if(!tD(c+12|0)){break a}if(b){a=x[b>>2];if(!x[b+4>>2]&a>>>0<$b(y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24))-8>>>0){break a}}d=1}db=c+48|0;return d|0}function Ye(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=a;e=db-16|0;db=e;a:{if(b>>>0<2147483632){b:{if(Do(b)){ff(d,b);break b}yi(e+8|0,fk(b)+1|0);f=x[e+8>>2];zd(d,f);jg(d,x[e+12>>2]);re(d,b);d=f}hd(sl(d,b,c)+b|0,0);db=e+16|0;break a}kg();p()}return a|0}function Taa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{b:{if((b|0)!=437){if((b|0)==1252){break b}d=0;if((b|0)==65001){break a}c:{if((b|0)!=28591){if((b|0)==28605){break c}if((b|0)!=20127){break b}d=1;break a}d=2;break a}d=3;break a}d=5;break a}d=8}aD(a,d,c)}function MA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;qT(a,b);Vc(a,$b(y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24))+504|0);pT(a,d);a:{b=$b(y[b+32|0]|y[b+33|0]<<8|(y[b+34|0]<<16|y[b+35|0]<<24));if(!b){break a}if(!Vc(a,b)){break a}OA(a,c);return}Vb(c,0,80)}function E3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[b>>2];e=x[b+8>>2];f=x[b+4>>2];a=0;a:while(1){b:{b=0;if((a|0)==(f|0)){break b}while(1)if((b|0)==(e|0)){a=a+1|0;continue a}else{c=x[(a<<2)+d>>2]+(b<<3)|0;x[c>>2]=0;x[c+4>>2]=0;b=b+1|0;continue}}break}}function R2(a){a=a|0;var b=0,c=0,d=0;b=db-32|0;db=b;if(!y[a+8|0]){Ji(a+12|0,x[a+4>>2]);ge(b+24|0,x[a+12>>2],x[a+16>>2]);c=x[x[a>>2]+40>>2];d=x[b+28>>2];x[b+8>>2]=x[b+24>>2];x[b+12>>2]=d;ib[c|0](b+16|0,a,0,b+8|0);v[a+8|0]=1}db=b+32|0;return x[a+12>>2]}function Jf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=db-16|0;db=e;Hf(a+12|0,d);a:{if(!b){d=0;b=0;break a}hj(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<2)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=kc(a),g=b+(d<<2)|0,x[f>>2]=g;db=e+16|0;return a|0}function aaa(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-32|0;db=c;w[c+30>>1]=b;b=c+30|0;Pm(c+8|0,b);d=x[c+8>>2];Pm(c,b);b=vg(c+16|0,d,x[c>>2]+2|0);x[23549]=0;O(729,a|0,b|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){tb(b);db=c+32|0;return}a=N()|0;tb(b);Q(a|0);p()}function QF(a,b){var c=0,d=0,e=0,f=0;c=db-16|0;db=c;x[b>>2]=0;v[c+15|0]=0;Ih(a,c+15|0);d=y[c+15|0];e=d>>>2|0;f=d&3;d=0;while(1){x[b>>2]=e;if((d|0)==(f|0)){db=c+16|0}else{v[c+15|0]=0;Ih(a,c+15|0);d=d+1|0;e=x[b>>2]|y[c+15|0]<<(d<<3)-2;continue}break}}function dca(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-32|0;db=c;v[c+31|0]=b;b=c+31|0;Uq(c+8|0,b);d=x[c+8>>2];Uq(c,b);b=vg(c+16|0,d,x[c>>2]+1|0);x[23549]=0;O(729,a|0,b|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){tb(b);db=c+32|0;return}a=N()|0;tb(b);Q(a|0);p()}function kC(a,b,c){var d=0,e=0;d=db-48|0;db=d;e=d+28|0;Df(e,a,c);a=x[d+28>>2];c=d+4|0;Tf(c,3,Ee(e),a);x[23549]=0;P(208,d+16|0,c|0);a=x[23549];x[23549]=0;if((a|0)!=1){a=d+16|0;Em(b,a);tb(a);Jc(d+28|0);db=d+48|0;return}a=N()|0;Jc(d+28|0);Q(a|0);p()}function jI(a,b){var c=0,d=0,e=0;o(+a);d=j(1)|0;e=j(0)|0;c=d>>>20&2047;if((c|0)!=2047){if(!c){if(a==0){c=0}else{a=jI(a*0x10000000000000000,b);c=x[b>>2]+-64|0}x[b>>2]=c;return a}x[b>>2]=c-1022;l(0,e|0);l(1,d&-2146435073|1071644672);a=+n()}return a}function aO(a,b,c,d){var e=0;e=-2147483648;e=!c|!(v[c+15|0]&1)?e:x[c+8>>2];a:{b:{if(!(!d|!(y[d+34|0]&32))){e=z[d+28>>1];break b}if((e|0)==-2147483648){break a}}Yp(b,e,a);if(!Ob(a+1074312|0,10)|y[a+480209|0]&64){break a}x[b+88>>2]=x[b+88>>2]&-257}}function hia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=db-16|0;db=e;while(1){a:{c=x[a>>2];if(oc(c,x[a+4>>2])>>>0>d>>>0){f=e+4|0;qg(f,x[xb(c,d)>>2]+40|0);c=qq(f,b);tb(f);if(!c){break a}g=x[xb(x[a>>2],d)>>2]}db=e+16|0;return g|0}d=d+1|0;continue}}function kaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=db-16|0;db=e;f=jf(a,c);ae(e,x[a+28>>2]);a:{b:{if(!f){c=-1;if(!ed(a,5)){break b}break a}c=x[f+8>>2]}d=x[a+28>>2];c:{if(!((c|0)!=4&(c|0)!=-1)){ak(d,b);break c}aI(d,b,c)}d=f}cf(a,d);db=e+16|0}function wA(a,b,c){var d=0;d=db-16|0;db=d;w[d+12>>1]=c;w[d+14>>1]=b;b=yb(x[a>>2]);c=yb(x[a+4>>2]);a=db-16|0;db=a;x[a+12>>2]=b;while(1){if(Kb(b,c)){if(z[b>>1]==z[d+14>>1]){w[b>>1]=z[d+12>>1]}b=x[Se(a+12|0)>>2];continue}break}db=a+16|0;db=d+16|0}function MQ(a,b){a=a|0;b=b|0;var c=0,d=0;d=db-16|0;db=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+D(b,872);b=x[c+4>>2];a=x[c+8>>2];while(1){if((a|0)==(b|0)){fc(c);db=d+16|0}else{LQ(Vb(b,0,872));b=b+872|0;x[c+4>>2]=b;continue}break}}function yv(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function mp(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=db-16|0;db=c;d=vb(c+12|0,x[a+4>>2]);e=vb(c+8|0,x[a>>2]);f=vb(c+4|0,x[b+4>>2]);g=b,h=AG(x[d>>2],x[e>>2],x[f>>2]),x[g+4>>2]=h;Pb(a,b+4|0);Pb(a+4|0,b+8|0);Pb(wb(a),kc(b));x[b>>2]=x[b+4>>2];db=c+16|0}function kv(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=db-16|0;db=c;d=vb(c+12|0,x[a+4>>2]);e=vb(c+8|0,x[a>>2]);f=vb(c+4|0,x[b+4>>2]);g=b,h=gD(x[d>>2],x[e>>2],x[f>>2]),x[g+4>>2]=h;Pb(a,b+4|0);Pb(a+4|0,b+8|0);Pb(wb(a),kc(b));x[b>>2]=x[b+4>>2];db=c+16|0}function Rq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=db-16|0;db=c;d=vb(c+12|0,x[a+4>>2]);e=vb(c+8|0,x[a>>2]);f=vb(c+4|0,x[b+4>>2]);g=b,h=hD(x[d>>2],x[e>>2],x[f>>2]),x[g+4>>2]=h;Pb(a,b+4|0);Pb(a+4|0,b+8|0);Pb(wb(a),kc(b));x[b>>2]=x[b+4>>2];db=c+16|0}function ip(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-11359647557788195e-27+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function Rb(){var a=0;a=x[23421];x[23549]=0;X(a|0);a=x[23549];x[23549]=0;a:{if((a|0)!=1){x[23549]=0;X(1206);a=x[23549];x[23549]=0;if((a|0)!=1){break a}}Y(T(0)|0)|0;x[23549]=0;X(1206);a=x[23549];x[23549]=0;if((a|0)!=1){break a}T(0)|0;Rb()}p()}function yga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=db-32|0;db=d;e=d+20|0;yp(e,c);Jj(d+12|0,e);x[23549]=0;V(284,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[23549];x[23549]=0;if((a|0)!=1){Ab(d+20|0);db=d+32|0;break a}a=N()|0;Ab(d+20|0);Q(a|0);p()}}function qO(a,b){var c=0,d=0;d=db-16|0;db=d;c=x[a+104>>2];a:{if(!c){break a}c=x[c>>2];if(!c){break a}x[a+76>>2]=c;x[a+88>>2]=x[a+88>>2]&-131|128;x[d+12>>2]=b<<8;x[d+8>>2]=c-1;b=c+(x[Cb(d+12|0,d+8|0)>>2]^-1)|0;x[a>>2]=0;x[a+4>>2]=b}db=d+16|0}function Ol(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=db-16|0;db=e;Hf(a+12|0,d);a:{if(!b){d=0;b=0;break a}yi(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+c|0;x[a+8>>2]=c;x[a+4>>2]=c;f=kc(a),g=b+d|0,x[f>>2]=g;db=e+16|0;return a|0}function Fia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=db-32|0;db=d;e=d+20|0;WA(e,c);Jj(d+12|0,e);x[23549]=0;V(100,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[23549];x[23549]=0;if((a|0)!=1){Ab(d+20|0);db=d+32|0;break a}a=N()|0;Ab(d+20|0);Q(a|0);p()}}function Bia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=db-32|0;db=d;e=d+20|0;dp(e,c);Jj(d+12|0,e);x[23549]=0;V(100,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[23549];x[23549]=0;if((a|0)!=1){Ab(d+20|0);db=d+32|0;break a}a=N()|0;Ab(d+20|0);Q(a|0);p()}}function jL(a,b,c){var d=0,e=0;if(E(F(a))<E(0x8000000000000000)){d=~~a>>>0}else{d=0}e=d&-2147483648;d=e?0-d|0:d;while(1){if(!((d|0)<0|(b|0)<=0)){b=b-1|0;d=d<<1;continue}break}b=(d>>>31|0)+b<<31-c|(d&2147483647)>>>c;return E((e?b^-1|e:b)|0)}function TW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=db-32|0;db=d;e=d+20|0;Uu(e,c);Jj(d+12|0,e);x[23549]=0;V(100,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[23549];x[23549]=0;if((a|0)!=1){Ab(d+20|0);db=d+32|0;break a}a=N()|0;Ab(d+20|0);Q(a|0);p()}}function Qg(a,b){var c=0,d=0,e=0;d=y[a+11|0];c=Bb(x[a+4>>2],d);a:{if((c|0)!=(Bb(x[b+4>>2],y[b+11|0])|0)){break a}a=Mb(a);b=Mb(b);if(!ue(d)){while(1){e=!c;if(!c|y[a|0]!=y[b|0]){break a}b=b+1|0;a=a+1|0;c=c-1|0;continue}}e=!Un(a,b,c)}return e}function DV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=db-32|0;db=d;e=d+20|0;YB(e,c);Jj(d+12|0,e);x[23549]=0;V(100,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[23549];x[23549]=0;if((a|0)!=1){Ab(d+20|0);db=d+32|0;break a}a=N()|0;Ab(d+20|0);Q(a|0);p()}}function xR(a){var b=0,c=0;a:{if(y[a+29|0]!=2){break a}b=y[a+28|0];if((b|0)!=26&(b|0)!=2|y[a+30|0]!=2){break a}b=y[a+31|0];if(b>>>0>21|!(1<<b&3146753)|y[a+33|0]>64){break a}b=y[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}c=vR(a+20|0)}return c}function wN(a,b){a=sN(a);sN(a+368680|0);if(b){rN(a,1);return}if(!y[463072]){wN(94368,1);v[463072]=1}kl(225480,291016,a+131112|0);kl(291016,356552,a+196648|0);kl(356552,422088,a+262184|0);kl(94392,225480,a+24|0);rc(a+327720|0,422088,40960)}function pE(a,b,c,d){var e=0,f=0;a:{if((c|0)==(d|0)){break a}b:{d=d-c|0;if((d|0)>(b-a|0)){break b}f=y[c|0];while(1){e=b-a|0;if((d|0)>(e|0)){break b}a=hq(a,(e-d|0)+1|0,f);if(!a){break b}if(!Un(a,c,d)){break a}a=a+1|0;continue}}a=b}return a}function ce(a,b){var c=0,d=0;c=x[a+4>>2];d=c+b|0;x[a+4>>2]=d;if(x[a+8>>2]>=(d|0)){d=x[a>>2]+(c>>3)|0;a=c&7;c=y[d|0]&255>>>a;a=a+b|0;b=0;while(1){if((a|0)>=9){a=a-8|0;b=c<<a|b;c=y[d+1|0];d=d+1|0;continue}break}a=c>>>8-a|b}else{a=0}return a}function a4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=db-16|0;db=e;d=fp(e+4|0,a,d);f=x[d+4>>2];x[23549]=0;a=ba(1035,wb(a)|0,b|0,c|0,f|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){x[d+4>>2]=a;fc(d);db=e+16|0;return}a=N()|0;fc(d);Q(a|0);p()}function Uia(a){a=a|0;var b=0,c=0,d=0;b=db-32|0;db=b;v[b+30|0]=0;w[b+28>>1]=0;c=ec(b+8|0,b+28|0,3);lc(b+20|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);a:{if(x[b+24>>2]!=3){break a}if(cd(b+28|0,14408,3)){break a}Zb(a,3);d=1}db=b+32|0;return d|0}function SE(a,b,c,d){var e=0,f=0,g=0,h=0;e=db-16|0;db=e;x[e+12>>2]=c;c=e+12|0;tc(c,d);tc(c,65535);d=z[e+12>>1];Sf(a,d);c=0;while(1){if((c|0)==(d|0)){db=e+16|0}else{f=y[b+c|0];g=nk(x[a>>2],x[a+4>>2],c),h=f,w[g>>1]=h;c=c+1|0;continue}break}}function Kea(a){a=a|0;var b=0,c=0,d=0;b=db-32|0;db=b;w[b+28>>1]=0;x[b+24>>2]=0;c=ec(b+8|0,b+24|0,6);lc(b+16|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);a:{if(x[b+20>>2]!=6){break a}if(cd(b+24|0,3856,6)){break a}Zb(a,6);d=1}db=b+32|0;return d|0}function KO(a,b){var c=0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a|0]=c;v[a+1|0]=c>>>8;v[a+2|0]=c>>>16;v[a+3|0]=c>>>24;b=y[b+3|0]|y[b+4|0]<<8|(y[b+5|0]<<16|y[b+6|0]<<24);v[a+3|0]=b;v[a+4|0]=b>>>8;v[a+5|0]=b>>>16;v[a+6|0]=b>>>24}function I2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=db-16|0;db=e;d=It(e+4|0,a,d);f=x[d+4>>2];x[23549]=0;a=ba(1064,wb(a)|0,b|0,c|0,f|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){x[d+4>>2]=a;fc(d);db=e+16|0;return}a=N()|0;fc(d);Q(a|0);p()}function $A(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Nb(a+8|0);x[23549]=0;d=R(188,b|0)|0;e=x[23549];x[23549]=0;b:{if((e|0)==1){break b}x[23549]=0;S(233,a|0,b|0,d|0);a=x[23549];x[23549]=0;if((a|0)==1){break b}break a}a=N()|0;bc(c);Q(a|0);p()}}function mw(a,b){var c=0,d=0,e=0,f=0;c=db-16|0;db=c;w[b>>1]=0;v[c+15|0]=0;Ih(a,c+15|0);d=y[c+15|0];e=d>>>1|0;f=d&1;d=0;while(1){w[b>>1]=e;if(d>>>0>=f>>>0){db=c+16|0}else{v[c+15|0]=0;Ih(a,c+15|0);e=z[b>>1]|y[c+15|0]<<7;d=1;continue}break}}function Dv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=db-16|0;db=e;Ng(e+8|0,b,c);x[23549]=0;Ja(157,a|0,x[e+8>>2],x[e+12>>2]);b=x[23549];x[23549]=0;if((b|0)!=1){x[a+8>>2]=0;rg(a+12|0,d);fe(d);db=e+16|0;return a|0}a=N()|0;fe(d);Q(a|0);p()}function pP(a){var b=0,c=0,d=0,e=0;c=db-16|0;db=c;b=x[a>>2];e=fh(b,x[a+4>>2]);b=yb(b);x[c+12>>2]=b;d=+(e>>>0);a=yb(x[a+4>>2]);while(1){if(Kb(b,a)){C[b>>3]=C[b>>3]/d;C[b+8>>3]=C[b+8>>3]/d;b=x[jl(c+12|0)>>2];continue}else{db=c+16|0}break}}function dC(a){var b=0,c=0,d=0,e=0;c=y[a+2|0];b=c+(y[a+5|0]|y[a+6|0]<<8)|0;c=(b>>>0<c>>>0?1:d)<<1|b>>>31;d=b<<1;b=c;a=y[a+3|0]|y[a+4|0]<<8;c=a>>>30|0;e=d;d=a<<2;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e+47|0;hb=b>>>0<47?a+1|0:a;return b}function bA(a,b){var c=0,d=0,e=0,f=0;c=a&16711680;d=c>>>8|0;e=c<<24;c=a&-16777216;f=c>>>24|0;c=e|c<<8;e=d|f|(a<<24|(a&65280)<<8);d=0;hb=e|(d|d);return((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24)|c}function ZN(a,b){var c=0,d=0;a:{if(!(y[a+89|0]&16)){break a}c=x[a+656>>2];if(!c){break a}c=x[c>>2];b:{if(c){d=a;a=x[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;x[d+696>>2]=a;a=(D(a,x[b>>2])|0)/65536|0;break b}if(x[a+696>>2]){break a}a=0}x[b>>2]=a}}function pO(a,b){var c=0,d=0;a:{if(!(v[a+851|0]&1)){break a}c=x[a+104>>2];if(!c){break a}d=x[c>>2];if(!d){break a}x[a+76>>2]=d;x[a>>2]=0;x[a+4>>2]=d-1;c=x[a+88>>2];x[a+88>>2]=b?c|134:c&-135|128;if(!b){break a}x[a+84>>2]=d;x[a+80>>2]=0}}function fi(a,b,c){var d=0,e=0,f=0,g=0;x[a+112>>2]=b;x[a+116>>2]=c;e=x[a+4>>2];d=x[a+44>>2]-e|0;x[a+120>>2]=d;x[a+124>>2]=d>>31;d=a;a=x[a+8>>2];f=a-e|0;g=f>>31;if(!(!(b|c)|((c|0)>=(g|0)&b>>>0>=f>>>0|(c|0)>(g|0)))){a=b+e|0}x[d+104>>2]=a}function Xja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;tv(c+8|0,b);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;if((d|0)!=(e|0)){v[b+2|0]=0;v[b|0]=0;v[b+1|0]=0}}function Ct(a){var b=0;a:{if(y[a+4|0]|(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1414687062){break a}if(Hb(y[a+6|0]|y[a+7|0]<<8)>>>0>1){break a}if(Hb(y[a+12|0]|y[a+13|0]<<8)){break a}b=(Hb(y[a+16|0]|y[a+17|0]<<8)|0)==20}return b}function oQ(a){var b=0,c=0,d=0;d=mo(a);while(1){if((a|0)!=(d|0)){b=y[a|0];a:{b:{if((b-97&255)>>>0<=5){c=b-32|0;break b}if(!(b-88>>>0<2|b-120>>>0<2)){c=99;if((b|0)==75|(b|0)==107){break b}break a}c=122}v[a|0]=c}a=a+1|0;continue}break}}function VP(a,b,c,d){var e=0,f=0,g=0,h=0;e=db-16|0;db=e;h=x[a+4>>2];f=(h-d|0)+b|0;g=Ei(e+4|0,a,c-f>>1);d=x[g+4>>2];a=f;while(1){if(a>>>0>=c>>>0){fc(g);tB(b,f,h);db=e+16|0}else{tj(d,z[a>>1]);d=d+2|0;x[g+4>>2]=d;a=a+2|0;continue}break}}function F3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=x[b>>2];d=x[b+8>>2];e=x[b+4>>2];a=0;a:while(1){b:{b=0;if((a|0)==(e|0)){break b}while(1)if((b|0)==(d|0)){a=a+1|0;continue a}else{f=eq(c,a,b),g=0,x[f>>2]=g;b=b+1|0;continue}}break}}function zO(a,b,c){var d=0;d=x[b+48>>2]+1|0;x[b+52>>2]=d;a:{if(A[Yb(x[a+484344>>2],z[b+70>>1])+12>>2]>d>>>0){break a}if(!c){w[b+74>>1]=z[b+72>>1]+1}x[b+52>>2]=0;if(!Ob(a+1074312|0,63)){break a}a=x[b+56>>2];x[b+56>>2]=0;x[b+52>>2]=a}}function Pia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;UA(c+8|0,b);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;a=(d|0)==(e|0);if(!a){Vb(b,0,4896)}return a|0}function Df(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Nb(a+8|0);x[23549]=0;S(233,a|0,b|0,c|0);c=x[23549];x[23549]=0;a:{if((c|0)!=1){a=x[a>>2];x[23549]=0;O(174,b|0,a|0)|0;a=x[23549];x[23549]=0;if((a|0)!=1){break a}}a=N()|0;bc(d);Q(a|0);p()}}function s$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ln(a);e=Bb(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Mb(a);gi(d+(e<<2)|0,b,c);b=c+e|0;Wg(a,b);zd(d+(b<<2)|0,0);return a|0}OF(a,d,(c-d|0)+e|0,e,e,0,c,b)}return a|0}function _0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((ib[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=dk(b,4,c,x[a+32>>2])}return c|0}function $U(a,b,c,d){var e=0,f=0,g=0,h=0;e=db-16|0;db=e;h=x[a+4>>2];f=(h-d|0)+b|0;g=Gk(e+4|0,a,c-f|0);d=x[g+4>>2];a=f;while(1){if(a>>>0>=c>>>0){fc(g);tB(b,f,h);db=e+16|0}else{Fk(d,y[a|0]);d=d+1|0;x[g+4>>2]=d;a=a+1|0;continue}break}}function kn(a,b){var c=0,d=0,e=0;a:{c=cG(b);d=db-16|0;db=d;if(c>>>0<1073741808){b:{if(qp(c)){ff(a,c);break b}hj(d+8|0,Ql(c)+1|0);e=x[d+8>>2];zd(a,e);jg(a,x[d+12>>2]);re(a,c);a=e}zd(gi(a,b,c)+(c<<2)|0,0);db=d+16|0;break a}kg();p()}}function UM(a){var b=0,c=0,d=0;c=db-544|0;db=c;a:{if(!(y[a+480210|0]&128)|!x[a+24668>>2]){break a}d=a+1298224|0;b=a+1074992|0;a=Qz(c,x[a+24620>>2]);while(1){if((b|0)==(d|0)){break a}rc(b+112|0,a,538);b=b+872|0;continue}}db=c+544|0}function Qz(a,b){var c=0,d=0,e=0,f=0;w[a+24>>1]=0;x[a+20>>2]=0;c=3546895/+(b>>>0);d=c*.25;a:{if(F(d)<2147483648){b=~~d;break a}b=-2147483648}x[a+16>>2]=b;x[a>>2]=0;x[a+4>>2]=0;e=a,f=WQ(c-+(b<<2)),x[e+8>>2]=f;x[a+12>>2]=hb;return a}function Oy(a,b,c){var d=0,e=0;d=Ud(a);a:{if(d){e=gc(a);while(1){a=d;d=y[a+16|0];if(Xn(c,d)){e=a;d=x[a>>2];if(d){continue}break a}if(!Xn(d,c)){break a}e=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=gc(a);e=a}x[b>>2]=a;return e}function SW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;Wu(c+8|0,b);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;a=(d|0)==(e|0);if(!a){Vb(b,0,65)}return a|0}function xja(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;d=Lb(x[a>>2],x[a+8>>2],64);a:{if(!d){a=0;while(1){if((a|0)!=32){Pq((a<<1)+b|0);a=a+1|0;continue}break}break a}zu(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}db=c+16|0;return d|0}function qW(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;d=Lb(x[a>>2],x[a+8>>2],120);a:{if(!d){a=0;while(1){if((a|0)!=120){tg(a+b|0);a=a+1|0;continue}break}break a}dc(c+8|0,b,120);pd(c,a,x[c+8>>2],x[c+12>>2])}db=c+16|0;return d|0}function pi(a){var b=0,c=0,d=0,e=0;b=ee(a);c=b&63;e=b<<24>>24;a:{if(!(b&64)){break a}b=6;while(1){d=ee(a);c=(d&127)<<b|c;if(d<<24>>24>=0){break a}d=b>>>0<25;b=b+7|0;if(d){continue}break}}return(e|0)<0?(c|0)<0?-2147483648:0-c|0:c}function bg(a,b){var c=0,d=0,e=0,f=0;d=z[a+22>>1];e=d+z[a+20>>1]|0;c=z[a+24>>1]<<17;while(1){if((d|0)==(e|0)){a=(c|0)/32768|0}else{f=c;c=((d&127)<<2)+a|0;c=f-D(x[xb(b,z[c+28>>1])>>2],w[c+26>>1])|0;d=d+1|0;continue}break}return a}function HR(a,b,c){var d=0,e=0,f=0,g=0;while(1){if((b|0)!=(c|0)){d=x[a>>2];e=x[a+4>>2];f=e>>>8|0;g=(e&255)<<24|d>>>8;d=(((y[b|0]^d)&255)<<3)+21232|0;e=x[d>>2];d=x[d+4>>2]^f;x[a>>2]=e^g;x[a+4>>2]=d;b=b+1|0;continue}break}return a}function QX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=db-16|0;db=e;f=x[d>>2];g=x[b+8>>2];if(g>>>0>c>>>0){x[e+12>>2]=g-c;x[e+8>>2]=x[d+4>>2];b=x[b+4>>2]+c|0;h=x[Cb(e+12|0,e+8|0)>>2];_g(b,b+h|0,f)}dc(a,f,h);db=e+16|0}function pB(a,b,c,d){var e=0,f=0,g=0;e=db-16|0;db=e;Hf(a+12|0,d);a:{if(!b){d=0;b=0;break a}vC(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+D(c,20)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=kc(a),g=b+D(d,20)|0,x[f>>2]=g;db=e+16|0;return a}function Jq(a){var b=0,c=0,d=0,e=0;c=db-16|0;db=c;b=db-16|0;db=b;Uq(b+8|0,c+15|0);d=x[b+12>>2];md(b,a,x[b+8>>2],x[b+12>>2]);e=x[b+4>>2];if((e|0)==(d|0)){dd(a,x[b+12>>2])}db=b+16|0;db=c+16|0;return((d|0)==(e|0)?y[c+15|0]:0)&255}function Hl(a,b,c,d){var e=0,f=0,g=0;e=db-16|0;db=e;Hf(a+12|0,d);a:{if(!b){d=0;b=0;break a}qE(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+D(c,12)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=kc(a),g=b+D(d,12)|0,x[f>>2]=g;db=e+16|0;return a}function FM(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=c;h=c>>31;c=0;while(1){if((b|0)!=(c|0)){d=x[a>>2];e=x[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Cc(zka(yka(d,d>>31,g,h),hb,256,0),hb);x[a+4>>2]=f-d;x[a>>2]=d+f;c=c+1|0;a=a+8|0;continue}break}}function DB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=x[a>>2];f=kk(e,x[a+4>>2]);while(1){a:{c=d&65535;if(c>>>0>=f>>>0){break a}c=Rf(e,c);if(!Kb(x[c>>2],x[c+4>>2])){break a}d=d+1|0;continue}break}return($g(a,d&65535,b)?d:-1)&65535}function Cea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=db-32|0;db=d;e=qf(x[b>>2],x[b+4>>2]);c=DQ(d+12|0,c);x[23549]=0;V(697,a|0,b|0,e-1&65535,c|0);a=x[23549];x[23549]=0;if((a|0)!=1){He(c);db=d+32|0;return}a=N()|0;He(c);Q(a|0);p()}function zka(a,b,c,d){var e=0,f=0,g=0,h=0;f=b^d;g=f>>31;e=b>>31;a=a^e;h=a-e|0;e=(b^e)-((a>>>0<e>>>0)+e|0)|0;a=d>>31;b=c^a;f=f>>31;a=Bka(h,e,b-a|0,(a^d)-((a>>>0>b>>>0)+a|0)|0)^f;b=a-f|0;hb=(g^hb)-((a>>>0<f>>>0)+g|0)|0;return b}function xO(a,b,c){var d=0,e=0,f=0;d=db-16|0;db=d;a:{if(!c){break a}x[b+40>>2]=c;if(!c|x[a+480180>>2]!=256){break a}x[d+12>>2]=c>>>4;x[d+8>>2]=1;e=b,f=x[Yc(d+12|0,d+8|0)>>2],x[e+40>>2]=f;e=b,f=$z(c&255),x[e+44>>2]=f}db=d+16|0}function Uga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=db-16|0;db=c;if(eh(178956970)>>>0<b>>>0){Rc();p()}d=Hc(D(b,24));x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=wb(a),f=b+D(x[c+12>>2],24)|0,x[e>>2]=f;db=c+16|0}function Mha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;QA(c+8|0,b);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;a=(d|0)==(e|0);if(!a){RA(b)}return a|0}function Iea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=db-16|0;db=c;if(eh(119304647)>>>0<b>>>0){Rc();p()}d=Hc(D(b,36));x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=wb(a),f=b+D(x[c+12>>2],36)|0,x[e>>2]=f;db=c+16|0}function $ba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;xP(c+8|0,b);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;a=(d|0)==(e|0);if(!a){rz(b)}return a|0}function xt(a,b,c,d){var e=0,f=0,g=0;e=db-16|0;db=e;Hf(a+12|0,d);a:{if(!b){d=0;b=0;break a}HQ(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<5)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=kc(a),g=b+(d<<5)|0,x[f>>2]=g;db=e+16|0;return a}function uj(a,b,c,d){var e=0,f=0,g=0;e=db-16|0;db=e;Hf(a+12|0,d);a:{if(!b){d=0;b=0;break a}mv(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<1)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=kc(a),g=b+(d<<1)|0,x[f>>2]=g;db=e+16|0;return a}function pd(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=db-16|0;db=e;g=x[b+8>>2];f=x[b>>2];x[e+8>>2]=c;x[e+12>>2]=d;h=x[x[f>>2]+28>>2];x[e>>2]=c;x[e+4>>2]=d;ib[h|0](a,f,g,e);x[b+8>>2]=x[b+8>>2]+x[a+4>>2];db=e+16|0}function ir(a,b,c,d){var e=0,f=0,g=0;e=db-16|0;db=e;Hf(a+12|0,d);a:{if(!b){d=0;b=0;break a}ND(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<3)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=kc(a),g=b+(d<<3)|0,x[f>>2]=g;db=e+16|0;return a}function ZT(a,b,c,d){var e=0,f=0,g=0;e=db-16|0;db=e;Hf(a+12|0,d);a:{if(!b){d=0;b=0;break a}WT(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+D(c,6)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=kc(a),g=b+D(d,6)|0,x[f>>2]=g;db=e+16|0;return a}function Wv(a,b,c,d){var e=0,f=0,g=0;e=db-16|0;db=e;Hf(a+12|0,d);a:{if(!b){d=0;b=0;break a}CE(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<4)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=kc(a),g=b+(d<<4)|0,x[f>>2]=g;db=e+16|0;return a}function Tu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;oC(c+8|0,b);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;a=(d|0)==(e|0);if(!a){nC(b)}return a|0}function Tp(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=131072/(C[Xo(b)>>3]-C[a>>3]);b=0;while(1){if((b|0)!=2048){d=-je(f*C[Qe(a,b)>>3]);a:{if(F(d)<2147483648){e=~~d;break a}e=-2147483648}g=xb(c,b),h=e,x[g>>2]=h;b=b+1|0;continue}break}}function St(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;dS(c+8|0,b);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;a=(d|0)==(e|0);if(!a){eS(b)}return a|0}function Pi(a,b,c){c=c&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=y[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(y[a+1|0]|32)!=120){break a}a=a+2|0}return a}function EC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;GC(c+8|0,b);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;a=(d|0)==(e|0);if(!a){FC(b)}return a|0}function iV(a){if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1179011410|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1179472708)){return 1}return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1179472708}function YT(a,b,c){var d=0,e=0,f=0;e=db-16|0;db=e;d=e+4|0;x[d>>2]=x[a+8>>2];f=x[a+8>>2];x[d+8>>2]=a+8;x[d+4>>2]=D(b,6)+f;b=x[d>>2];while(1){if(x[d+4>>2]!=(b|0)){hu(b,c);b=x[d>>2]+6|0;x[d>>2]=b;continue}break}Kd(d);db=e+16|0}function Xs(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=44044;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=43896;break a;case 2:c=43892;break a;case 1:break b;case 0:break c}}c=43888;break a}c=43884}x[a>>2]=x[c>>2]}function Qja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=db-16|0;db=c;if(eh(715827882)>>>0<b>>>0){Rc();p()}d=Hc(D(b,6));x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=wb(a),f=b+D(x[c+12>>2],6)|0,x[e>>2]=f;db=c+16|0}function Ld(a,b){var c=0,d=0,e=0,f=0,g=0;d=z[a+22>>1];g=d+z[a+20>>1]|0;c=d;while(1){a:{if((c|0)!=(g|0)){e=((c&127)<<2)+a|0;f=z[e+28>>1]+b|0;w[e+28>>1]=f;if((f&65535)>>>0<2048){break a}w[a+20>>1]=c-d}return}c=c+1|0;continue}}function AF(a,b,c,d){var e=0,f=0;a:{e=db-32|0;db=e;f=e+20|0;vk(f,c);Jj(e+12|0,f);x[23549]=0;V(d|0,a|0,b|0,x[e+12>>2],x[e+16>>2]);a=x[23549];x[23549]=0;if((a|0)!=1){Ab(e+20|0);db=e+32|0;break a}a=N()|0;Ab(e+20|0);Q(a|0);p()}}function Wfa(a,b){a=a|0;b=b|0;var c=0;b=db-32|0;db=b;c=-1;a:{if(!yB(a,b+20|0)){break a}c=0;if(!cS(b+20|0)){break a}c=-1;if(!xj(a,b+12|0)){break a}c=0;if(!x[b+16>>2]){break a}c=!(x[b+12>>2]&-2139062144)}db=b+32|0;return c|0}function Via(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;x[a+480180>>2]=b;Xz(c,tq(a));d=x[c+12>>2];b=a+1074320|0;x[b>>2]=x[c+8>>2];x[b+4>>2]=d;b=x[c+4>>2];x[a+1074312>>2]=x[c>>2];x[a+1074316>>2]=b;Xs(a+8|0,tq(a));db=c+16|0}function raa(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-32|0;db=c;d=-1;a:{if(!hE(a,c+8|0)){break a}d=0;if(!rM(c+8|0)|(x[b>>2]!=(y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24))|x[b+4>>2]?b:0)){break a}d=1}db=c+32|0;return d|0}function pga(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;d=Lb(x[a>>2],x[a+8>>2],6);a:{if(!d){a=0;while(1){if((a|0)!=6){tg(a+b|0);a=a+1|0;continue}break}break a}sB(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}db=c+16|0;return d|0}function Yt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Mc(a);e=Bb(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Mb(a);We(d+e|0,b,c);b=c+e|0;Wg(a,b);hd(b+d|0,0);return a|0}gq(a,d,(c-d|0)+e|0,e,e,0,c,b)}return a|0}function YE(a,b,c,d,e){var f=0;f=db-32|0;db=f;x[f+24>>2]=a;x[f+28>>2]=b;x[f+16>>2]=d;x[f+20>>2]=e;x[f+8>>2]=c;x[f+12>>2]=0;a=ZB(f+24|0,f+8|0);b=f+16|0;a=zE(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?a:b;db=f+32|0;return x[a>>2]}function ss(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=db-16|0;db=c;d=x[b>>2];b=oc(d,x[b+4>>2]);a=0;while(1){if((a|0)==(b|0)){db=c+16|0}else{x[c+12>>2]=0;e=xc(c+12|0);f=xb(d,a),g=x[e>>2],x[f>>2]=g;a=a+1|0;continue}break}}function Wm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=db-16|0;db=d;a:{if(c){Tb(d+4|0,c);break a}Gb(d+4|0)}x[23549]=0;S(11,a|0,b|0,d+4|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(d+4|0);db=d+16|0;return}a=N()|0;tb(d+4|0);Q(a|0);p()}function Rt(a,b){var c=0,d=0,e=0;if(x[a>>2]){VV(a);c=x[a>>2];KB(a);Eb(c);d=wb(a),e=0,x[d>>2]=e;x[a>>2]=0;x[a+4>>2]=0}x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=wb(b);d=wb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0}function zR(a,b,c){var d=0;d=db-16|0;db=d;v[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|(b>>>0>108|b>>>0>=c>>>0)|c>>>0>108)){v[d+14|0]=(z[(b<<1)+32846>>1]-z[(c<<1)+32846>>1]|0)/5;a=y[Sb(d+15|0,d+14|0)|0]}db=d+16|0;return a&255}function vy(a,b){var c=0;c=x[b+24>>2];c=c>>>0<=1?1:c;x[a+24628>>2]=c>>>0>=512?512:c;a:{if(!(x[b+16>>2]!=x[a+24620>>2]|x[b+20>>2]!=x[a+24624>>2])){c=0;if(x[b+12>>2]==x[a+24616>>2]){break a}}c=1}rc(a+24604|0,b,40);OM(a,c)}function cw(a,b,c,d,e){var f=0,g=0,h=0;f=db-16|0;db=f;g=rg(f+8|0,d);x[23549]=0;h=x[g+4>>2];x[f>>2]=x[g>>2];x[f+4>>2]=h;a=Xf(e,a,b,c,f);b=x[23549];x[23549]=0;if((b|0)!=1){fe(d);db=f+16|0;return a}a=N()|0;fe(d);Q(a|0);p()}function TN(a,b){var c=0,d=0,e=0,f=0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];d=wb(a);c=gc(a);a:{if(!x[d>>2]){x[a>>2]=c;break a}x[x[c>>2]+8>>2]=c;c=gc(b);x[b>>2]=c;x[c>>2]=0;e=wb(b),f=0,x[e>>2]=f}return a}function js(a){var b=0;a:{b=y[a+1376|0];b:{if(!b){b=-1;if(x[a+1384>>2]){break b}if(!ex(a)){break b}b=y[a+1376|0];if(!b){break a}}v[a+1376|0]=b-1;x[a+1400>>2]=x[a+1400>>2]+1;b=Ne(a)}return b}_(15329,13048,1578,5370);p()}function aS(a){var b=0,c=0,d=0,e=0;c=db-16|0;db=c;d=vb(c+12|0,a);a=x[d>>2];if(x[a>>2]){e=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(e|0)){b=b-56|0;cq(b);continue}break}x[a+4>>2]=e;a=x[d>>2];b=x[a>>2];_R(a);Eb(b)}db=c+16|0}function X3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=db-16|0;db=d;e=d+4|0;nK(e,c);a=x[a+1298464>>2];x[23549]=0;S(359,a|0,b|0,e|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(d+4|0);db=d+16|0;return}a=N()|0;tb(d+4|0);Q(a|0);p()}function VU(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=777268804){break a}if($b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))-257>>>0<4294967053){break a}b=!Hb(y[a+8|0]|y[a+9|0]<<8)}return b}function PN(a,b,c,d){var e=0,f=0;e=x[(D(c,872)+b|0)+704>>2];a:{if(!(!(e&134218752)|(d|0)!=1)|e&67108864){break a}b=z[(D(c,872)+b|0)+1402>>1];b=(b?b-1|0:c)&65535;if(b>>>0>126){break a}f=y[((b<<5)+a|0)+480288|0]}return f}function Fj(a,b,c){var d=0,e=0,f=0;d=db-16|0;db=d;dc(d+8|0,b,c);e=x[d+12>>2];lc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){Zb(a,x[d+12>>2])}db=d+16|0;a=(e|0)==(f|0);if(!a){Vb(b,0,c)}return a}function Bja(a){a=a|0;var b=0,c=0,d=0,e=0;b=db-16|0;db=b;if(eh(1073741823)>>>0<=8191){Rc();p()}c=Hc(32768);x[b+12>>2]=8192;x[b+8>>2]=c;c=x[b+8>>2];x[a+4>>2]=c;x[a>>2]=c;d=wb(a),e=c+(x[b+12>>2]<<2)|0,x[d>>2]=e;db=b+16|0}function BT(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function B8(a){a=a|0;var b=0;ib[x[x[a>>2]+128>>2]](a);Ix(a);x[a+4236>>2]=0;v[a+4202|0]=1;b=ib[x[x[a>>2]+192>>2]](a)|0;x[a+4328>>2]=0;x[a+4312>>2]=0;B[a+4240>>2]=b?E(.5):E(1);b=x[a+4256>>2];x[a+4324>>2]=b;x[a+4320>>2]=b}function $ha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=db-16|0;db=d;c=-1;a:{if(!xj(a,d+8|0)){break a}e=x[d+12>>2];c=0;if(!(x[d+8>>2]==(Jm(8876)|0)&e>>>0>255&e>>>0<260)){break a}c=Ge(a,b,e>>>0<259?80:76,0)}db=d+16|0;return c|0}function ZC(a,b){var c=0,d=0;c=db-16|0;db=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Lb(x[a>>2],x[a+8>>2],1)){break b}v[c+15|0]=0;Eg(a,c+15|0);d=v[c+15|0]}db=c+16|0;a=d<<24>>24;break a}_(11081,8977,136,13890);p()}return a}function Yy(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=x[b+480180>>2];if(f&64671904){b=y[(d&15)+43968|0];v[a+2|0]=0;w[a>>1]=b;return}g=a;a=(c&255)==4&(f|0)==4;c=(d&255)<<a<<4;vo(g,(h=Ob(b+1074312|0,66)?0:c,i=c,j=e,j?h:i),a)}function HP(a,b){a:{if(y[a+76|0]==(b|0)){break a}v[a+76|0]=b;if(b){b=0;if(z[a+24>>1]==15){w[a+20>>1]=0;b=1}x[a+8>>2]=0;x[a+16>>2]=b;return}b:{switch(x[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}x[a+16>>2]=3}}function yka(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=D(e,f);g=c&65535;h=a&65535;i=D(g,h);f=(i>>>16|0)+D(f,g)|0;e=(f&65535)+D(e,h)|0;hb=(D(b,c)+j|0)+D(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function xz(a,b,c){var d=0;a:{switch(c+1|0){case 0:case 3:NP(a,b);return;default:break a}}d=db-32|0;db=d;x[d+28>>2]=c;w[d+26>>1]=0;x[d+12>>2]=2;Sr(d+16|0,a,d+26|0,x[Cb(d+28|0,d+12|0)>>2]);w[b>>1]=z[d+26>>1];db=d+32|0}function _y(a,b,c){var d=0,e=0;e=z[a+480192>>1];a:{if(e){if(!Tc(b)|c>>>0>e>>>0){break a}c=x[((c<<2)+a|0)+900380>>2];if(!c){break a}d=z[_b(c+236|0,b-1|0)>>1];break a}d=c}return(z[a+480190>>1]>=(d&65535)>>>0?d:0)&65535}function nI(a,b){var c=0,d=0,e=0;c=db-256|0;db=c;if((b|0)>=2){x[(b<<2)+a>>2]=c;rc(c,x[a>>2],4);while(1){e=(d<<2)+a|0;d=d+1|0;rc(x[e>>2],x[(d<<2)+a>>2],4);x[e>>2]=x[e>>2]+4;if((b|0)!=(d|0)){continue}break}}db=c+256|0}function ica(a){a=a|0;var b=0,c=0;b=db-16|0;db=b;a:{if(!ie(a,10148)){c=b+4|0;cK(c,17161,a);a=Mb(c);x[23549]=0;P(40,44,a|0);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;tb(b+4|0);Q(a|0);p()}db=b+16|0;return}p()}function bx(a){var b=0;a:{b:{while(1){if(x[a+1380>>2]!=-1){break b}b=0;if(!is(a)){break a}if(!(v[a+1375|0]&1)){continue}break}cc(a,32);return 0}x[a+1396>>2]=0;x[a+1400>>2]=0;x[a+1384>>2]=0;v[a+1376|0]=0;b=1}return b}function Faa(a,b){a=a|0;b=b|0;var c=0;b=db-16|0;db=b;c=-1;a:{if(!xj(a,b+8|0)){break a}c=0;if(!vM(x[b+8>>2],x[b+12>>2])){break a}c=b+4|0;a=BR(a,c);if(!a){Dm(c)}c=-1;if(!a){break a}c=uM(x[b+4>>2])}db=b+16|0;return c|0}function jP(a,b){var c=0,d=0,e=0,f=0;e=C[a+48>>3];c=C[a+40>>3];C[a+48>>3]=c;f=C[a+64>>3];d=C[a+56>>3];C[a+64>>3]=d;C[a+40>>3]=b;b=e*C[a+16>>3]+(C[a>>3]*b+c*C[a+8>>3])-d*C[a+24>>3]-f*C[a+32>>3];C[a+56>>3]=b;return b}function lQ(a,b,c,d){var e=0,f=0,g=0;e=db-16|0;db=e;x[e+8>>2]=d;x[e+12>>2]=b;while(1){if(sd(b,c)){b=Gf(b);f=Gf(x[e+8>>2]),g=x[b>>2],x[f>>2]=g;b=fj(e+12|0);fj(e+8|0);b=x[b>>2];continue}break}vc(a,b,e+8|0);db=e+16|0}function iQ(a){var b=0;b=w[a+784>>1];if(b){x[a+692>>2]=(b&32767)-1;if((b|0)<0){x[a+88>>2]=x[a+88>>2]|256}w[a+784>>1]=0}b=y[a+795|0];if(b){v[a+795|0]=0;v[a+838|0]=b-1}b=y[a+796|0];if(b){v[a+796|0]=0;v[a+837|0]=b-1}}function Mp(a,b){a=rc(a,b,88);x[a+88>>2]=x[b+88>>2];rc(a+92|0,b+92|0,576);x[a+668>>2]=x[b+668>>2];rc(a+672|0,b+672|0,52);Ry(a+724|0,b+724|0);Ry(a+732|0,b+732|0);Ry(a+740|0,b+740|0);rc(a+748|0,b+748|0,123);return a}function En(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=c*c;a=d*e*(e*(c*.009465647849436732+.002974357433599673)+(c*.024528318116654728+.05338123784456704))+(d*(c*.13339200271297674+.3333313950307914)+a);return E(b?-1/a:a)}function Maa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-32|0;db=c;a:{if(Qh(a)>>>0<b>>>0){if(eh(1073741823)>>>0<b>>>0){break a}d=wb(a);e=a;a=Jf(c+12|0,b,oc(x[a>>2],x[a+4>>2]),d);lo(e,a);If(a)}db=c+32|0;return}Rc();p()}function qT(a,b){var c=0,d=0,e=0;c=db-16|0;db=c;sT(c+8|0,b);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;a=(d|0)==(e|0);if(!a){rT(b)}return a}function ok(a){tc(a+16|0,x[a>>2]);tc(a+8|0,x[a>>2]);if(A[a+12>>2]>=A[a+16>>2]){x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=z[a+34>>1]&65511}if(A[a+4>>2]>=A[a+8>>2]){x[a+4>>2]=0;x[a+8>>2]=0;w[a+34>>1]=z[a+34>>1]&65529}}function mB(a,b){var c=0,d=0,e=0;c=db-16|0;db=c;KU(c+8|0,b);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;a=(d|0)==(e|0);if(!a){LU(b)}return a}function lT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-32|0;db=c;a:{if(Qm(a)>>>0<b>>>0){if(eh(2147483647)>>>0<b>>>0){break a}d=wb(a);e=a;a=uj(c+12|0,b,Ic(x[a>>2],x[a+4>>2]),d);Rq(e,a);Di(a)}db=c+32|0;return}Rc();p()}function kfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-32|0;db=c;a:{if(tk(a)>>>0<b>>>0){if(eh(357913941)>>>0<b>>>0){break a}d=wb(a);e=a;a=Hl(c+12|0,b,Cd(x[a>>2],x[a+4>>2]),d);iR(e,a);hR(a)}db=c+32|0;return}Rc();p()}function dm(a,b){var c=E(0),d=0,e=0;c=E(1);d=w[a+28>>1];a:{if((d|0)>(b|0)){break a}e=x[a+4>>2];if((oc(e,x[a+8>>2])+d|0)-1<<16>>16<(b|0)){break a}c=B[xb(e,b-d|0)>>2];c=c<=E(10000000036274937e-31)?E(1):c}return c}function ar(a,b,c){var d=0,e=0;d=db-16|0;db=d;if(c>>>0<2147483632){a:{if(Do(c)){ff(a,c);break a}yi(d+8|0,fk(c)+1|0);e=x[d+8>>2];zd(a,e);jg(a,x[d+12>>2]);re(a,c);a=e}hd(We(a,b,c)+c|0,0);db=d+16|0;return}kg();p()}function Vba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-32|0;db=c;a:{if(an(a)>>>0<b>>>0){if(eh(536870911)>>>0<b>>>0){break a}d=wb(a);e=a;a=ir(c+12|0,b,Hg(x[a>>2],x[a+4>>2]),d);oz(e,a);hr(a)}db=c+32|0;return}Rc();p()}function Oaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-32|0;db=c;a:{if(tk(a)>>>0<b>>>0){if(eh(357913941)>>>0<b>>>0){break a}d=wb(a);e=a;a=Hl(c+12|0,b,Cd(x[a>>2],x[a+4>>2]),d);Ov(e,a);wr(a)}db=c+32|0;return}Rc();p()}function Kba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-32|0;db=c;a:{if(iz(a)>>>0<b>>>0){if(eh(613566756)>>>0<b>>>0){break a}d=wb(a);e=a;a=NO(c+12|0,b,hz(x[a>>2],x[a+4>>2]),d);MO(e,a);LO(a)}db=c+32|0;return}Rc();p()}function ty(a,b){var c=0,d=0;c=x[b+4>>2];x[a+24648>>2]=x[b>>2];x[a+24652>>2]=c;d=x[b+20>>2];c=a+24664|0;x[c>>2]=x[b+16>>2];x[c+4>>2]=d;d=x[b+12>>2];c=a+24656|0;x[c>>2]=x[b+8>>2];x[c+4>>2]=d;NM(a+24648|0);UM(a)}function Ut(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;rS(c+8|0,b);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;if((d|0)!=(e|0)){lA(b)}}function KH(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a>>2];a:{if(!c){break a}d=x[c+24>>2];b:{if((d|0)==x[c+28>>2]){b=ib[x[x[c>>2]+52>>2]](c,b)|0;break b}x[c+24>>2]=d+4;x[d>>2]=b}if(!zn(b)){break a}x[a>>2]=0}return a|0}function sG(a,b,c){var d=0,e=0;e=db-16|0;db=e;d=db-32|0;db=d;An(d+24|0,a,b);rl(d+16|0,x[d+24>>2],x[d+28>>2],c);a=XU(a,x[d+16>>2]);x[d+12>>2]=x[d+20>>2];vc(e+8|0,a,d+12|0);db=d+32|0;db=e+16|0;return x[e+12>>2]}function rG(a,b,c){var d=0,e=0;e=db-16|0;db=e;d=db-32|0;db=d;An(d+24|0,a,b);rl(d+16|0,x[d+24>>2],x[d+28>>2],c);a=Zx(a,x[d+16>>2]);x[d+12>>2]=x[d+20>>2];vc(e+8|0,a,d+12|0);db=d+32|0;db=e+16|0;return x[e+12>>2]}function maa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=db-16|0;db=f;c=jf(a,c);ae(f,x[a+28>>2]);a:{b:{if(!c){e=-1;if(!ed(a,5)){break b}break a}e=x[c+8>>2]}ib[d|0](x[a+28>>2],b,e);g=c}cf(a,g);db=f+16|0}function i4(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;d=c+4|0;nK(d,b);a=x[a+1298464>>2];x[23549]=0;S(359,a|0,1,d|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(c+4|0);db=c+16|0;return}a=N()|0;tb(c+4|0);Q(a|0);p()}function hca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=db-16|0;db=e;c=jf(a,c);ae(e,x[a+28>>2]);a:{b:{if(!c){d=-1;if(!ed(a,5)){break b}break a}d=x[c+8>>2]}xz(x[a+28>>2],b,d);f=c}a=cf(a,f);db=e+16|0;return a|0}function gw(a,b,c){var d=0;d=x[a+16>>2];if(!d){x[a+36>>2]=1;x[a+24>>2]=c;x[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(x[a+24>>2]!=2){break a}x[a+24>>2]=c;return}v[a+54|0]=1;x[a+24>>2]=2;x[a+36>>2]=x[a+36>>2]+1}}function g9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;d=Mj(a);if(d){e=x[b+4>>2];b=x[b>>2];x[c+8>>2]=b;x[c+12>>2]=e;a=x[x[d>>2]+72>>2];x[c>>2]=b;x[c+4>>2]=e;a=ib[a|0](d,c)|0}else{a=1}db=c+16|0;return a|0}function vA(a,b){var c=0,d=0,e=0,f=0;d=b?224:240;e=VD(a);a:while(1){if((a|0)!=(e|0)){f=td(a);b=a;while(1)if((b|0)==(f|0)){a=a+16|0;continue a}else{c=((y[Db(b,0)|0]&d)!=0)+c|0;b=b+4|0;continue}}break}return c}function qy(a,b,c){var d=0,e=0;d=x[b+656>>2];if(!d){return 0}d=bv(d,c);a=a+1074312|0;if(!Ob(a,31)){e=Ob(a,93)^1}a:{if(!(v[IM(b,c)+6|0]&1)){a=0;if(!(v[d+12|0]&1)|e){break a}}a=qc(x[d>>2],x[d+4>>2])^1}return a}function dba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=(b-a|0)/160|0;while(1){if((b|0)>0){b=b-1|0;x[a>>2]=x[c>>2];d=a+4|0;if((d|0)!=(c+4|0)){$M(d,x[c+4>>2],x[c+8>>2])}rc(a+16|0,c+16|0,144);a=a+160|0;continue}break}}function WQ(a){a=a*4294967296;if(F(a)<0x8000000000000000){hb=F(a)>=1?~~(a>0?H(J(a*2.3283064365386963e-10),4294967295):K((a-+(~~a>>>0>>>0))*2.3283064365386963e-10))>>>0:0;return~~a>>>0}hb=-2147483648;return 0}function Qv(a,b,c){var d=0,e=0;d=Mb(a);a=Bb(x[a+4>>2],y[a+11|0]);e=Mb(b);b=Bb(x[b+4>>2],y[b+11|0]);a:{if(a>>>0>=c>>>0){if(!b){break a}a=a+d|0;b=pE(c+d|0,a,e,b+e|0);c=(a|0)==(b|0)?-1:b-d|0}else{c=-1}}return c}function dfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;rm(a,b);b=yb(x[a>>2]);x[c+12>>2]=b;a=yb(x[a+4>>2]);while(1){if(Kb(b,a)){d=y[b|0]+(d&255)|0;v[b|0]=d;b=x[Oe(c+12|0)>>2];continue}else{db=c+16|0}break}}function Nu(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function MN(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;c=x[b+28>>2];x[a+24>>2]=x[b+24>>2];x[a+28>>2]=c;c=x[b+20>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=c;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function Et(a,b,c){var d=0,e=0,f=0,g=0;e=db-16|0;db=e;d=db-32|0;db=d;Od(d+24|0,a,b);rl(d+16|0,x[d+24>>2],x[d+28>>2],c);a=x[d+16>>2];f=d,g=WU(c,x[d+20>>2]),x[f+12>>2]=g;vc(e+8|0,a,d+12|0);db=d+32|0;db=e+16|0}function wd(a,b){var c=0,d=0;c=db-16|0;db=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Lb(x[a>>2],x[a+8>>2],1)){break b}v[c+15|0]=0;Eg(a,c+15|0);d=y[c+15|0]}db=c+16|0;break a}_(11081,8977,136,13890);p()}return d}function Wba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Nb(a);d=ig(a+12|0);v[a+32|0]=c;x[a+28>>2]=0;x[a+24>>2]=b;x[23549]=0;P(741,a|0,1);b=x[23549];x[23549]=0;if((b|0)!=1){return a|0}b=N()|0;bP(d);fP(a);Q(b|0);p()}function Gi(a,b,c){var d=0,e=0,f=0;d=db-16|0;db=d;dc(d+8|0,b,c);e=x[d+12>>2];lc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){Zb(a,x[d+12>>2])}db=d+16|0;if((e|0)!=(f|0)){Vb(b,0,c)}}function Fga(a){a=a|0;var b=0,c=0,d=0;b=db-32|0;db=b;w[b+30>>1]=0;c=ec(b+8|0,b+30|0,2);lc(b+20|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);if(!(x[b+24>>2]!=2|z[b+30>>1]!=21584)){Zb(a,2);d=1}db=b+32|0;return d|0}function aka(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;a:{if(!Lb(x[a>>2],x[a+8>>2],64)){a=0;while(1){if((a|0)!=64){tg(a+b|0);a=a+1|0;continue}break}break a}zu(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}db=c+16|0}function _ba(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;a:{if(!Lb(x[a>>2],x[a+8>>2],27)){a=0;while(1){if((a|0)!=27){tg(a+b|0);a=a+1|0;continue}break}break a}xP(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}db=c+16|0}function JP(a){var b=0,c=0,d=0;b=z[a+20>>1];w[a+28>>1]=z[a+22>>1]<<1|(y[x[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){if((b|0)!=4){c=(b<<2)+a|0;d=x[c>>2];if(d){jo(d);IP(x[c>>2])}b=b+1|0;continue}break}}function wf(a,b,c,d,e){var f=0;f=db-256|0;db=f;if(!(e&73728|(c|0)<=(d|0))){d=c-d|0;c=d>>>0<256;Vb(f,b&255,c?d:256);if(!c){while(1){lf(a,f,256);d=d-256|0;if(d>>>0>255){continue}break}}lf(a,f,d)}db=f+256|0}function uS(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;a:{if(!Lb(x[a>>2],x[a+8>>2],32)){a=0;while(1){if((a|0)!=32){tg(a+b|0);a=a+1|0;continue}break}break a}rS(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}db=c+16|0}function cZ(a){a=a|0;var b=0;a:{b:{if(!a){break b}b=Ln(a);if(MF(b,-1)|y[b+13|0]){break b}b=x[b+8>>2];if(b){x[23549]=0;R(b|0,a|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break a}}jc(a)}return}T(0)|0;Rb();p()}function BD(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=808603728|(y[a+4|0]-16&255)>>>0<249|((y[a+5|0]-16&255)>>>0<249|(y[a+6|0]-16&255)>>>0<249))){b=(y[a+7|0]-9&255)>>>0<7}return b}function zea(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;if((b|0)>=0){d=2147483647;a=wt(a);if(a>>>0<=1073741822){x[c+12>>2]=a<<1;x[c+8>>2]=b+31&-32;d=x[Yc(c+12|0,c+8|0)>>2]}db=c+16|0;return d|0}Rc();p()}function wT(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;sB(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;return(b|0)==(d|0)|0}function sn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-32|0;db=c;a:{if(pn(a)>>>0<b>>>0){if(eh(-1)>>>0<b>>>0){break a}d=wb(a);e=a;a=Ol(c+12|0,b,Pc(x[a>>2],x[a+4>>2]),d);mp(e,a);Ml(a)}db=c+32|0;return}Rc();p()}function nha(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;a:{if(!Lb(x[a>>2],x[a+8>>2],2)){a=0;while(1){if((a|0)!=2){tg(a+b|0);a=a+1|0;continue}break}break a}Pm(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}db=c+16|0}function gi(a,b,c){var d=0,e=0;e=db-16|0;db=e;d=db-32|0;db=d;An(d+24|0,b,(c<<2)+b|0);rl(d+16|0,x[d+24>>2],x[d+28>>2],a);b=x[d+16>>2];x[d+12>>2]=x[d+20>>2];vc(e+8|0,b,d+12|0);db=d+32|0;db=e+16|0;return a}function be(a,b){var c=0,d=0,e=0;b=b+7&-8;x[a+8>>2]=b+x[a+8>>2];d=x[a+80>>2];a:{if(d){c=b;b=x[a+88>>2];e=c+b|0;c=0;if((e|0)>x[a+92>>2]){break a}x[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Nd(b)}return c}function _h(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;Vm(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;return(b|0)==(d|0)|0}function Z6(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=x[b+52>>2];if(c&16){d=x[b+48>>2];c=x[b+28>>2];if(d>>>0<c>>>0){x[b+48>>2]=c;d=c}vg(a,x[b+24>>2],d);break a}if(c&8){vg(a,x[b+12>>2],x[b+20>>2]);break a}Gb(a)}}function M7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=db-16|0;db=f;b=Cc(zka(yka(d,d>>31,b,0),hb,1e3,0),hb);x[a+16>>2]=0;x[a+12>>2]=b+c;bL(a,e);b=x[a+12>>2];x[f+12>>2]=0;_L(a,b,f+12|0);db=f+16|0}function FG(a,b,c,d,e,f){var g=0,h=0,i=0;g=db-16|0;db=g;v[g+15|0]=0;v[g+14|0]=f;v[g+13|0]=e;v[g+12|0]=37;if(f){sh(g+13|0,g+14|0)}h=c,i=(Za(b|0,Pc(b,x[c>>2])|0,g+12|0,d|0,a|0)|0)+b|0,x[h>>2]=i;db=g+16|0}function $f(a){var b=0,c=0,d=0,e=0;b=db-16|0;db=b;c=2;if(a>>>0>=2){x[b+12>>2]=a>>>1;x[b+8>>2]=a^-1;d=b,e=x[Cb(b+12|0,b+8|0)>>2]+a|0,x[d+12>>2]=e;x[b+8>>2]=-1;c=x[Cb(b+12|0,b+8|0)>>2]}db=b+16|0;return c}function $V(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;a:{if(!Lb(x[a>>2],x[a+8>>2],8)){a=0;while(1){if((a|0)!=8){tg(a+b|0);a=a+1|0;continue}break}break a}Vm(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}db=c+16|0}function yY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=db-16|0;db=d;f=x[x[b>>2]+20>>2];e=x[c+12>>2];x[d+8>>2]=x[c+8>>2];x[d+12>>2]=e;e=x[c+4>>2];x[d>>2]=x[c>>2];x[d+4>>2]=e;ib[f|0](a,b,d,8);db=d+16|0}function vS(a,b){a=a|0;b=b|0;var c=0,d=0;d=x[a>>2];c=65535;a:{if(!se(d,x[a+4>>2],b)){break a}d=DB(a,x[Rf(d,b)+12>>2]);c=65535;if((d|0)==65535){break a}c=x[a>>2];a=Rf(c,b);mM(Rf(c,d),a);c=d}return c|0}function T8(a){a=a|0;var b=0,c=0,d=0;b=db-32|0;db=b;a:{if(Qh(a)>>>0<=12){if(eh(1073741823)>>>0<=12){break a}c=wb(a);d=a;a=Jf(b+12|0,13,oc(x[a>>2],x[a+4>>2]),c);lo(d,a);If(a)}db=b+32|0;return}Rc();p()}function A2(a,b){a=a|0;b=b|0;var c=0;a=ws(a);x[a>>2]=76264;c=Gb(a+32|0);x[a+44>>2]=0;x[a+48>>2]=8;x[23549]=0;P(81,a|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){return a|0}b=N()|0;tb(c);Pn(a);Q(b|0);p()}function yr(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=db-16|0;db=e;x[e+12>>2]=d;d=Bb(x[b+4>>2],y[b+11|0]);if(d>>>0<c>>>0){mq();p()}b=Mb(b);x[e+8>>2]=d-c;ar(a,b+c|0,x[Cb(e+12|0,e+8|0)>>2]);db=e+16|0}function XM(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){if((a|0)!=(c|0)){b=x[a>>2];a:{if(!b){break a}if(!(ib[x[x[b>>2]+116>>2]](b)|0)){break a}ib[x[x[b>>2]+96>>2]](b)}a=a+160|0;continue}break}}function TB(a,b){var c=0;c=db-16|0;db=c;a:{if(!Lb(x[a>>2],x[a+8>>2],512)){a=0;while(1){if((a|0)!=128){Dm((a<<2)+b|0);a=a+1|0;continue}break}break a}Gu(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}db=c+16|0}function OK(a){var b=0,c=0,d=E(0);if(!a){return E(1)}if((a|0)>=-99999){b=+(a|0)*3.321928094887362/2e3;c=b+.5;a:{if(F(c)<2147483648){a=~~c;break a}a=-2147483648}d=E(Dj(b-+(a|0)))}else{d=E(0)}return d}function Nk(a){a=a|0;var b=0;x[a>>2]=77460;x[23549]=0;P(69,a|0,0);b=x[23549];x[23549]=0;if((b|0)!=1){Xb(a+28|0);Eb(x[a+32>>2]);Eb(x[a+36>>2]);Eb(x[a+48>>2]);Eb(x[a+60>>2]);return a|0}T(0)|0;Rb();p()}function _u(a,b){var c=0;c=db-16|0;db=c;a:{if(!Lb(x[a>>2],x[a+8>>2],256)){a=0;while(1){if((a|0)!=256){tg(a+b|0);a=a+1|0;continue}break}break a}dc(c+8|0,b,256);pd(c,a,x[c+8>>2],x[c+12>>2])}db=c+16|0}function IS(a,b){var c=0,d=0,e=0;c=db-16|0;db=c;OS(c+8|0,b);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;if((d|0)!=(e|0)){PS(b)}}function nP(a,b,c,d,e,f){x[a+40>>2]=0;x[a+44>>2]=0;C[a+32>>3]=f;C[a+24>>3]=e;C[a+16>>3]=d;C[a+8>>3]=c;C[a>>3]=b;x[a+48>>2]=0;x[a+52>>2]=0;x[a+56>>2]=0;x[a+60>>2]=0;a=a- -64|0;x[a>>2]=0;x[a+4>>2]=0}function Md(a,b){var c=0,d=0,e=0;d=z[a+24>>1];if((d|0)!=(b&65535)){c=z[a+22>>1]-1&127;w[a+22>>1]=c;e=z[a+20>>1];if(e>>>0<=127){w[a+20>>1]=e+1}c=(c<<2)+a|0;w[c+26>>1]=b-d;w[c+28>>1]=0;w[a+24>>1]=b}}function JU(a){var b=0,c=0,d=0;a:{if(cd(a,21193,11)){break a}c=a+215|0;a=a+63|0;while(1){b=(a|0)==(c|0);if(b|y[a+16|0]>3|y[a+17|0]>3){break a}d=a;a=a+19|0;if(y[d+18|0]<16){continue}break}}return b}function Vi(a){var b=0;b=32767;a:{if(a>=E(32766.5)){break a}b=32768;if(a<=E(-32767.5)){break a}a=E(a+E(.5));b:{if(E(F(a))<E(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function Du(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(b){d=Mc(a);e=Bb(x[a+4>>2],y[a+11|0]);if(d-e>>>0<b>>>0){cm(a,d,(b-d|0)+e|0,e,e,0,0)}d=Mb(a);sl(d+e|0,b,c);b=b+e|0;Wg(a,b);hd(b+d|0,0)}return a|0}function yR(a,b){var c=0,d=0,e=0;c=db-16|0;db=c;KU(c+8|0,b);d=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){dd(a,x[c+12>>2])}db=c+16|0;a=(d|0)==(e|0);if(!a){LU(b)}return a}function yB(a,b){var c=0,d=0,e=0;c=db-16|0;db=c;xB(c+8|0,b);d=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){dd(a,x[c+12>>2])}db=c+16|0;a=(d|0)==(e|0);if(!a){hV(b)}return a}function xj(a,b){var c=0,d=0,e=0;c=db-16|0;db=c;Vm(c+8|0,b);d=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){dd(a,x[c+12>>2])}db=c+16|0;a=(d|0)==(e|0);if(!a){El(b)}return a}function uu(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function uD(a,b){var c=0,d=0,e=0;c=db-16|0;db=c;br(c+8|0,b);d=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){dd(a,x[c+12>>2])}db=c+16|0;a=(d|0)==(e|0);if(!a){cr(b)}return a}function hS(a,b){var c=0,d=0,e=0;c=db-16|0;db=c;dS(c+8|0,b);d=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){dd(a,x[c+12>>2])}db=c+16|0;a=(d|0)==(e|0);if(!a){eS(b)}return a}function hE(a,b){var c=0,d=0,e=0;c=db-16|0;db=c;fE(c+8|0,b);d=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){dd(a,x[c+12>>2])}db=c+16|0;a=(d|0)==(e|0);if(!a){Jv(b)}return a}function cN(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;d=c+4|0;aN(d,b+80|0);x[23549]=0;S(11,a|0,0,d|0);a=x[23549];x[23549]=0;if((a|0)!=1){tb(c+4|0);db=c+16|0;return}a=N()|0;tb(c+4|0);Q(a|0);p()}function Vga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;if(eh(1073741823)>>>0<b>>>0){Rc();p()}dD(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=wb(a),e=b+(x[c+12>>2]<<2)|0,x[d>>2]=e;db=c+16|0}function V9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=db-16|0;db=e;c=jf(a,c);ae(e,x[a+28>>2]);a:{b:{if(!c){d=-1;if(!ed(a,5)){break b}break a}d=x[c+8>>2]}xz(x[a+28>>2],b,d);f=c}cf(a,f);db=e+16|0}function QS(a,b){var c=0,d=0,e=0;c=db-16|0;db=c;OS(c+8|0,b);d=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){dd(a,x[c+12>>2])}db=c+16|0;a=(d|0)==(e|0);if(!a){PS(b)}return a}function GV(a,b){var c=0,d=0,e=0;c=db-16|0;db=c;yu(c+8|0,b);d=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){dd(a,x[c+12>>2])}db=c+16|0;a=(d|0)==(e|0);if(!a){HB(b)}return a}function ER(a,b){var c=0,d=0,e=0;c=db-16|0;db=c;LD(c+8|0,b);d=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){dd(a,x[c+12>>2])}db=c+16|0;a=(d|0)==(e|0);if(!a){yv(b)}return a}function C_(a){a=a|0;var b=0,c=0,d=0,e=0;b=db-16|0;db=b;if(eh(1073741823)>>>0<=29){Rc();p()}fG(b+8|0,rw(a),30);c=x[b+8>>2];x[a+4>>2]=c;x[a>>2]=c;d=wb(a),e=(x[b+12>>2]<<2)+c|0,x[d>>2]=e;db=b+16|0}function nA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;if(eh(2147483647)>>>0<b>>>0){Rc();p()}mv(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=wb(a),e=b+(x[c+12>>2]<<1)|0,x[d>>2]=e;db=c+16|0}function Oba(a){a=a|0;var b=0,c=0,d=0,e=0;b=db-16|0;db=b;if(eh(2147483647)>>>0<=2303){Rc();p()}mv(b+8|0,2304);c=x[b+8>>2];x[a+4>>2]=c;x[a>>2]=c;d=wb(a),e=(x[b+12>>2]<<1)+c|0,x[d>>2]=e;db=b+16|0}function L2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;if(eh(357913941)>>>0<b>>>0){Rc();p()}qE(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=wb(a),e=b+D(x[c+12>>2],12)|0,x[d>>2]=e;db=c+16|0}function Ku(a,b,c){var d=0;a=(a&65535)>>>D(c,3)|0;d=a>>>2&1|y[b+12|0]&-8;v[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=y[b+13|0]|y[b+14|0]<<8;v[b+15|0]=a;v[b+16|0]=a>>>8;v[b+12|0]=d|4}}function KW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;if(eh(214748364)>>>0<b>>>0){Rc();p()}vC(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=wb(a),e=b+D(x[c+12>>2],20)|0,x[d>>2]=e;db=c+16|0}function Hm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;if(eh(1073741823)>>>0<b>>>0){Rc();p()}hj(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=wb(a),e=b+(x[c+12>>2]<<2)|0,x[d>>2]=e;db=c+16|0}function BB(a,b){var c=0;c=db-16|0;db=c;x[c+12>>2]=1;x[c+8>>2]=a>>>4;b=Ub(128/(D(x[Re(c+12|0,c+8|0)>>2],b)|0)|0,1,15);v[c+7|0]=1;v[c+6|0]=a&15;a=y[af(c+7|0,c+6|0)|0];db=c+16|0;return a|b<<4&240}function nU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=db-16|0;db=d;Mf(a,d+14|0);e=z[d+14>>1];fN(b,e);c=0;while(1){if((c|0)==(e|0)){yy(b);db=d+16|0}else{ak(a,xb(x[b>>2],c));c=c+1|0;continue}break}}function mP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;if(eh(536870911)>>>0<b>>>0){Rc();p()}ND(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=wb(a),e=b+(x[c+12>>2]<<3)|0,x[d>>2]=e;db=c+16|0}function kU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;if(eh(715827882)>>>0<b>>>0){Rc();p()}WT(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=wb(a),e=b+D(x[c+12>>2],6)|0,x[d>>2]=e;db=c+16|0}function iP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;if(eh(268435455)>>>0<b>>>0){Rc();p()}CE(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=wb(a),e=b+(x[c+12>>2]<<4)|0,x[d>>2]=e;db=c+16|0}function gI(a){var b=0,c=0,d=0;d=x[a>>2];while(1){c=v[d|0];if(Kj(c)){d=d+1|0;x[a>>2]=d;if(b>>>0<=214748364){c=c-48|0;b=D(b,10);b=(c|0)>(b^2147483647)?-1:c+b|0}else{b=-1}continue}break}return b}function ON(a,b,c){var d=0,e=0;d=db-16|0;db=d;a=gr(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){fc(a);db=d+16|0}else{NN(b,x[c>>2],x[c+4>>2]);b=b+8|0;x[a+4>>2]=b;continue}break}}function NK(a,b){var c=0,d=0,e=0,f=0;if(a>E(.9999989867210388)){d=0}else{a=E(a*a);c=+a;e=32768/(1-c);f=c;c=Pe(31415.926535897932/+b);d=pm(e*(1-(f*c+M(+E(a+a)*(1-c)-+E(a*a)*(1-c*c)))))}return d}function II(a,b){var c=0,d=0,e=0,f=E(0),g=E(0),h=0;b=(b|0)>0?b:0;h=a+2304|0;while(1){if((b|0)!=(d|0)){c=d<<2;e=c+a|0;f=B[e>>2];c=c+h|0;g=B[c>>2];B[e>>2]=f+g;B[c>>2]=f-g;d=d+1|0;continue}break}}function wy(a,b){var c=0;a=bR(a,b);v[a+12|0]=y[b+12|0];c=y[b+13|0]|y[b+14|0]<<8|(y[b+15|0]<<16|y[b+16|0]<<24);v[a+13|0]=c;v[a+14|0]=c>>>8;v[a+15|0]=c>>>16;v[a+16|0]=c>>>24;v[a+17|0]=y[b+17|0]}function jK(){var a=0,b=0,c=0,d=0;a=db-16|0;db=a;b=Hc(1298472);x[23549]=0;c=R(1041,b|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){b=x[of(a+12|0,c)>>2];db=a+16|0;return b|0}a=N()|0;Eb(b);Q(a|0);p()}function Vaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=db-16|0;db=d;e=z[a+28>>1];w[d+12>>1]=e;f=d,g=(oc(x[a+4>>2],x[a+8>>2])+e|0)-1|0,w[f+14>>1]=g;a=aM(a,b,c,d+12|0);db=d+16|0;return a|0}function vj(a,b){var c=0,d=0;c=db-16|0;db=c;x[c+12>>2]=b;d=b;b=eh(2147483647);if(d>>>0<=b>>>0){a=Qm(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}db=c+16|0;return b}Rc();p()}function qu(a,b,c){var d=0,e=0;e=db-16|0;db=e;d=db-32|0;db=d;Od(d+24|0,a,b);rl(d+16|0,x[d+24>>2],x[d+28>>2],c);a=XU(a,x[d+16>>2]);x[d+12>>2]=x[d+20>>2];vc(e+8|0,a,d+12|0);db=d+32|0;db=e+16|0}function ie(a,b){var c=0;a:{c=Pf(b);if((c|0)==(Bb(x[a+4>>2],y[a+11|0])|0)){x[23549]=0;a=U(353,a|0,b|0,c|0)|0;b=x[23549];x[23549]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}T(0)|0;Rb();p()}function eg(a,b){var c=0,d=0;c=db-16|0;db=c;x[c+12>>2]=b;d=b;b=eh(1073741823);if(d>>>0<=b>>>0){a=Qh(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}db=c+16|0;return b}Rc();p()}function aj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=gl(a,b);if((d|0)==255){break a}Rj(a,b);Vp(a,b,0,0);if(!c){break a}e=_b(a+26|0,d),f=65535,w[e>>1]=f;a=Db(a+62|0,b);v[a|0]=y[a|0]|128}}function PF(a){a=a|0;var b=0,c=0,d=0;x[a>>2]=82040;d=a+8|0;while(1){b=x[a+8>>2];if(oc(b,x[a+12>>2])>>>0>c>>>0){b=x[xb(b,c)>>2];if(b){$m(b)}c=c+1|0;continue}break}tb(a+152|0);oG(d);return a|0}function zA(a,b,c,d){var e=0,f=0,g=0;e=db-16|0;db=e;f=x[b+12>>2];x[e+8>>2]=c;x[e+12>>2]=d;g=x[x[b>>2]+28>>2];x[e>>2]=c;x[e+4>>2]=d;ib[g|0](a,b,f,e);x[b+12>>2]=x[b+12>>2]+x[a+4>>2];db=e+16|0}function tS(a,b){var c=0,d=0,e=0;c=db-16|0;db=c;d=c,e=(lp(b)+-4.8737671609324025)*(a&32768?28.85390081777927:34.624680981335125),C[d+8>>3]=e;FO(c+8|0,127);a=uo(C[c+8>>3]);db=c+16|0;return a}function qB(a,b){var c=0,d=0;c=db-16|0;db=c;x[c+12>>2]=b;d=b;b=eh(214748364);if(d>>>0<=b>>>0){a=xC(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}db=c+16|0;return b}Rc();p()}function jr(a,b){var c=0,d=0;c=db-16|0;db=c;x[c+12>>2]=b;d=b;b=eh(536870911);if(d>>>0<=b>>>0){a=an(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}db=c+16|0;return b}Rc();p()}function ep(a,b){var c=0,d=0;c=db-16|0;db=c;x[c+12>>2]=b;d=b;b=eh(357913941);if(d>>>0<=b>>>0){a=tk(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}db=c+16|0;return b}Rc();p()}function Yv(a,b){var c=0,d=0;c=db-16|0;db=c;x[c+12>>2]=b;d=b;b=eh(268435455);if(d>>>0<=b>>>0){a=zr(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}db=c+16|0;return b}Rc();p()}function XA(a,b){var c=0,d=0;c=db-16|0;db=c;x[c+12>>2]=b;d=b;b=eh(715827882);if(d>>>0<=b>>>0){a=tu(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}db=c+16|0;return b}Rc();p()}function ID(a,b){var c=0,d=0;c=db-16|0;db=c;x[c+12>>2]=b;d=b;b=eh(119304647);if(d>>>0<=b>>>0){a=wv(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}db=c+16|0;return b}Rc();p()}function $p(a,b){var c=0,d=0;c=db-16|0;db=c;x[c+12>>2]=b;d=b;b=eh(134217727);if(d>>>0<=b>>>0){a=to(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}db=c+16|0;return b}Rc();p()}function wV(a,b){var c=0,d=0;c=db-16|0;db=c;Vu(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;return(b|0)==(d|0)}function wQ(a){var b=0,c=0,d=0;c=y[a+64|0]|y[a+65|0]<<8;b=y[a+72|0]|y[a+73|0]<<8;a=y[a+70|0]|y[a+71|0]<<8;b=b+a|0;a=(a>>>0>b>>>0|d)<<2|b>>>30;b=b<<2;c=b+c|0;hb=b>>>0>c>>>0?a+1|0:a;return c}function vD(a,b){var c=0,d=0;c=db-16|0;db=c;br(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;return(b|0)==(d|0)}function oH(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:v[a|0]=c;return;case 1:w[a>>1]=c;return;case 2:case 3:x[a>>2]=c;return;case 5:break b;default:break a}}x[a>>2]=c;x[a+4>>2]=d}}function lS(a,b){var c=0,d=0;c=db-16|0;db=c;GA(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;return(b|0)==(d|0)}function kV(a,b){var c=0,d=0;c=db-16|0;db=c;yu(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;return(b|0)==(d|0)}function jM(a,b){var c=0,d=0;c=db-16|0;db=c;x[c+12>>2]=b;d=b;b=eh(82595524);if(d>>>0<=b>>>0){a=Ys(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}db=c+16|0;return b}Rc();p()}function hC(a,b){var c=0,d=0;c=db-16|0;db=c;gC(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;return(b|0)==(d|0)}function fV(a,b){var c=0,d=0;c=db-16|0;db=c;zu(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;return(b|0)==(d|0)}function eW(a){var b=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;b=x[a>>2];if(b&8){x[a>>2]=b|32;return-1}x[a+4>>2]=0;x[a+8>>2]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];return 0}function eV(a,b){var c=0,d=0;c=db-16|0;db=c;xB(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;return(b|0)==(d|0)}function aA(a,b){var c=0,d=0;d=db-32|0;db=d;c=wb(a);c=Jf(d+12|0,eg(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);no(x[c+8>>2],x[b>>2]);x[c+8>>2]=x[c+8>>2]+4;lo(a,c);If(c);db=d+32|0}function Zq(a,b){var c=0,d=0;c=db-16|0;db=c;Pm(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;return(b|0)==(d|0)}function Wo(a,b){var c=0,d=0;c=db-16|0;db=c;Bh(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;return(b|0)==(d|0)}function Vs(a){var b=0;x[23549]=0;a=R(789,a|0)|0;b=x[23549];x[23549]=0;a:{if((b|0)==1){Y(T(0)|0)|0;x[23549]=0;X(17);b=x[23549];x[23549]=0;a=0;if((b|0)==1){break a}}return a}T(0)|0;Rb();p()}function OT(a,b){var c=0,d=0;c=db-16|0;db=c;NT(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;return(b|0)==(d|0)}function OE(a,b,c){var d=0;d=db-16|0;db=d;dc(d+8|0,b,c);b=x[d+12>>2];lc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);c=x[d+4>>2];if((b|0)==(c|0)){Zb(a,x[d+12>>2])}db=d+16|0;return(b|0)==(c|0)}function MD(a,b){var c=0,d=0;c=db-16|0;db=c;LD(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;return(b|0)==(d|0)}function KR(a){var b=0,c=0,d=0;c=y[a+32|0]|y[a+33|0]<<8;b=y[a+36|0]|y[a+37|0]<<8;a=y[a+34|0]|y[a+35|0]<<8;b=b+a|0;a=(a>>>0>b>>>0|d)<<1|b>>>31;b=b<<1;c=b+c|0;hb=b>>>0>c>>>0?a+1|0:a;return c}function Ju(a,b){var c=0,d=0;c=db-16|0;db=c;Iu(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;return(b|0)==(d|0)}function Hu(a,b){var c=0,d=0;c=db-16|0;db=c;Jo(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;return(b|0)==(d|0)}function HS(a,b){var c=0,d=0;c=db-16|0;db=c;GS(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;return(b|0)==(d|0)}function Eg(a,b){var c=0,d=0;c=db-16|0;db=c;Uq(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;return(b|0)==(d|0)}function CD(a,b){var c=0,d=0;c=db-16|0;db=c;fE(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Zb(a,x[c+12>>2])}db=c+16|0;return(b|0)==(d|0)}function sw(a,b,c,d,e,f,g,h,i){var j=0;j=db-16|0;db=j;ug(j,b,c,d,e,f,g,h,i^-2147483648);d=x[j>>2];c=x[j+4>>2];b=x[j+12>>2];x[a+8>>2]=x[j+8>>2];x[a+12>>2]=b;x[a>>2]=d;x[a+4>>2]=c;db=j+16|0}function SP(a){a=a|0;var b=0,c=0;b=db-32|0;db=b;v[a+16|0]=0;c=Dz(b,x[a+12>>2]);x[23549]=0;P(724,a|0,c|0);a=x[23549];x[23549]=0;if((a|0)!=1){Tj(c);db=b+32|0;return}a=N()|0;Tj(c);Q(a|0);p()}function MG(a,b){var c=0,d=0;d=db-32|0;db=d;c=wb(a);c=Ol(d+12|0,Ek(a,Pc(x[a>>2],x[a+4>>2])+1|0),Pc(x[a>>2],x[a+4>>2]),c);Fk(x[c+8>>2],y[b|0]);x[c+8>>2]=x[c+8>>2]+1;mp(a,c);Ml(c);db=d+32|0}function Kx(a,b,c,d){var e=0,f=0,g=0;e=c-b|0;a:{if((e|0)<=9){g=e;e=D(32-G(d|1)|0,1233)>>>12|0;f=61;if((g|0)<(e+(A[(e<<2)+91072>>2]<=d>>>0)|0)){break a}}c=Hx(b,d);f=0}x[a+4>>2]=f;x[a>>2]=c}function rQ(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function oY(a){a=a|0;var b=0,c=0;b=db-16|0;db=b;c=b+4|0;AD(c,0,a);x[23549]=0;a=R(111,c|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){tb(b+4|0);db=b+16|0;return a|0}a=N()|0;tb(b+4|0);Q(a|0);p()}function mg(a,b){a=a|0;b=b|0;var c=0,d=0;c=db+-64|0;db=c;d=dy(c+12|0,a);x[23549]=0;S(187,a|0,b|0,d|0);a=x[23549];x[23549]=0;if((a|0)!=1){Nj(d);db=c- -64|0;return}a=N()|0;Nj(d);Q(a|0);p()}function _T(a,b,c,d){var e=0;e=db-16|0;db=e;x[e+12>>2]=b;x[e+8>>2]=d;c=Un(a,c,x[Cb(e+12|0,e+8|0)>>2]);a:{if(c){break a}c=0;if((b|0)==(d|0)){break a}c=b>>>0<d>>>0?-1:1}db=e+16|0;return c}function Vk(a,b){var c=0,d=0;c=y[a|0];d=y[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=y[b+1|0];c=y[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function O9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=db-16|0;db=e;f=1;g=x[c>>2];if(g>>>0<Pc(a,b)>>>0){a=jn(e+4|0,Db(a,g),z[c+12>>1]);b=pw(d,a);Ab(a);f=b^1}db=e+16|0;return f|0}function N0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a+84>>2];d=c+256|0;f=EA(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;rc(b,e,c);b=e+d|0;x[a+84>>2]=b;x[a+8>>2]=b;x[a+4>>2]=c+e;return c|0}function Ke(a,b){var c=0,d=0;c=db-16|0;db=c;x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;x[a+8>>2]=x[c+8>>2];v[a+12|0]=0;db=c+16|0}function W6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=db-16|0;db=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;a=GK(f,b,c,d,0,0,0,0,e);db=f+16|0;return a|0}function T$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=db-16|0;db=g;x[g+8>>2]=624576549;x[g+12>>2]=1394948685;h=a;a=g+16|0;b=Ij(h,b,c,d,e,f,g+8|0,a);db=a;return b|0}function Rj(a,b){var c=0,d=0,e=0;a:{c=gl(a,b);if((c|0)==255){break a}if(Sj(x[a>>2])){break a}e=a+8|0;d=Db(e,c);v[d|0]=y[d|0]&223;d=qt(c);c=Db(e,c);Tg(x[a>>2],x[a+4>>2],b,d|176,y[c|0])}}function Nx(a){var b=0,c=0,d=0;C[a+4272>>3]=C[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){if(a>>>0<32){a=a+15|0;b=Yn(d)|b<<15;continue}break}C[c+4280>>3]=E(E(b|0)*E(-4.656612873077393e-10))}function Jn(a){var b=0,c=0;b=db-16|0;db=b;a:{if(!_J(y[a+20|0])){x[23549]=0;P(1043,b+15|0,a|0);c=x[23549];x[23549]=0;if((c|0)==1){break a}}v[a+20|0]=255;db=b+16|0;return}T(0)|0;Rb();p()}function rE(a,b){var c=0,d=0;d=db-32|0;db=d;c=wb(a);c=Hl(d+12|0,ep(a,Cd(x[a>>2],x[a+4>>2])+1|0),Cd(x[a>>2],x[a+4>>2]),c);xr(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+12;Ov(a,c);wr(c);db=d+32|0}function ps(a){var b=0,c=0,d=0;c=1;while(1){if(c){c=0;b=x[a+4>>2];d=((b<<2)+(gv(x[a>>2],1)^270549120)|0)+2019860093|0;x[a>>2]=d;b=b+D(gv(d,16),5)|0;x[a+4>>2]=b;continue}break}return b}function Mia(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;d=Lb(x[a>>2],x[a+8>>2],12);a:{if(!d){v[c|0]=0;Sh(b,12,c);break a}xB(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}db=c+16|0;return d|0}function L3(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;d=x[14235];x[c+8>>2]=x[14234];x[c+12>>2]=d;d=x[14233];x[c>>2]=x[14232];x[c+4>>2]=d;ib[x[vp(c,Lj(y[b+20|0]))>>2]](a,b);db=c+16|0}function ay(a,b,c){var d=0,e=0;d=db-16|0;db=d;a=oh(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){fc(a);db=d+16|0}else{Qs(b,B[c>>2]);b=b+4|0;x[a+4>>2]=b;continue}break}}function Oh(a){var b=0;a=Rh(a);b=2147483647;a:{if(a>=E(2147483648)){break a}b=-2147483648;if(a<=E(-2147483648)){break a}b=~~a;if(E(F(a))<E(2147483648)){break a}b=-2147483648}return b}function M$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=ib[x[x[a+8>>2]+20>>2]](a+8|0)|0;b=Mb(a);return Hj(g,h,c,d,e,f,b,b+(Bb(x[a+4>>2],y[a+11|0])<<2)|0)|0}function Lo(a,b,c){var d=0,e=0;d=db-16|0;db=d;a=Ei(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){fc(a);db=d+16|0}else{tj(b,z[c>>1]);b=b+2|0;x[a+4>>2]=b;continue}break}}function Ek(a,b){var c=0,d=0;c=db-16|0;db=c;x[c+12>>2]=b;d=b;b=eh(-1);if(d>>>0<=b>>>0){a=pn(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}db=c+16|0;return b}Rc();p()}function BC(a,b,c){var d=0,e=0;d=db-16|0;db=d;a=oh(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){fc(a);db=d+16|0}else{no(b,x[c>>2]);b=b+4|0;x[a+4>>2]=b;continue}break}}function jQ(a,b){var c=0;c=y[a+800|0];a:{if(c){break a}c=xi(y[a+797|0]-w[a+770>>1]|0);if(!b|c-1<<24>>24<0){break a}a=x[a+656>>2];if(!a){break a}c=y[Db(a+108|0,c-1|0)|0]}return c&255}function dx(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+D(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((D(b,306)+5<<16>>16)/10<<16>>16)|0)-1|0}function Wq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;if((b|0)<0){Rc();p()}dD(c+8|0,(b-1>>>5|0)+1|0);b=x[c+8>>2];x[a+4>>2]=0;x[a>>2]=b;d=wb(a),e=x[c+12>>2],x[d>>2]=e;db=c+16|0}function Ro(a,b,c){var d=0,e=0;d=db-16|0;db=d;a=Gk(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){fc(a);db=d+16|0}else{Fk(b,y[c|0]);b=b+1|0;x[a+4>>2]=b;continue}break}}function Ria(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=db-16|0;db=d;JT(b,c);c=Lb(x[a>>2],x[a+8>>2],c<<2);if(c){IT(d+8|0,x[b>>2],x[b+4>>2]);pd(d,a,x[d+8>>2],x[d+12>>2])}db=d+16|0;return c|0}function LK(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=db-16|0;db=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;c=KK(f,b,c,d,e,0,0,0,0);db=f+16|0;return+c}function Jea(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;d=Lb(x[a>>2],x[a+8>>2],4);a:{if(!d){v[c|0]=0;YU(b,4,c);break a}Bh(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}db=c+16|0;return d|0}function uh(a,b){var c=0;b=Qd(b);c=x[a+8>>2];if(oc(c,x[a+12>>2])>>>0>b>>>0){a=x[xb(c,b)>>2]!=0}else{a=0}if(!a){a=Yl(ac(4));x[a>>2]=92752;da(a|0,92888,1087);p()}return x[xb(c,b)>>2]}function qs(a){var b=0,c=0,d=0;b=db-16|0;db=b;x[b+12>>2]=12;while(1){x[b+8>>2]=32;if(A[Cb(b+12|0,b+8|0)>>2]<=c>>>0){db=b+16|0;a=d&4095}else{c=c+15|0;d=Yn(a);continue}break}return a}function pk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;if(eh(-1)>>>0<b>>>0){Rc();p()}yi(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=wb(a),e=b+x[c+12>>2]|0,x[d>>2]=e;db=c+16|0}function nz(a){var b=0,c=0;b=x[a>>2];c=x[b>>2];a:{if(!c){while(1){c=qh(b);b=x[b+8>>2];if(c){continue}break}break a}while(1){b=c;c=x[b+4>>2];if(c){continue}break}}x[a>>2]=b;return a}function WX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=db-16|0;db=d;PD(b,c);c=Lb(x[a>>2],x[a+8>>2],c<<3);if(c){OD(d+8|0,x[b>>2],x[b+4>>2]);pd(d,a,x[d+8>>2],x[d+12>>2])}db=d+16|0;return c|0}function MX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=db-16|0;db=d;x[d+12>>2]=c;c=0;a=ib[x[x[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Cb(d+12|0,d+8|0)>>2]}db=d+16|0;return c|0}function sO(a,b,c,d){a:{if((a|0)!=67108864){break a}a=D(d,872)+c|0;x[a+704>>2]=x[a+704>>2]&-129;a=d^1;if(a>>>0>=(b&65535)>>>0){break a}a=D(a,872)+c|0;x[a+704>>2]=x[a+704>>2]&-129}}function VX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=!b|(b>>>0>d>>>0|a>>>0>=d>>>0|d-a>>>0<b>>>0);a:{if(d){break a}a=a+b|0;if(Pc(x[c>>2],x[c+4>>2])>>>0>=a>>>0){break a}Ji(c,a)}return!d|0}function Mea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=db-16|0;db=d;aR(b,c);if(Lb(x[a>>2],x[a+8>>2],c<<8)){c=x[b>>2];dc(d+8|0,c,ph(c,x[b+4>>2])<<8);pd(d,a,x[d+8>>2],x[d+12>>2])}db=d+16|0}function ld(a,b){var c=0,d=0,e=0;a:{c=cG(b);d=ln(a);if(c>>>0<=d>>>0){e=b;b=c<<2;d=uk(Mb(a),e,b);Wg(a,c);zd(b+d|0,0);break a}e=a;a=Bb(x[a+4>>2],y[a+11|0]);OF(e,d,c-d|0,a,0,a,c,b)}}function bh(a,b,c){a:{if(b>>>0<=c>>>0){a=ac(8);x[23549]=0;b=R(179,a|0)|0;c=x[23549];x[23549]=0;if((c|0)!=1){break a}b=N()|0;jc(a);Q(b|0);p()}return y[a+c|0]}da(b|0,26136,154);p()}function ST(a,b){var c=0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a|0]=c;v[a+1|0]=c>>>8;v[a+2|0]=c>>>16;v[a+3|0]=c>>>24;b=y[b+4|0]|y[b+5|0]<<8;v[a+4|0]=b;v[a+5|0]=b>>>8}function JM(a){var b=0,c=0,d=0;b=db-16|0;db=b;while(1){x[b+12>>2]=7;x[b+8>>2]=32;if(A[Cb(b+12|0,b+8|0)>>2]<=c>>>0){db=b+16|0;a=d&127}else{c=c+15|0;d=Yn(a);continue}break}return a}function pia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=db-16|0;db=e;c=jf(a,c);ae(e,x[a+28>>2]);a:{if(!c){f=0;if(ed(a,5)){break a}}jU(x[a+28>>2],b,d,0);f=c}cf(a,f);db=e+16|0}function cf(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;a:{if(!b){b=1;if(ed(a,5)){break a}ae(c,x[a+28>>2])}x[a>>2]=x[a>>2]|134217728;x[a+20>>2]=x[a+20>>2]+1;b=0}db=c+16|0;return b|0}function Zj(a,b){var c=0,d=0,e=0;x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=wb(b);d=wb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function WO(a,b,c,d){var e=0,f=0;e=db-16|0;db=e;while(1){if(c){f=el(z[c+16>>1],x[c+20>>2],a,b);d=f?d:c;c=x[(f?c+4|0:c)>>2];continue}break}a=x[vb(e+12|0,d)>>2];db=e+16|0;return a}function S$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=ib[x[x[a+8>>2]+20>>2]](a+8|0)|0;b=Mb(a);return Ij(g,h,c,d,e,f,b,Bb(x[a+4>>2],y[a+11|0])+b|0)|0}function HC(a){var b=0,c=0;a:{if(cd(a,13879,3)){break a}b=y[a+3|0];b:{if(b>>>0<=7){if((b|0)==1){break b}break a}if(b>>>0>14){break a}}c=(y[a+40|0]-1&255)>>>0<32|b>>>0<9}return c}function GZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];if(a>>>0<=127){a=x[(a<<2)+82112>>2]}else{a=0}x[d>>2]=a;d=d+4|0;b=b+4|0;continue}break}return c|0}function Eia(a,b){a=a|0;b=b|0;var c=0;c=db-32|0;db=c;x[c+24>>2]=0;x[c+28>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;x[c>>2]=0;x[c+4>>2]=0;mU(b,c);lU(a,c);db=c+32|0}function xo(a){var b=0,c=0;b=x[23304];c=a+7&-8;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(a>>>0>jb()<<16>>>0){if(!(cb(a|0)|0)){break a}}x[23304]=a;return b}x[23424]=48;return-1}function aB(a,b,c){var d=0,e=0;d=db-16|0;db=d;a=Bq(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){fc(a);db=d+16|0}else{hu(b,c);b=b+6|0;x[a+4>>2]=b;continue}break}}function G7(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);if(b>>>0<=12){c=Fd(c,E(0));d=a+4208|0;if((b|0)==12){c=E(Rh(E(c*E(3)))/E(3));b=12}e=xb(d,b),f=c,B[e>>2]=f;v[a+5046|0]=1}}function wja(a,b){a=a|0;b=b|0;if(!eV(a,b)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0}}function sE(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-12|0;Ab(c);continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];tk(a);Eb(b)}}function pK(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-16|0;lj(c);continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];zr(a);Eb(b)}}function Z2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=db-16|0;db=d;x[d+12>>2]=c;mx(a,b,c);c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Cb(d+8|0,d+12|0)>>2]}db=d+16|0;return c|0}function US(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-24|0;ub(c);continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];Xt(a);Eb(b)}}function Cs(a){var b=0;b=x[a+24>>2];x[23549]=0;W(790,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){Yd(a+68|0);Yf(a+36|0);us(a+32|0);Xi(a+24|0);Wi(a+4|0);return xe(a)}T(0)|0;Rb();p()}function sfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=db-16|0;db=d;x[d+12>>2]=b;while(1){if(Kb(b,c)){x[d+8>>2]=x[b>>2];iA(a,d+8|0);b=x[Ae(d+12|0)>>2];continue}else{db=d+16|0}break}}function kZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=db-16|0;db=d;ib[x[x[a>>2]+12>>2]](d+8|0,a,b);a=x[d+8>>2];b=x[c>>2];a=qc(x[d+12>>2],x[c+4>>2])&(a|0)==(b|0);db=d+16|0;return a|0}function gfa(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;b=-1;a:{if(!xj(a,c+8|0)){break a}b=0;if(!cR(c+8|0)){break a}b=-1;if(!zh(a,4)){break a}b=CR(a)>>>31|0}db=c+16|0;return b|0}function fS(a){var b=0,c=0,d=0,e=0;d=y[a+4|0];e=y[a+92|0];c=y[a+94|0]|y[a+95|0]<<8;b=c+y[a+93|0]|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=b+e|0;a=d;d=b<<2;b=a+d|0;b=b-96|0;hb=0;return b}function Y9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=db-16|0;db=e;c=jf(a,c);ae(e,x[a+28>>2]);a:{if(!c){f=0;if(ed(a,5)){break a}}XL(d,x[a+28>>2],b);f=c}cf(a,f);db=e+16|0}function Dq(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a>>2];d=x[a+4>>2];if(Ic(c,d)>>>0>b>>>0){a=x[a+24>>2];b=nk(c,d,b);a=se(x[a+484344>>2],x[a+484348>>2],z[b>>1])}else{a=0}return a|0}function wF(a,b){var c=0,d=0;c=db-16|0;db=c;a=Gk(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){fc(a);db=c+16|0}else{tg(b);b=b+1|0;x[a+4>>2]=b;continue}break}}function uC(a,b){var c=0,d=0;c=db-16|0;db=c;a=Ei(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){fc(a);db=c+16|0}else{nv(b);b=b+2|0;x[a+4>>2]=b;continue}break}}function og(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=bh(x[d>>2],x[d+4>>2],a);return((bh(x[d>>2],x[d+4>>2],a+1|0)<<8|e<<16|bh(x[d>>2],x[d+4>>2],a+2|0))<<(b&7)&16777215)>>>24-c|0}function nG(a,b){var c=0,d=0;c=db-16|0;db=c;a=oh(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){fc(a);db=c+16|0}else{gG(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function Vw(a,b){var c=0,d=0;if(b>>>0<2147483632){if(Do(b)){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;ff(a,b);return a}c=fk(b)+1|0;d=Hc(c);jg(a,c);zd(a,d);re(a,b);return a}kg();p()}function TA(a,b){var c=0,d=0;c=db-16|0;db=c;a=oh(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){fc(a);db=c+16|0}else{Dm(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function Su(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=db-16|0;db=d;Ji(b,c);if(Lb(x[a>>2],x[a+8>>2],c)){c=x[b>>2];dc(d+8|0,c,Pc(c,x[b+4>>2]));pd(d,a,x[d+8>>2],x[d+12>>2])}db=d+16|0}function Oga(){var a=0,b=0,c=0;a=db-16|0;db=a;b=Hc(1);x[23549]=0;X(31);c=x[23549];x[23549]=0;if((c|0)!=1){b=x[of(a+12|0,b)>>2];db=a+16|0;return b|0}a=N()|0;Eb(b);Q(a|0);p()}function Lz(a,b){var c=0,d=0;c=db-16|0;db=c;a=oh(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){fc(a);db=c+16|0}else{tQ(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function BR(a,b){var c=0,d=0;c=db-16|0;db=c;Bh(c+8|0,b);b=x[c+12>>2];md(c,a,x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){dd(a,x[c+12>>2])}db=c+16|0;return(b|0)==(d|0)}function oE(a){var b=0;a:{b:{if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a&255)!=0}return b}function RU(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28163770){break a}if(cd(a+44|0,17404,3)){break a}b=(y[a+47|0]|y[a+48|0]<<8)>>>0>97}return b}function Ih(a,b){a=a|0;b=b|0;var c=0;c=db-32|0;db=c;v[c+31|0]=0;Jj(c+8|0,c+31|0);vn(c+20|0,a,x[c+8>>2],x[c+12>>2]);a=x[c+24>>2];v[b|0]=y[c+31|0];db=c+32|0;return(a|0)==1|0}function Yja(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;Vm(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);if((b|0)==x[c+4>>2]){Zb(a,x[c+12>>2])}db=c+16|0}function Xe(a,b,c){var d=0,e=0,f=0;d=db-16|0;db=d;x[d+8>>2]=c;x[d+4>>2]=31;e=d,f=UV(b,c),x[e+12>>2]=f;c=b;b=LB(d+4|0);_g(c,c+b|0,a);e=Db(a,b),f=0,v[e|0]=f;WV(a);db=d+16|0}function NC(a,b,c){var d=0;d=db-16|0;db=d;a=So(d+4|0,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){tj(b,z[c>>1]);b=x[a>>2]+2|0;x[a>>2]=b;continue}break}Kd(a);db=d+16|0}function EZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];if(!(a>>>0>127|!(x[(a<<2)+82112>>2]&b))){c=c+4|0;continue}break}d=c}return d|0}function xba(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;d=Lb(x[a>>2],x[a+8>>2],16);a:{if(!d){sC(b);break a}Vu(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}db=c+16|0;return d|0}function dw(a,b,c,d,e){var f=0;a:{f=Vs(4332);if(f){x[23549]=0;fa(e|0,f|0,a|0,b|0,c|0,d|0)|0;a=x[23549];x[23549]=0;if((a|0)==1){break a}}return f}a=N()|0;Eb(f);Q(a|0);p()}function Tia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=db-16|0;db=d;a:{if(a){ib[x[x[a>>2]+8>>2]](a,b,c);break a}if((b|0)>=6){break a}iN(d,9051,10741,140,42);aE(d,b,c)}db=d+16|0}function RT(a,b,c){var d=0;d=db-16|0;db=d;a=bw(d+4|0,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){Fk(b,y[c|0]);b=x[a>>2]+1|0;x[a>>2]=b;continue}break}Kd(a);db=d+16|0}function NX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=ib[x[x[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function vQ(a,b,c,d){a=ec(a,b,c);b=x[a+4>>2];a:{if((d|0)>=0){b=b+d|0;c=x[a>>2]+(b>>>3&536870908)|0;break a}b=b+d|0;c=x[a>>2]+((b-31|0)/32<<2)|0}x[a>>2]=c;x[a+4>>2]=b&31}function tE(a,b){a=a|0;b=b|0;var c=0,d=0;c=Mc(a);d=Bb(x[a+4>>2],y[a+11|0]);if((c|0)==(d|0)){xy(a,c,1,c,c,0)}c=Mb(a);sl(c+d|0,1,b);b=d+1|0;Wg(a,b);hd(b+c|0,0);return a|0}function nba(a,b){a=a|0;b=b|0;var c=0;a=ig(a);c=kj(x[b>>2]);b=Bf(b);x[23549]=0;S(784,a|0,c|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){return a|0}b=N()|0;WN(a);Q(b|0);p()}function jO(a,b,c){var d=0;d=c&15;if(d){v[b+824|0]=d}c=c&240;if(c){v[b+823|0]=c>>>4}x[b+88>>2]=x[b+88>>2]|131072;if(!(!d|!Ob(a+1074312|0,80))){v[b+824|0]=y[b+824|0]<<2}}function iA(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[wb(a)>>2]){c=db-16|0;db=c;a=oh(c+4|0,a,1);no(x[a+4>>2],x[b>>2]);x[a+4>>2]=x[a+4>>2]+4;fc(a);db=c+16|0;return}aA(a,b)}function Ul(a){a=a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function FZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){a=x[c>>2];if(a>>>0>127|!(x[(a<<2)+82112>>2]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function zo(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;d=Lb(x[a>>2],x[a+8>>2],4);a:{if(!d){LT(b);break a}Bh(c+8|0,b);pd(c,a,x[c+8>>2],x[c+12>>2])}db=c+16|0;return d|0}function vga(){var a=0,b=0,c=0;a=db-16|0;db=a;b=Tb(a+4|0,10148);x[23549]=0;W(35,b|0);c=x[23549];x[23549]=0;if((c|0)!=1){tb(b);db=a+16|0;return}a=N()|0;tb(b);Q(a|0);p()}function jaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=db-16|0;db=d;c=jf(a,c);ae(d,x[a+28>>2]);a:{if(!c){e=0;if(ed(a,5)){break a}}nU(x[a+28>>2],b,a);e=c}cf(a,e);db=d+16|0}function Tt(a){var b=0,c=0,d=0,e=0;while(1){a:{if((b|0)==32){e=c;break a}d=y[a+b|0];if((d-1&255)>>>0<31|((c^1)&1?0:d)){break a}b=b+1|0;c=!d|c;continue}break}return e&1}function JI(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if(!(b&6)|(b&240)!=240&(b&254)!=226){break a}a=y[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function ufa(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-48|0;db=c;d=-1;a:{if(!yR(a,c)){break a}d=0;if(!xR(c)){break a}d=Ge(a,b,wR(y[c+31|0],y[c+33|0]),hb)}db=c+48|0;return d|0}function tga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=db-16|0;db=d;PD(b,c);if(Lb(x[a>>2],x[a+8>>2],c<<3)){OD(d+8|0,x[b>>2],x[b+4>>2]);pd(d,a,x[d+8>>2],x[d+12>>2])}db=d+16|0}function cd(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}while(1){d=y[a|0];e=y[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}f=d-e|0}return f}function XJ(a,b){var c=0,d=0;c=db-16|0;db=c;a=Gk(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){fc(a);db=c+16|0}else{b=b+1|0;x[a+4>>2]=b;continue}break}}function uF(a,b,c){var d=0;a:{if(!a){a=ac(8);x[23549]=0;c=R(c|0,a|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){break a}b=N()|0;jc(a);Q(b|0);p()}return}da(c|0,b|0,931);p()}function NA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=db-16|0;db=d;JT(b,c);if(Lb(x[a>>2],x[a+8>>2],c<<2)){IT(d+8|0,x[b>>2],x[b+4>>2]);pd(d,a,x[d+8>>2],x[d+12>>2])}db=d+16|0}function AX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=db-16|0;db=d;x[d+12>>2]=c;c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Cb(d+12|0,d+8|0)>>2]}db=d+16|0;return c|0}function AR(a,b){var c=0;c=db-32|0;db=c;kS(c+24|0,a);ze(c+16|0,b);a=x[c+20>>2];x[c+8>>2]=x[c+16>>2];x[c+12>>2]=a;a=Gc(x[c+24>>2],x[c+28>>2],c+8|0);db=c+32|0;return a}function nQ(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if(!(b&6)|(b&224)!=224|(b&24)==8){break a}a=y[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function eU(a,b,c){var d=0,e=0,f=0;d=db-16|0;db=d;b=gc(b);a=rh(a,Hc(32),Ag(d+8|0,b));b=x[a>>2]+16|0;w[b>>1]=z[x[c>>2]>>1];Gb(b+4|0);e=gc(a),f=1,v[e+4|0]=f;db=d+16|0}function cS(a){if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=541938512|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1162627398)){return 1}return 0}function _2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;mx(a,b,c);a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function YP(a,b,c,d){var e=0;e=db-32|0;db=e;Od(e+24|0,b,c);rl(e+16|0,x[e+24>>2],x[e+28>>2],d);b=XP(b,x[e+16>>2]-b>>1);x[e+12>>2]=x[e+20>>2];vc(a,b,e+12|0);db=e+32|0}function P1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Bb(x[b+4>>2],y[b+11|0]);e=a;a=Bb(x[c+4>>2],y[c+11|0]);b=We(Mb(Vw(e,d+a|0)),Mb(b),d)+d|0;sl(We(b,Mb(c),a)+a|0,1,0)}function OX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=db-16|0;db=d;x[d+12>>2]=c;c=0;a=x[a+8>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Cb(d+12|0,d+8|0)>>2]}db=d+16|0;return c|0}function N1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=db-16|0;db=e;a=Yw(Na(x[a+60>>2],b|0,c|0,d&255,e+8|0)|0);db=e+16|0;hb=a?-1:x[e+12>>2];return(a?-1:x[e+8>>2])|0}function oga(a,b){a=a|0;b=b|0;var c=0,d=0;d=db-80|0;db=d;c=-1;a:{if(!GV(a,d+14|0)){break a}c=0;if(!qS(d+14|0)){break a}c=Ge(a,b,pS(d+14|0),hb)}db=d+80|0;return c|0}function TH(a,b){var c=0,d=0,e=0,f=0;c=x[a+24>>2];if((c|0)==x[a+28>>2]){return e=a,f=Lh(b),d=x[x[a>>2]+52>>2],ib[d](e|0,f|0)|0}x[a+24>>2]=c+1;v[c|0]=b;return Lh(b)}function GO(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[wb(a)>>2]){c=db-16|0;db=c;a=It(c+4|0,a,1);xr(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;fc(a);db=c+16|0;return}rE(a,b)}function rja(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;a:{if(!Lb(x[b>>2],x[b+8>>2],6)){v[c|0]=0;Sh(a,6,c);break a}sB(c+8|0,a);pd(c,b,x[c+8>>2],x[c+12>>2])}db=c+16|0}function Xfa(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;a:{if(!Lb(x[b>>2],x[b+8>>2],5)){v[c|0]=0;Sh(a,5,c);break a}Iu(c+8|0,a);pd(c,b,x[c+8>>2],x[c+12>>2])}db=c+16|0}function LQ(a){x[a>>2]=0;x[a+4>>2]=0;x[a+88>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;Qz(a+112|0,48e3);x[a+668>>2]=0;Pz(a+724|0);Pz(a+732|0);Pz(a+740|0);Wh(a+788|0);return a}function tJ(a,b){var c=0,d=0;c=Pc(x[a+4>>2],x[a+8>>2]);b=x[a+16>>2]+b|0;if(c>>>0<b>>>0){d=a+4|0;a:{if(c){a=$f(c);if(b>>>0<=a>>>0){break a}}a=uJ(b,65536)}Ji(d,a)}}function nY(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[wb(a)>>2]){c=db-16|0;db=c;a=Pv(c+4|0,a);xr(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;fc(a);db=c+16|0;return}rE(a,b)}function d1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=db-16|0;db=e;x[e>>2]=c;x[e+4>>2]=d;x[e+8>>2]=c;x[e+12>>2]=d;a=FH(a,e,b);x[a>>2]=77140;db=e+16|0;return a|0}function Zp(a){x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=128;x[a+4>>2]=256;x[a+32>>2]=363;x[a+36>>2]=952;x[a+16>>2]=48e3;x[a+20>>2]=2;x[a+24>>2]=128;x[a+28>>2]=0;return a}function Uaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=db-16|0;db=c;d=c,e=Hh(b),x[d+12>>2]=e;x[c+8>>2]=0;d=a,e=x[sj(c+12|0,c+8|0,44048)>>2],x[d+36>>2]=e;Cp(a);db=c+16|0}function SY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=db-16|0;db=d;x[d+12>>2]=x[c>>2];a=ib[x[x[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){x[c>>2]=x[d+12>>2]}db=d+16|0;return a|0}function LB(a){var b=0,c=0;a:{c=xb(a,3);if((c|0)==(a|0)){break a}b=a;while(1){b=b+4|0;if((c|0)==(b|0)){break a}a=jq(x[b>>2],x[a>>2])?b:a;continue}}return x[a>>2]}function Im(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;a:{if(!Lb(x[b>>2],x[b+8>>2],4)){v[c|0]=0;Sh(a,4,c);break a}Bh(c+8|0,a);pd(c,b,x[c+8>>2],x[c+12>>2])}db=c+16|0}function zW(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;x[c+12>>2]=-1;if(Eg(a,c+11|0)){x[c+4>>2]=y[c+11|0];d=iC(a,b,x[Cb(c+4|0,c+12|0)>>2])}db=c+16|0;return d|0}function pq(a){var b=0,c=0,d=0,e=0;b=x[a+4>>2];c=x[b>>2];x[a+4>>2]=c;if(c){Zl(c,a)}x[b+8>>2]=x[a+8>>2];d=x[a+8>>2]+(qh(a)?0:4)|0,e=b,x[d>>2]=e;x[b>>2]=a;Zl(a,b)}function oq(a){var b=0,c=0,d=0,e=0;b=x[a>>2];c=x[b+4>>2];x[a>>2]=c;if(c){Zl(c,a)}x[b+8>>2]=x[a+8>>2];d=x[a+8>>2]+(qh(a)?0:4)|0,e=b,x[d>>2]=e;x[b+4>>2]=a;Zl(a,b)}function mC(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;x[c+12>>2]=-1;if(Eg(a,c+11|0)){x[c+4>>2]=y[c+11|0];d=fC(a,b,x[Cb(c+4|0,c+12|0)>>2])}db=c+16|0;return d|0}function kN(a){var b=0,c=0,d=0;b=x[a+112>>2];if((b|0)>=11){b=378;while(1){if(b|c){jN(a);d=b;b=b-1|0;c=c-!d|0;continue}break}b=0}x[a+112>>2]=b+1;a=jN(a);return a}function bM(a,b){var c=0;c=db-16|0;db=c;a=Bl(c+4|0,a+8|0,b);b=x[a>>2];while(1){if(x[a+4>>2]!=(b|0)){tQ(b);b=x[a>>2]+4|0;x[a>>2]=b;continue}break}Kd(a);db=c+16|0}function ak(a,b){var c=0;c=db-32|0;db=c;x[c+28>>2]=0;Rv(c+8|0,c+28|0);vn(c+20|0,a,x[c+8>>2],x[c+12>>2]);a=x[c+24>>2];x[b>>2]=x[c+28>>2];db=c+32|0;return(a|0)==4}function Hc(a){a=a|0;var b=0;a=a>>>0<=1?1:a;a:{while(1){b=Nd(a);if(b){break a}b=x[117373];if(b){ib[b|0]();continue}break}da(_l(ac(4))|0,92296,25);p()}return b|0}function uk(a,b,c){var d=0;if(a>>>0<b>>>0){return rc(a,b,c)}if(c){d=a+c|0;b=b+c|0;while(1){d=d-1|0;b=b-1|0;v[d|0]=y[b|0];c=c-1|0;if(c){continue}break}}return a}function pc(a,b){var c=0;a=Yl(a);x[a+4>>2]=0;x[a>>2]=49296;c=Nd(Oc(x[b+4>>2],y[b+11|0])+1|0);x[a+4>>2]=c;if(c){rc(c,Mb(b),Oc(x[b+4>>2],y[b+11|0])+1|0)}return a}function is(a){var b=0;a:{if((Ne(a)|0)!=79){break a}if((Ne(a)|0)!=103){break a}if((Ne(a)|0)!=103){break a}b=(Ne(a)|0)==83}if(!b){cc(a,30);return 0}return CI(a)}function cR(a){if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1299020115){a=($b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))|0)==1}else{a=0}return a}function aha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Nb(a+8|0);x[23549]=0;S(233,a|0,b|0,c|0);a=x[23549];x[23549]=0;if((a|0)!=1){break a}a=N()|0;bc(d);Q(a|0);p()}}function aca(a,b){a=a|0;b=b|0;a=xc(a);v[a+534|0]=0;x[a+4>>2]=0;x[23549]=0;P(731,a|0,b|0);b=x[23549];x[23549]=0;if((b|0)!=1){return a|0}b=N()|0;ij(a);Q(b|0);p()}function Yu(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;a:{if(!Lb(x[b>>2],x[b+8>>2],2)){v[c|0]=0;tC(a,c);break a}Pm(c+8|0,a);pd(c,b,x[c+8>>2],x[c+12>>2])}db=c+16|0}function om(a){var b=0;b=2147483647;a:{if(a>=2147483647){break a}b=-2147483648;if(a<=-2147483648){break a}if(F(a)<2147483648){return~~a}b=-2147483648}return b}function lK(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;c=x[b+20>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=c;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function Fd(a,b){var c=0,d=0,e=E(0);c=db-16|0;db=c;x[c+8>>2]=1065353216;B[c+12>>2]=b;d=c,e=Af(a),B[d+4>>2]=e;a=B[nq(c+4|0,c+12|0,c+8|0)>>2];db=c+16|0;return a}function rA(a,b,c){var d=0;d=db-16|0;db=d;x[d+12>>2]=a;c=c&65535;while(1){if(!(!Kb(a,b)|(c|0)==z[a>>1])){a=x[Se(d+12|0)>>2];continue}break}db=d+16|0;return a}function qN(){var a=0,b=0,c=0,d=0;a=db-16|0;db=a;b=a+12|0;while(1){if(c>>>0<32){c=c+48|0;d=By(94240);continue}break}x[b>>2]=d;Yn(b);db=a+16|0;return x[b>>2]}
function md(a,b,c,d){var e=0,f=0,g=0;e=db-16|0;db=e;f=x[b+12>>2];x[e+8>>2]=c;x[e+12>>2]=d;g=x[x[b>>2]+28>>2];x[e>>2]=c;x[e+4>>2]=d;ib[g|0](a,b,f,e);db=e+16|0}function Y0(a,b){a=a|0;b=b|0;var c=0,d=0;b=Gw(x[b>>2]);x[a+36>>2]=b;c=a,d=Ig(b),x[c+44>>2]=d;c=a,d=wn(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){Wr(5504);p()}}function VK(a){a=a|0;var b=0;x[a+4240>>2]=0;x[a+4244>>2]=0;b=a+4264|0;x[b>>2]=0;x[b+4>>2]=0;b=a+4256|0;x[b>>2]=0;x[b+4>>2]=0;a=a+4248|0;x[a>>2]=0;x[a+4>>2]=0}function Tz(a){var b=0;a=je(a);b=32767;a:{if(a>=32767){break a}b=32768;if(a<=-32768){break a}b=~~a;if(F(a)<2147483648){break a}b=-2147483648}return b<<16>>16}function R0(a,b){a=a|0;b=b|0;var c=0,d=0;b=Kw(x[b>>2]);x[a+36>>2]=b;c=a,d=Ig(b),x[c+44>>2]=d;c=a,d=wn(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){Wr(5504);p()}}function G0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=x[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function jR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=db-16|0;db=d;while(1){if((b|0)==(c|0)){db=d+16|0}else{x[d+12>>2]=x[b>>2];iA(a,d+12|0);b=b+4|0;continue}break}}function Zb(a,b){a=a|0;b=b|0;var c=0;c=Lb(x[a>>2],x[a+8>>2],b);a:{if(c){b=x[a+8>>2]+b|0;break a}b=x[a>>2];b=ib[x[x[b>>2]+24>>2]](b)|0}x[a+8>>2]=b;return c|0}function Me(a,b){var c=0;c=x[a>>2];x[a>>2]=b;a:{if(c){a=x[gc(a)>>2];x[23549]=0;W(a|0,c|0);a=x[23549];x[23549]=0;if((a|0)==1){break a}}return}T(0)|0;Rb();p()}function J0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function Fea(a,b){a=a|0;b=b|0;var c=0,d=0;d=db-48|0;db=d;c=-1;a:{if(!yR(a,d)){break a}c=0;if(!FQ(d)){break a}c=Ge(a,b,EQ(y[d+47|0]),hb)}db=d+48|0;return c|0}function y_(a){a=a|0;if(y[467824]){return x[116955]}if(!y[468984]){v[468984]=1}ld(468960,88576);ld(468972,88588);v[467824]=1;x[116955]=468960;return 468960}function sg(a,b){var c=0,d=0,e=0;c=Mb(a);a=Bb(x[a+4>>2],y[a+11|0]);e=Pf(b);d=0;a:{if(!e){break a}a=a+c|0;b=pE(c,a,b,b+e|0);d=(a|0)==(b|0)?-1:b-c|0}return d}function oca(a,b){a=a|0;b=b|0;a=Nb(a);v[a+16|0]=0;x[a+12>>2]=b;x[23549]=0;W(723,a|0);b=x[23549];x[23549]=0;if((b|0)!=1){return a|0}b=N()|0;Cz(a);Q(b|0);p()}function k_(a){a=a|0;if(y[467816]){return x[116953]}if(!y[468952]){v[468952]=1}Wc(468928,13615);Wc(468940,13594);v[467816]=1;x[116953]=468928;return 468928}function bt(a,b){var c=0,d=0,e=E(0);c=db-16|0;db=c;B[c+12>>2]=b;x[c+8>>2]=0;x[c+4>>2]=1065353216;d=a,e=B[nq(c+12|0,c+8|0,c+4|0)>>2],B[d+144>>2]=e;db=c+16|0}function zU(a,b){var c=0;c=yka(b&65535,0,384,0);b=a&65535;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+hb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;hb=b>>>0<256?a+1|0:a;return b}function zD(a,b){a=a|0;b=b|0;var c=0,d=0;c=a;a=x[b>>2];d=(ib[x[x[a>>2]+20>>2]](a)|0)+x[b+8>>2]|0;a=x[b>>2];ec(c,d,(ib[x[x[a>>2]+24>>2]](a)|0)-x[b+8>>2]|0)}function hx(a,b){var c=0;while(1){c=(b|0)>=120?120:b;a=E(a*E(B[((c&3)<<2)+64864>>2]*E(1073741824>>>(c>>2)|0)));b=b-c|0;if((b|0)>0){continue}break}return a}function ci(a){var b=0,c=0;b=a*a;c=b*a;return E(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function _p(a,b){var c=0,d=0;a:{if(!a){break a}c=yka(a,0,b,0);d=hb;if((a|b)>>>0<65536){break a}c=d?-1:c}a=Nd(c);if(!(!a|!(y[a-4|0]&3))){Vb(a,0,c)}return a}function ZV(a,b,c){var d=0;b=b-a>>2;while(1){if((b|0)>0){d=x[c>>2];v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;b=b-1|0;a=a+4|0;continue}break}}function Yi(a,b,c,d){var e=0;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;e=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=e;C[a>>3]=C[a>>3]-c;C[a+8>>3]=C[a+8>>3]-d}function Hi(a,b,c,d,e){a:{e=Vs(e);if(e){x[23549]=0;ba(d|0,e|0,a|0,b|0,c|0)|0;a=x[23549];x[23549]=0;if((a|0)==1){break a}}return e}a=N()|0;Eb(e);Q(a|0);p()}function BX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function pU(a,b,c,d){var e=0;e=db-32|0;db=e;Od(e+24|0,b,c);rl(e+16|0,x[e+24>>2],x[e+28>>2],d);b=x[e+16>>2];x[e+12>>2]=x[e+20>>2];vc(a,b,e+12|0);db=e+32|0}function aI(a,b,c){var d=0;d=db-32|0;db=d;x[d+28>>2]=c;x[d+24>>2]=0;x[d+12>>2]=4;Sr(d+16|0,a,d+24|0,x[Cb(d+28|0,d+12|0)>>2]);x[b>>2]=x[d+24>>2];db=d+32|0}function PX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function u7(a){a=a|0;var b=0,c=E(0);v[a+4202|0]=1;b=a,c=cz(E(E(E(E(A[x[a+16>>2]+24620>>2])/E(3))+E(-80))/E(15920)),E(0),E(1)),B[b+4272>>2]=c;WK(a);VK(a)}function gS(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=441273424|y[a+5|0]!=16|(y[a+54|0]-33&255)>>>0<224)){b=y[a+4|0]>95}return b}function Vg(a){var b=0,c=0;b=x[a>>2];c=x[b+4>>2];a:{if(!c){while(1){if(!qh(b)){b=x[b+8>>2];continue}break}b=x[b+8>>2];break a}b=jT(c)}x[a>>2]=b;return a}function LR(a){var b=0;return(y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1297236819|y[a+29|0]!=16?b:((y[a+42|0]|y[a+43|0]<<8)-1&65535)>>>0<2}function Gn(a,b){var c=0,d=0;b=b+7&-8;d=x[a+80>>2];a:{if(d){b=x[a+92>>2]-b|0;c=0;if((b|0)<x[a+88>>2]){break a}x[a+92>>2]=b;return b+d|0}c=Nd(b)}return c}function E6(a,b,c){a=a|0;b=b|0;c=c|0;a=zs(a,x[b+28>>2]);xK(b+28|0,c);x[23549]=0;P(69,b|0,1);b=x[23549];x[23549]=0;if((b|0)==1){b=N()|0;Xb(a);Q(b|0);p()}}function zm(a,b){var c=0,d=0,e=0;pu(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=wb(b);d=wb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function xZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];v[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function bR(a,b){var c=0,d=0,e=0;$t(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=wb(b);d=wb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function at(a,b,c){var d=0;a:{if(b&134218752){break a}if(!Pj(c)){break a}b=y[c+34|0];if((b+5&255)>>>0<6){break a}d=x[(D(b,160)+a|0)+906140>>2]}return d}function aU(a,b,c){var d=0;d=db-32|0;db=d;x[d+28>>2]=c;v[d+27|0]=0;x[d+12>>2]=1;Sr(d+16|0,a,d+27|0,x[Cb(d+28|0,d+12|0)>>2]);v[b|0]=y[d+27|0];db=d+32|0}function Vc(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(A[a+8>>2]<b>>>0){d=x[a>>2];c=0;if(!(ib[x[x[d>>2]+32>>2]](d,0,b)|0)){break a}}x[a+8>>2]=b;c=1}return c|0}function V4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=db-32|0;db=h;i=h+8|0;lJ(i,b,c,d,e,f,g);ad(a,h+20|0);lm(i);db=h+32|0}function On(a,b){x[a+20>>2]=0;x[a+24>>2]=b;x[a+12>>2]=0;x[a+4>>2]=4098;x[a+8>>2]=6;x[a+16>>2]=!b;Vb(a+32|0,0,40);YH(a+28|0);x[a+72>>2]=0;x[a+76>>2]=-1}function uv(a,b){var c=0;c=db-16|0;db=c;a:{if(!Lb(x[b>>2],x[b+8>>2],3)){v[c|0]=0;Sh(a,3,c);break a}tv(c+8|0,a);pd(c,b,x[c+8>>2],x[c+12>>2])}db=c+16|0}function mO(a,b,c){var d=0,e=0;x[b+56>>2]=0;d=b,e=ao(a,z[b+70>>1],x[b+48>>2],c,0),w[d+68>>1]=e;if(!(!(y[a+480180|0]&5)|x[b+60>>2]==-1)){x[b+60>>2]=0}}function Au(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;Im(c+12|0,a);x[c+8>>2]=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);nu(c+8|0,b);db=c+16|0}function pv(a,b,c,d,e){var f=0;while(1){if((d|0)!=(f|0)){B[b>>2]=E(x[a>>2])*e;B[c>>2]=E(x[a+4>>2])*e;f=f+1|0;c=c+4|0;a=a+8|0;b=b+4|0;continue}break}}function pZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b|0];v[e|0]=(a|0)<0?d:a;e=e+1|0;b=b+1|0;continue}break}return c|0}function nE(){var a=0,b=0,c=0;b=db-16|0;db=b;a=Tb(b+4|0,14956);if(Oc(x[a+4>>2],y[a+11|0])){c=(sg(a,13616)|0)!=-1}else{c=0}tb(a);db=b+16|0;return c|0}function aga(a,b){a=a|0;b=b|0;var c=0,d=0;d=db-96|0;db=d;c=-1;a:{if(!hS(a,d)){break a}c=0;if(!gS(d)){break a}c=Ge(a,b,fS(d),hb)}db=d+96|0;return c|0}function Li(a,b){var c=0;if(ue(y[a+11|0])){c=x[a>>2];mk(x[a+8>>2]);Eb(c)}c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];ff(b,0);zd(b,0)}function JK(a,b){a=a|0;b=b|0;var c=0,d=0;d=db-16|0;db=d;c=rK(Hc(12));x[c+8>>2]=b;x[c+4>>2]=a;x[c>>2]=49196;a=x[of(d+12|0,c)>>2];db=d+16|0;return a|0}function D2(a,b,c){a=a|0;b=b|0;c=c|0;a:{a=qg(a,b);x[23549]=0;O(53,a+12|0,c|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){break a}b=N()|0;tb(a);Q(b|0);p()}}function Bfa(a,b){a=a|0;b=b|0;var c=0,d=0;d=db-96|0;db=d;c=-1;a:{if(!hS(a,d)){break a}c=0;if(!LR(d)){break a}c=Ge(a,b,KR(d),hb)}db=d+96|0;return c|0}function yz(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-32|0;x[a+8>>2]=b;Tj(b);continue}break}c=x[a>>2];if(c){vr(a);Eb(c)}}function xv(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-36|0;x[a+8>>2]=b;Vo(b);continue}break}c=x[a>>2];if(c){kc(a);Eb(c)}}function wr(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;x[a+8>>2]=b;Ab(b);continue}break}c=x[a>>2];if(c){vr(a);Eb(c)}}function mu(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-20|0;x[a+8>>2]=b;ub(b);continue}break}c=x[a>>2];if(c){kc(a);Eb(c)}}function hM(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-52|0;x[a+8>>2]=b;Nj(b);continue}break}c=x[a>>2];if(c){kc(a);Eb(c)}}function ZR(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-56|0;x[a+8>>2]=b;cq(b);continue}break}c=x[a>>2];if(c){kc(a);Eb(c)}}function ZM(a){if(y[a+480224|0]==2){return+A[a+1074420>>2]/1e4}return+A[a+24620>>2]/(+A[a+1074404>>2]*+(D(x[a+1074408>>2],x[a+1074416>>2])>>>0))*60}function Yp(a,b,c){a:{if(!Ob(c+1074312|0,102)){break a}c=z[a+692>>1]+1|0;w[a+784>>1]=c;if(!(v[a+89|0]&1)){break a}w[a+784>>1]=c|32768}x[a+692>>2]=b}function NV(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-28|0;x[a+8>>2]=b;Gd(b);continue}break}c=x[a>>2];if(c){kc(a);Eb(c)}}function NE(a,b,c){var d=0;d=db-32|0;db=d;v[d+28|0]=44;x[d+20>>2]=-1;x[d+24>>2]=0;x[d+12>>2]=1058;x[d+16>>2]=c;IE(a,b,d+12|0,57,74,73,60);db=d+32|0}function $Y(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Kg(a,x[b+8>>2],f)){iw(b,c,d,e);return}a=x[a+8>>2];ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)}function vz(a,b,c){var d=0,e=0,f=0;d=gl(a,b);if((d|0)!=255){e=_b(a+26|0,d),f=c,w[e>>1]=f;a=a+62|0;e=Db(a,b),f=255,v[e|0]=f;e=Db(a,c),f=d,v[e|0]=f}}function hV(a){v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0}function c1(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;ib[x[x[a+32>>2]+d>>2]](b,a,x[d+x[a+36>>2]>>2]);continue}break}}function IU(a,b){var c=0;c=yka(b&255,0,9,0);b=a&255;a=b>>>31|0;b=b<<1;c=c+b|0;a=a+hb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;hb=b>>>0<11?a+1|0:a;return b}function FF(a){var b=0,c=0;c=a>>>23&255;b=0;a:{if(c>>>0<127){break a}b=2;if(c>>>0>150){break a}c=1<<150-c;b=0;if(c-1&a){break a}b=a&c?1:2}return b}function Cr(a,b,c,d){var e=0;e=db-32|0;db=e;v[e+28|0]=44;x[e+20>>2]=-1;x[e+24>>2]=0;x[e+12>>2]=c;x[e+16>>2]=d;IE(a,b,e+12|0,70,76,75,71);db=e+32|0}function Aka(a,b,c){var d=0;d=b>>31;a=a^d;wka(a-d|0,(b^d)-((a>>>0<d>>>0)+d|0)|0,c,0);hb=gb;a=d^fb;b=a-d|0;hb=(d^hb)-((a>>>0<d>>>0)+d|0)|0;return b}function AS(a){return(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))==1279545165&(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1297239878}function AP(a){var b=0,c=0,d=0;d=y[a+26|0];b=d+27|0;while(1){if((c|0)==(d|0)){a=b&65535}else{b=y[(a+c|0)+27|0]+b|0;c=c+1|0;continue}break}return a}function $v(a,b,c,d){var e=0;e=ac(8);x[23549]=0;a=O(d|0,e|0,a|0)|0;d=x[23549];x[23549]=0;if((d|0)!=1){da(a|0,c|0,b|0);p()}a=N()|0;jc(e);Q(a|0);p()}function nC(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0}function lz(a){var b=0,c=0;b=db-16|0;db=b;x[b+12>>2]=a;c=b+12|0;a=1;while(1){if((a|0)>0){Vg(c);a=a-1|0;continue}break}db=b+16|0;return x[b+12>>2]}function S5(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=db-32|0;db=h;i=h+8|0;lJ(i,b,c,d,e,f,g);ad(a,i);lm(i);db=h+32|0}function R7(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);if(b>>>0<=1){c=Fd(c,E(0));if((b|0)==1){d=1;c=Rh(c)}e=xb(a+4208|0,d),f=c,B[e>>2]=f;cL(a)}}function DD(a){a=a|0;var b=0;a=Gb(a);x[23549]=0;R(160,a+12|0)|0;b=x[23549];x[23549]=0;if((b|0)!=1){xc(a+32|0);return a|0}b=N()|0;tb(a);Q(b|0);p()}function tp(a,b){var c=0;a:{if(!JI(b)|(y[b+1|0]^y[a+1|0])>>>0>1){break a}b=y[b+2|0];a=y[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function nka(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;x[c+12>>2]=-1;if(Eg(a,c+11|0)){x[c+4>>2]=y[c+11|0];XV(a,b,x[Cb(c+4|0,c+12|0)>>2])}db=c+16|0}function YL(a){var b=0;b=db-16|0;db=b;B[b+12>>2]=F(a);x[b+8>>2]=646978941;x[b+4>>2]=1259902592;a=B[nq(b+12|0,b+8|0,b+4|0)>>2];db=b+16|0;return a}function Mf(a,b){a=a|0;b=b|0;var c=0;c=db-32|0;db=c;w[c+30>>1]=0;Il(c+8|0,c+30|0);vn(c+20|0,a,x[c+8>>2],x[c+12>>2]);w[b>>1]=z[c+30>>1];db=c+32|0}function Jw(a){var b=0,c=0;b=db-16|0;db=b;c=-1;a:{if(Uw(a)){break a}if((ib[x[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=y[b+15|0]}db=b+16|0;return c}function lR(a){a=a|0;var b=0,c=0;w[a+34>>1]=0;b=db-16|0;db=b;v[b+15|0]=0;c=a+43|0;am(c,c+22|0,b+15|0);db=b+16|0;x[a+20>>2]=0;nd(a,0);return a|0}function eO(a,b){v[a+840|0]=b;v[a+812|0]=b;v[a+811|0]=b;v[a+809|0]=b;v[a+807|0]=b;v[a+806|0]=b;v[a+833|0]=b;v[a+826|0]=b>>>4;v[a+827|0]=b<<2&60}function dk(a,b,c,d){var e=0;e=D(b,c);a:{if(x[d+76>>2]<0){a=FB(a,e,d);break a}a=FB(a,e,d)}if((e|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function FW(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;x[c+12>>2]=-1;if(Eg(a,c+11|0)){x[c+4>>2]=y[c+11|0];kC(a,b,x[Cb(c+4|0,c+12|0)>>2])}db=c+16|0}function xga(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=pg(b);pg(b);break a}a=Fg(b);Fg(b)}while(1){if(a){if(a&1){Zb(b,260)}a=a>>>1|0;continue}break}}function sI(a,b,c,d,e,f){var g=0,h=0;g=x[a+32>>2];if(!y[a+23|0]){x[(c<<2)+g>>2]=b;return}h=g;g=d<<2;x[h+g>>2]=b;v[x[a+8>>2]+d|0]=e;x[f+g>>2]=c}function lc(a,b,c,d,e){var f=0,g=0;f=db-16|0;db=f;x[f+8>>2]=d;x[f+12>>2]=e;g=x[x[b>>2]+28>>2];x[f>>2]=d;x[f+4>>2]=e;ib[g|0](a,b,c,f);db=f+16|0}function fT(a){var b=0;if(!(cd(a,14672,3)|(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))-2147483647>>>0<2147484072)){b=y[a+3|0]<6}return b}function en(a,b){var c=0,d=0;d=x[a+4>>2];c=x[a+8>>2];while(1){if((c|0)!=(d|0)){c=c-b|0;x[a+8>>2]=c;continue}break}b=x[a>>2];if(b){kc(a);Eb(b)}}function cK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Pf(b);e=a;a=Bb(x[c+4>>2],y[c+11|0]);b=We(Mb(Vw(e,d+a|0)),b,d)+d|0;sl(We(b,Mb(c),a)+a|0,1,0)}function GR(a,b,c,d){var e=0;e=c&4;a:{b:{if(!(e|(b&255)!=4)){if(c&2){break b}Xc(a,8,1,0,10);return}b=16;if(e){break a}}b=8}Xc(a,b,c&2|1,0,d^1)}function $6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!b){zx(a,0,0,0,0,0,0,c,d);return}zx(a,x[b>>2],x[b+4>>2],x[b+8>>2],x[b+12>>2],x[b+24>>2],b,c,d)}function lt(a,b){var c=0,d=0;d=qf(a,b);while(1){a:{c=d;if(!(c&65535)){c=0;break a}d=c-1|0;if(!se(a,b,d&65535)){continue}}break}return c&65535}function hR(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){vr(a);Eb(b)}}function bi(a){var b=0;a=a*a;b=a*a;return E(a*b*(a*2439044879627741e-20+-.001388676377460993)+(b*.04166662332373906+(a*-.499999997251031+1)))}function Um(a,b){var c=0;a=Zm(a);x[a>>2]=61420;c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c;v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2];return a}function JE(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-16|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){vr(a);Eb(b)}}function IQ(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-32|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){vr(a);Eb(b)}}function sz(a,b,c){var d=0;while(1){if((b|0)!=(c|0)){d=x[a>>2];x[a>>2]=d<<8^x[((y[b|0]^d>>>24)<<2)+29260>>2];b=b+1|0;continue}break}return a}function T4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=db-32|0;db=g;h=g+8|0;mJ(h,b,c,d,e,f);ad(a,g+20|0);lm(h);db=g+32|0}function If(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-4|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){Iz(a);Eb(b)}}function GB(a,b){var c=0,d=0,e=0;c=db-16|0;db=c;w[c+14>>1]=1;d=c,e=vl(a,b),w[d+12>>1]=e;a=z[Ve(c+14|0,c+12|0)>>1];db=c+16|0;return a-1&65535}function zb(a,b){var c=0;if(ue(y[a+11|0])){Eb(x[a>>2])}c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];ff(b,0);hd(b,0);return a}function cv(a,b){var c=0;a:{if(!b){break a}if(!Lb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=1){c=XC(a,1);break a}c=Fg(a);Zb(a,b-2|0)}return c}function Yf(a){var b=0,c=0,d=0;d=db-16|0;db=d;b=vb(d+12|0,a);c=x[b>>2];if(x[c>>2]){Dc(c);b=x[b>>2];c=x[b>>2];Xt(b);Eb(c)}db=d+16|0;return a}function No(a,b){var c=0;a:{if(!b){break a}if(!Lb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=3){c=YC(a,b);break a}c=pg(a);Zb(a,b-4|0)}return c}function Be(a,b,c){v[a+11|0]=c;v[a+10|0]=b;v[a+12|0]=y[a+12|0]&251;w[a+8>>1]=65535;x[a>>2]=0;x[a+4>>2]=0;v[a+12|0]=y[a+12|0]&252|1;return a}function al(a){var b=0,c=0,d=0;b=db-16|0;db=b;c=x[a+24>>2];d=x[a+40>>2];x[b+12>>2]=1;a=x[Yc(a+20|0,b+12|0)>>2];db=b+16|0;return D(a,c+d|0)}function YH(a){var b=0,c=0;x[23549]=0;c=ca(1077)|0;b=x[23549];x[23549]=0;if((b|0)!=1){b=a;a=x[c>>2];x[b>>2]=a;Xm(a);return}T(0)|0;Rb();p()}function TL(a,b,c){var d=0,e=0;d=Mc(a);if(d>>>0>=c>>>0){SA(a,pl(Mb(a),b,c),c);return}e=a;a=Bb(x[a+4>>2],y[a+11|0]);gq(e,d,c-d|0,a,0,a,c,b)}function Jb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=db-16|0;db=d;if(b>>>0>=120){lq(12e3);p()}e=d+8|0;Fb(e,a,b);Dh(e,c);db=d+16|0;return a|0}function JF(a,b,c,d,e){var f=0;f=c;c=0;a:{if(!d){break a}c=b>>8;if(!(b&1)){break a}c=fw(x[d>>2],c)}ib[x[x[a>>2]+28>>2]](a,f,c+d|0,b&2?e:2)}function IZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=db-16|0;db=a;x[a+12>>2]=e;x[a+8>>2]=d-c;b=Cb(a+12|0,a+8|0);db=a+16|0;return x[b>>2]}function dA(a,b){var c=0,d=0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[b>>2]=0;x[b+4>>2]=0;c=wb(b),d=0,x[c>>2]=d;return a}function bV(a){var b=0,c=0,d=0;c=db-16|0;db=c;b=c+13|0;uv(b,a);a=y[Db(b,0)|0];d=y[Db(b,1)|0];b=y[Db(b,2)|0];db=c+16|0;return a|d<<8|b<<16}function Sc(a){var b=0;b=db-16|0;db=b;x[b+12>>2]=a;x[b+8>>2]=-32768;x[b+4>>2]=32767;a=w[Re(b+8|0,qd(b+12|0,b+4|0))>>1];db=b+16|0;return a}function Mm(a,b,c){var d=0,e=0,f=0;d=db-16|0;db=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[Sb(d+15|0,d+14|0)|0]|(c?-128:0),v[e+21|0]=f;db=d+16|0}function Lm(a,b,c){var d=0,e=0,f=0;d=db-16|0;db=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[Sb(d+15|0,d+14|0)|0]|(c?-128:0),v[e+22|0]=f;db=d+16|0}function Fba(a){a=a|0;var b=0;b=x[a>>2];if(ib[x[x[b>>2]+32>>2]](b,0,32)|0){a=x[a>>2];a=ib[x[x[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function $z(a){a=50-(D(y[(a>>>4|0)+31600|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Cc((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function j9(a,b){a=a|0;b=b|0;var c=0;b=db-16|0;db=b;c=x[a+20>>2];ge(b,x[c+4>>2],x[c+8>>2]);EL(a,ec(b+8|0,x[b>>2],x[b+4>>2]),0);db=b+16|0}function bF(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=x[a>>2];if(d>>>0<=127){d=x[(d<<2)+c>>2]}x[a>>2]=d;a=a+4|0;continue}break}return b}function Mj(a){var b=0,c=0;b=Rm(x[x[a+20>>2]+28>>2]);if(!(b>>>0>249|y[a+4200|0]>=b>>>0)){c=x[(x[a+16>>2]+D(b,160)|0)+906300>>2]}return c}function dd(a,b){var c=0,d=0,e=0;c=zh(a,b);if(c){x[a+12>>2]=x[a+12>>2]+b;return c}d=a,e=ib[x[x[a>>2]+24>>2]](a)|0,x[d+12>>2]=e;return c}function Q5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=db-32|0;db=g;h=g+8|0;mJ(h,b,c,d,e,f);ad(a,h);lm(h);db=g+32|0}function L1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=x[b>>2]+7&-8;x[c>>2]=b+16;d=a,e=Lv(x[b>>2],x[b+4>>2],x[b+8>>2],x[b+12>>2]),C[d>>3]=e}function AA(a){var b=0;b=Hb(y[a+26|0]|y[a+27|0]<<8);return((y[a+24|0]>15)+(y[a+25|0]>64)|0)+(Hb(y[a+22|0]|y[a+23|0]<<8)<<1>>>0<b>>>0)|0}function pba(a,b){a=a|0;b=b|0;a=Qy(a);x[23549]=0;P(781,a|0,b|0);b=x[23549];x[23549]=0;if((b|0)==1){b=N()|0;Op(a);Q(b|0);p()}return a|0}function kR(a){var b=0,c=0;c=db-16|0;db=c;b=vb(c+12|0,a);a=x[b>>2];if(x[a>>2]){fR(a,x[a>>2]);a=x[b>>2];b=x[a>>2];tk(a);Eb(b)}db=c+16|0}function Ml(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-1|0;x[a+8>>2]=b;continue}break}a=x[a>>2];if(a){Eb(a)}}function s1(a,b){a=a|0;b=b|0;x[a+4>>2]=b;v[a|0]=0;b=x[x[b>>2]-12>>2]+b|0;if(!x[b+16>>2]){b=x[b+72>>2];if(b){OH(b)}v[a|0]=1}return a|0}function c9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!Tc(c&255))){GL(a,8,E(0))}a=Mj(a);if(a){ib[x[x[a>>2]+92>>2]](a,b,c,d,e)}}function C2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Bx(x[a+32>>2],b,c,d,2);if(a>>>0<=15){a=y[a+43952|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function B2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Bx(x[a+32>>2],b,c,d,3);if(a>>>0<=45){a=y[a+43904|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function AW(a,b){a=a|0;b=b|0;x[a+4>>2]=b;v[a|0]=0;b=x[x[b>>2]-12>>2]+b|0;if(!x[b+16>>2]){b=x[b+72>>2];if(b){Tq(b)}v[a|0]=1}return a|0}function zi(a,b,c){v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24;v[a+4|0]=c;v[a+5|0]=c>>>8;v[a+6|0]=c>>>16;v[a+7|0]=c>>>24}function uo(a){var b=0;a=je(a);b=255;a:{if(a>=255){break a}b=0;if(a<=0){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b}function aF(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=v[a|0];if((d|0)>=0){d=x[(d<<2)+c>>2]}v[a|0]=d;a=a+1|0;continue}break}return b}function VS(a){var b=0;b=db-16|0;db=b;x[b+12>>2]=a;x[b+8>>2]=-128;x[b+4>>2]=127;a=v[Re(b+8|0,qd(b+12|0,b+4|0))|0];db=b+16|0;return a}function Jba(a,b){a=a|0;b=b|0;a=Hu(a,b);if(!a){v[b+6|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0}return a|0}function es(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=x[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=x[c>>2];x[a>>2]=d<<b;x[a+4>>2]=c<<b|d>>>32-b}function e8(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;if(b>>>0<=4){c=Fd(c,E(0));d=((b<<2)+a|0)+4220|0;if((b|0)==4){c=Rh(c)}B[d>>2]=c;eL(a)}}function Qw(a){a=a|0;var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+1;return Lh(v[b|0])|0}function Of(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;if(b>>>0>=120){lq(11965);p()}d=c+8|0;Fb(d,a,b);Dh(d,0);db=c+16|0;return a|0}function Mh(a,b){var c=0,d=0;c=x[a>>2];d=x[a+4>>2];b=x[a+16>>2]+b|0;a=x[a+12>>2];b=(b|0)%(a|0)|0;return B[Fc(c,d,(b>>31&a)+b|0)>>2]}function gs(a,b){var c=0,d=0;c=x[a+4>>2];a:{if(b>>>0<=31){d=x[a>>2];break a}b=b-32|0;d=c;c=0}x[a+4>>2]=c>>>b;x[a>>2]=c<<32-b|d>>>b}function Nh(a,b){var c=0,d=0,e=0;o(+a);c=j(1)|0;d=j(0)|0;o(+b);e=j(1)|0;j(0)|0;l(0,d|0);l(1,c&2147483647|e&-2147483648);return+n()}function G1(a){a=a|0;var b=0;if((ib[x[x[a>>2]+36>>2]](a)|0)!=-1){b=a;a=x[a+12>>2];x[b+12>>2]=a+1;a=Lh(v[a|0])}else{a=-1}return a|0}function xi(a){var b=0;b=db-16|0;db=b;x[b+12>>2]=a;x[b+8>>2]=0;x[b+4>>2]=255;a=y[Re(b+8|0,qd(b+12|0,b+4|0))|0];db=b+16|0;return a}function rba(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;if(b>>>0>=250){lq(12e3);p()}d=c+8|0;Fb(d,a,b);xm(d);db=c+16|0;return a|0}function rI(a,b){a:{if(a&255){a=1;if((b|0)!=255){break a}_(13909,13048,1180,5675);p()}if((b|0)==255){return 0}a=b>>>0>10}return a}function AT(a,b){var c=0;c=db-16|0;db=c;a=oh(c+4|0,a,1);kq(x[a+4>>2],z[b>>1]|z[b+2>>1]<<16);x[a+4>>2]=x[a+4>>2]+4;fc(a);db=c+16|0}function zZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){x[d>>2]=v[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function u1(a){a=a|0;var b=0;if((ib[x[x[a>>2]+36>>2]](a)|0)!=-1){b=a;a=x[a+12>>2];x[b+12>>2]=a+4;a=x[a>>2]}else{a=-1}return a|0}function qq(a,b){var c=0;c=Bb(x[a+4>>2],y[a+11|0]);if((c|0)==(Bb(x[b+4>>2],y[b+11|0])|0)){a=Un(Mb(a),Mb(b),c)}else{a=1}return!a}function pz(a,b){var c=0;c=x[a+484360>>2];b=b&255;if(bj(c,x[a+484364>>2])>>>0<=b>>>0){return Wb(c,y[a+484376|0])}return jj(c,b)}function lO(a,b,c,d){a:{if(d>>>0>=64){d=-1;if(y[a+480180|0]&2){break a}}x[b+56>>2]=0;d=ao(a,z[b+70>>1],x[b+48>>2],c,0)}return d}function iK(a){a=a|0;var b=0,c=0;b=db-16|0;db=b;c=TJ(Hc(8));x[c+4>>2]=a;x[c>>2]=56952;a=x[of(b+12|0,c)>>2];db=b+16|0;return a|0}function fe(a){var b=0;a=x[a+4>>2];if(a){if($m(a)){a:{b=a+8|0;if(x[b>>2]){if((Bv(b)|0)!=-1){break a}}ib[x[x[a>>2]+16>>2]](a)}}}}function eA(a,b){var c=0;c=db-16|0;db=c;a=ec(c+8|0,(b>>>3&536870908)+a|0,1<<b);a=Ib(x[x[a>>2]>>2],x[a+4>>2]);db=c+16|0;return a}function cx(a,b,c){var d=0;d=x[a+32>>2];if(A[a+40>>2]<d+c>>>0){x[a+96>>2]=1;return 0}rc(b,d,c);x[a+32>>2]=x[a+32>>2]+c;return 1}function _E(a,b,c){var d=0;d=db-16|0;db=d;x[d+8>>2]=a;x[d+12>>2]=b;x[d>>2]=c;x[d+4>>2]=0;a=Vq(d+8|0,d);db=d+16|0;return x[a>>2]}function VE(a,b,c,d){a=Nb(a);x[23549]=0;S(d|0,a|0,b|0,c|0);b=x[23549];x[23549]=0;if((b|0)!=1){return a}b=N()|0;sc(a);Q(b|0);p()}function LZ(a){a=a|0;var b=0;b=db-16|0;db=b;di(ei(b+12|0,x[a+8>>2]));db=b+16|0;a=x[a+8>>2];if(!a){return 1}return(TF(a)|0)==1|0}function KG(a,b,c,d,e,f){a=ib[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=Rr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function HG(a,b,c,d,e,f){a=ib[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=Pr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function wq(a){var b=0;b=-1;a:{if(a>=4294967295){break a}b=0;if(a<=0){break a}if(a<4294967296&a>=0){return~~a>>>0}b=0}return b}function wo(a){var b=0,c=0;c=db-16|0;db=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Dc(b);a=x[a>>2];b=x[a>>2];zT(a);Eb(b)}db=c+16|0}function vi(a){var b=0,c=0;c=db-16|0;db=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Dc(b);a=x[a>>2];b=x[a>>2];to(a);Eb(b)}db=c+16|0}function tN(a){var b=0,c=0;c=db-16|0;db=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Dc(b);a=x[a>>2];b=x[a>>2];mV(a);Eb(b)}db=c+16|0}function rZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function mN(a){var b=0,c=0;c=db-16|0;db=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Zs(b);a=x[a>>2];b=x[a>>2];Ys(a);Eb(b)}db=c+16|0}function lC(a,b){var c=0;c=x[b+4>>2];if(c){dc(a,c,x[b>>2]);return}c=x[b+8>>2];b=x[b+12>>2];if(!qc(c,b)){ge(a,c,b);return}Xd(a)}function gN(a){var b=0,c=0;c=db-16|0;db=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){ap(b);a=x[a>>2];b=x[a>>2];wv(a);Eb(b)}db=c+16|0}function fP(a){var b=0,c=0;c=db-16|0;db=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){aP(b);a=x[a>>2];b=x[a>>2];tk(a);Eb(b)}db=c+16|0}function _d(a){var b=0,c=0;c=db-16|0;db=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){VV(b);a=x[a>>2];b=x[a>>2];KB(a);Eb(b)}db=c+16|0}function Zz(a){var b=0,c=0;c=db-16|0;db=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Dc(b);a=x[a>>2];b=x[a>>2];tk(a);Eb(b)}db=c+16|0}function OO(a){var b=0,c=0;c=db-16|0;db=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Dc(b);a=x[a>>2];b=x[a>>2];iz(a);Eb(b)}db=c+16|0}function Ls(a){var b=0;b=C[a+4248>>3]/+A[x[a+16>>2]+24620>>2];C[a+4264>>3]=b;if(y[a+4240|0]){C[a+4264>>3]=b*(C[a+4288>>3]/60)}}function LP(a,b,c,d,e){x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(b){re(b,a)}if(c){re(c,a)}if(d){re(d,a)}if(e){re(e,a)}}function Ks(a){var b=0,c=0;c=db-16|0;db=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Dc(b);a=x[a>>2];b=x[a>>2];Tx(a);Eb(b)}db=c+16|0}function KE(a,b,c){a=Rh(a);a:{if(a>=b){break a}c=0;if(a<=E(0)){break a}if(a<E(4294967296)&a>=E(0)){c=~~a>>>0;break a}}return c}function Gt(a){var b=0,c=0;c=db-16|0;db=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Dc(b);a=x[a>>2];b=x[a>>2];Oz(a);Eb(b)}db=c+16|0}function Cz(a){var b=0,c=0;c=db-16|0;db=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){RP(b);a=x[a>>2];b=x[a>>2];to(a);Eb(b)}db=c+16|0}function rl(a,b,c,d){var e=0,f=0,g=0,h=0;e=db-16|0;db=e;f=b;b=c-b|0;g=e,h=uk(d,f,b)+b|0,x[g+12>>2]=h;vc(a,c,e+12|0);db=e+16|0}function nw(a,b){var c=0,d=0,e=0,f=0;c=Pf(b);d=Hc(c+13|0);x[d+8>>2]=0;x[d+4>>2]=c;x[d>>2]=c;e=a,f=rc(kc(d),b,c+1|0),x[e>>2]=f}function lE(a){a=a|0;var b=0;a=Gb(a);x[23549]=0;P(122,a|0,13442);b=x[23549];x[23549]=0;if((b|0)==1){b=N()|0;tb(a);Q(b|0);p()}}function ZY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Kg(a,x[b+8>>2],0)){gw(b,c,d);return}a=x[a+8>>2];ib[x[x[a>>2]+28>>2]](a,b,c,d)}function Nq(a,b){return jq(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24),y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))?b:a}function ml(a,b){var c=0;a:{if(A[a+12>>2]<b>>>0){c=0;if(!(ib[x[x[a>>2]+32>>2]](a,0,b)|0)){break a}}x[a+12>>2]=b;c=1}return c}function mT(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;w[c+14>>1]=b;if((vl(x[a>>2],x[a+4>>2])|0)!=65535){$B(a,c+14|0)}db=c+16|0}function cg(a,b,c){var d=0;d=4;a:{b:{switch(b-1|0){case 0:d=c;break a;case 1:break b;default:break a}}d=c?3:2}return ho(a,d)}function Zk(a,b,c,d){var e=0;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;e=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=e;iy(a,c,d)}function LG(a,b,c,d,e,f){a=ib[x[x[a+8>>2]>>2]](a+8|0)|0;a=Rr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function IG(a,b,c,d,e,f){a=ib[x[x[a+8>>2]>>2]](a+8|0)|0;a=Pr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function BO(a){Vy(a);x[a>>2]=0;x[a+4>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;a=ig(a);ig(a+12|0);v[a+24|0]=1}function $K(a){a=a|0;var b=0,c=0;b=a+4960|0;c=a+4504|0;while(1){b=sc(b-24|0);if((c|0)!=(b|0)){continue}break}return yf(a)|0}function mA(a){x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function O8(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;if(b>>>0<=2){d=(a+b|0)+4232|0,e=Ug(E(Fd(c,E(0))*E(127))),v[d|0]=e;Js(a)}}function LE(a,b){x[a>>2]=b;YH(a+4|0);x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function C9(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;if(b>>>0<=3){d=(a+b|0)+4264|0,e=Ug(E(Fd(c,E(0))*E(255))),v[d|0]=e;Os(a)}}function AM(a,b){var c=0;if(!(y[a|0]!=y[b|0]|C[a+8>>3]!=C[b+8>>3]|y[a+16|0]!=y[b+16|0])){c=x[a+20>>2]==x[b+20>>2]}return c}function ke(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=x[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}x[a>>2]=b}}function de(a,b){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))}function To(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=x[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}x[a>>2]=b}}function vR(a){var b=0,c=0;while(1){b=c;if((b|0)!=8){c=b+1|0;if((y[a+b|0]-32&255)>>>0<95){continue}}break}return(b|0)==8}function cQ(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){$P(a,1);$P(a,0)}}function bQ(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){aQ(a,1);aQ(a,0)}}function UC(a,b){var c=0;c=yka(b&255,0,1536,0);b=hb;a=yka(a&255,0,25,0);c=a+c|0;b=hb+b|0;hb=a>>>0>c>>>0?b+1|0:b;return c}function TS(a,b){var c=0;c=db-16|0;db=c;a:{if(!zh(a,4)){LT(b);break a}Bh(c+8|0,b);zA(c,a,x[c+8>>2],x[c+12>>2])}db=c+16|0}function TQ(a){var b=0;if(!(y[a+35|0]&2)){a=a+68|0;b=9;while(1){if(b){x[a>>2]=268435456;b=b-1|0;a=a+4|0;continue}break}}}function Lg(a,b,c,d,e){var f=0;f=db-16|0;db=f;x[f+12>>2]=e;c=ei(f+8|0,c);a=Tr(a,b,d,x[f+12>>2]);di(c);db=f+16|0;return a}function LH(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+4;return x[b>>2]}function gT(a,b,c,d){var e=0,f=0,g=0;e=db-16|0;db=e;a=oh(e+4|0,a,d);f=a,g=xq(b,c,x[a+4>>2]),x[f+4>>2]=g;fc(a);db=e+16|0}function YA(a,b,c,d){var e=0,f=0,g=0;e=db-16|0;db=e;a=Gk(e+4|0,a,d);f=a,g=xq(b,c,x[a+4>>2]),x[f+4>>2]=g;fc(a);db=e+16|0}function qS(a){var b=0;if(!(cd(a,13583,3)|y[a+3|0]>31|(v[a+27|0]<0|y[a+32|0]>64))){b=(y[a+33|0]-1&255)>>>0<32}return b}function ot(a){var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=b+c;if(b*1e-7<c){continue}break}return b}function oi(a,b,c){c=c&255;while(1){a:{if((a|0)!=(b|0)){if((c|0)!=y[a|0]){break a}}else{a=b}return a}a=a+1|0;continue}}function Rba(a){a=a|0;var b=0,c=0;b=db-16|0;db=b;c=of(b+12|0,Vb(Hc(6668),0,6668));db=b+16|0;x[a>>2]=x[c>>2];return a|0}function Ne(a){var b=0;b=x[a+32>>2];a:{if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1;a=0;break a}x[a+32>>2]=b+1;a=y[b|0]}return a}function CY(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return ib[a|0](h|b,c,d,e,b|f,g)|0}function $N(a,b,c,d){var e=0,f=0;if(c&255){e=a,f=Ub(x[a>>2]+((D(c<<24>>24,(d^-1|-256)+b|0)|0)/2|0)|0,0,256),x[e>>2]=f}}function th(a){var b=0;while(1){a:{if((b|0)!=46){if(y[b+43984|0]!=(a|0)){break a}}else{b=0}return b}b=b+1|0;continue}}function U0(a,b){a=a|0;b=b|0;var c=0,d=0;ib[x[x[a>>2]+24>>2]](a)|0;b=Kw(x[b>>2]);x[a+36>>2]=b;c=a,d=wn(b),v[c+44|0]=d}function RG(a,b,c){var d=0;d=db-16|0;db=d;x[d+12>>2]=c;b=ei(d+8|0,b);a=nH(a,9160,x[d+12>>2]);di(b);db=d+16|0;return a}function R9(a){a=a|0;var b=0;b=db-16|0;db=b;if(!ed(a,4)){jw(a)}a=x[vb(b+12|0,yb(x[a+44>>2]))>>2];db=b+16|0;return a|0}function P9(a){a=a|0;var b=0;b=db-16|0;db=b;if(!ed(a,4)){jw(a)}a=x[vb(b+12|0,yb(x[a+48>>2]))>>2];db=b+16|0;return a|0}function $0(a,b){a=a|0;b=b|0;var c=0,d=0;ib[x[x[a>>2]+24>>2]](a)|0;b=Gw(x[b>>2]);x[a+36>>2]=b;c=a,d=wn(b),v[c+44|0]=d}function zg(a){var b=0;vm(a);b=Bt(x[a>>2],rk(z[a+34>>1]));x[a+20>>2]=b;if(!b){return 0}return pj(x[a>>2],z[a+34>>1])}function y7(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=2){c=Fd(c,E(0));d=xb(a+4208|0,b),e=c,B[d>>2]=e;WK(a)}}function s8(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=5){c=Fd(c,E(0));d=xb(a+4208|0,b),e=c,B[d>>2]=e;kL(a)}}function q7(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=3){c=Fd(c,E(0));d=xb(a+4208|0,b),e=c,B[d>>2]=e;UK(a)}}function l8(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=4){c=Fd(c,E(0));d=xb(a+4208|0,b),e=c,B[d>>2]=e;gL(a)}}function kQ(a){x[a+700>>2]=0;w[a+842>>1]=0;x[a+688>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0}function ik(a){var b=0;if(!y[a+12|0]){b=db-16|0;db=b;vb(b+12|0,x[x[a+8>>2]>>2]);vb(b+8|0,x[x[a+4>>2]>>2]);db=b+16|0}}function gl(a,b){a=a+62|0;if(v[Db(a,b)|0]<0){return 255}if(y[Db(a,b)|0]!=255){a=y[Db(a,b)|0]&127}else{a=255}return a}function ap(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-36|0;Vo(b);continue}break}x[a+4>>2]=c}function VV(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-28|0;Gd(b);continue}break}x[a+4>>2]=c}function D0(a){a=a|0;var b=0,c=0;c=x[a+4>>2];b=x[a>>2];a=x[a+8>>2];b=b+(a>>1)|0;if(a&1){c=x[c+x[b>>2]>>2]}ib[c|0](b)}function sH(a,b,c,d,e,f,g,h,i){x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function nM(a){var b=0,c=0,d=0;if(x[a>>2]){Dc(a);b=x[a>>2];tu(a);Eb(b);c=wb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function eh(a){var b=0;b=db-16|0;db=b;x[b+12>>2]=a;x[b+8>>2]=2147483647;a=Cb(b+12|0,b+8|0);db=b+16|0;return x[a>>2]}function ZP(a){var b=0,c=0,d=0;if(x[a>>2]){Dc(a);b=x[a>>2];Qm(a);Eb(b);c=wb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function YO(a){var b=0,c=0,d=0;if(x[a>>2]){Dc(a);b=x[a>>2];an(a);Eb(b);c=wb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function Hh(a){var b=0;b=db-16|0;db=b;x[b+12>>2]=a;x[b+8>>2]=2147483647;a=x[Cb(b+12|0,b+8|0)>>2];db=b+16|0;return a}function $t(a){var b=0,c=0,d=0;if(x[a>>2]){Dc(a);b=x[a>>2];Qh(a);Eb(b);c=wb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function rc(a,b,c){var d=0;if(c){d=a;while(1){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function pI(a,b,c){var d=0,e=0,f=0;e=c*c;C[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;C[b>>3]=d*d+((c+c)*d+(c*c-e))}function YV(a,b,c,d,e){v[a+4|0]=b;v[a|0]=69;v[a+1|0]=99;v[a+2|0]=104;v[a+3|0]=111;v[a+7|0]=e;v[a+6|0]=d;v[a+5|0]=c}function OG(a,b){var c=0;c=db-16|0;db=c;a=Gk(c+4|0,a,1);Fk(x[a+4>>2],y[b|0]);x[a+4>>2]=x[a+4>>2]+1;fc(a);db=c+16|0}function iO(a,b){var c=0;c=b&15;if(c){v[a+827|0]=c<<2}b=b&240;if(b){v[a+826|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|262144}function fL(a){a=a|0;x[a+4244>>2]=0;x[a+4248>>2]=0;x[a+4228>>2]=0;x[a+4232>>2]=0;a=a+4252|0;x[a>>2]=0;x[a+4>>2]=0}function bN(a,b){var c=0;c=db-16|0;db=c;a=Kz(c+4|0,a);no(x[a+4>>2],x[b>>2]);x[a+4>>2]=x[a+4>>2]+4;fc(a);db=c+16|0}function Qr(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}Pb(a,b);a=a+4|0;continue}}}function QH(a,b){a=a|0;b=b|0;var c=0;c=x[a>>2];a:{if(!c){break a}if(!qc(TH(c,b),-1)){break a}x[a>>2]=0}return a|0}function Nl(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}sh(a,b);a=a+1|0;continue}}}function EM(a,b){var c=0,d=0;c=x[a+4>>2];d=x[b+4>>2];if((c|0)==(d|0)){a=BM(x[a>>2],c,x[b>>2],d)}else{a=1}return!a}function $k(a,b){var c=0;c=b&15;if(c){v[a+824|0]=c<<2}b=b&240;if(b){v[a+823|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|131072}function h4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(a){c=a;a=ib[x[x[b>>2]+8>>2]](b)|0;d=c,e=_f(a?a:21204),x[d>>2]=e}}function vw(a,b,c){while(1){a:{if((a|0)!=(b|0)){if(x[a>>2]!=(c|0)){break a}}else{a=b}return a}a=a+4|0;continue}}function az(a,b){var c=0;c=1;a:{switch((b&255)-4|0){default:c=(a&255)==11;break;case 0:case 2:break a}}return c}function xu(a){var b=0;b=db-16|0;db=b;x[b+12>>2]=a;x[b+8>>2]=65535;a=z[Cb(b+12|0,b+8|0)>>1];db=b+16|0;return a}function vu(a,b){var c=0;c=db-16|0;db=c;x[c+12>>2]=(D(a,b)>>>0)/255;ke(c+12|0,0,15);db=c+16|0;return y[c+12|0]}function ed(a,b){var c=0;c=db-16|0;db=c;pG(c+8|0,a+24|0,b);a=Ib(x[x[c+8>>2]>>2],x[c+12>>2]);db=c+16|0;return a}function dM(a){var b=0;b=db-16|0;db=b;x[b+12>>2]=a;x[b+8>>2]=32767;a=w[Cb(b+12|0,b+8|0)>>1];db=b+16|0;return a}function Kg(a,b,c){if(!c){return x[a+4>>2]==x[b+4>>2]}if((a|0)==(b|0)){return 1}return!Vk(x[a+4>>2],x[b+4>>2])}function Jm(a){a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);return a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)}function Dh(a,b){var c=0;c=x[a+4>>2];if(b){a=x[a>>2];x[a>>2]=x[a>>2]|c;return}a=x[a>>2];x[a>>2]=x[a>>2]&(c^-1)}function $E(a,b){var c=0,d=0;c=a+68|0;a=0;while(1){if((a|0)!=9){d=xb(c,a);a=a+1|0;x[d>>2]=a<<b;continue}break}}function ru(a){var b=0;b=db-16|0;db=b;w[b+14>>1]=a;w[b+12>>1]=255;a=y[Uc(b+14|0,b+12|0)|0];db=b+16|0;return a}function nZ(){if(y[467692]){return x[116922]}zs(467684,x[TK()>>2]);v[467692]=1;x[116922]=467684;return 467684}function ew(a,b,c,d,e,f,g){var h=0;h=b>>8;if(b&1){h=fw(x[e>>2],h)}ib[x[x[a>>2]+20>>2]](a,c,d,e+h|0,b&2?f:2,g)}function cl(a,b,c,d){var e=0;e=db-16|0;db=e;x[e+12>>2]=d;x[e+8>>2]=c;ec(a,b,x[Cb(e+12|0,e+8|0)>>2]);db=e+16|0}function Yj(a,b){var c=0;c=db-16|0;db=c;x[c+12>>2]=a;a=c+12|0;x[a>>2]=x[a>>2]+(b<<2);db=c+16|0;return x[a>>2]}function IM(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+732|0;case 1:break a}}return a+740|0}function Bp(a,b){var c=0;c=db-32|0;db=c;Bh(c+16|0,b);vn(c+24|0,a,x[c+16>>2],x[c+20>>2]);Bh(c+8|0,b);db=c+32|0}function mi(a){var b=0,c=0;x[x[a+20>>2]>>2]=a;c=x[a+12>>2];b=x[c>>2];x[a+4>>2]=b;if(b){x[b+8>>2]=a}x[c>>2]=a}function _ja(a,b){a=a|0;b=b|0;var c=0;b=db-80|0;db=b;c=-1;if(GV(a,b+14|0)){c=FV(b+14|0)}db=b+80|0;return c|0}function VH(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+36>>2]](a)|0}return Lh(v[b|0])}function JG(a,b,c,d,e){b=Ni(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function IP(a){var b=0;b=x[a+4>>2];w[a+70>>1]=y[((z[b+20>>1]>>>6|z[b+22>>1]<<4)&65535)+29120|0]>>>z[a+68>>1]}function GG(a,b,c,d,e){b=Mi(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function dy(a,b){a=Nb(a);x[a+20>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;Nb(a+24|0);Gb(a+36|0);x[a+48>>2]=b;return a}function Sba(){var a=0;a=db-16|0;db=a;if(Ya(a+12|0,4)|0){ds(x[23424],12500);p()}db=a+16|0;return x[a+12>>2]}function Km(a){var b=0;b=db-16|0;db=b;x[b+12>>2]=a;x[b+8>>2]=255;a=y[Cb(b+12|0,b+8|0)|0];db=b+16|0;return a}function JS(a,b){v[a+6|0]=255;x[a+16>>2]=0;w[a+4>>1]=0;x[a>>2]=0;if(b>=0){C[a+8>>3]=b;x[a+16>>2]=3}return a}function Fha(a,b){a=a|0;b=b|0;if(!wT(a,b)){v[b+4|0]=0;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0}}function FI(a,b,c,d){B[d+4>>2]=a+c;a=E(a+E(c*E(-.5)));b=E(b*E(.8660253882408142));B[d+8>>2]=a-b;B[d>>2]=b+a}function DL(a,b){a=a|0;b=b|0;var c=0;c=Bb(x[a+4>>2],y[a+11|0]);if(c>>>0<b>>>0){Du(a,b-c|0,0);return}QT(a,b)}function wR(a,b){var c=0;c=b&255;b=c>>>24|0;a=a&255?1120:1056;c=a+(c<<8)|0;hb=a>>>0>c>>>0?b+1|0:b;return c}function vha(a,b){a=a|0;b=b|0;var c=0;b=db-16|0;db=b;c=-1;if(xj(a,b+8|0)){c=fT(b+8|0)}db=b+16|0;return c|0}function ft(a){var b=0,c=0;while(1){if(b>>>0>=8){a=c<<24>>24}else{b=b+15|0;c=Yn(a);continue}break}return a}function bv(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function Wx(a,b){var c=0;c=Mb(a);if(c>>>0<=b>>>0){a=Bb(x[a+4>>2],y[a+11|0])+c>>>0>=b>>>0}else{a=0}return a}function Q4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return nF(a,b,c,d,e,f,g,12767,1007)|0}function Iga(a,b){a=a|0;b=b|0;var c=0;b=db-16|0;db=b;c=-1;if(yB(a,b+4|0)){c=AS(b+4|0)}db=b+16|0;return c|0}function B4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return nF(a,b,c,d,e,f,g,12835,1014)|0}function iW(a,b){a=a|0;b=b|0;var c=0;b=db-16|0;db=b;c=-1;if(xj(a,b+8|0)){c=RB(b+8|0)}db=b+16|0;return c|0}function eP(a,b){var c=0;c=x[a+484344>>2];if(se(c,x[a+484348>>2],b)){a=x[Yb(c,b)+12>>2]}else{a=1}return a}function SF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;x[e>>2]=c;x[h>>2]=f;return 3}function Ob(a,b){var c=0;c=db-16|0;db=c;pD(c+8|0,a,b);a=Ib(x[x[c+8>>2]>>2],x[c+12>>2]);db=c+16|0;return a}function Kk(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+36>>2]](a)|0}return x[b>>2]}function Hr(a,b,c,d,e,f){var g=0;g=b>>8;if(b&1){g=fw(x[d>>2],g)}ib[x[x[a>>2]+24>>2]](a,c,d+g|0,b&2?e:2,f)}function FV(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1179468868&(y[a+4|0]-1&255)>>>0<10}function wC(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-20|0;ub(c);continue}break}x[a+4>>2]=b}function vW(a){a=a|0;var b=0;b=x[a+76>>2];if(qc(-1,b)){b=PC(x[a+28>>2],32);x[a+76>>2]=b}return b<<24>>24}function le(a,b){a=Fl(a,x[b>>2],x[b+4>>2]);x[a+8>>2]=x[b+8>>2];Fl(a+12|0,x[b+12>>2],x[b+16>>2]);return a}function lN(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-52|0;Nj(c);continue}break}x[a+4>>2]=b}function kx(a,b,c){b=(D(D(ix(a),jx(a,b)),125)>>>0)/(MI(a,b)>>>0)|0;a=(a&6)==6?b&134217724:b;return a?a:c}function fR(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;Zz(c);continue}break}x[a+4>>2]=b}function Qb(a,b,c){var d=0;c=c+x[a+4>>2]|0;d=b;b=x[a>>2]+b|0;c=d>>>0>b>>>0?c+1|0:c;x[a>>2]=b;x[a+4>>2]=c}function QP(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-32|0;Tj(c);continue}break}x[a+4>>2]=b}function $O(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;He(c);continue}break}x[a+4>>2]=b}function ut(a,b){b=yka(a,a>>31,b,b>>31);a=hb;b=b+5e5|0;a=b>>>0<5e5?a+1|0:a;return Cc(zka(b,a,1e6,0),hb)}function TF(a){var b=0,c=0;b=db-16|0;db=b;a=ei(b+12|0,a);c=x[x[116055]>>2];di(a);db=b+16|0;return c?4:1}function Si(a){a:{a=a&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function FO(a,b){var c=0,d=0;a:{if(b<0){break a}c=C[a>>3];if(!(c<0)){d=b;if(!(b<c)){break a}}C[a>>3]=d}}function el(a,b,c,d){a=a&65535;c=c&65535;if(a>>>0>=c>>>0){a=b>>>0<d>>>0&a>>>0<=c>>>0}else{a=1}return a}function PB(a){a=a|0;var b=0,c=0;b=db-16|0;db=b;if(Zq(a,b+14|0)){c=Hb(z[b+14>>1])}db=b+16|0;return c|0}function Io(a){a=a|0;var b=0,c=0;b=db-16|0;db=b;if(Wo(a,b+12|0)){c=$b(x[b+12>>2])}db=b+16|0;return c|0}function xQ(a){if(((y[a+68|0]|y[a+69|0]<<8)-128&65535)>>>0>=65409){a=cd(a,17261,17)}else{a=1}return!a}function uB(a,b){if(b>>>0<=126){Te(((b<<5)+a|0)+480280|0);ko((D(b,872)+a|0)+1074992|0,a,b,134217728)}}function sX(a){a=a|0;var b=0,c=0;b=db-16|0;db=b;c=-1;if(xj(a,b+8|0)){c=BD(b+8|0)}db=b+16|0;return c|0}function pu(a){var b=0,c=0;if(x[a>>2]){Dc(a);Eb(x[a>>2]);b=wb(a),c=0,x[b>>2]=c;x[a>>2]=0;x[a+4>>2]=0}}function ZX(a){a=a|0;var b=0,c=0;b=db-32|0;db=b;c=-1;if(hE(a,b+8|0)){c=gE(b+8|0)}db=b+32|0;return c|0}function Vb(a,b,c){var d=0;if(c){d=a;while(1){v[d|0]=b;d=d+1|0;c=c-1|0;if(c){continue}break}}return a}function zQ(a){_d(a+140|0);ub(a+120|0);ub(a+100|0);ub(a+80|0);ub(a+60|0);ub(a+40|0);ub(a+20|0);ub(a)}function sN(a){x[a+20>>2]=0;v[a+16|0]=7;x[a+8>>2]=1889785610;x[a+12>>2]=1072630333;v[a|0]=3;return a}function jF(a,b,c){var d=0;d=db-16|0;db=d;c=Tb(d+4|0,c);a=pc(a,c);tb(c);x[a>>2]=b;db=d+16|0;return a}function jA(a,b,c){var d=0;d=x[c+4>>2];if((d|0)==(b|0)){a=(_T(a,b,x[c>>2],d)|0)!=0}else{a=1}return a}function hha(a){a=a|0;var b=0;b=db-16|0;db=b;a=Zq(a,b+14|0);db=b+16|0;return(a?z[b+14>>1]:0)<<16>>16}function gU(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){fU(c+52|0);tb(c+40|0);sc(c+16|0);sc(c+4|0);Eb(c)}}function cX(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;Nm(c+8|0,b);Xq(a,x[c+8>>2],x[c+12>>2]);db=c+16|0}function bX(a,b){a=a|0;b=b|0;x[a>>2]=0;x[a+4>>2]=0;Xj(a+8|0,0);Wq(a,127);eD(a,127,y[b|0]);return a|0}function SS(a){w[a+10>>1]=0;w[a+12>>1]=0;w[a+8>>1]=1084;x[a>>2]=0;x[a+4>>2]=40;w[a+14>>1]=0;return a}function Mu(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0}function He(a){var b=0,c=0;b=db-16|0;db=b;a=x[vb(b+12|0,a)>>2];c=x[a>>2];if(c){wb(a);Eb(c)}db=b+16|0}function El(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0}function E2(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;jC(c+8|0,b);Xq(a,x[c+8>>2],x[c+12>>2]);db=c+16|0}function fG(a,b,c){a:{if(!(y[b+120|0]|c>>>0>30)){v[b+120|0]=1;break a}b=UP(c)}x[a+4>>2]=c;x[a>>2]=b}function cP(a,b,c){var d=0;d=db-16|0;db=d;a=x[vb(d+12|0,WO(b,c,Ud(a),gc(a)))>>2];db=d+16|0;return a}function ad(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];cE(b);return a}function VM(a,b){if(b>>>0<=255){a=x[((b<<2)+a|0)+900380>>2];a=a?a+492|0:21204}else{a=21204}return a}function UF(a,b,c,d,e){var f=0;f=db-16|0;db=f;e=ei(f+12|0,e);a=Vr(a,b,c,d);di(e);db=f+16|0;return a}function e4(a,b){a=a|0;b=b|0;var c=0;b=Mb(b);c=x[a+4>>2];if(c){ib[c|0](b,x[a+8>>2]);return}Fs(b,a)}function dv(a){a=a|0;var b=0;b=db-16|0;db=b;a=Eg(a,b+15|0);db=b+16|0;return(a?y[b+15|0]:0)<<24>>24}function a9(a,b,c){a=a|0;b=b|0;c=c|0;a=Mj(a);if(!a){return 0}return ib[x[x[a>>2]+100>>2]](a,b,c)|0}function Wn(a,b,c,d){a=a&255;c=c&255;if(a>>>0>=c>>>0){a=b>>>0<d>>>0&a>>>0<=c>>>0}else{a=1}return a}function iG(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-4|0;continue}break}x[a+4>>2]=b}function hf(a,b){a=a|0;b=b|0;var c=0,d=0;c=db-16|0;db=c;d=a;a=Tb(c+4|0,b);ad(d,a);tb(a);db=c+16|0}function aia(a){a=a|0;var b=0;b=db-16|0;db=b;a=Wo(a,b+12|0);db=b+16|0;return E(a?B[b+12>>2]:E(0))}function z1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+44>>2]](a,b,c,d,e,f)|0}function vn(a,b,c,d){var e=0;e=db-16|0;db=e;Ng(e+8|0,c,d);CH(a,b,x[e+8>>2],x[e+12>>2]);db=e+16|0}function kB(a,b){var c=0;c=db-16|0;db=c;x[c+12>>2]=a;a=x[GU(c+12|0,0-b|0)>>2];db=c+16|0;return a}function W4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return tF(a,b,c,d,e,f,10502,1004)|0}function Uz(a,b,c){b=b-a>>2;while(1){if((b|0)>0){x[a>>2]=x[c>>2];b=b-1|0;a=a+4|0;continue}break}}function Sr(a,b,c,d){var e=0;e=db-16|0;db=e;dc(e+8|0,c,d);CH(a,b,x[e+8>>2],x[e+12>>2]);db=e+16|0}function N3(a){a=a|0;var b=0;b=db-16|0;db=b;a=x[of(b+12|0,Zj(Hc(12),a))>>2];db=b+16|0;return a|0}function D1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+24>>2]](a,b,c,d,e,f)|0}function C1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+16>>2]](a,b,c,d,e,f)|0}function B1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+28>>2]](a,b,c,d,e,f)|0}function A1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0}function sS(a){var b=0,c=0;b=1;c=x[a>>2];a:{if((c|0)>0){b=120;if(c>>>0<121){break a}}x[a>>2]=b}}function qv(a,b){a=wD(a,x[b>>2],x[b+4>>2]);x[a+8>>2]=x[b+8>>2];wD(a+12|0,x[b+12>>2],x[b+16>>2])}function oW(a,b){a=a|0;b=b|0;if(!Ju(a,b)){v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b|0]=0}}function k1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[x[x[b>>2]+16>>2]](a,b,x[c+8>>2],x[c+12>>2],0,d)}function TY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Kg(a,x[b+8>>2],f)){iw(b,c,d,e)}}function T5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return tF(a,b,c,d,e,f,10547,978)|0}function Naa(a,b){a=a|0;b=b|0;pi(a);pi(a);a:{if(b>>>0>=60){Zb(a,4);break a}pi(a)}return pi(a)|0}function zV(a,b){return(Ub((D(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Ub((D(a&15,b)>>>0)/15|0,1,15))&255}function tI(a){var b=0;b=+((a&2097151)>>>0);return E(zj(+E((a|0)<0?-b:b),(a>>>21&1023)-788|0))}function iH(a){var b=0;b=x[116055];if(a){x[116055]=(a|0)==-1?467476:a}return(b|0)==467476?-1:b}function ee(a){a=a|0;var b=0;b=db-16|0;db=b;a=Eg(a,b+15|0);db=b+16|0;return(a?y[b+15|0]:0)&255}function LV(a){var b=0;if(!(cd(a,26404,20)|(y[a+25|0]-9&255)>>>0<248)){b=v[a+47|0]>=0}return b}function CR(a){var b=0,c=0;b=db-16|0;db=b;if(BR(a,b+12|0)){c=$b(x[b+12>>2])}db=b+16|0;return c}function Br(a,b,c,d){var e=0;x[a>>2]=x[b>>2];e=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=(c<<d)+e;return a}function eR(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=D(c,12)+d;return a}function am(a,b,c){b=b-a|0;while(1){if((b|0)>0){v[a|0]=y[c|0];b=b-1|0;a=a+1|0;continue}break}}function Sga(a){a=a|0;var b=0,c=0;b=db-32|0;db=b;c=a;a=xh(b+12|0);dT(c,a,0,0);ub(a);db=b+32|0}function Gc(a,b,c){var d=0;d=x[c+4>>2];if((d|0)==(b|0)){a=_T(a,b,x[c>>2],d)}else{a=1}return!a}function GT(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1279544644&y[a+4|0]<32}function w1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return ib[x[x[a>>2]+32>>2]](a,b,c,d,e)|0}function cG(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(x[b>>2]){continue}break}return b-a>>2}function XP(a,b){var c=0;c=db-16|0;db=c;x[c+12>>2]=a;a=x[WP(c+12|0,b)>>2];db=c+16|0;return a}function RF(a){a=a|0;var b=0;x[a>>2]=82060;b=x[a+8>>2];if(!(!b|!y[a+12|0])){Eb(b)}return a|0}function Mv(a){var b=0;b=db-16|0;db=b;x[b+12>>2]=a;a=dh(x[Bj(b+12|0)>>2]);db=b+16|0;return a}function Ie(a,b){var c=0;c=db-16|0;db=c;x[c+12>>2]=a;a=x[cU(c+12|0,b)>>2];db=c+16|0;return a}function yC(a){var b=0;b=x[a>>2];if(x[b>>2]){wC(b,x[b>>2]);a=x[a>>2];b=x[a>>2];xC(a);Eb(b)}}function qga(a){a=a|0;var b=0;b=db-16|0;db=b;a=_h(a,b+8|0);db=b+16|0;return+(a?C[b+8>>3]:0)}function ow(a,b,c){var d=0;d=db-16|0;db=d;c=ei(d+12|0,c);a=Ww(a,b);di(c);db=d+16|0;return a}function Uy(a){var b=0;x[a+84>>2]=0;x[a+88>>2]=0;b=x[a+80>>2];x[a+92>>2]=b;x[a+96>>2]=b<<12}function UJ(a,b,c,d,e){if(!((b|0)==(c|0)|(d|0)>=0)){v[b|0]=45;d=yL(d);b=b+1|0}JJ(a,b,c,d,e)}function RB(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==810369604&y[a+4|0]<4}function Fg(a){var b=0;b=db-16|0;db=b;a=Zq(a,b+14|0);db=b+16|0;return(a?z[b+14>>1]:0)&65535}function Dg(a){var b=0,c=0;while(1){c=b&65535;if(c>>>0<127){uB(a,c);b=b+1|0;continue}break}}function $C(a,b){if((a&4088)>>>0>=520){b=gv(0-Cka(b^1230262859,25)|0,4)^1247037516}return b}function wD(a,b,c){var d=0;d=db-16|0;db=d;b=Fl(d+8|0,b,c);ZD(b,a);fe(b);db=d+16|0;return a}function k7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;zx(a,b,c,d,e,0,0,f,g)}function fk(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function bL(a,b){var c=0;c=x[a+12>>2];if((c|0)>0){x[a+20>>2]=(x[a+16>>2]+(b+c|0)|0)%(c|0)}}function UH(a){var b=0;b=x[a>>2];if(b){if(!qc(VH(b),-1)){return!x[a>>2]}x[a>>2]=0}return 1}function Kl(a,b,c){var d=E(0);if(b>>>0<=c>>>0){d=B[xb(a+4208|0,b)>>2]}else{d=E(0)}return d}function Cv(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=x[(b<<2)+21208>>2]}else{b=9625}Tb(a,b)}function w6(a,b,c){a=a|0;b=b|0;c=c|0;ib[x[x[b>>2]+8>>2]](b,c);zs(a,x[b+4>>2]);xK(b+4|0,c)}function tV(a,b,c){var d=0;d=db-16|0;db=d;zi(d+8|0,b,c);db=d+16|0;return x[d+8>>2]==(a|0)}function sK(a){a=a|0;var b=0;x[a>>2]=49296;b=x[a+4>>2];if(b){Eb(b);x[a+4>>2]=0}return a|0}function f9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Mj(a);if(a){ib[x[x[a>>2]+76>>2]](a,b,c,d)}}function e9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Mj(a);if(a){ib[x[x[a>>2]+84>>2]](a,b,c,d)}}function d9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Mj(a);if(a){ib[x[x[a>>2]+88>>2]](a,b,c,d)}}function _x(a,b){if((a|0)>=0){return(a>>>0)%(b>>>0)|0}return(((a^-1)>>>0)%(b>>>0)^-1)+b|0}function _k(a,b,c){a=a+1074992|0;return x[(a+D(b,872)|0)+680>>2]>x[(a+D(c,872)|0)+680>>2]}function LC(a){var b=0;b=a&255;a=b>>>21|0;b=(b<<11)+2624|0;hb=b>>>0<2624?a+1|0:a;return b}function Hv(){var a=0,b=0;a=db-16|0;db=a;b=of(a+12|0,Nb(Hc(12)));db=a+16|0;return x[b>>2]}function Fw(a,b,c,d){var e=0;e=db-16|0;db=e;x[e+12>>2]=d;a=Tr(a,b,c,d);db=e+16|0;return a}function Cka(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function zz(a,b){a=Zj(a,b);ad(a+12|0,b+12|0);w[a+28>>1]=z[b+28>>1];x[a+24>>2]=x[b+24>>2]}function yN(a,b){var c=0;c=y[a+851|0];if(c&1){v[a+851|0]=c|64;x[a+852>>2]=x[a+852>>2]+b}}function uN(a){a=Gb(a);Gb(a+12|0);Gb(a+24|0);Gb(a+36|0);Gb(a+48|0);x[a+60>>2]=0;return a}function kS(a,b){var c=0;c=db-16|0;db=c;Nm(c+8|0,b);$T(a,x[c+8>>2],x[c+12>>2]);db=c+16|0}function Ql(a){var b=0;if(a>>>0>=2){b=eH(a+1|0);a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function tt(a){var b=0;b=db-16|0;db=b;v[b+15|0]=0;am(a,mo(a),b+15|0);db=b+16|0;return a}function sl(a,b,c){var d=0;d=db-16|0;db=d;v[d+15|0]=c;Sh(a,b,d+15|0);db=d+16|0;return a}function nq(a,b,c){var d=E(0);d=B[a>>2];if(!fu(d,B[b>>2])){b=fu(B[c>>2],d)?c:a}return b}function mH(a,b){var c=0;c=db-16|0;db=c;x[c+12>>2]=b;a=nH(a,11034,b);db=c+16|0;return a}function h9(a,b){a=a|0;b=b|0;a=Mj(a);if(!a){return 1}return ib[x[x[a>>2]+68>>2]](a,b)|0}function gB(a){var b=0;b=qQ(a);while(1){if((a|0)!=(b|0)){WV(a);a=a+32|0;continue}break}}function bw(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=c+d;return a}function Wh(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;return a}function Ns(a,b,c,d){if(!((b|0)==(c|0)|(d|0)>=0)){v[b|0]=45;d=yL(d);b=b+1|0}Kx(a,b,c,d)}function MH(a){var b=0;b=x[a>>2];if(b){if(!zn(Kk(b))){return!x[a>>2]}x[a>>2]=0}return 1}function Kp(a,b,c){a=al(a)-x[a+16>>2]|0;if(a>>>0>=2){c=E(E(E(c-b)/E(a>>>0))+b)}return c}function EX(a){a=a|0;var b=0;b=x[a+4>>2];return(ib[x[x[b>>2]+20>>2]](b)|0)+x[a+12>>2]|0}function $m(a){var b=0;b=Bv(a+4|0);if((b|0)==-1){ib[x[x[a>>2]+8>>2]](a)}return(b|0)==-1}function zk(a,b,c){var d=0,e=0;d=db-16|0;db=d;e=d+8|0;Ll(e,a+24|0,b);Dh(e,c);db=d+16|0}function zc(a,b){var c=0,d=0;c=db-16|0;db=c;d=c+8|0;Nm(d,a);Al(d,b);db=c+16|0;return a}function ts(a){if(_J(a)){a=ac(4);x[a>>2]=0;a=Yl(a);x[a>>2]=91820;da(a|0,91856,25);p()}}function i0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return eF(b,c,d,e,f,1)|0}
function fY(){var a=0;a:{if(oE(19927555)){break a}if(nE()){break a}a=mE()^1}return a|0}function bl(a,b){var c=0,d=0;c=db-16|0;db=c;d=c+8|0;Fb(d,a,b);xm(d);db=c+16|0;return a}function _D(a,b){var c=0;c=db-16|0;db=c;b=rg(c+8|0,b);ZD(b,a);fe(b);db=c+16|0;return a}function Uu(a,b){a=a|0;b=b|0;var c=0;c=db-16|0;db=c;v[c+15|0]=b;vK(a,c+15|0);db=c+16|0}function U4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return sF(a,b,c,d,e,12223,1005)|0}function SB(a,b,c){v[a+2|0]=1;b=b&15;if(c){b=y[b+26352|0]}else{b=(b<<2)+4|0}v[a+4|0]=b}function EQ(a){var b=0;b=a&255;a=b>>>27|0;b=(b<<5)+259|0;hb=b>>>0<259?a+1|0:a;return b}function CO(a,b){var c=0,d=0;c=db-16|0;db=c;d=c+8|0;Ll(d,a,b);xm(d);db=c+16|0;return a}function BP(a,b){return(a>>>0<=62?63-(D((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function z4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return mF(a,b,c,d,e,9581,1015)|0}function yG(a,b){var c=0,d=0;Me(a,Zd(b));b=gc(b);c=gc(a),d=x[b>>2],x[c>>2]=d;return a}function vZ(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[((b&255)<<2)+80560>>2]}return b<<24>>24}function tZ(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[((b&255)<<2)+79024>>2]}return b<<24>>24}function p_(a){a=a|0;a=468984;while(1){a=Ec(a-12|0);if((a|0)!=468960){continue}break}}function o_(a){a=a|0;a=468912;while(1){a=Ec(a-12|0);if((a|0)!=468624){continue}break}}function nk(a,b,c){a=a|0;b=b|0;c=c|0;if(Ic(a,b)>>>0<=c>>>0){$u();p()}return(c<<1)+a|0}function n_(a){a=a|0;a=468312;while(1){a=Ec(a-12|0);if((a|0)!=468144){continue}break}}function kG(a){var b=0;b=x[a>>2];if(x[b>>2]){lG(b);a=x[a>>2];jG(rw(a),x[a>>2],Qh(a))}}function g0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return eF(b,c,d,e,f,0)|0}function et(a,b){if(!(v[b+851|0]&1&x[a+480180>>2]==8)){ry(a,b,0);ry(a,b,1);ry(a,b,2)}}function du(a,b){var c=0;c=db-16|0;db=c;w[c+14>>1]=b;_t(a+236|0,128,c+14|0);db=c+16|0}function a_(a){a=a|0;a=468952;while(1){a=tb(a-12|0);if((a|0)!=468928){continue}break}}function _g(a,b,c){var d=0;d=db-16|0;db=d;pU(d+8|0,a,b,c);db=d+16|0;return x[d+12>>2]}function _Z(a){a=a|0;a=468136;while(1){a=tb(a-12|0);if((a|0)!=467968){continue}break}}function _$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return cF(b,c,d,e,f,1)|0}function Y$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return cF(b,c,d,e,f,0)|0}function T1(a,b){a=a|0;b=b|0;a=z[a>>1];b=z[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function S1(a,b){a=a|0;b=b|0;a=x[a>>2];b=x[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function R5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return sF(a,b,c,d,e,12323,979)|0}function Ot(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function O4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return mF(a,b,c,d,e,9509,1008)|0}function Fs(a,b){a=a|0;b=b|0;b=db-16|0;db=b;x[b>>2]=a;HK(17412,b);Es(93232);db=b+16|0}function $Z(a){a=a|0;a=468608;while(1){a=tb(a-12|0);if((a|0)!=468320){continue}break}}function wg(a,b,c){var d=0;d=C[a>>3];if(!yQ(d,C[b>>3])){b=yQ(C[c>>3],d)?c:a}return b}function sj(a,b,c){var d=0;d=x[a>>2];if(!Ko(d,x[b>>2])){b=Ko(x[c>>2],d)?c:a}return b}function se(a,b,c){if(Gm(a,b,c)){a=Rf(a,c);a=Kb(x[a>>2],x[a+4>>2])}else{a=0}return a}function rf(a){a=a|0;var b=0;b=x[a>>2];return(ib[x[x[b>>2]+24>>2]](b)|0)-x[a+8>>2]|0}function pg(a){var b=0;b=db-16|0;db=b;a=Wo(a,b+12|0);db=b+16|0;return a?x[b+12>>2]:0}function _v(a,b){var c=0;while(1){if((b|0)!=(c|0)){tg(a+c|0);c=c+1|0;continue}break}}function Yz(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2]}function Yn(a){var b=0;b=a;a=x[a>>2];x[b>>2]=D(a,214013)+2531011;return a>>>16&32767}function Uh(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;Wh(a)}function NQ(a,b,c,d,e,f){a=vb(a,b);vb(a+4|0,c);vb(a+8|0,d);vb(a+12|0,e);vb(a+16|0,f)}function xp(a){a=a|0;x[a+56>>2]=76800;x[a>>2]=76780;As(a+4|0);Nk(a+56|0);return a|0}function vq(a,b){var c=0,d=0,e=0;c=x[a+24>>2];d=a,e=Le(Dj(b)*+(c>>>0)),x[d+24>>2]=e}function vV(a){var b=0;b=x[a>>2];if(x[b>>2]){Dc(b);a=x[a>>2];b=x[a>>2];tu(a);Eb(b)}}function rg(a,b){x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[b>>2]=0;x[b+4>>2]=0;return a}function nR(a){var b=0;b=x[a>>2];if(x[b>>2]){Dc(b);a=x[a>>2];b=x[a>>2];Qh(a);Eb(b)}}function mf(a){a=a|0;x[a+60>>2]=76964;x[a>>2]=76944;As(a+8|0);Nk(a+60|0);return a|0}function lD(a){var b=0;b=x[a>>2];if(x[b>>2]){Dc(b);a=x[a>>2];b=x[a>>2];Qm(a);Eb(b)}}function kH(a){return(a|0)!=0&(a|0)!=88784&(a|0)!=88808&(a|0)!=467392&(a|0)!=467416}function jx(a,b){return y[(D(a>>>1&3,15)+D(a>>>3&1,45)+((b&240)>>>4)|0)+63761|0]<<1}function gR(a){var b=0;b=x[a>>2];if(x[b>>2]){Dc(b);a=x[a>>2];b=x[a>>2];wb(a);Eb(b)}}function dU(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[gc(a)+4|0]){lj(b+16|0)}Eb(b)}}function bU(a){var b=0;b=x[a>>2];if(x[b>>2]){Dc(b);a=x[a>>2];b=x[a>>2];zr(a);Eb(b)}}function ZO(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[gc(a)+4|0]){_O(b+16|0)}Eb(b)}}function VF(a){a=a|0;x[a>>2]=83144;if(x[a+8>>2]!=(yd()|0)){jH(x[a+8>>2])}return a|0}function T6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return FK(a,b,c,d,0,0,0,0,e)|0}function Rd(a){var b=0;b=db-16|0;db=b;x[b+12>>2]=49464;vc(a,49360,b+12|0);db=b+16|0}function RQ(a){var b=0;b=x[a>>2];if(x[b>>2]){Dc(b);a=x[a>>2];b=x[a>>2];wv(a);Eb(b)}}function N8(a,b){a=a|0;b=b|0;return E(b>>>0<=2?E(E(y[(a+b|0)+4232|0])/E(127)):E(0))}function CM(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[gc(a)+4|0]){Ab(b+16|0)}Eb(b)}}function By(a){var b=0;b=db-16|0;db=b;vb(b+12|0,a+116|0);a=kN(a);db=b+16|0;return a}function B9(a,b){a=a|0;b=b|0;return E(b>>>0<=3?E(E(y[(a+b|0)+4264|0])/E(255)):E(0))}function $D(a){var b=0;b=x[a>>2];if(x[b>>2]){Dc(b);a=x[a>>2];b=x[a>>2];an(a);Eb(b)}}function wI(a,b){b=x[a+32>>2]+b|0;x[a+32>>2]=b;if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1}}function s9(a){a=a|0;v[a+4202|0]=1;x[a+4232>>2]=x[x[a+16>>2]+24620>>2];Os(a);JL(a)}function hO(a,b){var c=0;c=b&15;if(c){v[a+830|0]=c}b=b&240;if(b){v[a+829|0]=b>>>4}}function gp(a,b,c,d){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+(c<<d);return a}function b8(a){a=a|0;v[a+4202|0]=1;x[a+4256>>2]=x[x[a+16>>2]+24620>>2];eL(a);dL(a)}function Er(a,b,c,d){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+D(c,d);return a}function ro(a,b){a=rc(a,b,34);w[a+34>>1]=z[b+34>>1];rc(a+36|0,b+36|0,68);return a}function kj(a){var b=0;b=db-16|0;db=b;a=x[vb(b+12|0,yb(a))>>2];db=b+16|0;return a}function cD(a,b,c){while(1){if(b){x[a>>2]=x[c>>2];b=b-1|0;a=a+4|0;continue}break}}function _t(a,b,c){while(1){if(b){w[a>>1]=z[c>>1];b=b-1|0;a=a+2|0;continue}break}}function ZL(a,b,c){while(1){if(b){B[a>>2]=B[c>>2];b=b-1|0;a=a+4|0;continue}break}}function Kf(a){var b=0;b=db-16|0;db=b;a=x[vb(b+12|0,gc(a))>>2];db=b+16|0;return a}function FQ(a){if((y[a+14|0]-53&255)>>>0>=252){a=cd(a,15183,14)}else{a=1}return!a}function Bf(a){var b=0;b=db-16|0;db=b;a=x[vb(b+12|0,Kf(a))>>2];db=b+16|0;return a}function Ar(a,b,c,d){if(b>>>0>=d>>>0){wi();p()}c=Hc(D(b,c));x[a+4>>2]=b;x[a>>2]=c}function wl(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;hc(a+8|0,b+8|0)}function HK(a,b){var c=0;c=db-16|0;db=c;x[c+12>>2]=b;iI(93232,a,b,0,0);db=c+16|0}function EY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ib[a|0](b,c,d)|0;eb=hb;return a|0}function xha(a,b,c){a=a|0;b=b|0;c=c|0;ad(a,iT(c,Mb(b),Bb(x[b+4>>2],y[b+11|0])))}function rh(a,b,c){a=vb(a,b);b=x[c+4>>2];x[a+4>>2]=x[c>>2];x[a+8>>2]=b;return a}function ig(a){var b=0,c=0;xc(a+4|0);Xj(a+8|0,0);b=a,c=gc(a),x[b>>2]=c;return a}function c$(){var a=0,b=0,c=0;a=Pd(469040);x[a>>2]=83144;b=a,c=yd(),x[b+8>>2]=c}function aN(a,b){var c=0,d=0;c=db-16|0;db=c;d=c+4|0;pA(d,1,b);Bc(a,d);db=c+16|0}function Yh(a){return(wj(x[a>>2],x[a+4>>2])|0)!=(0-wj(x[a+12>>2],x[a+16>>2])|0)}function YU(a,b,c){while(1){if(b){v[a|0]=y[c|0];b=b-1|0;a=a+1|0;continue}break}}function Tv(a,b,c,d){if(b>>>0>=d>>>0){wi();p()}c=Hc(b<<c);x[a+4>>2]=b;x[a>>2]=c}function Sv(a,b){b=a+b|0;while(1){b=tb(b-12|0);if((b|0)!=(a|0)){continue}break}}function Od(a,b,c){var d=0;d=db-16|0;db=d;x[d+12>>2]=c;vc(a,b,d+12|0);db=d+16|0}function Hea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;Vv(a,b,c,d,e,284,538,538)}function HZ(a,b,c){a=a|0;b=b|0;c=c|0;return(x[(c<<2)+82112>>2]&b)!=0&c>>>0<=127}function Ec(a){var b=0;if(ue(y[a+11|0])){b=x[a>>2];mk(x[a+8>>2]);Eb(b)}return a}function EE(){var a=0;a=db-16|0;x[a+8>>2]=0;x[a+12>>2]=1048576;return C[a+8>>3]}function DY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[a|0](b,c,d,e,f)}function An(a,b,c){var d=0;d=db-16|0;db=d;x[d+12>>2]=c;wm(a,b,d+12|0);db=d+16|0}function yfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;Vv(a,b,c,d,e,100,99,125)}function x_(a){a=a|0;if(!y[467920]){kn(467908,83380);v[467920]=1}return 467908}function v_(a){a=a|0;if(!y[467952]){kn(467940,83464);v[467952]=1}return 467940}function t_(a){a=a|0;if(!y[467856]){kn(467844,83308);v[467856]=1}return 467844}function r_(a){a=a|0;if(!y[467888]){kn(467876,83344);v[467888]=1}return 467876}function qo(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0}function my(a,b){a=a|0;b=b|0;if(x[a+4>>2]!=x[wb(a)>>2]){bN(a,b);return}aA(a,b)}function mv(a,b){var c=0;if((b|0)<0){wi();p()}c=Hc(b<<1);x[a+4>>2]=b;x[a>>2]=c}function j_(a){a=a|0;if(!y[467904]){Tb(467892,13330);v[467904]=1}return 467892}function i2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return UI(a-88|0,b,c,d,e)|0}function c_(a){a=a|0;if(!y[467872]){Tb(467860,13484);v[467872]=1}return 467860}function ZU(a,b){a=a|0;b=b|0;if(x[a+4>>2]!=x[wb(a)>>2]){OG(a,b);return}MG(a,b)}function Ru(a,b){return Le(Dj((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function OC(a){var b=0;b=db-16|0;db=b;v[b+15|0]=0;am(a,cp(a),b+15|0);db=b+16|0}function AY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ib[a|0](b,c,d,e)|0}function yb(a){var b=0;b=db-16|0;db=b;a=x[vb(b+12|0,a)>>2];db=b+16|0;return a}function mZ(a,b){a=a|0;b=b|0;a=Yl(a);x[a>>2]=92348;nw(a+4|0,Mb(b));return a|0}function h_(a){a=a|0;if(!y[467936]){Tb(467924,9151);v[467936]=1}return 467924}function gZ(a,b,c){a=a|0;b=b|0;c=c|0;if(!y[469488]){v[469488]=1}ec(a,c,93676)}function f_(a){a=a|0;if(!y[467840]){Tb(467828,5206);v[467840]=1}return 467828}function dN(a,b){a=a|0;b=b|0;if(A[a+4>>2]<A[wb(a)>>2]){bN(a,b);return}aA(a,b)}function Zia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;Vv(a,b,c,d,e,100,99,99)}function Zi(a){if(Ob(a+1074312|0,7)){a=ym(x[a+480180>>2])^1}else{a=0}return a}function Ze(a){if(ue(y[a+11|0])){hd(x[a>>2],0);re(a,0);return}hd(a,0);ff(a,0)}function YY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Kg(a,x[b+8>>2],0)){gw(b,c,d)}}function Xx(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function Vx(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function Ti(a,b,c){if(x[a+80>>2]){x[a+92>>2]=x[a+92>>2]+(c+7&-8);return}Eb(b)}function SO(a){x[a>>2]=0;x[a+4>>2]=0;x[a>>2]=-2078137563;x[a+4>>2]=-873292572}function Hs(a,b){var c=0;c=a;a=(b>>>0)/1e6|0;return Ex(Xk(c,a),D(a,-1e6)+b|0)}function Gx(a,b){var c=0;c=a;a=(b>>>0)/100|0;return Xk(Xk(c,a),D(a,-100)+b|0)}function Ex(a,b){var c=0;c=a;a=(b>>>0)/1e4|0;return Gx(Xk(c,a),D(a,-1e4)+b|0)}function Em(a,b){var c=0,d=0;c=db-16|0;db=c;d=c+8|0;jC(d,a);Al(d,b);db=c+16|0}function DQ(a,b){a=WR(a,b);v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2];return a}function Ce(a,b){var c=0,d=0;c=db-16|0;db=c;d=c+8|0;hv(d,a);Al(d,b);db=c+16|0}function $y(a){var b=0;if(!(y[a+2|0]|(y[a|0]|y[a+1|0]))){b=!y[a+3|0]}return b}function $j(a){var b=0;b=db-16|0;db=b;a=x[of(b+12|0,a)>>2];db=b+16|0;return a}function d8(a,b){a=a|0;b=b|0;return E(b>>>0<=4?B[((b<<2)+a|0)+4220>>2]:E(0))}function Wd(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[b+8>>2];Zb(b,c);Fv(a,b,d,c)}function UG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[x[x[a>>2]+32>>2]](a,b,c,d)|0}function QN(a,b,c){var d=0;return!b|!(y[a+35|0]&4?!a|(c|0)!=1:1)?d:y[b+34|0]}function QG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[x[x[a>>2]+48>>2]](a,b,c,d)|0}function M4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return fn(a,b,c,d,12724,1009)|0}function H4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return fn(a,b,c,d,12798,1011)|0}function Ee(a){var b=0;b=db-16|0;db=b;Kq(b+8|0,a);db=b+16|0;return x[b+8>>2]}function vP(a,b){b=1/(1/(b*6.283185307179586/3546895)+1);nP(a,b,0,0,b+-1,0)}function uL(a){a=a|0;x[a>>2]=46468;sc(a+4276|0);sc(a+4264|0);return yf(a)|0}function ng(a,b){var c=0;c=a;a=x[a+8>>2];b=a-b|0;x[c+8>>2]=a>>>0>=b>>>0?b:0}function k0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return fF(b,c,d,e,1)|0}function jT(a){var b=0;while(1){b=a;a=x[a>>2];if(a){continue}break}return b}function h0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return fF(b,c,d,e,0)|0}function e1(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)!=1){GH(a,c);return}Tb(a,7818)}function a0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return dF(b,c,d,e,1)|0}function Zr(a,b,c,d,e,f,g,h){return ib[x[x[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function Z$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return dF(b,c,d,e,0)|0}function Vz(a,b){return(+(a>>>0)+ +(b|0)*4294967296)*2.3283064365386963e-10}function S4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return fn(a,b,c,d,9318,1006)|0}function MI(a,b){a=a^-1;return x[(b&12)+63764>>2]>>>(a>>>3&1)>>>(a>>>4&1)|0}function K4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return fn(a,b,c,d,9464,1010)|0}function JH(a,b,c,d,e,f,g,h){return ib[x[x[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function Gk(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+c;return a}function F4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return fn(a,b,c,d,9542,1012)|0}function DZ(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[(b<<2)+80560>>2]}return b|0}function D4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return fn(a,b,c,d,9349,1013)|0}function BZ(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[(b<<2)+79024>>2]}return b|0}function jZ(a,b,c){a=a|0;b=b|0;c=c|0;return qc(a,x[b+4>>2])&x[b>>2]==(c|0)}function gh(a,b,c){x[a+8>>2]=b;x[a+12>>2]=c;x[a>>2]=0;x[a+4>>2]=0;return a}function Vj(a){var b=0;b=z[a+172>>1];a=z[a+156>>1];return(AQ(a)?b:a)&65535}function wia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=No(a,b),x[d>>2]=e}function via(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=cv(a,b),w[d>>1]=e}function sc(a){var b=0;b=db-16|0;db=b;nR(vb(b+12|0,a));db=b+16|0;return a}function bc(a){var b=0;b=db-16|0;db=b;KD(vb(b+12|0,a));db=b+16|0;return a}function bD(a,b){while(1){if(b){x[a>>2]=0;b=b-1|0;a=a+4|0;continue}break}}function Zc(a,b){a=_D(a,b);x[a+8>>2]=x[b+8>>2];_D(a+12|0,b+12|0);return a}function Xc(a,b,c,d,e){v[a+3|0]=e;v[a+2|0]=d;v[a+1|0]=c;v[a|0]=b;return a}function W8(a,b){a=a|0;b=b|0;a=x[a+20>>2];v[a+24|0]=y[a+24|0]&253|(b?2:0)}function TD(a,b){a=a|0;b=b|0;a=Yl(a);x[a>>2]=92348;nw(a+4|0,b);return a|0}function SD(a,b){a=rg(a,b);x[a+8>>2]=x[b+8>>2];rg(a+12|0,b+12|0);return a}function Mb(a){var b=0,c=0,d=0;return b=x[a>>2],c=a,d=ue(y[a+11|0]),d?b:c}function Lb(a,b,c){a=a|0;b=b|0;c=c|0;return ib[x[x[a>>2]+32>>2]](a,b,c)|0}function KS(a,b){v[a+6|0]=255;x[a+16>>2]=b;w[a+4>>1]=0;x[a>>2]=0;return a}function Jk(a,b,c){a=a|0;b=b|0;c=c|0;return ib[x[x[a>>2]+12>>2]](a,b,c)|0}function Ho(a,b,c){a=a|0;b=b|0;c=c|0;return ib[x[x[a>>2]+48>>2]](a,b,c)|0}function uQ(a,b){v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function Iw(a,b){var c=0;c=Bs(a+4|0);x[a>>2]=77592;x[c>>2]=77612;On(c,b)}function Hw(a,b){var c=0;c=yH(a+4|0);x[a>>2]=77960;x[c>>2]=77980;On(c,b)}function $H(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;gh(a,-1,-1)}function uV(a,b,c){a=a&255;return a>>>0>=(b&255)>>>0&a>>>0<=(c&255)>>>0}function qL(a){a=a|0;return E(E(E(B[xb(a+4208|0,5)>>2]*E(198))+E(-99)))}function mc(a,b){var c=0,d=0;x[a>>2]=b;c=a,d=Pf(b),x[c+4>>2]=d;return a}function kp(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;x[e>>2]=c;return 3}function bJ(a){a=a|0;return+(+A[x[a+32>>2]+480240>>2]*152587890625e-16)}function Mc(a){if(ue(y[a+11|0])){a=mk(x[a+8>>2])-1|0}else{a=10}return a}function KP(a,b){x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=b?b:49716;x[a+12>>2]=0}function DP(a){if(a>>>0<=8){return y[a+29248|0]}return y[a+29239|0]|256}function CB(a,b,c){var d=0;d=(b|0)/(c|0)|0;x[a>>2]=d;x[a+4>>2]=b-D(c,d)}function $w(a){return((jh(a)+(jh(a)<<8)|0)+(jh(a)<<16)|0)+(jh(a)<<24)|0}function sha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return cw(a,b,c,d,531)|0}function ly(a,b){if(b){ly(a,x[b>>2]);ly(a,x[b+4>>2]);Ab(b+16|0);Eb(b)}}function ln(a){if(ue(y[a+11|0])){a=mk(x[a+8>>2])-1|0}else{a=1}return a}function kW(a){a=a|0;x[a+16>>2]=x[a+16>>2]|1;if(v[a+20|0]&1){ra();p()}}function hw(a,b,c){if(!(x[a+28>>2]==1|x[a+4>>2]!=(b|0))){x[a+28>>2]=c}}function gz(a,b){if(b){gz(a,x[b>>2]);gz(a,x[b+4>>2]);lm(b+16|0);Eb(b)}}function dr(a){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function _A(a,b){if(b){_A(a,x[b>>2]);_A(a,x[b+4>>2]);lj(b+16|0);Eb(b)}}function ZA(a,b){if(b){ZA(a,x[b>>2]);ZA(a,x[b+4>>2]);lj(b+16|0);Eb(b)}}function Sp(a,b){if(b){Sp(a,x[b>>2]);Sp(a,x[b+4>>2]);_O(b+16|0);Eb(b)}}function Ry(a,b){x[a>>2]=x[b>>2];w[a+4>>1]=z[b+4>>1];v[a+6|0]=y[b+6|0]}function Dz(a,b){a=Nb(a);Gb(a+12|0);w[a+28>>1]=0;x[a+24>>2]=b;return a}function Dk(a,b){a=a|0;b=b|0;v[a|0]=2;v[a+1|0]=3;v[a+2|0]=0;v[a+3|0]=4}function qw(a){a=a|0;if(x[a+8>>2]!=(yd()|0)){jH(x[a+8>>2])}return a|0}function mr(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return cw(a,b,c,d,155)|0}function iN(a,b,c,d,e){x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b}function gka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;FE(a,b,c,d,287,286,285)}function gK(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Jn(c+120|0);Eb(c)}}function cV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return cw(a,b,c,d,323)|0}function RY(a){a=a|0;if(!a){return 0}return(Py(a,91904,92048)|0)!=0|0}function OQ(a,b,c,d,e){a=vb(a,b);vb(a+4|0,c);vb(a+8|0,d);vb(a+12|0,e)}function KD(a){var b=0;b=x[a>>2];if(x[b>>2]){Dc(b);Eb(x[x[a>>2]>>2])}}function FY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ib[a|0](b,c,d,e)}function wi(){var a=0;a=_l(ac(4));x[a>>2]=92232;da(a|0,92308,25);p()}function vT(a,b){x[a>>2]=x[b>>2];w[a+4>>1]=z[b+4>>1];hc(a+8|0,b+8|0)}function tY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;FE(a,b,c,d,103,102,101)}function j$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;qg(a,f)}function E0(a){a=a|0;var b=0;b=x[116924]+1|0;x[116924]=b;x[a+4>>2]=b}function BY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ib[a|0](b,c,d)|0}function BQ(a,b){a=dA(a,b);v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2]}function xN(a,b){x[a+852>>2]=x[a+852>>2]+b;v[a+851|0]=y[a+851|0]|64}function kl(a,b,c){var d=0;d=db-16|0;db=d;pU(d+8|0,a,b,c);db=d+16|0}function ZB(a,b){return zE(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?b:a}function Vq(a,b){return fv(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?b:a}function Rl(a,b){return b?a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24):a}function L4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return lF(a,b,c,d,4)|0}function J4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return lF(a,b,c,d,2)|0}function G4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return kF(a,b,c,d,4)|0}function Fc(a,b,c){if(oc(a,b)>>>0<=c>>>0){$u();p()}return(c<<2)+a|0}function FT(a){v[a+4|0]=0;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0}function E4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return kF(a,b,c,d,2)|0}function yi(a,b){a=a|0;b=b|0;var c=0;c=Hc(b);x[a+4>>2]=b;x[a>>2]=c}function yZ(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function jG(a,b,c){a:{if((a|0)==(b|0)){v[b+120|0]=0;break a}Eb(b)}}function hj(a,b){a=a|0;b=b|0;var c=0;c=UP(b);x[a+4>>2]=b;x[a>>2]=c}function eQ(a,b){var c=0,d=0;c=vb(a,x[b>>2]),d=y[b+4|0],v[c+4|0]=d}function bd(a){a=(a|0)>=32767?32767:a;return(a|0)<=-32768?-32768:a}function t7(a,b,c){a=a|0;b=b|0;c=c|0;return Hi(a,b,c,906,86224)|0}function qn(a,b){if(A[a+4>>2]<A[wb(a)>>2]){OG(a,b);return}MG(a,b)}function pha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;GE(a,b,c,d,284,538)}function oj(a,b){if(hg(x[a>>2],x[a+4>>2])>>>0>b>>>0){v[a+16|0]=b}}function oI(a,b){a=mI(a-1|0);if(!a){a=mI(b);a=a?a+32|0:0}return a}function dT(a,b,c,d){a=le(a,b);w[a+22>>1]=d;w[a+20>>1]=c;return a}function I4(a,b){a=a|0;b=b|0;if(!x[23549]){x[23549]=a;x[23550]=b}}function Gl(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+32>>2]](a,0,b)|0}function GX(a){a=a|0;a=x[a+4>>2];return ib[x[x[a>>2]+12>>2]](a)|0}function Fm(a,b){x[a>>2]=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];return a}function FX(a){a=a|0;a=x[a+4>>2];return ib[x[x[a>>2]+16>>2]](a)|0}function Av(a,b,c){a=rg(a,b);x[a+8>>2]=0;rg(a+12|0,c);fe(c);fe(b)}function $I(a){a=a|0;return+(+x[x[a+32>>2]+1074456>>2]*.00390625)}function zha(a,b){a=a|0;b=b|0;a=ju(a,b);x[a>>2]=92556;return a|0}function zE(a,b,c,d){return a>>>0<c>>>0&(b|0)<=(d|0)|(b|0)<(d|0)}function w8(a,b,c){a=a|0;b=b|0;c=c|0;return Hi(a,b,c,898,4280)|0}function ux(a){var b=0;b=db-16|0;db=b;pK(vb(b+12|0,a));db=b+16|0}function ql(a){var b=0;b=db-16|0;db=b;bU(vb(b+12|0,a));db=b+16|0}function p9(a,b,c){a=a|0;b=b|0;c=c|0;return Hi(a,b,c,885,4304)|0}function oe(a){var b=0;b=db-16|0;db=b;$D(vb(b+12|0,a));db=b+16|0}function oG(a){var b=0;b=db-16|0;db=b;kG(vb(b+12|0,a));db=b+16|0}function o8(a,b,c){a=a|0;b=b|0;c=c|0;return Hi(a,b,c,899,4276)|0}function nx(a,b,c){return Kh(x[a>>2],x[a+4>>2],b,x[a+12>>2]+c|0)}function kd(a){var b=0;b=db-16|0;db=b;yC(vb(b+12|0,a));db=b+16|0}function id(a){var b=0;b=db-16|0;db=b;lD(vb(b+12|0,a));db=b+16|0}function h8(a,b,c){a=a|0;b=b|0;c=c|0;return Hi(a,b,c,900,4268)|0}function gd(a,b){return((a^-2147483648)>>>b)-(-2147483648>>>b)|0}function fja(a,b){a=a|0;b=b|0;a=ju(a,b);x[a>>2]=92504;return a|0}function ek(a){var b=0;b=db-16|0;db=b;vV(vb(b+12|0,a));db=b+16|0}function dq(a,b,c){a=Hb(a&65535);return(a|0)>=(b|0)&(a|0)<=(c|0)}function _Q(a){var b=0;b=db-16|0;db=b;RQ(vb(b+12|0,a));db=b+16|0}function Yd(a){var b=0;b=db-16|0;db=b;sE(vb(b+12|0,a));db=b+16|0}function YD(a,b,c){a=Zm(a);x[a+8>>2]=c;x[a+4>>2]=b;x[a>>2]=61420}function XK(a){return E(E(B[xb(a+4208|0,11)>>2]*E(19980))+E(20))}function U7(a,b,c){a=a|0;b=b|0;c=c|0;return Hi(a,b,c,902,4228)|0}function Q8(a,b,c){a=a|0;b=b|0;c=c|0;return Hi(a,b,c,895,4236)|0}function L7(a,b,c){a=a|0;b=b|0;c=c|0;return Hi(a,b,c,903,5048)|0}function Kt(a){var b=0;b=db-16|0;db=b;gR(vb(b+12|0,a));db=b+16|0}function I9(a,b,c){a=a|0;b=b|0;c=c|0;return Hi(a,b,c,877,4268)|0}function Hn(a,b,c){return WS(x[a>>2],x[a+4>>2],b,x[a+12>>2]+c|0)}function HX(a){a=a|0;a=x[a+4>>2];return ib[x[x[a>>2]+8>>2]](a)|0}function Fy(a){tb(a+48|0);tb(a+36|0);tb(a+24|0);tb(a+12|0);tb(a)}function B7(a,b,c){a=a|0;b=b|0;c=c|0;return Hi(a,b,c,905,4276)|0}function $S(a){var b=0;b=db-16|0;db=b;US(vb(b+12|0,a));db=b+16|0}function yl(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+28>>2]](a,b)|0}function xe(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Is(b)}return a}function vY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;GE(a,b,c,d,100,99)}function rd(a,b,c,d){x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;return a}function i7(a,b){a=a|0;b=b|0;if(!b){return 3}x[b>>2]=a;return 0}function fv(a,b,c,d){return(b|0)==(d|0)&a>>>0<c>>>0|b>>>0<d>>>0}function dO(a,b){a=a|0;b=b|0;a=ju(a,b);x[a>>2]=92368;return a|0}function Yr(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+44>>2]](a,b)|0}function YK(a){return E(E(B[xb(a+4208|0,0)>>2]*E(1e4))+E(-1e4))}function Nv(a){var b=0;b=db-16|0;B[b+12>>2]=a;return B[b+12>>2]}function Lba(a,b){a=a|0;b=b|0;a=CT(a,b);if(!a){BT(b)}return a|0}function JZ(a){a=a|0;a=x[a+8>>2];if(!a){return 1}return TF(a)|0}function Gr(a){var b=0;b=db-16|0;C[b+8>>3]=a;return C[b+8>>3]*a}function Aw(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+12>>2]](a,b)|0}function zh(a,b){return ib[x[x[a>>2]+32>>2]](a,x[a+12>>2],b)|0}function zY(a,b){a=a|0;b=b|0;ib[x[x[b>>2]+16>>2]](a,b,0,0,1,8)}function vv(a,b){a=ad(a,b);hc(a+12|0,b+12|0);Vf(a+32|0,b+32|0)}function sv(a,b){a=a|0;b=b|0;a=vD(a,b);if(!a){cr(b)}return a|0}function pr(a,b){a=a|0;b=b|0;a=CD(a,b);if(!a){Jv(b)}return a|0}function oL(a){a=a|0;return Uj(E(B[xb(a+4208|0,4)>>2]*E(4)))|0}function fB(a,b){a=a|0;b=b|0;a=OT(a,b);if(!a){VA(b)}return a|0}function cC(a,b){a=a|0;b=b|0;a=Hu(a,b);if(!a){Mu(b)}return a|0}function bp(a,b){a=a|0;b=b|0;a=MD(a,b);if(!a){yv(b)}return a|0}function _q(a,b){var c=0;c=b+1|0;x[a>>2]=x[a>>2]>(c|0)?c:b+2|0}function WM(a,b){return b>>>0>=4e3?21204:((b<<5)+a|0)+946304|0}function W3(a,b,c){a=a|0;b=b|0;c=c|0;XO(a,0,x[b+1298404>>2],c)}function Vt(a,b){a=a|0;b=b|0;a=fV(a,b);if(!a){su(b)}return a|0}function UV(a,b){if(!b){return-1}b=hq(a,b,0);return b?b-a|0:-1}function RM(a,b,c,d){w[a+4>>1]=c;v[a+6|0]=b;x[a>>2]=d;return a}function LA(a,b){a=a|0;b=b|0;a=Wo(a,b);if(!a){Dm(b)}return a|0}function IR(a){return y[a+15|0]<<12|y[a+14|0]<<4|y[a+13|0]<<20}function Hk(a){return yb(Mb(a)+(Bb(x[a+4>>2],y[a+11|0])<<2)|0)}function HO(a,b){a=a|0;b=b|0;a=wV(a,b);if(!a){uu(b)}return a|0}function DE(a){w[a+12>>1]=0;x[a+8>>2]=-1;x[a>>2]=0;x[a+4>>2]=0}function C$(a,b){a=a|0;b=b|0;RN(a,Qw(x[b>>2])<<24>>24,x[b>>2])}function Bo(a,b){a=a|0;b=b|0;a=eV(a,b);if(!a){hV(b)}return a|0}function $h(a,b){a=a|0;b=b|0;a=_h(a,b);if(!a){El(b)}return a|0}function uJ(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function pja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;PE(a,b,c,d,347)}function ol(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){gc(a);Eb(b)}}function nN(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Eb(ij(c))}}function ih(a,b,c){return(x[((c&255)<<2)+a>>2]&b)!=0&(c|0)>=0}function bka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;TE(a,b,c,d,125)}function bE(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Eb(bc(c))}}function a8(a,b,c){a=a|0;b=b|0;c=c|0;return dw(a,b,c,0,901)|0}function V7(a,b,c){a=a|0;b=b|0;c=c|0;return dw(a,b,c,1,901)|0}function UP(a){if(a>>>0>=1073741824){wi();p()}return Hc(a<<2)}function MF(a,b){var c=0;c=a;a=x[a>>2]+b|0;x[c>>2]=a;return a}function Iia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;PE(a,b,c,d,416)}function G8(a,b,c){a=a|0;b=b|0;c=c|0;return dw(a,b,c,0,897)|0}function Fl(a,b,c){x[a+4>>2]=c;x[a>>2]=b;if(c){Xm(c)}return a}function $b(a){return a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)}function yX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dc(a,x[d>>2],0)}function x8(a){a=a|0;return E(E(B[xb(a+4208|0,6)>>2]*E(20)))}function vN(a){x[a>>2]=0;Nb(a+4|0);Vb(a+16|0,0,144);return a}function pL(a){a=a|0;return E(E(B[xb(a+4208|0,2)>>2]*E(10)))}function mI(a){var b=0,c=0,d=0;return b=xka(a),c=0,d=a,d?b:c}function fba(a){a=a|0;a=ju(a,21204);x[a>>2]=92448;return a|0}function dJ(a){a=a|0;return+(65536/+A[x[a+32>>2]+480244>>2])}function _3(a,b){a=a|0;b=b|0;x[a>>2]=x[b>>2];qg(a+4|0,b+4|0)}function Pb(a,b){var c=0;c=x[a>>2];x[a>>2]=x[b>>2];x[b>>2]=c}function Ox(a){a=a|0;x[a+32>>2]=0;x[a+28>>2]=x[a+28>>2]&-7|2}function Kia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;TE(a,b,c,d,99)}function Ii(a){var b=0;o(+a);b=j(1)|0;j(0)|0;return b>>>20|0}function Gg(a,b,c,d){hb=b-((a>>>0<c>>>0)+d|0)|0;return a-c|0}function GM(a,b){var c=0;c=z[a>>1];w[a>>1]=z[b>>1];w[b>>1]=c}function As(a){a=a|0;x[a>>2]=76264;tb(a+32|0);return Pn(a)|0}function zq(a){return x[a+20>>2]+(x[a+8>>2]-x[a+24>>2]|0)|0}function wu(a,b,c){a=a|0;b=b|0;c=c|0;return XE(a,b,c,307)|0}function uZ(a,b,c){a=a|0;b=b|0;c=c|0;return aF(b,c,80560)|0}function tx(a,b,c,d,e,f){return iF(a,b,c,d,e,f,57012,57808)}function sZ(a,b,c){a=a|0;b=b|0;c=c|0;return aF(b,c,79024)|0}function rx(a,b,c,d,e,f){return iF(a,b,c,d,e,f,57888,58652)}function rD(a,b){return Yt(a,Mb(b),Bb(x[b+4>>2],y[b+11|0]))}function ju(a,b){a=Yl(a);x[a>>2]=92328;nw(a+4|0,b);return a}function hq(a,b,c){if(!b){return 0}return au(a,c<<24>>24,b)}function gX(a){a=a|0;a=UD(a,13176);x[a>>2]=26156;return a|0}function ei(a,b){var c=0,d=0;c=a,d=iH(b),x[c>>2]=d;return a}function dt(a,b){if(b){dt(a,x[b>>2]);dt(a,x[b+4>>2]);Eb(b)}}function ct(a,b){if(b){ct(a,x[b>>2]);ct(a,x[b+4>>2]);Eb(b)}}function bT(a){var b=0;b=x[a+100>>2];x[a+100>>2]=0;return b}function b9(a){a=a|0;a=Mj(a);if(a){ib[x[x[a>>2]+96>>2]](a)}}function XN(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Eb(Sy(b))}}function XB(a,b,c){a=a|0;b=b|0;c=c|0;return XE(a,b,c,248)|0}function WJ(a,b){a=a|0;b=b|0;return ri(x[b>>2],x[b+4>>2])|0}function W7(a){a=a|0;return E(E(B[xb(a+4208|0,6)>>2]*E(4)))}function VJ(a,b){a=a|0;b=b|0;return ne(x[b>>2],x[b+4>>2])|0}function Sz(a,b){if(b){Sz(a,x[b>>2]);Sz(a,x[b+4>>2]);Eb(b)}}function Rz(a,b){if(b){Rz(a,x[b>>2]);Rz(a,x[b+4>>2]);Eb(b)}}function Qn(a,b){return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function Qk(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Eb(Yf(b))}}function L5(a,b){a=a|0;b=b|0;return E(qF(a,b,6170,1075834))}function J5(a,b){a=a|0;b=b|0;return E(pF(a,b,6213,1075834))}function IA(a,b){if(b){IA(a,x[b>>2]);IA(a,x[b+4>>2]);Eb(b)}}function I5(a,b){a=a|0;b=b|0;return E(pF(a,b,6115,1075835))}function HA(a,b){if(b){HA(a,x[b>>2]);HA(a,x[b+4>>2]);Eb(b)}}function H5(a,b){a=a|0;b=b|0;return E(qF(a,b,6071,1075835))}function GY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[a|0](b,c,d)}function CZ(a,b,c){a=a|0;b=b|0;c=c|0;return bF(b,c,80560)|0}function Bv(a){var b=0;b=a;a=x[a>>2]-1|0;x[b>>2]=a;return a}function AZ(a,b,c){a=a|0;b=b|0;c=c|0;return bF(b,c,79024)|0}function $fa(a,b,c){a=a|0;b=b|0;c=c|0;return VE(a,b,c,36)|0}function xn(a,b,c,d){x[a+16>>2]=d;x[a+12>>2]=c;x[a+8>>2]=b}function xm(a){var b=0;b=x[a>>2];x[b>>2]=x[b>>2]|x[a+4>>2]}function rY(a){a=a|0;a=dO(a,7854);x[a>>2]=42056;return a|0}function qZ(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)<0?c:b)|0}function iy(a,b,c){C[a>>3]=C[a>>3]+b;C[a+8>>3]=C[a+8>>3]+c}function eK(a){return(Mb(a)+Bb(x[a+4>>2],y[a+11|0])|0)-1|0}function b1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;hb=0;return 0}function Xq(a,b,c){a=a|0;b=b|0;c=c|0;vg(a,b,oi(b,b+c|0,0))}function V3(a){a=a|0;tK(a,2,100);oj(x[a+24>>2]+484360|0,0)}function TX(a){a=a|0;a=UD(a,8602);x[a>>2]=30564;return a|0}function tia(a,b,c){a=a|0;b=b|0;c=c|0;vg(a,b,Pc(b,c)+b|0)}function tf(a){return yb(Mb(a)+Bb(x[a+4>>2],y[a+11|0])|0)}function oo(a){x[a>>2]=0;x[a+4>>2]=0;Xj(a+8|0,0);return a}function oA(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Eb(c)}}function fx(a,b){return x[((a>>>24^b)<<2)+463088>>2]^a<<8}function fK(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Is(c)}}function dD(a,b){var c=0;c=Hc(b<<2);x[a+4>>2]=b;x[a>>2]=c}function Zo(a){a=XD(a);x[a+8>>2]=0;x[a>>2]=88708;return a}function Wg(a,b){if(ue(y[a+11|0])){re(a,b);return}ff(a,b)}function SV(a,b){v[a|0]=y[b|0];v[a+1|0]=y[b+1|0];return a}function O3(a,b,c){a=a|0;b=b|0;c=c|0;ar(a,b,c);return a|0}function Mw(a,b,c){x[a+28>>2]=c;x[a+20>>2]=b;x[a+24>>2]=b}function EF(a,b,c){b=Ia(936,a|0,b|0,c|0)|0;hb=eb;return b}function Dp(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function Cc(a,b){return YE(a,b,2147483647,-2147483648,-1)}function BI(a){while(1){if((js(a)|0)!=-1){continue}break}}function $c(a,b,c,d){return Ad(a,D(z[b+480188>>1],c)+d|0)}function xK(a,b){Xm(x[b>>2]);$m(x[a>>2]);x[a>>2]=x[b>>2]}function sh(a,b){var c=0;c=y[a|0];v[a|0]=y[b|0];v[b|0]=c}function rJ(a){a=a|0;x[a>>2]=60764;bc(a+12|0);return a|0}function qz(a,b){C[a>>3]=C[a>>3]*b;C[a+8>>3]=C[a+8>>3]*b}function cu(a){sc(a+88|0);sc(a+68|0);sc(a+48|0);return a}function c4(a,b,c){a=a|0;b=b|0;c=c|0;ad(a,iT(c,b,Pf(b)))}function bG(a){a=a|0;x[a>>2]=83232;tb(a+16|0);return a|0}function aG(a){a=a|0;x[a>>2]=83192;tb(a+12|0);return a|0}function _H(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;gh(a,-1,-1)}function Z1(a,b,c){a=a|0;b=b|0;c=c|0;return Nd(D(b,c))|0}function Y4(a,b){a=a|0;b=b|0;return gn(a,b,11769,1001)|0}function Ui(a){return Ne(a)|Ne(a)<<8|Ne(a)<<16|Ne(a)<<24}function UX(a,b,c){a=a|0;b=b|0;c=c|0;Fv(a,b,x[b+8>>2],c)}function UN(a,b){a=TN(a,b);TN(a+12|0,b+12|0);v[a+24|0]=1}function Dt(a,b){Pb(a,b);Pb(a+4|0,b+4|0);Pb(wb(a),wb(b))}function Dm(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0}function z8(a){a=a|0;return B[xb(a+4208|0,3)>>2]<E(1)|0}function yba(a,b,c){a=a|0;b=b|0;c=c|0;zF(a,b,c,777,778)}function xJ(a){a=a|0;x[a>>2]=61228;bc(a+4|0);return a|0}function x5(a,b){a=a|0;b=b|0;return gn(a,b,11640,987)|0}function wm(a,b,c){x[a>>2]=b;x[a+4>>2]=x[c>>2];return a}function v5(a,b){a=a|0;b=b|0;return vF(a,b,13148,988)|0}function uM(a){return(a|0)==1179012417|(a|0)==538987841}function rs(a){a=a|0;x[a>>2]=49508;ux(a+4|0);return a|0}function k5(a,b){a=a|0;b=b|0;return gn(a,b,11675,995)|0}function jB(a){a=a&255;return Tc(a)^1|(a-49&255)>>>0<36}function hG(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){$m(b)}}function h5(a,b){a=a|0;b=b|0;return gn(a,b,11705,997)|0}function bH(a,b,c){a=vb(a,b);vb(a+4|0,x[c>>2]);return a}function Y7(a){a=a|0;return B[xb(a+4208|0,1)>>2]<E(1)|0}function Xf(a,b,c,d,e){return Ka(a|0,b|0,c|0,d|0,e|0)|0}function Vd(a,b,c){return a>>>0<b>>>0?b:a>>>0<c>>>0?a:c}function RD(a){a=a|0;x[a>>2]=43328;fe(a+4|0);return a|0}function QO(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Eb(b)}}function Pn(a){a=a|0;x[a>>2]=76136;Xb(a+4|0);return a|0}function P5(a,b){a=a|0;b=b|0;return gn(a,b,11737,980)|0}function O7(a){a=a|0;cL(a);v[a+4202|0]=1;x[a+4224>>2]=0}function Nb(a){x[a>>2]=0;x[a+4>>2]=0;xc(a+8|0);return a}function LI(a,b,c){x[a+4>>2]=0;x[a>>2]=b;x[a+8>>2]=c<<3}function IF(a){a=dh(x[a>>2]);if((Bv(a+8|0)|0)<0){Eb(a)}}function Ev(a){a=a|0;x[a>>2]=92348;IF(a+4|0);return a|0}function Dba(a,b,c){a=a|0;b=b|0;c=c|0;HE(a,b,c,773,772)}function Caa(a,b,c){a=a|0;b=b|0;c=c|0;HE(a,b,c,845,844)}function CU(a){a=a|0;x[a>>2]=92328;IF(a+4|0);return a|0}function CF(a,b,c,d,e){return Ca(a|0,b|0,c|0,d|0,e|0)|0}function $r(a){a=a|0;x[a>>2]=76200;Xb(a+4|0);return a|0}function $o(a){var b=0;b=x[a+8>>2];x[a+8>>2]=0;return b}function $4(a,b){a=a|0;b=b|0;return gn(a,b,11801,1e3)|0}function yM(a,b){return D(b&65535,a&65535)+7>>>3&65535}function v$(a,b){a=a|0;b=b|0;ec(a,LH(x[b>>2]),x[b>>2])}function sp(a){return y[a+2|0]&2?(y[a+1|0]&6)==6?4:1:0}function sia(a,b){a=a|0;b=b|0;return Tb(a,b?b:21204)|0}function oea(a,b){a=a|0;b=b|0;if(!lS(a,b)){Vb(b,0,40)}}function oX(a){a=a|0;WC(Mb(a),Bb(x[a+4>>2],y[a+11|0]))}function jh(a){var b=0;b=js(a);x[a+1396>>2]=0;return b}function j1(a){a=a|0;return xp(x[x[a>>2]-12>>2]+a|0)|0}function ix(a){return(a&6)==6?384:1152>>>((a&14)==2)|0}function h1(a){a=a|0;return mf(x[x[a>>2]-12>>2]+a|0)|0}function XH(a){a=a|0;return bs(x[x[a>>2]-12>>2]+a|0)|0}function Ub(a,b,c){return(a|0)<(b|0)?b:(a|0)<(c|0)?a:c}function SH(a){a=a|0;return as(x[x[a>>2]-12>>2]+a|0)|0}function R6(a,b){a=a|0;b=b|0;return vF(a,b,6373,929)|0}function Mg(a,b){a=a|0;b=b|0;ib[x[x[b>>2]+20>>2]](a,b)}function K0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;vg(a,c,d)}function H0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;fH(a,c,d)}function Gh(a,b){a=a|0;b=b|0;ib[x[x[b>>2]+24>>2]](a,b)}function Fh(a,b){a=a|0;b=b|0;ib[x[x[b>>2]+28>>2]](a,b)}function Bn(a,b){x[a+16>>2]=!x[a+24>>2]|(x[a+16>>2]|b)}function Aba(a,b,c){a=a|0;b=b|0;c=c|0;xF(a,b,c,55,776)}function zv(a,b,c){x[a+4>>2]=c;x[a>>2]=b;if(c){Xm(c)}}function zB(a,b){a=le(a,b);Vb(a+20|0,0,1040);return a}function tb(a){if(ue(y[a+11|0])){Eb(x[a>>2])}return a}function r9(a,b,c){a=a|0;b=b|0;c=c|0;ec(a,b+4260|0,8)}function qM(a,b){return(b>>>0>15?63:v[a+b|0])<<24>>24}function pM(a,b){return(b>>>0>45?63:v[a+b|0])<<24>>24}function oO(a,b,c,d){return Sc(ao(a,b,c,d,0)-32768|0)}function nr(a,b){a=hc(a,b);Vb(a+20|0,0,1040);return a}function nn(a,b){return ib[x[x[a>>2]+36>>2]](a,b,0)|0}function mn(a,b){return ib[x[x[a>>2]+52>>2]](a,b,0)|0}function i3(a,b){a=a|0;b=b|0;GO(x[a>>2],b);return a|0}function gf(a,b,c,d){v[a+8|0]=d;x[a+4>>2]=c;x[a>>2]=b}function aY(a,b,c){a=a|0;b=b|0;c=c|0;zF(a,b,c,87,139)}function Tb(a,b){a=a|0;b=b|0;ar(a,b,Pf(b));return a|0}function Sy(a){Op(a+223860|0);bc(a+223848|0);return a}function Ri(a){a=a|0;return ib[x[x[a>>2]+16>>2]](a)|0}function Qi(a){a=a|0;return ib[x[x[a>>2]+12>>2]](a)|0}function In(a,b,c,d){return x[(c<<2)+a>>2]+(b+d<<1)|0}function Ig(a){a=a|0;return ib[x[x[a>>2]+24>>2]](a)|0}function I8(a,b,c){a=a|0;b=b|0;c=c|0;ec(a,b+4228|0,7)}function Ff(a,b,c,d){b=b+d|0;hb=a+c>>>0<c>>>0?b+1|0:b}function BL(a){sc(a+36|0);sc(a+24|0);Ks(a+12|0);Ks(a)}function $G(a,b,c){a=gH(a,b,c,0,-2147483648);return a}function ze(a,b){ec(a,Mb(b),Bb(x[b+4>>2],y[b+11|0]))}function yq(a,b,c,d,e){ec(a,b+d|0,(e|0)==-1?c-d|0:e)}function yE(a,b,c,d){return(a|0)==(c|0)&(b|0)==(d|0)}function xka(a){if(a){return 31-G(a-1^a)|0}return 32}function x9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function rv(a){a=a|0;return ib[x[x[a>>2]+8>>2]](a)|0}function oD(a,b){return(y[b+34|0]&8)>>>3&(a&2050)==2}function nS(a){var b=0;a=a+8|0;hb=a>>>0<8|b;return a}function _X(a,b,c){a=a|0;b=b|0;c=c|0;xF(a,b,c,4,140)}function Us(a){a=a|0;a=xh(a);x[a+20>>2]=0;return a|0}function OV(a,b,c,d){return Fr(a,b,c,d,28,153391690)}function Mq(a,b,c){if(b){gM(a+36|0,b,oi(b,b+c|0,0))}}function HD(a,b,c,d){return Fr(a,b,c,d,36,119304648)}function Gz(a){a=Nb(a);x[a+12>>2]=0;w[a+16>>1]=65280}function Ega(a,b,c){a=a|0;b=b|0;c=c|0;ME(a,b,c,13,2)}function Am(a){a=(a|0)>=120?120:a;return(a|0)<=1?1:a}function $8(a){a=a|0;v[a+4202|0]=1;Ls(a);Nx(a);CL(a)}function y8(a){a=a|0;return E(B[xb(a+4208|0,1)>>2])}function tr(a,b){a=a|0;b=b|0;return Yt(a,b,Pf(b))|0}function tn(a,b,c){x[a>>2]=b;x[a+4>>2]=c-b;return a}function sP(a,b){x[a+8>>2]=0;x[a+12>>2]=0;C[a>>3]=b}function rga(a,b){a=a|0;b=b|0;return Fj(a,b,1030)|0}function rL(a){a=a|0;return E(B[xb(a+4208|0,0)>>2])}function pV(a,b,c,d){return Fr(a,b,c,d,48,89478486)}function pD(a,b,c){ec(a,(c>>>3&536870908)+b|0,1<<c)}function mD(a){return lI(a,E(15845632502852868e13))}function m2(a,b,c){a=a|0;b=b|0;c=c|0;YI(a-88|0,b,c)}function kea(a,b){a=a|0;b=b|0;ar(a,b,12);return a|0}function k2(a,b,c){a=a|0;b=b|0;c=c|0;WI(a-88|0,b,c)}function jka(a,b,c){a=a|0;b=b|0;c=c|0;AF(a,b,c,284)}function iga(a,b){a=a|0;b=b|0;return OE(a,b,1100)|0}function gj(a){if(!a){return 0}return x[a+44>>2]!=0}function dI(a,b){x[a>>2]=b;x[a+4>>2]=b>>31;return a}function d4(a){a=a|0;a=x[a+4>>2];return(a?a:4952)|0}function Zd(a){var b=0;b=x[a>>2];x[a>>2]=0;return b}function Yo(a){a=a|0;a=kc(a);ib[x[x[a>>2]>>2]](a)|0}function Yga(a,b,c){a=a|0;b=b|0;c=c|0;ME(a,b,c,5,3)}function X7(a){a=a|0;return E(B[xb(a+4208|0,3)>>2])}function Un(a,b,c){if(!c){return 0}return cd(a,b,c)}function TC(a){return lI(a,E(2524354896707238e-44))}function Qo(a,b,c){ec(a,(c>>>3&536870908)+b|0,c&31)}function Qga(a){a=a|0;ij(94228);ij(94220);tb(94208)}function Pz(a){v[a+6|0]=0;w[a+4>>1]=65535;x[a>>2]=0}function Pj(a){if(!a){return 0}return ej(y[a+31|0])}function NO(a,b,c,d){return Fr(a,b,c,d,7,613566757)}function I_(){Pd(469272);eG(469280);x[117318]=86080}function HY(a){a=a|0;a=ib[a|0]()|0;eb=hb;return a|0}function G_(){Pd(469288);eG(469296);x[117322]=86236}function Dea(a,b,c){a=a|0;b=b|0;c=c|0;ad(a,tr(b,c))}function Bha(a,b,c){a=a|0;b=b|0;c=c|0;SE(a,b,c,256)}function zaa(a,b){a=a|0;b=b|0;return Fj(a,b,225)|0}function waa(a,b){a=a|0;b=b|0;return Fj(a,b,326)|0}function rha(a,b){a=a|0;b=b|0;return Fj(a,b,422)|0}function o2(a,b,c){a=a|0;b=b|0;c=+c;_I(a-88|0,b,c)}function lha(a,b){a=a|0;b=b|0;return Fj(a,b,826)|0}function l2(a,b){a=a|0;b=b|0;return XI(a-88|0,b)|0}function kr(a,b,c){a=a|0;b=b|0;c=c|0;ad(a,rD(b,c))}function jE(a,b,c){a=a|0;b=b|0;c=c|0;AF(a,b,c,100)}function j2(a,b){a=a|0;b=b|0;return VI(a-88|0,b)|0}function hm(a){$i(a+724|0);$i(a+732|0);$i(a+740|0)}function b2(a,b,c){a=a|0;b=b|0;c=+c;QI(a-92|0,b,c)}function Yw(a){if(!a){return 0}x[23424]=a;return-1}function Y1(a,b){a=a|0;b=b|0;return Dr(a,b,1081)|0}function W1(a,b){a=a|0;b=b|0;return Dr(a,b,1082)|0}function V1(a,b){a=a|0;b=b|0;return Dr(a,b,1083)|0}function J2(a,b){a=a|0;b=b|0;return Dr(a,b,1079)|0}function Cl(a,b){return(a&65535)>>>0<(b&65535)>>>0}function Cja(a,b){a=a|0;b=b|0;return QE(a,b,329)|0}function Bga(a,b){a=a|0;b=b|0;if(!Hu(a,b)){Mu(b)}}
function $1(a,b,c){a=a|0;b=b|0;c=+c;OI(a-92|0,b,c)}function zT(a){return(x[wb(a)>>2]-x[a>>2]|0)/33|0}function xC(a){return(x[wb(a)>>2]-x[a>>2]|0)/20|0}function wv(a){return(x[wb(a)>>2]-x[a>>2]|0)/36|0}function wha(a,b){a=a|0;b=b|0;if(!vD(a,b)){cr(b)}}function wU(a){if(!(a&255)){return 1}return Tc(a)}function vM(a,b){return(a|0)==1179011410&b>>>0>80}function uaa(a,b){a=a|0;b=b|0;return Fj(a,b,60)|0}function tk(a){return(x[wb(a)>>2]-x[a>>2]|0)/12|0}function tH(a){return(Kj(a)|0)!=0|(a|32)-97>>>0<6}function rU(a,b){a=a|0;b=b|0;return QE(a,b,307)|0}function nm(a,b,c){x[a+4>>2]=c;w[a>>1]=b;return a}function mV(a){return(x[wb(a)>>2]-x[a>>2]|0)/48|0}function fl(a,b,c){C[a+8>>3]=c;C[a>>3]=b;return a}function eq(a,b,c){return x[(b<<2)+a>>2]+(c<<2)|0}function ec(a,b,c){x[a+4>>2]=c;x[a>>2]=b;return a}function _R(a){return(x[wb(a)>>2]-x[a>>2]|0)/56|0}function Zfa(a,b){a=a|0;b=b|0;return Fj(a,b,71)|0}function Ys(a){return(x[wb(a)>>2]-x[a>>2]|0)/52|0}function Xt(a){return(x[wb(a)>>2]-x[a>>2]|0)/24|0}function XD(a){x[a+4>>2]=0;x[a>>2]=91800;return a}function Wha(a,b){a=a|0;b=b|0;return Fj(a,b,91)|0}function UD(a,b){a=TD(a,b);x[a>>2]=92608;return a}function Tja(a,b){a=a|0;b=b|0;if(!wV(a,b)){uu(b)}}function Rha(a,b){a=a|0;b=b|0;if(!CT(a,b)){BT(b)}}function Qp(a,b){x[a+4>>2]=256;x[a>>2]=b;return a}function Ph(a,b,c){x[a>>2]=b;x[a+4>>2]=c;return a}function Og(a,b){a=a|0;b=b|0;return UH(a)^UH(b)^1}function MC(a){return!cd(a,26240,25)&y[a+34|0]<65}function KB(a){return(x[wb(a)>>2]-x[a>>2]|0)/28|0}function Jh(a,b){a=a|0;b=b|0;return MH(a)^MH(b)^1}function Haa(a,b){a=a|0;b=b|0;if(!CD(a,b)){Jv(b)}}function GF(a){return(a<<1)+16777216>>>0<16777217}function F7(a,b){a=a|0;b=b|0;return E(Kl(a,b,12))}function Baa(a,b){a=a|0;b=b|0;return Fj(a,b,73)|0}function B5(a){a=a|0;return aw(a,12655,1074416)|0}function yW(a,b){a=a|0;b=b|0;if(!hC(a,b)){Nu(b)}}function xx(a,b){x[a>>2]=x[b>>2];ad(a+4|0,b+4|0)}function wz(a){x[a+24>>2]=z[a+20>>1]<<z[a+22>>1]}function w7(a,b){a=a|0;b=b|0;return E(Kl(a,b,2))}function vo(a,b,c){v[a+2|0]=c;w[a>>1]=b;return a}function tu(a){return(x[wb(a)>>2]-x[a>>2]|0)/6|0}function r8(a,b){a=a|0;b=b|0;return E(Kl(a,b,5))}function p7(a,b){a=a|0;b=b|0;return E(Kl(a,b,3))}function n2(a,b){a=a|0;b=b|0;return+ZI(a-88|0,b)}function mL(a){a=a|0;sc(a+4256|0);return yf(a)|0}function k8(a,b){a=a|0;b=b|0;return E(Kl(a,b,4))}function iz(a){return(x[wb(a)>>2]-x[a>>2]|0)/7|0}function gV(a,b){a=a|0;b=b|0;if(!fV(a,b)){su(b)}}function fka(a,b){a=a|0;b=b|0;return Du(a,1,b)|0}function cE(a){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0}function aC(a,b){a=a|0;b=b|0;if(!MD(a,b)){yv(b)}}function a2(a,b){a=a|0;b=b|0;return+PI(a-92|0,b)}function _o(a,b,c){a=Xd(a);x[a+4>>2]=c;x[a>>2]=b}function _1(a,b){a=a|0;b=b|0;return+NI(a-92|0,b)}function WP(a,b){x[a>>2]=x[a>>2]+(b<<1);return a}function RN(a,b,c){x[a+4>>2]=c;v[a|0]=b;return a}function Qu(a,b){a=a|0;b=b|0;if(!Zq(a,b)){Pq(b)}}function Q7(a,b){a=a|0;b=b|0;return E(Kl(a,b,1))}function Ps(a){a=a|0;sc(a+4208|0);return yf(a)|0}function OA(a,b){a=a|0;b=b|0;if(!OT(a,b)){VA(b)}}function MJ(a,b){a=a|0;b=b|0;xk(a,b,57848,57856)}function LJ(a,b){a=a|0;b=b|0;xk(a,b,57864,57872)}function IL(a){a=a|0;bc(a+4208|0);return yf(a)|0}function HJ(a,b){a=a|0;b=b|0;xk(a,b,58668,58676)}function GU(a,b){x[a>>2]=x[a>>2]+D(b,6);return a}function GJ(a,b){a=a|0;b=b|0;xk(a,b,58684,58692)}function FJ(a,b){a=a|0;b=b|0;xk(a,b,59496,59504)}function F5(a){a=a|0;return oF(a,8694,1074448)|0}function EV(a,b){a=kV(a,b);if(!a){HB(b)}return a}function EJ(a,b){a=a|0;b=b|0;xk(a,b,59512,59520)}function DF(a,b,c,d,e){Ha(a|0,b|0,c|0,d|0,e|0,1)}function D8(a,b){a=a|0;b=b|0;return E(Kl(a,b,6))}function Cq(a,b){a=a|0;b=b|0;if(!_h(a,b)){El(b)}}function C5(a){a=a|0;return aw(a,5260,1074424)|0}function BJ(a,b){a=a|0;b=b|0;xk(a,b,60324,60332)}function AJ(a,b){a=a|0;b=b|0;xk(a,b,60340,60348)}function yja(a,b){a=a|0;b=b|0;hp(a,b,346,345,8)}function wn(a){return ib[x[x[a>>2]+28>>2]](a)|0}function vka(a,b){a=a|0;b=b|0;hp(a,b,283,282,8)}function qd(a,b){return Ko(x[b>>2],x[a>>2])?b:a}function kga(a,b){a=a|0;b=b|0;hp(a,b,587,586,8)}function gu(a,b){a=a|0;b=b|0;return Lb(a,b,1)^1}function g4(a){a=a|0;return jF(a,49256,12379)|0}function eI(a,b){if(!a){return 0}return Ww(a,b)}function eG(a){var b=0,c=0;b=a,c=yd(),x[b>>2]=c}function eC(a,b){return(b&255)==2&(a&255)>>>0<3}function bI(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function a5(a){a=a|0;return aw(a,5757,480272)|0}function _S(a){var b=0;b=x[a>>2];Oe(a);return b}function Yha(a,b){a=a|0;b=b|0;hp(a,b,461,460,6)}function Yc(a,b){return jq(x[a>>2],x[b>>2])?b:a}function Vy(a){if(y[a+24|0]){YN(a);v[a+24|0]=0}}function Ve(a,b){return Cl(z[a>>1],z[b>>1])?b:a}function Uja(a,b,c){a=a|0;b=b|0;c=c|0;iC(a,b,c)}function Uc(a,b){return Cl(z[b>>1],z[a>>1])?b:a}function Sfa(a,b){a=a|0;b=b|0;hp(a,b,619,618,8)}function Re(a,b){return Ko(x[a>>2],x[b>>2])?b:a}function Lx(a,b){return fu(B[a>>2],B[b>>2])?b:a}function D5(a){a=a|0;return oF(a,7051,480214)|0}function Ch(a,b,c){return Da(941,a|0,b|0,c|0)|0}function Cb(a,b){return jq(x[b>>2],x[a>>2])?b:a}function Ak(a){return ib[x[x[a>>2]+36>>2]](a)|0}function $l(a,b){return fu(B[b>>2],B[a>>2])?b:a}function $W(a,b){a=a|0;b=b|0;Lp(a,b);return a|0}function zP(a){rz(a);Vb(a+27|0,0,255);return a}function uP(a){x[a>>2]=0;x[a+4>>2]=-1;return a}function qt(a){return(a>>>0<9?a:a-9|256)&65535}function p8(a){a=a|0;v[a+4202|0]=1;iL(a);kL(a)}function lf(a,b,c){if(!(y[a|0]&32)){FB(b,c,a)}}function lZ(a,b,c){a=a|0;b=b|0;c=c|0;ec(a,c,b)}function jga(a,b){a=a|0;b=b|0;return lS(a,b)|0}function iaa(a,b){a=a|0;b=b|0;yy(lM(a+24|0,b))}function i8(a){a=a|0;v[a+4202|0]=1;gL(a);fL(a)}function hn(a,b,c,d,e){La(a|0,b|0,c|0,d|0,e|0)}function f4(a){a=a|0;return jF(a,49276,8089)|0}function dg(a,b,c){a=zka(a,b,c,c>>31);return a}function bB(a,b,c){a=a|0;b=b|0;c=c|0;fC(a,b,c)}function _j(a,b){return(D(b,104)+a|0)+484380|0}function Xk(a,b){return Gs((b<<1)+91120|0,2,a)}function Ur(a,b){return(a&255)>>>0<(b&255)>>>0}function Rm(a){return(a>>>0<=127?-1:a^128)&255}function QB(a,b,c){a=a|0;b=b|0;c=c|0;XV(a,b,c)}function Q9(a,b,c){a=a|0;b=b|0;c=c|0;TL(a,b,c)}function P3(a,b){a=a|0;b=b|0;ad(a,tr(b,17221))}function C7(a){a=a|0;ZK(a);Dx(a);v[a+4202|0]=1}function Ag(a,b){v[a+4|0]=0;x[a>>2]=b;return a}function zw(a,b,c){a=gH(a,b,c,-1,-1);return a}function zX(a){a=a|0;x[a>>2]=43192;return a|0}function yH(a){a=wK(a);x[a>>2]=77824;return a}function xX(a){a=a|0;x[a>>2]=42952;return a|0}function tc(a,b){if(A[a>>2]>b>>>0){x[a>>2]=b}}function sm(a,b,c,d){return(b-d|0)+(a-c<<3)|0}function ska(a,b){a=a|0;b=b|0;Xv(a,b,44,2,44)}function sY(a,b){a=a|0;b=b|0;return tE(a,b)|0}function rt(a,b){a=a|0;b=b|0;return qg(a,b)|0}function rK(a){a=a|0;x[a>>2]=49340;return a|0}function qG(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function mja(a,b){a=a|0;b=b|0;UE(a,b,350,349)}function mR(a){return Le(443250/+(a>>>0)*1e4)}function i1(a){a=a|0;IH(x[x[a>>2]-12>>2]+a|0)}function hs(a,b){a=a|0;b=b|0;return rD(a,b)|0}function g1(a){a=a|0;HH(x[x[a>>2]-12>>2]+a|0)}function fW(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function eka(a,b){a=a|0;b=b|0;UE(a,b,289,288)}function af(a,b){return Ur(y[a|0],y[b|0])?b:a}function _l(a){a=Yl(a);x[a>>2]=92212;return a}function Zh(a,b){if(x[a>>2]>(b|0)){x[a>>2]=b}}function Xd(a){x[a>>2]=0;x[a+4>>2]=0;return a}function Wf(a,b){if(z[a>>1]>b>>>0){w[a>>1]=b}}function WH(a){a=a|0;Rw(x[x[a>>2]-12>>2]+a|0)}function W2(a){a=a|0;x[a>>2]=60864;return a|0}function Tx(a){return x[wb(a)>>2]-x[a>>2]>>11}function Sb(a,b){return Ur(y[b|0],y[a|0])?b:a}function RH(a){a=a|0;Pw(x[x[a>>2]-12>>2]+a|0)}function Qha(a,b){a=a|0;b=b|0;Xv(a,b,17,3,16)}function QU(a){a=(a&65535)-98|0;hb=0;return a}function Pd(a){a=XD(a);x[a>>2]=83520;return a}function OR(a){a=yka(a&65535,0,80,0);return a}function O2(a){a=a|0;x[a>>2]=60364;return a|0}function LX(a){a=a|0;x[a>>2]=61284;return a|0}function Kv(a,b){a=a|0;b=b|0;return tr(a,b)|0}function Bs(a){a=wK(a);x[a>>2]=77432;return a}function Bka(a,b,c,d){a=wka(a,b,c,d);return a}function BV(a){v[a+12|0]=y[a+12|0]|2;return a}function zr(a){return x[wb(a)>>2]-x[a>>2]>>4}function to(a){return x[wb(a)>>2]-x[a>>2]>>5}function t5(a){a=a|0;return rF(a,6532,992)|0}function qh(a){return x[x[a+8>>2]>>2]==(a|0)}function h$(a){a=a|0;Td(a,468992,Qd(467504))}function f$(a){a=a|0;Td(a,469008,Qd(467708))}function ey(a,b){return D((b-a|0)/6|0,6)+a|0}function e$(a){a=a|0;Td(a,469024,Qd(467700))}function d$(a){a=a|0;Td(a,469032,Qd(467716))}function b$(a){a=a|0;Td(a,469040,Qd(467724))}function an(a){return x[wb(a)>>2]-x[a>>2]>>3}function a3(a){a=a|0;wJ(a);return x[a+16>>2]}function a$(a){a=a|0;Td(a,469056,Qd(467732))}function __(a){a=a|0;Td(a,469072,Qd(467740))}function Z_(a){a=a|0;Td(a,469080,Qd(467756))}function Y_(a){a=a|0;Td(a,469088,Qd(467764))}function X_(a){a=a|0;Td(a,469112,Qd(467772))}function W_(a){a=a|0;Td(a,469144,Qd(467520))}function WS(a,b,c,d){return(D(b,d)+c<<1)+a|0}function V_(a){a=a|0;Td(a,469152,Qd(467528))}function Uo(a,b,c,d){a=zka(a,b,c,d);return a}function Uj(a){return KE(a,E(4294967296),-1)}function U_(a){a=a|0;Td(a,469160,Qd(467536))}function T_(a){a=a|0;Td(a,469168,Qd(467544))}function S_(a){a=a|0;Td(a,469176,Qd(467584))}function R_(a){a=a|0;Td(a,469184,Qd(467592))}function Qy(a){v[a+24|0]=0;v[a|0]=0;return a}function Qm(a){return x[wb(a)>>2]-x[a>>2]>>1}function Qh(a){return x[wb(a)>>2]-x[a>>2]>>2}function Q_(a){a=a|0;Td(a,469192,Qd(467600))}function Q1(a){a=a|0;return ya(x[a+60>>2])|0}function Px(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function Pg(a,b,c,d){return(D(b,d)+c<<3)+a|0}function P_(a){a=a|0;Td(a,469200,Qd(467608))}function Oz(a){return x[wb(a)>>2]-x[a>>2]>>8}function O_(a){a=a|0;Td(a,469208,Qd(467616))}function N_(a){a=a|0;Td(a,469216,Qd(467624))}function NF(a,b,c){a=a|0;b=b|0;c=c|0;GH(a,c)}function N5(a){a=a|0;return rF(a,6995,984)|0}function M_(a){a=a|0;Td(a,469224,Qd(467632))}function ML(a){x[a>>2]=x[a>>2]-2048;return a}function Lj(a){a=a&255;return(a|0)==255?-1:a}function L_(a){a=a|0;Td(a,469232,Qd(467640))}function Kh(a,b,c,d){return(D(b,d)+c<<2)+a|0}function K_(a){a=a|0;Td(a,469240,Qd(467552))}function J_(a){a=a|0;Td(a,469256,Qd(467560))}function Iz(a){return x[kc(a)>>2]-x[a>>2]>>2}function H_(a){a=a|0;Td(a,469272,Qd(467568))}function Fx(a){return E(E(a*E(7900))+E(100))}function F_(a){a=a|0;Td(a,469288,Qd(467576))}function E_(a){a=a|0;Td(a,469304,Qd(467648))}function Dfa(a,b){a=a|0;b=b|0;Zv(a,b,1042,2)}function D_(a){a=a|0;Td(a,469312,Qd(467656))}function Bb(a,b){if(!ue(b)){a=rj(b)}return a}function Aia(a,b){a=a|0;b=b|0;Cr(a,b,1042,2)}function $_(a){a=a|0;Td(a,469064,Qd(467748))}function $T(a,b,c){ec(a,b,oi(b,b+c|0,0)-b|0)}function yn(a){a=a|0;LH(x[a>>2]);return a|0}function wY(a,b){a=a|0;b=b|0;Uv(a,b,1058,2)}function tka(a,b){a=a|0;b=b|0;Zv(a,b,274,0)}function st(a,b,c){v[a|0]=b;v[a+1|0]=y[c|0]}function rW(a,b){a=a|0;b=b|0;Zv(a,b,1025,2)}function pn(a){return x[wb(a)>>2]-x[a>>2]|0}function pf(a,b){if(y[a|0]>b>>>0){v[a|0]=b}}function kq(a,b){w[a>>1]=b;w[a+2>>1]=b>>>16}function ki(a,b){a=a|0;b=b|0;return E(E(0))}function il(a,b){return a<<24>>24<b<<24>>24}function g$(a){a=a|0;Td(a,469e3,Qd(467512))}function cU(a,b){x[a>>2]=x[a>>2]+b;return a}function b3(a){a=a|0;wJ(a);return x[a+4>>2]}function aq(a,b){return a<<16>>16<b<<16>>16}function _9(a,b){a=a|0;b=b|0;Cr(a,b,1058,1)}function U1(a,b){a=a|0;b=b|0;Cr(a,b,1025,4)}function Tl(a){a=a|0;Qw(x[a>>2]);return a|0}function R1(a,b){a=a|0;b=b|0;Cr(a,b,1025,2)}function OJ(a){v[a+4|0]=0;v[a|0]=0;return a}function MK(a){return Oh(E(OK(a)*E(32768)))}function JQ(a){x[a>>2]=x[a>>2]-256;return a}function Is(a){a=a|0;ib[x[x[a>>2]+4>>2]](a)}function Gm(a,b,c){return qf(a,b)>>>0>c>>>0}function yg(a){x[a>>2]=x[a>>2]+20;return a}function xY(a,b){a=a|0;b=b|0;Uv(a,b,290,0)}function xT(a){x[a>>2]=x[a>>2]-33;return a}function x1(a){a=a|0;return uh(a,467536)|0}function ww(a){a=a|0;return uh(a,467772)|0}function vm(a){Ez(x[a+20>>2]);x[a+20>>2]=0}function vX(a,b){a=a|0;b=b|0;Uv(a,b,257,0)}function v9(a,b){a=a|0;b=b|0;v[a+4201|0]=b}function so(a){x[a>>2]=x[a>>2]+52;return a}function qka(a,b){a=a|0;b=b|0;Aj(a+12|0,b)}function po(a){x[a>>2]=x[a>>2]-32;return a}function ms(a){return(a|0)<=65535&(a|0)>=0}function mka(a,b){a=a|0;b=b|0;Aj(a+36|0,b)}function mfa(a,b){a=a|0;b=b|0;RE(a,b,2,31)}function lV(a){x[a>>2]=x[a>>2]-48;return a}function lI(a,b){return E(Nv(a?E(-b):b)*b)}function kK(a){x[a>>2]=x[a>>2]-24;return a}function jl(a){x[a>>2]=x[a>>2]+16;return a}function hk(a){x[a>>2]=x[a>>2]+28;return a}function gg(a){return E(F(a))==E(Infinity)}function fM(a){x[a>>2]=x[a>>2]-52;return a}function cq(a){He(a+24|0);bc(a+12|0);bc(a)}function bf(a,b,c){a=yka(c,0,a,b);return a}function baa(a,b){a=a|0;b=b|0;qg(a,b+36|0)}function Zu(a){a=a|0;return uh(a,467708)|0}function YR(a){x[a>>2]=x[a>>2]-56;return a}function YQ(a,b,c,d){ec(a,b,(d|0)==-1?c:d)}function XR(a){x[a>>2]=x[a>>2]+56;return a}function Wp(a){x[a>>2]=x[a>>2]+32;return a}function Wc(a,b){a=a|0;b=b|0;TL(a,b,Pf(b))}function Waa(a,b){a=a|0;b=b|0;Aj(a+40|0,b)}function Vo(a){or(a+32|0);ub(a+12|0);tb(a)}function V8(a,b,c){a=a|0;b=b|0;c=c|0;Xd(a)}function SU(a){x[a>>2]=x[a>>2]-20;return a}function SN(a,b){return _E(a,b,2147483647)}function RX(a){a=a|0;return x[a+4>>2]!=0|0}function RK(a){return E(E(a*E(96))+E(-96))}function Nw(a){a=a|0;return uh(a,467700)|0}function Nj(a){tb(a+36|0);sc(a+24|0);ek(a)}function Kw(a){a=a|0;return uh(a,467716)|0}function Jr(a,b){ib[x[x[b>>2]+40>>2]](a,b)}function Jl(a){x[a>>2]=x[a>>2]-16;return a}function Gw(a){a=a|0;return uh(a,467724)|0}function FD(a){x[a>>2]=x[a>>2]-36;return a}function ED(a){x[a>>2]=x[a>>2]+36;return a}function E1(a){a=a|0;return uh(a,467520)|0}function Cw(a){a=a|0;return uh(a,467764)|0}function Cu(a){x[a>>2]=x[a>>2]-28;return a}function Ck(a,b){ib[x[x[b>>2]+44>>2]](a,b)}function Cj(a){x[a>>2]=x[a>>2]-12;return a}function Bw(){da(_l(ac(4))|0,92296,25);p()}function Bk(a,b){ib[x[x[b>>2]+32>>2]](a,b)}function Bj(a){x[a>>2]=x[a>>2]+12;return a}function zs(a,b){x[a>>2]=b;Xm(b);return a}function x2(a,b){a=a|0;b=b|0;gJ(a-88|0,b)}function w2(a,b){a=a|0;b=b|0;fJ(a-88|0,b)}function uga(a,b){a=a|0;b=b|0;Gi(a,b,106)}function tG(a){x[a>>2]=x[a>>2]-1;return a}function qk(a){x[a>>2]=x[a>>2]-2;return a}function px(a,b,c,d){return eq(a,c,b+d|0)}function nJ(a,b){a=a|0;b=b|0;qg(a,b+12|0)}function mt(a){x[a>>2]=x[a>>2]+8;return a}function ls(a){a=a|0;Cs(a+8|0);return a|0}function lk(a){x[a>>2]=x[a>>2]+6;return a}function ika(a,b){a=a|0;b=b|0;Gi(a,b,136)}function g2(a,b){a=a|0;b=b|0;TI(a-88|0,b)}function fr(a){x[a>>2]=x[a>>2]-8;return a}function fj(a){x[a>>2]=x[a>>2]-4;return a}function d2(a,b){a=a|0;b=b|0;SI(a-92|0,b)}function c2(a,b){a=a|0;b=b|0;RI(a-92|0,b)}function bs(a){a=a|0;Nk(a+8|0);return a|0}function bm(a){return E(F(a))<E(Infinity)}function as(a){a=a|0;Nk(a+4|0);return a|0}function XZ(a,b){a=a|0;b=b|0;qg(a,b+16|0)}function We(a,b,c){_g(b,b+c|0,a);return a}function TT(a){x[a>>2]=x[a>>2]-6;return a}function Se(a){x[a>>2]=x[a>>2]+2;return a}function SK(a){a=a|0;Vb(a+4296|0,0,81928)}function SI(a,b){a=a|0;b=b|0;gF(a,b,2048)}function Rja(a,b){a=a|0;b=b|0;RE(a,b,3,8)}function RI(a,b){a=a|0;b=b|0;gF(a,b,4096)}function Oe(a){x[a>>2]=x[a>>2]+1;return a}function Nf(a){a=a|0;xh(a+8|0);return a|0}function Mk(a){a=a|0;return VH(a)<<24>>24}function IO(a){x[a>>2]=x[a>>2]-7;return a}function DO(a,b){if(B[a>>2]>b){B[a>>2]=b}}function BF(a){a=za(a|0)|0;hb=eb;return a}function Ap(a,b){v[a|0]=b+48;return a+1|0}function Aga(a,b){a=a|0;b=b|0;Gi(a,b,274)}function Ae(a){x[a>>2]=x[a>>2]+4;return a}function z2(a){a=a|0;return ls(a-88|0)|0}function v2(a,b){a=a|0;b=+b;eJ(a-88|0,b)}function un(a){return a-97>>>0<26?a&95:a}function uH(a){return a-65>>>0<26?a|32:a}function tja(a,b){a=a|0;b=b|0;Gi(a,b,34)}function t2(a,b){a=a|0;b=+b;cJ(a-88|0,b)}function sga(a,b){a=a|0;b=b|0;Gi(a,b,72)}function rk(a){return D(Sm(a),Jd(a))&255}function q2(a,b){a=a|0;b=+b;aJ(a-88|0,b)}function pT(a,b){a=a|0;b=b|0;Gi(a,b,284)}function kw(a){return a-469504>>>2&65535}function jg(a,b){x[a+8>>2]=b|-2147483648}function fc(a){x[x[a>>2]+4>>2]=x[a+4>>2]}function f2(a){a=a|0;return ls(a-92|0)|0}function av(a,b,c,d,e){ZE(a,b,c,d,e,128)}function _r(a,b){x[a+24>>2]=x[a+24>>2]+b}function ZD(a,b){Pb(a,b);Pb(a+4|0,b+4|0)}function Wr(a){a=a|0;$v(a,154,92656,981)}function WZ(a,b){a=a|0;b=b|0;kn(a,83264)}function VZ(a,b){a=a|0;b=b|0;kn(a,83284)}function Sd(a,b){return(b|0)!=0&(a|0)!=0}function RZ(a,b){a=a|0;b=b|0;Tb(a,11138)}function Qq(a,b,c,d,e){ZE(a,b,c,d,e,256)}function QZ(a,b){a=a|0;b=b|0;Tb(a,11255)}function Pha(a,b){a=a|0;b=b|0;Mq(a,b,17)}function NN(a,b,c){x[a>>2]=b;x[a+4>>2]=c}function J8(a){a=a|0;v[a+4202|0]=1;wL(a)}function Ik(a){return(a|0)==32|a-9>>>0<5}function I7(a){a=a|0;return x[a+4260>>2]}function Fn(a,b,c){return ib[c|0](a,b)|0}function Eo(a,b){v[a|0]=b;v[a+1|0]=b>>>8}function Aha(a,b){a=a|0;b=b|0;Gi(a,b,42)}function $i(a){w[a+4>>1]=65535;x[a>>2]=0}function vJ(a){x[a+4>>2]=x[a+4>>2]|8192}function u9(a){a=a|0;return y[a+4201|0]}function t9(a){a=a|0;return y[a+4202|0]}function lU(a,b){a=a|0;b=b|0;Mq(a,b,32)}function jn(a,b,c){return vg(a,b,b+c|0)}function iU(a,b){a=a|0;b=b|0;return b|0}function hT(a,b){x[a>>2]=x[a>>2]+(b<<2)}function gea(a,b){a=a|0;b=b|0;NE(a,b,3)}function f7(a){a=a|0;return(a|0)==277|0}function dZ(a){a=a|0;if(a){MF(Ln(a),1)}}function cz(a,b,c){return a<b?b:a>c?c:a}function cW(a,b){a=a|0;b=b|0;Gi(a,b,50)}function bz(a,b,c){return a<b?b:a>c?c:a}function _m(a){a=x[a+8>>2];if(a){Eb(a)}}function Zw(a){return(q(a),j(2))>>>20|0}function Xg(a,b,c){v[a+4|0]=c;x[a>>2]=b}function UR(a,b,c,d){return sm(c,d,a,b)}function Th(a){return(a&65535)>>>0<3999}function Qj(a,b){return Ty(a&255,b&255)}function PW(a,b){a=a|0;b=b|0;Gi(a,b,59)}function Oha(a,b){a=a|0;b=b|0;kC(a,b,8)}function LN(a,b){return(gl(a,b)|0)!=255}function KF(a){return(z[a+2>>1]<<2)+a|0}function Hb(a){return(a<<8|a>>>8)&65535}function Gs(a,b,c){return _g(a,a+b|0,c)}function EG(a,b){a=a|0;b=b|0;Ye(a,1,45)}function DW(a,b){a=a|0;b=b|0;Mq(a,b,11)}function DG(a,b){a=a|0;b=b|0;NG(a,1,45)}function u2(a){a=a|0;return+dJ(a-88|0)}function sV(a,b,c){return Er(a,b,c,48)}function r7(a){a=a|0;return-2013527448}function r2(a){a=a|0;return+bJ(a-88|0)}function p2(a){a=a|0;return+$I(a-88|0)}function kE(a,b){x[a+4>>2]=3;x[a>>2]=b}function ge(a,b,c){tn(a,b,Pc(b,c)+b|0)}function fea(a){a=a|0;JR(a);return a|0}function ez(a,b){return YE(a,b,-1,0,0)}function bK(a){return a?(a|0)==2?3:2:1}function _i(a,b){return Mb(a)+(b<<2)|0}function YZ(a){a=a|0;return x[a+12>>2]}function Xu(a,b,c){return Er(a,b,c,20)}function Ug(a){return KE(a,E(255),255)}function SA(a,b,c){Wg(a,c);hd(b+c|0,0)}function Rv(a,b){x[a+4>>2]=4;x[a>>2]=b}function LL(a){a=a|0;return 1869112133}function Kr(a){a=a|0;return 2147483647}function Kd(a){x[x[a+8>>2]>>2]=x[a>>2]}function Jj(a,b){x[a+4>>2]=1;x[a>>2]=b}function It(a,b,c){return Er(a,b,c,12)}function Il(a,b){x[a+4>>2]=2;x[a>>2]=b}function FA(a,b){a=a|0;b=b|0;NE(a,b,2)}function DX(a){a=a|0;return x[a+16>>2]}function CP(a,b,c){return VE(a,b,c,41)}function z7(a){a=a|0;return 302837129}function ym(a){return(a&740327453)!=0}function wK(a){x[a>>2]=77460;return a}function wE(a){a=E(a-a);return E(a/a)}function vO(a,b){return(0-b|0)!=(a|0)}function vC(a,b){Ar(a,b,20,214748365)}function u8(a){a=a|0;return-285139079}function tM(a,b){Xc(a,b&4?16:8,1,0,0)}function sf(a,b,c){return $c(a,b,c,0)}function qf(a,b){return kk(a,b)&65535}function qE(a,b){Ar(a,b,12,357913942)}function oh(a,b,c){return gp(a,b,c,2)}function n9(a){a=a|0;return 542066252}function m8(a){a=a|0;return-284078960}function lr(a){a=a|0;return x[a+4>>2]}function jJ(a){x[a>>2]=62056;return a}function j7(a,b){a=a|0;b=b|0;return 3}function ii(a,b,c){ad(ad(a,b)+12|0,c)}function iJ(a){x[a>>2]=62080;return a}function hJ(a){x[a>>2]=62160;return a}function gr(a,b,c){return gp(a,b,c,3)}function g7(a,b){a=a|0;b=b|0;return 2}function fp(a,b,c){return gp(a,b,c,4)}function f8(a){a=a|0;return-281111764}function ej(a){return(a-1&255)>>>0<17}function di(a){a=x[a>>2];if(a){iH(a)}}function cs(a,b){a=a|0;b=b|0;return-1}function aT(a){EI(a);ve(x[a+80>>2],a)}function _7(a){a=a|0;return-271958638}function Zm(a){x[a>>2]=60816;return a}function Yl(a){x[a>>2]=92908;return a}function Y2(a){a=a|0;return y[a+40|0]}function X0(a){a=a|0;return wH(a,0)|0}function WD(a){a=a|0;return x[a+8>>2]}function W0(a){a=a|0;return wH(a,1)|0}function TR(a,b,c){kl(a,(b<<2)+a|0,c)}function TJ(a){x[a>>2]=49588;return a}function So(a,b,c){return Br(a,b,c,1)}function S7(a){a=a|0;return-620920304}function Qx(a,b){a=a|0;b=b|0;return 1}function Q0(a){a=a|0;return vH(a,0)|0}function P0(a){a=a|0;return vH(a,1)|0}function OD(a,b,c){dc(a,b,Hg(b,c)<<3)}function NJ(a){x[a>>2]=57832;return a}function Mz(a,b,c){return gp(a,b,c,5)}function J7(a){a=a|0;return-275227023}function IT(a,b,c){dc(a,b,oc(b,c)<<2)}function IK(a,b){a=a|0;b=b|0;return 0}function GQ(a,b,c){return Br(a,b,c,5)}function Fe(a,b){x[a+4>>2]=b;return a}function FR(a){return(a|0)>=120?120:a}function F8(a){a=a|0;return-270114148}function Ei(a,b,c){return gp(a,b,c,1)}function Co(a,b){w[a+8>>1]=b;return a}function Bq(a,b,c){return Er(a,b,c,6)}function Bl(a,b,c){return Br(a,b,c,2)}function BE(a,b,c){return Br(a,b,c,4)}function AQ(a){return(a&65535)==65534}function ys(a){return z[a+480192>>1]}function xs(a){return z[a+480190>>1]}function wt(a){return x[wb(a)>>2]<<5}function wp(a){return z[a+480188>>1]}function wba(a){a=a|0;return Ig(a)|0}function vk(a,b){a=a|0;b=b|0;Rn(a,b)}function up(a,b,c,d,e){JJ(a,b,c,d,e)}function uE(a,b){a=a|0;b=b|0;Np(a,b)}function qj(a,b){a=a|0;b=b|0;TV(a,b)}function lw(a){return(a<<2)+469504|0}function lja(a){a=a|0;return Hc(a)|0}function lh(a,b){a=a|0;b=b|0;qg(a,b)}function ku(a,b){return y[a+b|0]!=63}function iM(a,b){Ar(a,b,52,82595525)}function gY(a,b){a=a|0;b=b|0;xE(a,b)}function df(a){return F(a)==Infinity}function cM(a,b){return Yj(a,b-a>>2)}function bO(a){return(a+5&255)>>>0<2}function Zg(a){ql(a+44|0);bc(a+32|0)}function Xm(a){x[a+4>>2]=x[a+4>>2]+1}function XQ(a,b){return D(b,872)+a|0}function WT(a,b){Ar(a,b,6,715827883)}function WA(a,b){a=a|0;b=b|0;mK(a,b)}function TZ(a){a=a|0;return v[a+8|0]}function Sq(a,b){a=a|0;b=b|0;uv(a,b)}function SZ(a){a=a|0;return v[a+9|0]}function S8(a,b){a=a|0;b=b|0;rt(a,b)}function S2(a){a=a|0;return y[a+8|0]}function Rn(a,b){a=a|0;b=b|0;lh(a,b)}function Qaa(a){a=a|0;return pi(a)|0}function PM(a,b){a=a|0;b=b|0;JN(a,b)}function PK(a){x[a>>2]=0;x[a+4>>2]=0}function NS(a,b){if(!HS(a,b)){tA(b)}}function ND(a,b){Tv(a,b,3,536870912)}function Mx(a,b){a=a|0;b=b|0;DL(a,b)}function KL(a,b,c){a=a|0;b=b|0;c=c|0}function Hja(a){a=a|0;return bV(a)|0}function HQ(a,b){Tv(a,b,5,134217728)}function EK(a){a=a|0;uF(a,49120,930)}function DR(a){return(a&255)>>>0<129}function Cx(a){a=a|0;uF(a,49176,932)}function CE(a,b){Tv(a,b,4,268435456)}function CA(a,b){return Ie(a,0-b|0)}
function zC(a){if(!y[a+4|0]){yC(a)}}function yK(a){a=a|0;return Nk(a)|0}function xq(a,b,c){return _g(a,b,c)}function wX(a){a=a|0;DD(Vb(a,0,36))}function vl(a,b){return xu(Ic(a,b))}function vb(a,b){x[a>>2]=b;return a}function ul(a){if(!y[a+4|0]){vV(a)}}function tX(a){a=a|0;return xh(a)|0}function sd(a,b){return(a|0)!=(b|0)}function rq(a){return(a&255)==1?1:2}function qc(a,b){return(a|0)==(b|0)}function qK(a){if(!y[a+4|0]){pK(a)}}function q1(a){a=a|0;return Kk(a)|0}function pl(a,b,c){return uk(a,b,c)}function pe(a,b,c){return bH(a,b,c)}function pJ(a){if(!y[a+4|0]){sE(a)}}function nt(a){if(!y[a+4|0]){$D(a)}}function nl(a,b){return D(b,24)+a|0}function mG(a){if(!y[a+4|0]){kG(a)}}function ll(a){if(!y[a+4|0]){lD(a)}}function kk(a,b){return(b-a|0)/52|0}function kD(a){a=a|0;return Fg(a)|0}function jv(a){v[a+2|0]=0;w[a>>1]=0}function jq(a,b){return a>>>0<b>>>0}function hy(a,b){return D(b,28)+a|0}function hP(a){if(!y[a+4|0]){bU(a)}}function fA(a,b){return D(b,56)+a|0}function eu(a,b){return(b-a|0)/33|0}function er(a,b){return(b-a|0)/36|0}function daa(a){a=a|0;Mq(a,21204,1)}function dW(a){a=a|0;return rv(a)|0}function bj(a,b){return hg(a,b)&255}function ax(a){return!cd(a,93224,6)}function au(a,b,c){return EA(a,b,c)}function Zf(a){return Lh(a)<<24>>24}function ZS(a){if(!y[a+4|0]){US(a)}}function XX(a){a=a|0;return pg(a)|0}function Wb(a,b){return te(a,b&255)}function WU(a,b){return Ie(a,b-a|0)}function Vh(a){if(!y[a+4|0]){KD(a)}}function Vf(a,b){return Xj(a,Zd(b))}function TV(a,b){RV(a,x[a+16>>2]|b)}function SQ(a){if(!y[a+4|0]){RQ(a)}}function Rf(a,b){return D(b,52)+a|0}function Pt(a,b){return(b-a|0)/56|0}function Op(a){if(y[a+24|0]){YN(a)}}function N7(a){a=a|0;x[a+4224>>2]=0}function Mn(a,b){return(b-a|0)/24|0}function Jt(a){if(!y[a+4|0]){gR(a)}}function Hp(a){return uV(a,251,255)}function Ft(a,b){return D(b,36)+a|0}function Fq(a,b){return(b-a|0)/28|0}function Ef(a,b){return(b-a|0)/20|0}function ET(a,b){return D(b,33)+a|0}function EH(a){a=a|0;return Ev(a)|0}function Cg(a,b){return D(b,20)+a|0}function Cd(a,b){return(b-a|0)/12|0}function Bg(a){if(!y[a+4|0]){nR(a)}}function Aq(a,b){return(b-a|0)/48|0}function $d(a,b){return D(b,12)+a|0}function zG(a){return uh(a,467584)}function wG(a){return uh(a,467608)}function vG(a){return uh(a,467600)}function ue(a){return(a&128)>>>7|0}function pj(a,b){return D(rk(b),a)}function mk(a){return a&2147483647}function kY(a){a=a|0;Wm(a,1,13289)}function ji(a){a=a|0;v[a+4202|0]=0}function hz(a,b){return(b-a|0)/7|0}function ho(a,b){return(b<<13)+a|0}function hh(a,b){x[a>>2]=x[a>>2]|b}function cO(a){oe(a+8|0);XN(a+4|0)}function bk(a,b){return(b-a|0)/6|0}function _M(a,b){x[a>>2]=x[a>>2]+b}function _J(a){return(Lj(a)|0)==-1}function ZJ(a,b){a=a|0;b=b|0;bc(b)}function YJ(a,b){a=a|0;b=b|0;um(b)}function X1(a,b){a=a|0;b=b|0;Eb(b)}function Ts(a,b){return(a-b|0)/6|0}function Sk(a,b){return(a+b|0)-1|0}function Qc(a,b){return _E(a,b,-1)}function QV(a,b){return Gk(a,b,28)}function Pv(a,b){return Gk(a,b,12)}function Pq(a){v[a|0]=0;v[a+1|0]=0}function Lw(a){return qc(a,-1)?0:a}function Ko(a,b){return(a|0)<(b|0)}function Kn(a,b){x[a+1298464>>2]=b}function JD(a,b){return Gk(a,b,36)}function Eh(a,b){a=a|0;b=b|0;Gb(a)}function CT(a,b){return OE(a,b,18)}function BU(a){return y[a+1|0]!=63}function BG(a){return uh(a,467592)}function Ad(a,b){return D(b,6)+a|0}function AE(a){C[(db-16|0)+8>>3]=a}function $q(a,b){return(b<<11)+a|0}function zba(a){a=a|0;yF(a,46,45)}function xc(a){x[a>>2]=0;return a}function xb(a,b){return(b<<2)+a|0}function wx(a,b){return AM(a,b)^1}function ws(a){return LE(a,76136)}function wh(a){x[a>>2]=1;return a}function uc(a,b){return Mb(a)+b|0}function te(a,b){return(b<<5)+a|0}function qm(a,b){return(b<<8)+a|0}function qJ(a){x[a>>2]=x[a>>2]+24}function nD(a){return(a&16)>>>4|0}function lu(a,b){return ie(a,b)^1}function km(a){w[a>>1]=0;return a}function iZ(a){a=a|0;return 12996}function hZ(a){a=a|0;return 10169}function fw(a,b){return x[a+b>>2]}function f1(a){a=a|0;return 10289}function cH(a,b){return bH(a,0,b)}function bba(a){a=a|0;Sf(a,cj(a))}function _s(a){bc(a+4|0);return a}function _n(a){return a+1074328|0}function _c(a,b){return(b<<4)+a|0}function _b(a,b){return(b<<1)+a|0}function Wga(a){a=a|0;hf(a,16407)}function Ud(a){return x[gc(a)>>2]}function Tc(a){return uV(a,1,120)}function TO(a,b){return Gk(a,b,8)}function Qfa(a){a=a|0;mT(a,65535)}function Qe(a,b){return(b<<3)+a|0}function PY(a){a=a|0;return 12882}function PH(a){return LE(a,76200)}function OY(a){a=a|0;return 10659}function Kz(a,b){return Gk(a,b,4)}function Kj(a){return a-48>>>0<10}function Kb(a,b){return qc(a,b)^1}function Jia(a){a=a|0;hf(a,15804)}function Ez(a){if(a){Eb(a+-64|0)}}function Bm(a){x[a>>2]=2;return a}function Af(a){return a!=a?E(0):a}function zia(a){a=a|0;hf(a,4319)}function zfa(a){a=a|0;hf(a,4106)}function zL(a){return(a&8)>>>3|0}function zH(a){x[a+72>>2]=466604}function uX(a){a=a|0;WC(a,Pf(a))}function sW(a){a=a|0;hf(a,4299)}
function qha(a){a=a|0;hf(a,3863)}function oha(a){a=a|0;hf(a,4828)}function nT(a,b){rc(a,b+4|0,256)}function lq(a){$v(a,24,92588,26)}function kJ(a,b){return Hg(a,b)}
function gv(a,b){return Cka(a,b)}function eZ(a){a=a|0;return 6807}function dz(a){v[a|0]=0;return a}function bY(a){a=a|0;hf(a,16434)}function Xga(a){a=a|0;hf(a,3948)}function Tf(a,b,c,d){gf(a,c,d,b)}function QY(a){a=a|0;return 9728}function Ng(a,b,c){tn(a,b,b+c|0)}function NY(a){a=a|0;return 5661}function Hf(a,b){vb(xc(a)+4|0,b)}function HV(a){$v(a,24,92536,23)}function Gia(a){a=a|0;hf(a,4425)}function Eq(a){return Vb(a,0,48)}function Eja(a){a=a|0;hf(a,3872)}function Bu(a,b,c){SE(a,b,c,128)}function BH(a){x[a+72>>2]=466520}function Ax(a,b,c,d){Kx(a,b,c,d)}function $X(a){a=a|0;yF(a,50,72)}function zl(a,b,c){gf(a,c,22,b)}function yo(a,b){return Cl(a,b)}function y2(a){a=a|0;lx(a-88|0)}function xg(a,b){return Kb(a,b)}function xd(a,b){return!Bb(a,b)}function wj(a,b){return b-a>>11}function w_(a){a=a|0;Ec(467908)}function vp(a,b){return xb(a,b)}function vd(a){return(a&255)!=0}function uy(a){w[a+480214>>1]=0}function uf(a){tb(a+20|0);tb(a)}function ub(a){fe(a+12|0);fe(a)}function u_(a){a=a|0;Ec(467940)}function tl(a,b,c){gf(a,c,28,b)}function si(a,b){return(a|b)!=0}function s_(a){a=a|0;Ec(467844)}function rw(a){return wb(a+8|0)}function ri(a,b){return Pc(a,b)}function q_(a){a=a|0;Ec(467876)}function qC(a){return(a&255)==1}function pw(a,b){return Qg(a,b)}function pm(a){return om(je(a))}function pG(a,b,c){ec(a,b,1<<c)}function pA(a,b,c){gf(a,c,64,b)}function of(a,b){return Xj(a,b)}function od(a){return yb(Mb(a))}function oM(a,b){return ey(a,b)}function nj(a,b,c){gf(a,c,20,b)}function ne(a,b){return oc(a,b)}function lm(a){tb(a+12|0);tb(a)}function jz(a,b){return Ic(a,b)}function jj(a,b){return te(a,b)}function jH(a){if(kH(a)){Eb(a)}}function it(a,b){return fz(a,b)}function ij(a){oA(a,0);return a}function i_(a){a=a|0;tb(467892)}function hl(a,b){return aq(a,b)}function hc(a,b){return SD(a,b)}function gt(a){bP(a+12|0);fP(a)}function g_(a){a=a|0;tb(467924)}function fg(a){return ti(a)?0:a}function ev(a,b){return YC(a,b)}function ef(a,b){return Eg(a,b)}function e_(a){a=a|0;tb(467828)}function e2(a){a=a|0;lx(a-92|0)}function dH(a,b){return Cd(a,b)}function ck(a,b,c){gf(a,c,12,b)}function cY(a){a=a|0;hf(a,4473)}function b_(a){a=a|0;tb(467860)}function ai(a,b){return sd(a,b)}function aV(a,b){return he(b,a)}function _e(a,b,c){gf(a,c,32,b)}function _C(a,b){return XC(a,b)}function Zx(a,b){return cM(a,b)}function Yb(a,b){return Rf(a,b)}function YN(a){WN(a+12|0);VN(a)}function Xn(a,b){return Ur(a,b)}function Xj(a,b){return vb(a,b)}function Xh(a,b,c){gf(a,c,13,b)}function XU(a,b){return WU(a,b)}function Tj(a){tb(a+12|0);id(a)}function Sg(a){return bO(a&255)}function Oc(a,b){return Bb(a,b)}function OB(a,b,c){gf(a,c,30,b)}function Lr(a){a=a|0;return 127}function Le(a){return wq(je(a))}function Ki(a,b){return a>>>b&1}function KM(a,b){return IM(a,b)}function JB(a,b){return Fo(b,a)}function Ib(a,b){return(a&b)!=0}function Ci(a,b){return bv(a,b)}function Cf(a){a=a|0;return a|0}function Ac(a,b){return $q(a,b)}function zn(a){return(a|0)==-1}function yx(a){a=a|0;Eb(sK(a))}function wZ(a){a=a|0;Eb(RF(a))}function ve(a,b){if(!a){Eb(b)}}function qQ(a){return a+4896|0}function ph(a,b){return b-a>>8}function oc(a,b){return b-a>>2}function oZ(a){a=a|0;Eb(PF(a))}function lx(a){a=a|0;Eb(ls(a))}function lL(a){a=a|0;Eb(mL(a))}function l1(a){a=a|0;Eb(As(a))}function hg(a,b){return b-a>>5}function fh(a,b){return b-a>>4}function dG(a){a=a|0;Eb(qw(a))}function cn(a){a=a|0;Eb(CU(a))}function cc(a,b){x[a+100>>2]=b}function cI(){return(bb()|0)>0}function c3(a){a=a|0;Eb(xJ(a))}function bu(a,b){return a-b>>2}function _K(a){a=a|0;Eb($K(a))}function ZZ(a){a=a|0;Eb(bG(a))}function Ym(a){a=a|0;Eb(Ev(a))}function Wz(a){return a+4096|0}function Wk(a){a=a|0;Eb(yf(a))}function VD(a){return a+1024|0}function UZ(a){a=a|0;Eb(aG(a))}function Ty(a,b){return a<<8|b}function Tw(a){a=a|0;Eb(Nk(a))}function Tn(a){a=a|0;Eb(Ps(a))}function T2(a){a=a|0;Eb(rJ(a))}function Sw(a){a=a|0;Eb(Pn(a))}function Rw(a){a=a|0;Eb(bs(a))}function QT(a,b){SA(a,Mb(a),b)}function Pw(a){a=a|0;Eb(as(a))}function PZ(a){a=a|0;Eb(VF(a))}function PT(a,b){tn(a,b,td(b))}function Ow(a){a=a|0;Eb($r(a))}function NL(a){return a-2048|0}function Jx(a){a=a|0;Eb(uL(a))}function Jd(a){return a&64?2:1}function Ic(a,b){return b-a>>1}function IX(a){a=a|0;Eb(RD(a))}function IH(a){a=a|0;Eb(xp(a))}function Hg(a,b){return b-a>>3}function HL(a){a=a|0;Eb(IL(a))}function HH(a){a=a|0;Eb(mf(a))}function H7(a){a=a|0;return 13}function G3(a){a=a|0;Eb(rs(a))}function Fo(a,b){return a-b>>1}function Do(a){return a>>>0<11}function At(a){return a>>>27^a}function $R(a,b){Xv(a,b,5,3,4)}function zM(a,b,c){fl(a,b,-c)}function ye(a){a=a|0;return 2}function xL(a){a=a|0;return 3}function we(a){a=a|0;return 1}function vs(a,b){x[a+32>>2]=b}function uq(a){return a+256|0}function ud(a){return(a|0)!=0}function uA(a,b){dc(a,b,1024)}function tL(a){a=a|0;return 7}function t8(a){a=a|0;return 6}function sA(a){return a+128|0}function qp(a){return a>>>0<2}function pQ(a){return a+512|0}function mS(a,b){dc(a,b,1108)}function m9(a){a=a|0;return 9}function io(a,b){x[a+36>>2]=b}function ic(a){a=a|0;return 0}function he(a,b){return a-b|0}function hL(a){a=a|0;return 5}function d7(){return 19927555}function cp(a){return a+20|0}
function bS(a,b){gf(a,b,33,1)}function ZH(a){a=a|0;return-1}function Yq(a,b){gf(a,b,26,3)}function VB(a,b){dc(a,b,1954)}function UA(a,b){dc(a,b,4896)}function Sn(a){a=a|0;return 4}function Sm(a){return a&1?2:1}function Sj(a){return ud(a)^1}function Pk(a){return(a&5)!=0}function Pc(a,b){return b-a|0}function NU(a,b){gf(a,b,40,2)}function Mo(a){return a>>>0<5}function KT(a){Eq(Vb(a,0,48))}function KQ(a){return a-256|0}function Gb(a){cE(a);return a}function Db(a,b){return a+b|0}function $e(a,b){w[a+28>>1]=b}function yh(a){return a-36|0}function yU(a,b){dc(a,b,576)}function yT(a){return a-33|0}function yS(a,b){dc(a,b,126)}function wk(a){return a-16|0}function wO(a,b,c){jm(a,c,b)}function vc(a,b,c){wm(a,b,c)}function vU(a,b){dc(a,b,674)}function td(a){return a+16|0}function sQ(a,b){dc(a,b,263)}function re(a,b){x[a+4>>2]=b}function r1(a){a=a|0;TV(a,1)}function py(a,b){v[a+34|0]=b}function pR(a,b){dc(a,b,204)}function oy(a,b){v[a+32|0]=b}function oU(a){return a+36|0}function ny(a,b){v[a+35|0]=b}function nB(a){return a-20|0}function mo(a){return a+32|0}function lG(a){iG(a,x[a>>2])}function lB(a,b){gf(a,b,8,2)}function kz(a){v[a+6152|0]=0}function kc(a){return a+12|0}function iq(a){return a+14|0}function gA(a,b){oA(a,Zd(b))}function fq(a,b){return a<<b}function ff(a,b){v[a+11|0]=b}function eH(a){return a+3&-4}function dh(a){return a-12|0}function dc(a,b,c){ec(a,b,c)}function by(a){return a-52|0}function bq(a,b,c){Qo(a,b,c)}function aP(a){$O(a,x[a>>2])}function Zs(a){lN(a,x[a>>2])}function Zl(a,b){x[a+8>>2]=b}function Wj(a){return a-32|0}function Sh(a,b,c){YU(a,b,c)}function SC(a,b){dc(a,b,497)}function RR(a,b){dc(a,b,146)}function RP(a){QP(a,x[a>>2])}function QM(a){return a+24|0}function Nt(a){return a-56|0}function NR(a,b){dc(a,b,608)}function MT(a,b){dc(a,b,128)}function Ln(a){return a-24|0}function Ll(a,b,c){pG(a,b,c)}function KV(a,b){dc(a,b,610)}function Hq(a,b){dc(a,b,192)}function HU(a,b){dc(a,b,218)}function Gv(a,b){bE(a,Zd(b))}function Gu(a,b){dc(a,b,512)}function Gp(a,b){B[a+8>>2]=b}function Go(a,b){le(a,b+8|0)}function GS(a,b){dc(a,b,130)}function GP(a){return a+48|0}function Fp(a,b){B[a+4>>2]=b}function Fb(a,b,c){pD(a,b,c)}function Ep(a,b){v[a+33|0]=b}function EU(a,b){dc(a,b,157)}function ES(a,b){dc(a,b,600)}function EO(a,b,c){gm(a,c,b)}function De(a,b){a=a|0;b=b|0}function Dc(a){re(a,x[a>>2])}function Cm(a){return a-28|0}function AB(a){return a-48|0}function zu(a,b){dc(a,b,64)}function yu(a,b){dc(a,b,66)}function yQ(a,b){return a<b}function yL(a){return 0-a|0}function xP(a,b){dc(a,b,27)}function xG(a){return a-1|0}function xB(a,b){dc(a,b,12)}function wb(a){return a+8|0}function sT(a,b){dc(a,b,52)}function rj(a){return a&127}function rV(a,b){rc(a,b,48)}function rS(a,b){dc(a,b,32)}function ou(a,b){dc(a,b,22)}function oC(a,b){dc(a,b,11)}function mq(){lq(10884);p()}function kg(){HV(10884);p()}function jC(a,b){ec(a,b,20)}function hv(a,b){ec(a,b,22)}function gc(a){return a+4|0}function gC(a,b){dc(a,b,17)}function fu(a,b){return a<b}function fd(a){return a+1|0}function fE(a,b){dc(a,b,24)}function dS(a,b){dc(a,b,96)}function c7(){return 393228}function br(a,b){dc(a,b,36)}function Xo(a){return a-8|0}function Wu(a,b){dc(a,b,65)}function Vu(a,b){dc(a,b,16)}function Uf(a,b){v[a+3|0]=b}function Ue(a){return a+2|0}function UT(a){return a-6|0}function UB(a){Vb(a,0,1954)}function Sx(a){Vb(a,0,2048)}function QA(a,b){dc(a,b,33)}function PU(a,b){dc(a,b,98)}function Oo(a,b){v[a+1|0]=b}function Om(a){return a-2|0}function OS(a,b){dc(a,b,30)}function Nm(a,b){ec(a,b,32)}function NT(a,b){dc(a,b,80)}function NB(a,b){WE(a,b,32)}function MB(a){x[a+12>>2]=0}function Lh(a){return a&255}function LD(a,b){dc(a,b,20)}function KU(a,b){dc(a,b,48)}function KC(a,b){dc(a,b,38)}function Jp(a){Vb(a,0,8192)}function JO(a){return a-7|0}function IC(a,b){Gi(a,b,37)}function Gf(a){return a-4|0}function GC(a,b){dc(a,b,41)}function GA(a,b){dc(a,b,40)}function Eu(a,b){WE(a,b,64)}function Cy(a){Vb(a,0,4096)}function Ai(a){return a+3|0}function zd(a,b){x[a>>2]=b}function yc(a){a=a|0;Eb(a)}function xU(a){Vb(a,0,576)}function xS(a){Vb(a,0,126)}function wc(a){x[a+8>>2]=0}function tv(a,b){dc(a,b,3)}function tm(a,b){Qo(a,b,0)}function tj(a,b){w[a>>1]=b}function ti(a){return a!=a}function tC(a,b){Sh(a,2,b)}function tA(a){Vb(a,0,130)}function sr(a){a=a|0;ur(a)}function sU(a){Vb(a,0,192)}function sL(a,b){ZL(a,3,b)}function sB(a,b){dc(a,b,6)}function oR(a){Vb(a,0,204)}function hU(a){ZA(a,Ud(a))}function fU(a){_A(a,Ud(a))}function dl(a){gz(a,Ud(a))}function bP(a){Sp(a,Ud(a))}function Xb(a){$m(x[a>>2])}function WN(a){ct(a,Ud(a))}function Vn(a,b){B[a>>2]=b}function Vm(a,b){dc(a,b,8)}function VN(a){dt(a,Ud(a))}function Uq(a,b){dc(a,b,1)}function Rc(){HV(7616);p()}function RC(a){Vb(a,0,497)}function QR(a){Vb(a,0,146)}function QQ(a){Rz(a,Ud(a))}function Pm(a,b){dc(a,b,2)}function PQ(a){Sz(a,Ud(a))}function Nz(a){Vb(a,0,256)}function MR(a){Vb(a,0,608)}function KA(a){HA(a,Ud(a))}function Jo(a,b){dc(a,b,7)}function Je(a){v[a+12|0]=1}function JW(a){a=a|0;xh(a)}function JV(a){Vb(a,0,610)}function JA(a){IA(a,Ud(a))}function Iu(a,b){dc(a,b,5)}function DU(a){Vb(a,0,157)}function DS(a){Vb(a,0,600)}function DM(a){ly(a,Ud(a))}function Bh(a,b){dc(a,b,4)}function $u(){lq(7616);p()}function y1(a){a=a|0;eb=a}function su(a){Vb(a,0,64)}function rT(a){Vb(a,0,52)}function ov(a){return a&1}function l4(){return 2048}function hd(a,b){v[a|0]=b}function eS(a){Vb(a,0,96)}function cr(a){Vb(a,0,36)}function VA(a){Vb(a,0,80)}function RA(a){Vb(a,0,33)}function OU(a){Vb(a,0,98)}function OL(a){en(a,2048)}function LU(a){Vb(a,0,48)}function K3(){return db|0}function K2(a){a=a|0;db=a}function JC(a){Vb(a,0,38)}function Hd(a){v[a+4|0]=1}function HB(a){Vb(a,0,66)}function FC(a){Vb(a,0,41)}function xr(a,b){ad(a,b)}function tQ(a){x[a>>2]=0}function rB(a,b){hc(a,b)}function nv(a){w[a>>1]=0}function no(a,b){zd(a,b)}function lj(a){tb(a+4|0)}function kM(a,b){lN(a,b)}function jt(a,b){TM(a,b)}function iS(a,b){le(a,b)}function hu(a,b){ST(a,b)}function hi(a,b){Ih(a,b)}function dn(a,b){RV(a,b)}function ch(a){a=a|0;p()}function _O(a){oe(a+8|0)}function YB(a,b){vK(a,b)}function Ux(a,b){Vf(a,b)}function Qs(a,b){Vn(a,b)}function PP(a,b){QP(a,b)}function PA(a,b){vT(a,b)}function Nc(a,b){zs(a,b)}function NP(a,b){Mf(a,b)}function Kq(a,b){lC(a,b)}function Jc(a){bc(a+8|0)}function Id(a,b){Ag(a,b)}function IB(a,b){wl(a,b)}function Gd(a){ub(a+8|0)}function Fk(a,b){hd(a,b)}function Dd(a,b){re(a,b)}function BS(a){_v(a,512)}function wB(a){$E(a,16)}function vE(a){Sv(a,48)}function tg(a){v[a|0]=0}function sC(a){_v(a,16)}function rr(a){Sv(a,36)}function nV(a){en(a,48)}function Po(a){$E(a,11)}function Mga(){ra();p()}function Ah(a){Sv(a,24)}function us(a){gK(a,0)}function or(a){bE(a,0)}function hr(a){en(a,8)}function bZ(){LF();p()}function Xi(a){hK(a,0)}function XT(a){en(a,6)}function Wi(a){fK(a,0)}function NM(a){rN(a,0)}function Lf(a){gU(a,0)}function LT(a){_v(a,4)}function LO(a){en(a,7)}function LF(){sa();p()}function Kc(a){Me(a,0)}function Ey(a){oN(a,0)}function Dy(a){nN(a,0)}function Di(a){en(a,2)}function vr(a){kc(a)}function um(a){sc(a)}function qA(a){lk(a)}function kf(a){a=a|0}function gG(a){xc(a)}function dR(a){Nb(a)}function VO(a){oo(a)}function QJ(a){Oe(a)}function Ab(a){tb(a)}function $Q(a){Ae(a)}
// EMSCRIPTEN_END_FUNCS
e=y;var ib=c([null,Tb,kr,qg,QD,Wm,vX,uX,AD,oX,kX,aD,AW,vW,Iq,qj,kW,Z,Zu,yl,QH,Ig,Ho,fja,CU,Cf,zha,Qga,Oga,Mga,Gga,vga,iA,$fa,Tfa,ica,sfa,jR,K1,J1,ds,jR,Sba,Hba,dO,Np,Lp,kba,jba,eN,Zaa,yi,gM,qg,Tb,QD,Q9,Rn,DL,Mx,lh,TK,m7,h7,Z6,E6,w6,x1,w1,c1,Rn,p4,Np,Q3,M3,r3,l3,lh,U2,J2,A2,s2,h2,Y1,W1,V1,U1,hs,R1,P1,Qw,ra,Lb,zY,yY,xY,wY,vY,uY,vk,tY,uE,hs,sY,rY,da,pY,oY,yr,lh,nY,mY,lY,nE,mE,kY,yr,jY,dp,Kv,sr,Aj,Wc,hf,eY,dp,gY,fY,dY,iY,cY,jE,bY,jE,hY,lE,aY,$X,_X,vk,iE,Vc,Lb,XX,bp,WX,Ig,VX,dE,UX,sk,dE,mr,TX,Ev,Dv,wX,SX,KX,JX,tX,Ji,nX,mX,rv,DD,lX,Oaa,Paa,GO,Maa,Naa,my,Us,Zb,Qaa,Wd,zD,hX,gX,kD,eX,dX,kD,ee,dv,$W,eaa,rf,aha,xba,fX,ee,Df,mW,wba,Pja,oaa,daa,TW,DC,SW,RW,CC,QW,lg,PW,OW,Bc,NW,MW,mg,$g,LW,Hm,KW,AC,JW,GW,mC,FW,EW,DW,Su,XO,QC,sx,CW,BW,zW,yW,xW,Uu,wW,cC,Bd,Aj,sW,rW,Lu,bC,qW,pW,oW,aC,nW,$B,Tu,pk,Yu,vka,Fu,uka,Jb,Of,hf,tka,QB,ska,Wc,PB,rka,qka,pka,dW,cW,nd,oka,Io,nka,mka,lka,$V,_V,Ji,hf,kka,jka,lca,ika,ah,hka,eka,gk,gka,uE,hs,fka,_h,Nf,bka,aka,$ja,DV,Yja,gk,mj,Xja,Wja,Dq,Vja,EB,Uja,Tja,Sja,Rja,Qja,pk,jV,gV,Mja,Jja,cV,sn,Ija,Sf,IV,Hja,Su,Gja,Fja,vB,Eja,Dv,Dja,Cja,ZU,_ea,Bja,pk,yja,Fu,Ao,xja,wja,cW,vja,uja,tja,sja,rja,Im,qja,pja,oja,mja,gk,TU,nja,_h,Nf,DB,gja,cja,Bi,Zia,Yia,Via,Uia,Tia,Sia,Ria,Qia,Cq,Pia,Oia,Nia,fB,aX,Mia,Lia,hf,Kia,Jia,Iia,_W,Hia,Gia,Fia,Eia,rU,qU,Dia,Cia,hf,Bia,Aia,CV,_ia,zia,yia,$ia,xia,wia,via,cB,cB,bB,uia,tia,nU,cB,kU,sia,d_,ria,qia,pia,oia,nia,mia,lia,jU,pd,zo,aia,WA,kia,R9,P9,O9,N9,M9,L9,jia,iia,Mf,hia,gia,fia,eia,kr,kca,hca,aaa,maa,naa,dia,cia,bia,Yaa,J9,Rn,fca,eca,dca,cca,Yha,Xha,Wha,Vha,Uha,Tha,Sha,Rha,Qha,Pha,Oha,Nha,Mha,Kha,Jha,Lha,wT,Nf,pT,OA,Gha,NA,Fha,Eha,Dha,Cha,oT,MA,Bha,dv,CC,Aha,mT,lT,Xq,LA,yha,Ye,xha,kr,Cq,Qu,Cq,wha,Sq,hf,DV,Cq,pca,sn,tha,sha,rha,qha,FA,Zt,pha,oha,nha,mha,lha,kha,jha,EC,iha,hha,gha,fha,eha,dha,cha,bha,$A,$ga,_ga,Zga,Yga,hf,mU,lU,hB,Xga,Wga,Lu,Dv,Vga,Uga,Tga,Rba,Qba,Pba,vk,Sga,wu,Au,vg,vba,Wba,kt,RO,uba,tba,yO,ht,rO,sba,gO,EP,rba,tz,aj,$h,Fga,Ega,Vt,Pga,gu,Bga,XB,Aga,zga,vS,zo,yga,xga,uS,wga,uga,tga,Ut,sga,rga,qga,pga,nA,kga,kA,jga,iga,hga,gk,_h,Nf,$h,ega,dga,cga,bga,NA,Zfa,Yfa,Ut,Xfa,Hm,paa,Ufa,Sfa,mj,jS,kA,Tu,Rfa,Qfa,Pfa,Ofa,St,Nfa,St,Mfa,Gl,bX,Jfa,gk,Kfa,Lfa,cA,WR,Mt,_h,Nf,Vt,Gfa,Dfa,OA,Cfa,zfa,yfa,JR,uS,fB,xfa,Lu,hf,nfa,mfa,aC,lfa,kfa,jfa,ifa,lR,hfa,Io,efa,dfa,cfa,bfa,afa,$ea,rm,aR,Zea,Yea,Xea,Wea,Vea,Uea,Tea,Sea,Rea,Qea,Pea,Oea,Nea,NA,Mea,Lea,Kea,gu,Jea,Iea,Hea,Fu,Fba,bp,dW,Nba,Mba,Fu,Lba,$h,bp,Kba,Jba,Iba,Gea,MQ,Dea,Cea,Bea,Aea,zea,yea,Wq,vea,uea,tea,sea,rea,qea,pea,oea,nea,mea,lea,kea,qY,xE,jea,hf,iea,hea,nk,Tba,qca,lja,SP,nca,mca,Az,jca,gca,rt,bca,FP,$ba,_ba,wP,Zba,Yba,Xba,mP,kP,iP,go,dP,Vba,Uba,Oba,Bo,Dba,mj,HO,pr,Laa,Kaa,Jaa,Taa,cX,Iaa,sv,pr,cC,Haa,HO,Bba,Gaa,Gba,gk,_h,Nf,Eba,gk,_h,Nf,Cba,gk,_h,Nf,iE,hs,vk,qba,pba,oba,nba,mba,lba,oca,fea,MP,iba,Hc,gba,haa,fba,ZX,sX,jX,qX,dba,cba,iX,rX,YX,pX,fN,bba,aba,$aa,dN,cN,Ay,_aa,aca,Xaa,Waa,Vaa,Uaa,eM,_9,tr,tE,aE,my,dN,Raa,Rn,Du,Oq,zba,Aba,Daa,Caa,mj,Baa,kA,Aaa,zaa,yaa,Vt,xaa,$h,waa,vaa,uaa,taa,saa,gk,_h,Nf,Eaa,laa,kaa,jaa,iaa,Ih,Sl,gaa,faa,Rs,Ss,caa,Y9,X9,W9,V9,U9,aM,$9,Cp,$L,yk,Ih,Mf,S9,cf,K9,T9,Z9,H9,G9,Z8,F9,E9,QL,Jf,_L,o9,_8,Ol,U8,lh,T8,S8,R8,my,rt,P8,$M,vL,v8,n8,g8,$7,T7,K7,M7,A7,s7,JK,Fs,l7,k7,f3,h3,a7,$6,Y6,Kv,Saa,j3,V6,JK,U6,S3,H3,V3,S6,N2,EK,Cx,Q6,g4,sK,f4,cK,O6,D9,L6,D7,M6,x7,J6,O3,c4,H6,P3,DK,kr,CK,BK,AK,v6,t6,EK,Cx,q6,p6,o6,n6,m6,l6,k6,j6,i6,h6,g6,f6,e6,d6,c6,b6,a6,$5,_5,Z5,Y5,X5,W5,V5,S5,Q5,O5,TD,E2,W3,M5,y5,N3,w5,u5,Uk,F2,G2,s5,M2,l5,j5,baa,g5,Cx,b5,_4,X4,Nn,nJ,V4,T4,R4,P4,N4,L4,J4,G4,E4,C4,A4,y4,uK,t4,r4,YM,Wt,tK,n4,m4,k4,j4,i4,h4,yp,yba,qr,PM,mh,iP,a4,$3,_3,Y3,nh,eN,U3,hba,R3,L3,Hm,pk,pk,I3,eba,T3,b4,X3,Cv,_,i3,jK,iK,g3,yJ,e3,d3,V2,L2,I2,H2,Rn,D2,SM,gea,Z1,X1,T1,S1,M1,L1,FH,EH,nZ,E1,D1,C1,B1,A1,z1,s1,Ig,r1,Cf,fZ,mZ,d1,EH,a1,Tq,OH,Kw,Gw,N0,M0,Cw,Gh,Fh,Rr,Eb,Bw,Og,Mk,Aw,Tl,E0,D0,Ri,Mg,UG,Qi,Nw,ww,Gh,Fh,Pr,Jh,q1,yl,yn,Ri,Mg,QG,Qi,j0,e0,KH,$$,Yr,Ho,W$,Mr,kf,E$,Wr,D$,C$,B$,CG,z$,Yt,x$,w$,Jk,v$,CG,t$,s$,q$,p$,m$,l$,h$,g$,f$,e$,d$,c$,b$,a$,$_,__,Z_,Y_,X_,W_,V_,U_,T_,S_,R_,Q_,P_,O_,N_,M_,L_,K_,J_,I_,H_,G_,F_,E_,D_,C_,B_,n_,o_,p_,w_,u_,s_,q_,_Z,$Z,a_,i_,g_,e_,b_,hj,LF,Ym,lr,eea,dea,cea,bea,aea,$da,_da,Zda,Yda,Xda,Wda,Vda,Uda,Tda,Sda,Rda,Qda,Pda,Oda,Nda,Mda,Lda,Kda,Jda,Ida,Hda,Gda,Fda,Eda,Dda,Cda,Bda,Ada,zda,yda,xda,wda,vda,uda,tda,sda,rda,qda,pda,oda,nda,mda,lda,kda,jda,ida,hda,gda,fda,eda,dda,cda,bda,ada,$ca,_ca,Zca,Yca,Xca,Wca,Vca,Uca,Tca,Sca,Rca,Qca,Pca,Oca,Nca,Mca,Lca,Kca,Jca,Ica,Hca,Gca,Fca,Eca,Dca,Cca,Bca,Aca,zca,yca,xca,wca,vca,uca,tca,sca,rca,Ym,xea,wea,Xia,Wia,Bfa,Afa,ufa,tfa,Iha,Hha,oga,nga,_ha,Zha,iW,hW,kja,jja,IW,HW,uW,tW,gga,fga,Ffa,Efa,Fea,Eea,_ja,Zja,Oja,Nja,XW,WW,VW,UW,Wfa,Vfa,Ifa,Hfa,Dga,Cga,$ha,fW,eja,dja,bja,aja,dka,cka,Aja,zja,aga,_fa,Faa,raa,qaa,Iga,Hga,gfa,ffa,mga,lga,ija,hja,wfa,vfa,pfa,ofa,Lja,Kja,rfa,qfa,Rga,Kga,Jga,ZW,YW,lW,jW,vha,uha,Nga,Lga,cn,lr,xX,yc,Yo,IK,yc,Cf,yc,ic,we,we,ic,ic,yX,NX,MX,zX,yc,Yo,yc,RD,IX,HX,GX,FX,EX,DX,CX,BX,AX,Ps,Tn,Tn,LL,ic,kf,ic,ic,ic,De,Sn,C9,B9,A9,z9,y9,ki,Qx,Qx,Px,KL,Px,Px,x9,kf,fW,w9,v9,u9,t9,s9,ji,JL,W8,ic,ic,we,Ox,ye,ye,we,r9,q9,De,kf,De,kf,IL,HL,HL,n9,ic,kf,ic,ic,ic,De,m9,GL,l9,k9,j9,i9,ki,h9,g9,f9,e9,d9,c9,b9,a9,$8,ji,CL,ic,ic,we,ye,ye,we,FL,EL,yf,ch,bZ,Y8,Rx,X8,ic,V8,KL,G8,w8,o8,h8,a8,U7,L7,B7,t7,V7,I9,p9,Q8,Ps,Tn,Tn,LL,ic,kf,ic,ic,ic,De,xL,O8,N8,M8,L8,K8,ki,J8,ji,wL,ic,ic,we,ye,ye,we,I8,H8,mL,lL,lL,u8,ic,kf,ic,ic,ic,De,t8,s8,r8,q8,ki,p8,ji,iL,ic,ic,we,ye,ye,Wk,Wk,m8,ic,kf,ic,ic,ic,De,hL,l8,k8,j8,ki,i8,ji,fL,ic,ic,we,ye,ye,Ps,Tn,Tn,f8,ic,kf,ic,ic,ic,De,hL,e8,d8,c8,ki,b8,ji,dL,ic,ic,we,ye,ye,uL,Jx,Jx,_7,ic,kf,ic,ic,ic,De,tL,Z7,D8,C8,ki,B8,ji,A8,ic,ic,we,ye,ye,De,kf,rL,Y7,X7,qL,W7,pL,oL,Jx,Is,F8,tL,E8,rL,z8,y8,qL,x8,pL,oL,Wk,Wk,S7,ic,kf,ic,ic,ic,De,ye,R7,Q7,P7,ki,O7,ji,N7,ic,ic,we,ye,ye,$K,_K,_K,J7,ic,kf,ic,ic,I7,De,H7,G7,F7,E7,ki,C7,ji,Dx,ic,ic,we,ye,ye,De,kf,Wk,Wk,z7,ic,kf,ic,ic,ic,De,xL,y7,w7,v7,ki,u7,ji,VK,ic,ic,we,ye,ye,Wk,Wk,r7,ic,kf,ic,ic,ic,De,Sn,q7,p7,o7,ki,n7,ji,SK,ic,ic,we,ye,ye,rK,yc,e4,yx,d4,yx,yx,ch,rs,G3,Z3,Cf,ch,Cf,yc,F3,E3,ch,WJ,VJ,WJ,VJ,De,ss,De,ss,ZJ,YJ,ZJ,YJ,yc,J3,Cf,yc,D3,C3,yc,MJ,LJ,ch,z3,IJ,y3,IJ,B3,KJ,A3,KJ,yc,x3,w3,yc,HJ,GJ,os,os,os,os,v3,qx,qx,qx,yc,u3,t3,yc,FJ,EJ,p3,CJ,o3,CJ,s3,DJ,q3,DJ,yc,n3,m3,yc,BJ,AJ,ns,ns,ns,ns,k3,ox,ox,ox,O2,yc,Yo,yc,rJ,T2,we,we,S2,R2,lr,Q2,P2,ch,ch,W2,yc,Yo,yc,xJ,c3,we,ic,we,b3,a3,$2,_2,Z2,Y2,X2,ch,LX,yc,Yo,yc,yc,RX,we,we,lr,WD,QX,PX,OX,De,ss,De,ss,ls,lx,C2,B2,gJ,fJ,eJ,dJ,cJ,bJ,aJ,$I,_I,ZI,YI,XI,WI,VI,UI,TI,SI,RI,QI,PI,OI,NI,z2,y2,x2,w2,v2,u2,t2,r2,q2,p2,o2,n2,m2,l2,k2,j2,i2,g2,f2,e2,d2,c2,b2,a2,$1,_1,Cf,ch,Cf,ch,Cf,ch,Q1,O1,N1,Pn,Sw,De,bI,$H,_H,ic,ic,H1,ZH,G1,cs,F1,cs,$r,Ow,De,bI,$H,_H,ic,ic,v1,ZH,u1,cs,t1,cs,As,l1,m1,k1,p1,o1,n1,xp,IH,j1,i1,as,Pw,SH,RH,mf,HH,h1,g1,bs,Rw,XH,WH,Cf,yc,f1,lZ,kZ,jZ,e1,Ym,I1,ic,b1,Sw,R0,Q0,P0,O0,yK,Tw,Nk,Tw,Sw,U0,xH,T0,S0,Ow,Y0,X0,W0,V0,bs,Rw,XH,WH,yK,Tw,Ow,$0,xH,_0,Z0,as,Pw,SH,RH,PF,oZ,Is,RF,wZ,vZ,uZ,tZ,sZ,iU,rZ,qZ,pZ,VF,PZ,OZ,NZ,MZ,LZ,ic,KZ,JZ,aG,UZ,TZ,SZ,nJ,RZ,QZ,bG,ZZ,WD,YZ,XZ,WZ,VZ,Cf,yc,yc,HZ,GZ,FZ,EZ,DZ,CZ,BZ,AZ,iU,zZ,yZ,xZ,yc,SF,SF,kp,we,we,IZ,we,yc,YF,XF,kp,ic,ic,WF,Sn,yc,YF,XF,kp,ic,ic,WF,Sn,yc,$F,_F,kp,ic,ic,ZF,Sn,yc,$F,_F,kp,ic,ic,ZF,Sn,Cf,yc,L0,K0,J0,Cf,yc,I0,H0,G0,yc,F0,C0,B0,A0,YG,YG,z0,y0,x0,w0,v0,yc,u0,t0,s0,r0,PG,PG,q0,p0,o0,n0,m0,yc,l0,k0,i0,h0,g0,f0,d0,c0,yc,b0,a0,_$,Z$,Y$,X$,V$,U$,Cf,yc,ye,T$,S$,R$,Q$,P$,O$,m_,l_,k_,j_,h_,f_,c_,Cf,yc,ye,N$,M$,L$,K$,J$,I$,A_,z_,y_,x_,v_,t_,r_,qw,dG,H$,qw,dG,G$,yc,Lr,Lr,Eh,Eh,Eh,EG,ic,Dk,Dk,yc,Lr,Lr,Eh,Eh,Eh,EG,ic,Dk,Dk,yc,Kr,Kr,Eh,Eh,Eh,DG,ic,Dk,Dk,yc,Kr,Kr,Eh,Eh,Eh,DG,ic,Dk,Dk,yc,F$,A$,yc,y$,u$,yc,r$,o$,yc,n$,k$,yc,qG,j$,De,yc,qG,i$,De,Cf,ch,yc,iZ,NF,yc,hZ,gZ,NF,Ym,ch,yc,eZ,sa,Cf,yc,kf,kf,aZ,UY,WY,XY,yc,PY,yc,OY,cn,Ym,cn,cn,cn,cn,Ym,yc,NY,yc,TY,VY,YY,yc,$Y,_Y,ZY,yc,QY]);function jb(){return u.byteLength/65536|0}function ob(pb){pb=pb|0;var kb=jb()|0;var lb=kb+pb|0;if(kb<lb&&lb<65536){var mb=new ArrayBuffer(D(lb,65536));var nb=new Int8Array(mb);nb.set(v);v=new Int8Array(mb);w=new Int16Array(mb);x=new Int32Array(mb);y=new Uint8Array(mb);z=new Uint16Array(mb);A=new Uint32Array(mb);B=new Float32Array(mb);C=new Float64Array(mb);u=mb;t.buffer=u;e=y}return kb}return{"ta":gW,"ua":c7,"va":d7,"wa":yc,"xa":b7,"ya":_6,"za":X6,"Aa":Fs,"Ba":De,"Ca":f7,"Da":e7,"Ea":j7,"Fa":Qx,"Ga":g7,"Ha":IK,"Ia":i7,"Ja":Cf,"Ka":LK,"La":KK,"Ma":LK,"Na":l4,"Oa":MY,"Pa":LY,"Qa":KY,"Ra":W6,"Sa":GK,"Ta":T6,"Ua":FK,"Va":C6,"Wa":v4,"Xa":w4,"Ya":A6,"Za":z6,"_a":y6,"$a":B6,"ab":x4,"bb":Z4,"cb":o4,"db":a5,"eb":z5,"fb":s4,"gb":d5,"hb":u4,"ib":c5,"jb":q4,"kb":D4,"lb":z4,"mb":B4,"nb":S4,"ob":O4,"pb":Q4,"qb":F4,"rb":H4,"sb":K4,"tb":M4,"ub":t5,"vb":v5,"wb":G5,"xb":B5,"yb":A5,"zb":F5,"Ab":E5,"Bb":C5,"Cb":D5,"Db":K5,"Eb":L5,"Fb":H5,"Gb":J5,"Hb":I5,"Ib":m5,"Jb":r5,"Kb":p5,"Lb":o5,"Mb":q5,"Nb":n5,"Ob":Y4,"Pb":P5,"Qb":k5,"Rb":h5,"Sb":x5,"Tb":$4,"Ub":i5,"Vb":f5,"Wb":e5,"Xb":R5,"Yb":U4,"Zb":T5,"_b":W4,"$b":N5,"ac":R6,"bc":P6,"cc":JY,"dc":N6,"ec":K6,"fc":I6,"gc":G6,"hc":IY,"ic":F6,"jc":D6,"kc":x6,"lc":u6,"mc":s6,"nc":U5,"oc":r6,"pc":ib,"qc":I4,"rc":y1,"sc":K3,"tc":K2,"uc":cZ,"vc":dZ,"wc":SY,"xc":RY,"yc":HY,"zc":FY,"Ac":AY,"Bc":GY,"Cc":FY,"Dc":EY,"Ec":BY,"Fc":DY,"Gc":CY,"Hc":BY,"Ic":AY,"Jc":AY}}return qb(sb)}
// EMSCRIPTEN_END_ASM


)(info);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module, info)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];
